@@ -26,46 +26,47 @@
  ******************************************************************************/
 
 
+#include <sjbase/base.h>
 
-#include "../basesj.h"
-
-#include "sj_see.h"
-#define SJ_IMPLEMENT_HELPERS
-#include "sj_see_helpers.h"
 
 #if SJ_USE_SCRIPTS
 
 
+#include <see_dom/sj_see.h>
+#define SJ_IMPLEMENT_HELPERS
+#include <see_dom/sj_see_helpers.h>
+
+
+
 /*******************************************************************************
- *  Callbacks for SEE_system
+ * Callbacks for SEE_system
  ******************************************************************************/
 
 
+static void SjSee_abort(SEE_interpreter* interpr_, const char* msgPtr) SEE_dead;
+
 
 static void SjSee_abort(SEE_interpreter* interpr_, const char* msgPtr)
 {
 	wxString msgStr(msgPtr, wxConvUTF8);
 	wxLogError(wxT("Fatal: %s [%s]"), msgStr.c_str(), HOST_DATA->m_executionScope.c_str());
 	SjMainApp::FatalError();
+	abort();
 }
 
 
-
 static void* SjSee_malloc(SEE_interpreter* interpr, SEE_size_t size)
 {
 	return SjGcAlloc(size, (interpr?0:SJ_GC_ALLOC_STATIC));
 }
 
 
-
 static void* SjSee_malloc_string(SEE_interpreter* interpr, SEE_size_t size)
 {
 	return SjGcAlloc(size, (interpr?0:SJ_GC_ALLOC_STATIC) | SJ_GC_ALLOC_STRING);
 }
 
 
-
-
 static void* SjSee_malloc_finalize(SEE_interpreter* interpr, SEE_size_t size,
                                    void (*finalizefn)(SEE_interpreter*, void*, void*), void* closure)
 {
@@ -75,23 +76,20 @@ static void* SjSee_malloc_finalize(SEE_interpreter* interpr, SEE_size_t size,
 }
 
 
-
 static void SjSee_free(SEE_interpreter* interpr, void* ptr)
 {
 	SjGcUnref(ptr);
 }
 
 
-
 /*******************************************************************************
- *  SjSee constructor / destructor
+ * SjSee constructor / destructor
  ******************************************************************************/
 
 
 SjSee* SjSee::s_first = NULL;
 
 
-
 SjSee::SjSee()
 {
 	SjGcLocker gclocker;
@@ -117,7 +115,6 @@ SjSee::SjSee()
 }
 
 
-
 SjSee::~SjSee()
 {
 	SjGcLocker gclocker;
@@ -151,27 +148,27 @@ SjSee::~SjSee()
 
 	// remove from list
 	{
-#ifdef __WXDEBUG__
-		bool dbg_removed = false;
-		long dbg_oldCnt = 0;
-		{
-			SjSee* dbg_cur = s_first;
-			while( dbg_cur )
+		#ifdef __WXDEBUG__
+			bool dbg_removed = false;
+			long dbg_oldCnt = 0;
 			{
-				dbg_oldCnt++;
-				dbg_cur = dbg_cur->m_next;
+				SjSee* dbg_cur = s_first;
+				while( dbg_cur )
+				{
+					dbg_oldCnt++;
+					dbg_cur = dbg_cur->m_next;
+				}
 			}
-		}
-#endif
+		#endif
 
 		SjSee *cur = s_first, **prev = &s_first;
 		while( cur )
 		{
 			if( cur==this )
 			{
-#ifdef __WXDEBUG__
-				dbg_removed = true;
-#endif
+				#ifdef __WXDEBUG__
+					dbg_removed = true;
+				#endif
 				*prev = m_next;
 				break;
 			}
@@ -179,30 +176,28 @@ SjSee::~SjSee()
 			cur = cur->m_next;
 		}
 
-#ifdef __WXDEBUG__
-		wxASSERT( dbg_removed );
-		{
-			long dbg_newCnt = 0;
-			SjSee* dbg_cur = s_first;
-			while( dbg_cur )
+		#ifdef __WXDEBUG__
+			wxASSERT( dbg_removed );
 			{
-				dbg_newCnt++;
-				dbg_cur = dbg_cur->m_next;
+				long dbg_newCnt = 0;
+				SjSee* dbg_cur = s_first;
+				while( dbg_cur )
+				{
+					dbg_newCnt++;
+					dbg_cur = dbg_cur->m_next;
+				}
+				wxASSERT( dbg_newCnt == dbg_oldCnt - 1 );
 			}
-			wxASSERT( dbg_newCnt == dbg_oldCnt - 1 );
-		}
-#endif
+		#endif
 	}
 }
 
 
-
 /*******************************************************************************
- *  SjSee - embedding and events
+ * SjSee - embedding and events
  ******************************************************************************/
 
 
-
 void SjSee::ReceiveMsg(int msg)
 {
 	SjGcLocker gclocker;
@@ -224,7 +219,6 @@ bool SjSee::HasGlobalEmbeddings(SjSeePersistent embedId) const
 }
 
 
-
 wxArrayString SjSee::GetGlobalEmbeddings(SjSeePersistent embedId)
 {
 	wxArrayString strings;
@@ -238,7 +232,6 @@ wxArrayString SjSee::GetGlobalEmbeddings(SjSeePersistent embedId)
 }
 
 
-
 bool SjSee::OnGlobalEmbedding(SjSeePersistent embedId, int globalIndex, SjSee* doDefaultAction)
 {
 	SjGcLocker gclocker;
@@ -253,7 +246,7 @@ bool SjSee::OnGlobalEmbedding(SjSeePersistent embedId, int globalIndex, SjSee* d
 		localCount = strings.GetCount();
 
 		if( (globalIndex >= localIndexStart && globalIndex < localIndexStart+localCount)
-		        ||  doDefaultAction == cur )
+		 ||  doDefaultAction == cur )
 		{
 			return cur->Program_onGlobalEmbed(embedId, doDefaultAction? 0 : globalIndex-localIndexStart);
 		}
@@ -266,10 +259,8 @@ bool SjSee::OnGlobalEmbedding(SjSeePersistent embedId, int globalIndex, SjSee* d
 }
 
 
-
-
 /*******************************************************************************
- *  SjSee - execute scripts
+ * SjSee - execute scripts
  ******************************************************************************/
 
 
@@ -339,7 +330,7 @@ static void SeeLogErrorObj(SEE_interpreter* interpr_, SEE_value* errorValue)
 	          );
 
 	// old stuff
-#if 0
+	#if 0
 	{
 		SEE_value errorObjAsStr;
 		SEE_ToString(interpr_, errorValue, &errorObjAsStr);
@@ -350,11 +341,10 @@ static void SeeLogErrorObj(SEE_interpreter* interpr_, SEE_value* errorValue)
 
 		wxLogError(wxT("%s [%s]"), error.c_str(), HOST_DATA->m_executionScope.c_str());
 	}
-#endif
+	#endif
 }
 
 
-
 bool SjSee::Execute(const wxString& script__)
 {
 	wxASSERT( !m_executionScope.IsEmpty() );
@@ -438,7 +428,6 @@ bool SjSee::Execute(const wxString& script__)
 }
 
 
-
 bool SjSee::ExecuteAsFunction(const wxString& script)
 {
 	wxASSERT( !m_executionScope.IsEmpty() );
@@ -459,14 +448,12 @@ bool SjSee::ExecuteAsFunction(const wxString& script)
 }
 
 
-
 bool SjSee::IsResultDefined()
 {
 	return SEE_VALUE_GET_TYPE(m_executeResult)!=SEE_UNDEFINED;
 }
 
 
-
 wxString SjSee::GetResultString()
 {
 	SjGcLocker gcLocker;
@@ -496,7 +483,6 @@ wxString SjSee::GetResultString()
 }
 
 
-
 double SjSee::GetResultDouble()
 {
 	SjGcLocker gcLocker;
@@ -528,7 +514,6 @@ double SjSee::GetResultDouble()
 }
 
 
-
 long SjSee::GetResultLong()
 {
 	SjGcLocker gcLocker;
@@ -558,15 +543,14 @@ long SjSee::GetResultLong()
 }
 
 
-
 wxString SjSee::GetFineName(const wxString& scope, const wxString& append)
 {
 	wxString fineName(scope);
 
 
 	if( fineName.Find(wxT('/')) != -1
-	        || fineName.Find(wxT('\\')) != -1
-	        || fineName.Find(wxT(':')) != -1 )
+	 || fineName.Find(wxT('\\')) != -1
+	 || fineName.Find(wxT(':')) != -1 )
 	{
 		// strip path
 		fineName = SjTools::GetFileNameFromUrl(fineName, NULL, true);
@@ -591,11 +575,10 @@ wxString SjSee::GetFineName(const wxString& scope, const wxString& append)
 
 
 /*******************************************************************************
- *  Some Tools as declared in sj_see_helper.h
+ * Some Tools as declared in sj_see_helper.h
  ******************************************************************************/
 
 
-
 wxString SeeValueToWxString(SEE_interpreter* interpr, SEE_value* value)
 {
 	SEE_string* ret = NULL;
@@ -610,21 +593,21 @@ wxString SeeValueToWxString(SEE_interpreter* interpr, SEE_value* value)
 
 	if( ret )
 	{
-#ifdef __WXMSW__
-		wxASSERT( sizeof(SEE_char_t) == sizeof(wxChar) );
-		return wxString((const wxChar *) ret->data, ret->length); // (const wxChar *) added on VC2008 migration
-#else
-		SEE_char_t* retPtr = ret->data;
-		long i, iCount = (long)ret->length;
-		wxChar* wxBase = (wxChar*)malloc((iCount+1)*sizeof(wxChar)); if( wxBase == NULL ) { return wxEmptyString; }
-		wxChar* wxPtr = wxBase;
-		for( i = 0; i < iCount; i++ )
-			wxPtr[i] = (wxChar)retPtr[i];
-		wxPtr[iCount] = 0;
-		wxString wx(wxBase);
-		free(wxBase);
-		return wx;
-#endif
+		#ifdef __WXMSW__
+			wxASSERT( sizeof(SEE_char_t) == sizeof(wxChar) );
+			return wxString((const wxChar *) ret->data, ret->length); // (const wxChar *) added on VC2008 migration
+		#else
+			SEE_char_t* retPtr = ret->data;
+			long i, iCount = (long)ret->length;
+			wxChar* wxBase = (wxChar*)malloc((iCount+1)*sizeof(wxChar)); if( wxBase == NULL ) { return wxEmptyString; }
+			wxChar* wxPtr = wxBase;
+			for( i = 0; i < iCount; i++ )
+				wxPtr[i] = (wxChar)retPtr[i];
+			wxPtr[iCount] = 0;
+			wxString wx(wxBase);
+			free(wxBase);
+			return wx;
+		#endif
 	}
 	else
 	{
@@ -693,7 +676,7 @@ double SeeValueToDouble(SEE_interpreter* interpr, SEE_value* value)
 SEE_string* WxStringToSeeString(SEE_interpreter* interpr, const wxString& src)
 {
 	long            srcLen = src.Len(), i;
-	const wxChar*   srcPtr = static_cast<const wxChar*>src.c_str();
+	const wxChar*   srcPtr = static_cast<const wxChar*>(src.c_str());
 	SEE_string*     dest = SEE_string_new(interpr, srcLen); // the object is freed in the garbage collection
 	SEE_char_t*     destPtr = dest->data;
 
@@ -705,7 +688,6 @@ SEE_string* WxStringToSeeString(SEE_interpreter* interpr, const wxString& src)
 }
 
 
-
 SEE_object* WxArrayStringToSeeObject(SEE_interpreter* interpr, const wxArrayString& wx)
 {
 	// construct an array to A
@@ -725,7 +707,6 @@ SEE_object* WxArrayStringToSeeObject(SEE_interpreter* interpr, const wxArrayStri
 }
 
 
-
 SEE_object* WxArrayLongToSeeObject(SEE_interpreter* interpr, const wxArrayLong& wx)
 {
 	// construct an array to A
@@ -815,17 +796,13 @@ void SjSee::AddPersistentObject(SEE_object* newObj, SjSeePersistent scope, SEE_v
 		cur->m_param2                   = param2;
 		cur->m_unexpectedUnpersistent   = unexpectedUnpersistent;
 
-#if 0
-		// add as first object, very easy and fast
-		cur->m_next = m_persistentAnchor->m_next;
-		m_persistentAnchor->m_next = cur;
-#else
-		// add as last object, little slower, but we need this eg. for proper menu ordering
+		// add as last object (little slower as adding as first, but we need this eg. for proper menu ordering)
 		persistent_object* test = m_persistentAnchor;
 		while( test->m_next )
+		{
 			test = test->m_next;
+		}
 		test->m_next = cur;
-#endif
 	}
 }
 
@@ -834,9 +811,7 @@ void SjSee::RemovePersistentObject(SEE_object* oldObj)
 {
 	if( oldObj )
 	{
-#ifdef __WXDEBUG__
 		bool dbg_removed = false;
-#endif
 		persistent_object *cur = m_persistentAnchor, *prev = NULL;
 		while( cur )
 		{
@@ -844,9 +819,7 @@ void SjSee::RemovePersistentObject(SEE_object* oldObj)
 			{
 				wxASSERT( prev ); // as we have a "dummy" anchor, prev should always be valid here
 				prev->m_next = cur->m_next;
-#ifdef __WXDEBUG__
 				dbg_removed = true;
-#endif
 				break;
 			}
 
@@ -858,5 +831,6 @@ void SjSee::RemovePersistentObject(SEE_object* oldObj)
 	}
 }
 
+
 #endif // SJ_USE_SCRIPTS
 
