@@ -40,7 +40,7 @@
 
 enum SjFadeDir
 {
-    SJ_FADEDIR_IN
+     SJ_FADEDIR_IN
     ,SJ_FADEDIR_OUT
 };
 
@@ -48,7 +48,7 @@ enum SjFadeDir
 class SjAutoFader : public wxTimer
 {
 public:
-	SjAutoFader     (long secondsToFade, SjFadeDir dir);
+	                SjAutoFader     (long secondsToFade, SjFadeDir dir);
 	void            Notify              ();
 	virtual void    OnFadingDone        ();
 	long            GetOrgVolume        () const { return m_orgVol; }
@@ -249,12 +249,25 @@ void SjAutoCtrl::LoadAutoCtrlSettings()
 	m_autoPlayMusicSelId                = c->Read(wxT("autoctrl/autoPlayId"),       0L/*=current view*/);
 	m_autoPlayMusicSelIgnoreId          = c->Read(wxT("autoctrl/autoPlayIgnoreId"), 0L/*=none*/);
 
+	m_limitPlayTimeSeconds              = c->Read(wxT("autoctrl/limitPlayTime"),    SJ_AUTOCTRL_DEF_LIMITPLAYTIMESECONDS);
+
 	m_sleepMinutes                      = c->Read(wxT("autoctrl/sleepMinutes"),     SJ_SLEEPMODE_DEF_MINUTES);
 	m_sleepFadeSeconds                  = c->Read(wxT("autoctrl/sleepFadeSeconds"), SJ_SLEEPMODE_DEF_FADE_SECONDS);
 	long sleepFlags                     = c->Read(wxT("autoctrl/sleepFlags"),       SJ_SLEEPMODE_DEF_FLAGS);
 	m_sleepAction                       = (SjShutdownEtc)(sleepFlags&SJ_SLEEPMODE_ACTION_MASK);
 	m_sleepTimemode                     = sleepFlags&SJ_SLEEPMODE_TIMEMODE_MASK;
 
+	m_jingleFlags                       = c->Read(wxT("autoctrl/jingleFlags"),     0L);
+	m_jingleEvery                       = c->Read(wxT("autoctrl/jingleEvery"),     SJ_JINGLE_DEF_MINUTES);
+	m_jingleEveryMusicSelId             = c->Read(wxT("autoctrl/jingleEveryId"),   0L/*=none*/);
+	m_jingleEveryTriggerTimestamp       = SjTools::GetMsTicks(); // do as if a jingle was played on program startup
+	for( int i = 0; i < SJ_JINGLE_AT_CNT; i++ )
+	{
+		m_jingleAt[i]                   = c->Read(wxString::Format("autoctrl/jingleAt%i", i),    0L);
+		m_jingleAtMusicSelId[i]         = c->Read(wxString::Format("autoctrl/jingleAtId%i", i),  0L/*=none*/);
+		m_jingleAtTriggerTimestamp[i]   = 0; // not: SjTools::GetMsTicks() - this will force the first trigger without any timeouts
+	}
+
 	m_stateStartVisTimestamp            = 0;
 	m_stateStopVisTimestamp             = 0;
 	m_stateGotoCurrClickedTimestamp     = 0;
@@ -315,10 +328,21 @@ void SjAutoCtrl::SaveAutoCtrlSettings()
 	c->Write(wxT("autoctrl/autoPlayId"),        m_autoPlayMusicSelId);
 	c->Write(wxT("autoctrl/autoPlayIgnoreId"),  m_autoPlayMusicSelIgnoreId);
 
+	c->Write(wxT("autoctrl/limitPlayTime"),     m_limitPlayTimeSeconds);
+
 	c->Write(wxT("autoctrl/sleepMinutes"),      m_sleepMinutes);
 	c->Write(wxT("autoctrl/sleepFlags"),        m_sleepAction|m_sleepTimemode);
 	c->Write(wxT("autoctrl/sleepFadeSeconds"),  m_sleepFadeSeconds);
 
+	c->Write(wxT("autoctrl/jingleFlags"),       m_jingleFlags);
+	c->Write(wxT("autoctrl/jingleEvery"),       m_jingleEvery);
+	c->Write(wxT("autoctrl/jingleEveryId"),     m_jingleEveryMusicSelId);
+	for( int i = 0; i < SJ_JINGLE_AT_CNT; i++ )
+	{
+		c->Write(wxString::Format("autoctrl/jingleAt%i", i),   m_jingleAt[i]);
+		c->Write(wxString::Format("autoctrl/jingleAtId%i", i), m_jingleAtMusicSelId[i]);
+	}
+
 	// if the previous number of tracks to play was larger than the new one,
 	// align the number of left tracks
 	if( m_stateAutoPlayTracksLeft > m_autoPlayNumTracks )
@@ -364,6 +388,12 @@ void SjAutoCtrl::ValidateSettings()
 		m_stopVisMinutes = SJ_AUTOCTRL_DEF_STOPVISMINUTES;
 	}
 
+	if( m_limitPlayTimeSeconds < SJ_AUTOCTRL_MIN_LIMITPLAYTIMESECONDS
+	 || m_limitPlayTimeSeconds > SJ_AUTOCTRL_MAX_LIMITPLAYTIMESECONDS )
+	{
+		m_limitPlayTimeSeconds = SJ_AUTOCTRL_DEF_LIMITPLAYTIMESECONDS;
+	}
+
 	// for these values, set to min/max as the user may enter very large or
 	// very slow values to get a special effect
 	if( m_autoPlayWaitMinutes < SJ_AUTOCTRL_MIN_AUTOPLAYWAITMINUTES )   m_autoPlayWaitMinutes = SJ_AUTOCTRL_MIN_AUTOPLAYWAITMINUTES;
@@ -378,6 +408,12 @@ void SjAutoCtrl::ValidateSettings()
 
 	if( m_sleepFadeSeconds < SJ_SLEEPMODE_MIN_FADE_SECONDS ) m_sleepFadeSeconds = SJ_SLEEPMODE_MIN_FADE_SECONDS;
 	if( m_sleepFadeSeconds > SJ_SLEEPMODE_MAX_FADE_SECONDS ) m_sleepFadeSeconds = SJ_SLEEPMODE_MAX_FADE_SECONDS;
+
+	// jingles
+	if( m_jingleEvery < SJ_JINGLE_MIN_MINUTES || m_jingleEvery > SJ_JINGLE_MAX_MINUTES ) { m_jingleEvery = SJ_JINGLE_DEF_MINUTES; }
+	for( int i = 0; i < SJ_JINGLE_AT_CNT; i++ ) {
+		if( m_jingleAt[i] < 0 || m_jingleAt[i] >= 24*60 ) { m_jingleAt[i] = 0; }
+	}
 }
 
 
@@ -391,6 +427,8 @@ void SjAutoCtrl::OnOneSecondTimer()
 
 		unsigned long thisTimestamp = SjTools::GetMsTicks();
 
+		g_mainFrame->m_player.OneSecondTimer();
+
 		// automatic control: do cleanup temp?
 		//////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -443,8 +481,7 @@ void SjAutoCtrl::OnOneSecondTimer()
 
 						m_stateFollowPlaylistUrlFollowed = currUrl;
 
-						wxCommandEvent fwd(wxEVT_COMMAND_MENU_SELECTED, IDO_GOTOCURRAUTO);
-						g_mainFrame->GetEventHandler()->AddPendingEvent(fwd);
+						g_mainFrame->GetEventHandler()->QueueEvent(new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, IDO_GOTOCURRAUTO));
 					}
 				}
 			}
@@ -492,7 +529,7 @@ void SjAutoCtrl::OnOneSecondTimer()
 						}
 						else
 						{
-							if( !IsCurrTrackCloseToEnd() )
+							if( IsCurrTrackCloseToEnd() == 0 )
 							{
 								SwitchToDefLayout();
 
@@ -526,6 +563,82 @@ void SjAutoCtrl::OnOneSecondTimer()
 			}
 		}
 
+		// automatic control: jingles
+		//////////////////////////////////////////////////////////////////////////////////////////////
+
+
+		if( m_jingleFlags&(SJ_JINGLE_EVERY|SJ_JINGLE_AT0|SJ_JINGLE_AT1)
+		 && !g_mainFrame->m_inConstruction
+		 && !g_mainFrame->m_mainApp->IsInShutdown() )
+		{
+			if( m_jingleFlags&SJ_JINGLE_EVERY // the normal jingles are only played if the jukebox is playing.
+			 && g_mainFrame->IsPlaying() )
+			{
+				unsigned long nextTimestamp = m_jingleEveryTriggerTimestamp+m_jingleEvery*60*1000;
+				if( thisTimestamp > nextTimestamp )
+				{
+					m_jingleEveryTriggerTimestamp = thisTimestamp;
+					SjAdvSearch advSearch = g_advSearchModule->GetSearchById(m_jingleEveryMusicSelId);
+					if( advSearch.GetId()==0 )
+					{
+						SjTools::SetFlag(m_jingleFlags, SJ_JINGLE_EVERY, false);
+						SaveAutoCtrlSettings();
+					}
+					wxString url = advSearch.GetRandomUrl();
+					if( !url.IsEmpty() ) {
+						g_mainFrame->Enqueue(url, -2/*enqueue next*/, TRUE/*verified*/);
+					}
+				}
+			}
+
+			for( int i = 0; i < SJ_JINGLE_AT_CNT; i++ )
+			{
+				if( m_jingleFlags&(SJ_JINGLE_AT0<<i) ) // the jingles at conctrete times are played even if the jukebox is paused/stopped.
+				{
+					wxDateTime now = wxDateTime::Now();
+					long thisMinuteOfToday = now.GetHour()*60 + now.GetMinute();
+					if( m_jingleAt[i] == thisMinuteOfToday
+					 && thisTimestamp > m_jingleAtTriggerTimestamp[i]+70*1000 )
+					{
+						m_jingleAtTriggerTimestamp[i] = thisTimestamp;
+						SjAdvSearch advSearch = g_advSearchModule->GetSearchById(m_jingleAtMusicSelId[i]);
+						if( advSearch.GetId()==0 || (m_jingleFlags&(SJ_JINGLE_AT0_DAILY<<i))==0 )
+						{
+							SjTools::SetFlag(m_jingleFlags, SJ_JINGLE_AT0<<i, false);
+							SaveAutoCtrlSettings();
+						}
+						wxString url = advSearch.GetRandomUrl();
+						if( !url.IsEmpty() ) {
+							g_mainFrame->Enqueue(url, (m_jingleFlags&(SJ_JINGLE_AT0_WAIT<<i))? -2 : -3, TRUE/*verified*/);
+						}
+					}
+				}
+			}
+		}
+
+		// automatic control: limit play time
+		//////////////////////////////////////////////////////////////////////////////////////////////
+
+		if( (m_flags & SJ_AUTOCTRL_LIMIT_PLAY_TIME)
+		 && !g_mainFrame->m_inConstruction
+		 && !g_mainFrame->m_mainApp->IsInShutdown()
+		 && !SjBusyInfo::InYield()
+		 &&  IsCurrTrackCloseToEnd() != 1 /*limit if we're "not close to end" or if "we don't know"*/
+		 &&  g_mainFrame->IsPlaying() )
+		{
+			long elapsedMs = g_mainFrame->GetElapsedTime();
+			if( elapsedMs > m_limitPlayTimeSeconds*1000 )
+			{
+				g_mainFrame->SetDisplayMsg(_("Play time exceeded"), 5000); // should be set before GotoNextRegardAP() to avoid flickering
+				if( !g_mainFrame->GotoNextRegardAP(true /*fade to next*/, false /*do not ignore timeouts (leave a gap of some minutes if desired*/) )
+				{
+					g_mainFrame->Stop();
+					g_mainFrame->m_haltedManually = false; /*set to "true" in Stop() - but this was no manual stop, we want the autoplay to start over*/
+				}
+			}
+		}
+
+
 		// automatic control: check auto-play
 		//////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -541,7 +654,7 @@ void SjAutoCtrl::OnOneSecondTimer()
 
 				// ...see if we have to add an auto-play URL
 				if( !g_mainFrame->m_haltedManually
-				        && !m_stateHaltedBySleep )
+				 && !m_stateHaltedBySleep )
 				{
 					if( m_stateAutoPlayTracksLeft > 0 && LastTrackWasAutoPlay() )
 					{
@@ -549,7 +662,7 @@ void SjAutoCtrl::OnOneSecondTimer()
 						m_stateAutoPlayTracksLeft--;
 					}
 					else if( (thisTimestamp > (m_stateAutoPlayLastPlaybackTimestamp+m_autoPlayWaitMinutes*60*1000))
-					         || (m_stateLastUnqueueId!=0 && m_stateLastUnqueueId==m_stateLastAutoPlayQueueId) )
+					      || (m_stateLastUnqueueId!=0 && m_stateLastUnqueueId==m_stateLastAutoPlayQueueId) )
 					{
 						wxASSERT( m_autoPlayNumTracks > 0 );
 
@@ -569,7 +682,7 @@ void SjAutoCtrl::OnOneSecondTimer()
 
 				/*// ...see if we have to add an auto-play URL,
 				// we do this only if the player is not paused
-				if(  IsCurrTrackCloseToEnd()
+				if(  IsCurrTrackCloseToEnd() != 0
 				 && !g_mainFrame->IsPaused()
 				 && !g_mainFrame->HasNextIgnoreAP() ) // HasNext() seems only to work exactly if playing, so better check m_haltedManually in the stopped-condtion above
 				{
@@ -596,7 +709,7 @@ void SjAutoCtrl::OnOneSecondTimer()
 
 		if( (m_flags & SJ_AUTOCTRL_SLEEP)
 		 && !g_mainFrame->m_inConstruction
-		  && !g_mainFrame->m_mainApp->IsInShutdown() )
+		 && !g_mainFrame->m_mainApp->IsInShutdown() )
 		{
 			#ifdef __WXDEBUG__
 				if( m_stateTriggerSleep )
@@ -634,7 +747,7 @@ void SjAutoCtrl::OnOneSecondTimer()
 						wxDateTime now = wxDateTime::Now();
 						long thisMinuteOfToday = now.GetHour()*60 + now.GetMinute();
 						if(  m_sleepMinutes == thisMinuteOfToday
-						        && (s_thisTriggerTimestamp == 0 || (thisTimestamp>s_thisTriggerTimestamp+70*1000)) )
+						 && (s_thisTriggerTimestamp == 0 || (thisTimestamp>s_thisTriggerTimestamp+70*1000)) )
 						{
 							m_stateTriggerSleep = TRUE;
 							s_thisTriggerTimestamp = thisTimestamp;
@@ -649,7 +762,7 @@ void SjAutoCtrl::OnOneSecondTimer()
 
 					m_stateSleepWaitTimestamp = 0;
 					if( m_flags&SJ_AUTOCTRL_SLEEP_FADE
-					        && g_mainFrame->IsPlaying() )
+					 && g_mainFrame->IsPlaying() )
 					{
 						m_stateTriggerSleep = FALSE;
 						if( m_stateSleepAutoFader )
@@ -710,8 +823,7 @@ void SjAutoCtrl::OnOneSecondTimer()
 				wxEvent* event = (wxEvent*)m_pendingEvents[i];
 				if( event )
 				{
-					g_mainFrame->GetEventHandler()->AddPendingEvent(*event);
-					delete event;
+					g_mainFrame->GetEventHandler()->QueueEvent(event);
 				}
 			}
 			m_pendingEvents.Clear();
@@ -782,7 +894,7 @@ bool SjAutoCtrl::LastTrackWasAutoPlay()
 {
 	long queueCount = g_mainFrame->GetQueueCount();
 	if( queueCount > 0
-	        && g_mainFrame->m_player.m_queue.GetIdByPos(queueCount-1) == m_stateLastAutoPlayQueueId )
+	 && g_mainFrame->m_player.m_queue.GetIdByPos(queueCount-1) == m_stateLastAutoPlayQueueId )
 	{
 		return TRUE;
 	}
@@ -793,18 +905,25 @@ bool SjAutoCtrl::LastTrackWasAutoPlay()
 }
 
 
-bool SjAutoCtrl::IsCurrTrackCloseToEnd()
+int SjAutoCtrl::IsCurrTrackCloseToEnd() // returns 0, 1 or -1 for unknown
 {
-	long    remainingMs = g_mainFrame->GetRemainingTime();
-	long    crossfadeMs = g_mainFrame->m_player.GetAutoCrossfade()? g_mainFrame->m_player.m_autoCrossfadeMs : 0;
-	#define headroomMs 10000L // 10 seconds before anythings starts; the player itself prepares a new stream 5 seconds before the end of the previous one
-
-	if( remainingMs < (crossfadeMs+headroomMs) )
+	long remainingMs = g_mainFrame->GetRemainingTime();
+	wxASSERT( remainingMs >= -1 );
+	if( remainingMs < 0 )
 	{
-		return TRUE;    // we're close to end
+		return -1; // dont'know
 	}
 
-	return FALSE;       // we're not close to end
+	long crossfadeMs = g_mainFrame->m_player.GetAutoCrossfade()? g_mainFrame->m_player.m_autoCrossfadeMs : 0;
+	wxASSERT( remainingMs >= 0 );
+	wxASSERT( crossfadeMs >= 0 );
+	#define headroomMs 10000L // 10 seconds before anythings starts; the player itself prepares a new stream 5 seconds before the end of the previous one
+	if( remainingMs < (crossfadeMs+headroomMs) )
+	{
+		return 1; // we're close to end
+	}
+
+	return 0; // we're not close to end
 }
 
 
@@ -897,7 +1016,7 @@ wxString SjAutoCtrl::GetAutoPlayUrl()
 
 	wxSqlt sql;
 	unsigned long now = SjTools::GetMsTicks();
-	long selectedTrackId;
+	long selectedTrackId = 0;
 	for( int iterations = 0; iterations < MAX_ITERATIONS; iterations++ )
 	{
 		long testIndex = SjTools::Rand(trackIdsCount);
