@@ -33,6 +33,7 @@
 #include <sjbase/browser_cover.h>
 #include <sjbase/browser_list.h>
 #include <sjmodules/kiosk/virtkeybd.h>
+#include <sjmodules/vis/vis_module.h>
 #include <sjbase/columnmixer.h>
 
 
@@ -48,11 +49,7 @@ BEGIN_EVENT_TABLE(SjBrowserWindow, wxWindow)
 	EVT_ENTER_WINDOW        (   SjBrowserWindow::OnMouseEnter       )
 	EVT_MOTION              (   SjBrowserWindow::OnMouseMotion      )
 	EVT_MOUSEWHEEL          (   SjBrowserWindow::OnMouseWheel       )
-	#ifdef __WXMAC__ // the context menu MUST be opened on down on MAC: TODO: we should use EVT_CONTEXT_MENU here
-	EVT_RIGHT_DOWN          (   SjBrowserWindow::OnMouseRight       )
-	#else
-	EVT_RIGHT_UP            (   SjBrowserWindow::OnMouseRight       )
-	#endif
+	EVT_CONTEXT_MENU        (   SjBrowserWindow::OnMouseRight       )
 	EVT_MIDDLE_UP           (   SjBrowserWindow::OnMouseMiddleUp    )
 	EVT_KEY_DOWN            (   SjBrowserWindow::OnKeyDown          )
 END_EVENT_TABLE()
@@ -131,8 +128,7 @@ void SjBrowserWindow::OnMouseLeftDClick(wxMouseEvent& event)
 	if( !m_currView->OnMouseLeftDClick(event) )
 	{
 		// click not used -> toggle view
-		wxCommandEvent fwd(wxEVT_COMMAND_MENU_SELECTED, IDT_WORKSPACE_TOGGLE_VIEW);
-		g_mainFrame->GetEventHandler()->AddPendingEvent(fwd);
+		g_mainFrame->GetEventHandler()->QueueEvent(new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, IDT_WORKSPACE_TOGGLE_VIEW));
 	}
 }
 
@@ -141,8 +137,7 @@ void SjBrowserWindow::OnMouseEnter(wxMouseEvent& event)
 {
 	// if the mouse enters this window, send a mouse leave
 	// message to the parent window
-	wxMouseEvent pendEvt(wxEVT_LEAVE_WINDOW);
-	GetParent()->GetEventHandler()->AddPendingEvent(pendEvt);
+	GetParent()->GetEventHandler()->QueueEvent(new wxMouseEvent(wxEVT_LEAVE_WINDOW));
 
 	if( !HasCapture() )
 		ResetCursor();
@@ -186,128 +181,135 @@ void SjBrowserWindow::OnMouseMotion(wxMouseEvent& event)
 }
 
 
-static void simulateSlider(long zDelta, long wheelDelta, int targetUp, int targetDown)
-{
-	SjSkinValue dummy;
-	long i, cnt = (zDelta>0? zDelta : (zDelta*-1))/wheelDelta;
-	if( cnt<1 ) cnt = 1; if( cnt > 3 ) cnt = 3;
-	for( i = 0; i < cnt; i++ )
-	{
-		g_mainFrame->OnSkinTargetEvent(zDelta>0?targetUp:targetDown, dummy, 0);
-	}
-}
-
-
 void SjBrowserWindow::OnMouseWheel(wxMouseEvent& event)
 {
 	if( g_accelModule == NULL || m_mouseAction == SJ_ACTION_DRAGNDROP
-	        || m_mouseAction == SJ_ACTION_COLUMNWIDTH || m_mouseAction == SJ_ACTION_COLUMNMOVE || m_currView == NULL ) return;
+	 || m_mouseAction == SJ_ACTION_COLUMNWIDTH || m_mouseAction == SJ_ACTION_COLUMNMOVE || m_currView == NULL ) return;
 
 	#if SJ_USE_TOOLTIPS
 		g_tools->m_toolTipManager.ClearToolTipProvider();
 	#endif
 
-	long zDelta = event.GetWheelRotation();
-	long wheelDelta = event.GetWheelDelta();
+	// get information about the mouse wheel event
 
-	// is the mouse over the display? over the volume slider?
+	bool scrollVert = event.GetWheelAxis() == wxMOUSE_WHEEL_HORIZONTAL? false : true;
+	if( ((event.AltDown() || event.ShiftDown() || event.CmdDown() || event.ControlDown()) && g_accelModule->m_flags&SJ_ACCEL_WHEEL_MODIFIER_AXIS_TOGGLE)
+	 || (event.RightIsDown() && g_accelModule->m_flags&SJ_ACCEL_WHEEL_RMOUSE_AXIS_TOGGLE) )
+	{
+		scrollVert = !scrollVert;
+	}
+
+	if( event.RightIsDown() && g_accelModule->m_flags&SJ_ACCEL_WHEEL_RMOUSE_AXIS_TOGGLE )
+	{
+		m_skipContextMenuEvent = 1; // skip WM_RBUTTONUP and WM_CONTEXTMENU
+	}
 
 	int mouseX, mouseY;
 	::wxGetMousePosition(&mouseX, &mouseY);
 	g_mainFrame->ScreenToClient(&mouseX, &mouseY);
+
 	int targetId = g_mainFrame->FindTargetId(mouseX, mouseY);
 
-	if( g_accelModule->m_flags&SJ_ACCEL_CONTEXT_SENSITIVE_WHEEL )
+	// for some targets, the mouse wheel does some (optional) special things
+
+	if( (targetId>=IDT_DISPLAY_LINE_FIRST && targetId<=IDT_DISPLAY_LINE_LAST)
+	 ||  targetId==IDT_DISPLAY_UP
+	 ||  targetId==IDT_DISPLAY_DOWN
+	 ||  targetId==IDT_DISPLAY_V_SCROLL )
 	{
-		if( (targetId>=IDT_DISPLAY_LINE_FIRST && targetId<=IDT_DISPLAY_LINE_LAST)
-		        ||  targetId==IDT_DISPLAY_UP
-		        ||  targetId==IDT_DISPLAY_DOWN
-		        ||  targetId==IDT_DISPLAY_V_SCROLL )
+		if( scrollVert )
 		{
-			simulateSlider(zDelta, wheelDelta, IDT_DISPLAY_UP, IDT_DISPLAY_DOWN);
-			return;
+			static SjWheelHelper s_dispWheelHelper;
+			long actions, dir; s_dispWheelHelper.PushRotationNPopAction(event, actions, dir);
+			while( actions-- )
+			{
+				SjSkinValue dummy;
+				g_mainFrame->OnSkinTargetEvent(dir>0?IDT_DISPLAY_UP:IDT_DISPLAY_DOWN, dummy, 0);
+			}
 		}
-		else if( targetId==IDT_MAIN_VOL_UP
-		         || targetId==IDT_MAIN_VOL_DOWN
-		         || targetId==IDT_MAIN_VOL_SLIDER
-		         || targetId==IDT_MAIN_VOL_MUTE )
+		return;
+	}
+	else if( g_accelModule->m_flags&SJ_ACCEL_WHEEL_VALUE_INPUT )
+	{
+		if( targetId==IDT_MAIN_VOL_UP
+		 || targetId==IDT_MAIN_VOL_DOWN
+		 || targetId==IDT_MAIN_VOL_SLIDER
+		 || targetId==IDT_MAIN_VOL_MUTE )
 		{
-			simulateSlider(zDelta, wheelDelta, IDT_MAIN_VOL_UP, IDT_MAIN_VOL_DOWN);
+			if( scrollVert )
+			{
+				static SjWheelHelper s_volWheelHelper;
+				long actions, dir; s_volWheelHelper.PushRotationNPopAction(event, actions, dir);
+				while( actions-- )
+				{
+					SjSkinValue dummy;
+					g_mainFrame->OnSkinTargetEvent(dir>0?IDT_MAIN_VOL_UP:IDT_MAIN_VOL_DOWN, dummy, 0);
+				}
+			}
 			return;
 		}
 		else if( (targetId>=IDT_WORKSPACE_GOTO_A && targetId<=IDT_WORKSPACE_GOTO_0_9)
-		         ||  targetId==IDT_WORKSPACE_GOTO_PREV_AZ
-		         ||  targetId==IDT_WORKSPACE_GOTO_NEXT_AZ )
+			   || targetId==IDT_WORKSPACE_GOTO_PREV_AZ
+			   || targetId==IDT_WORKSPACE_GOTO_NEXT_AZ )
 		{
-			// added for 2.10, see http://www.silverjuke.net/forum/post.php?p=2720#2720
-			SjSkinValue dummy;
-			g_mainFrame->OnSkinTargetEvent(zDelta>0?IDT_WORKSPACE_GOTO_PREV_AZ:IDT_WORKSPACE_GOTO_NEXT_AZ, dummy, 0);
+			if( scrollVert )
+			{
+				static SjWheelHelper s_azWheelHelper;
+				long actions, dir; s_azWheelHelper.PushRotationNPopAction(event, actions, dir);
+				while( actions-- )
+				{
+					SjSkinValue dummy;
+					g_mainFrame->OnSkinTargetEvent(dir>0?IDT_WORKSPACE_GOTO_PREV_AZ:IDT_WORKSPACE_GOTO_NEXT_AZ, dummy, 0);
+				}
+			}
 			return;
 		}
 		else if( targetId == IDT_WORKSPACE_H_SCROLL
-		         || targetId == IDT_WORKSPACE_LINE_LEFT
-		         || targetId == IDT_WORKSPACE_LINE_RIGHT
-		         || targetId == IDT_WORKSPACE_PAGE_LEFT
-		         || targetId == IDT_WORKSPACE_PAGE_RIGHT )
+			  || targetId == IDT_WORKSPACE_LINE_LEFT
+			  || targetId == IDT_WORKSPACE_LINE_RIGHT
+			  || targetId == IDT_WORKSPACE_PAGE_LEFT
+			  || targetId == IDT_WORKSPACE_PAGE_RIGHT )
 		{
-			SjSkinValue dummy;
-			g_mainFrame->OnSkinTargetEvent(zDelta>0?IDT_WORKSPACE_PAGE_LEFT:IDT_WORKSPACE_PAGE_RIGHT, dummy, 0);
-			return;
+			if( scrollVert )
+			{
+				static SjWheelHelper s_hscrollWheelHelper;
+				long actions, dir; s_hscrollWheelHelper.PushRotationNPopAction(event, actions, dir);
+				while( actions-- )
+				{
+					SjSkinValue dummy;
+					g_mainFrame->OnSkinTargetEvent(dir>0?IDT_WORKSPACE_LINE_LEFT:IDT_WORKSPACE_LINE_RIGHT, dummy, 0);
+				}
+				return;
+			}
+		}
+		else if( targetId == IDT_WORKSPACE_V_SCROLL
+			  || targetId == IDT_WORKSPACE_LINE_UP
+			  || targetId == IDT_WORKSPACE_LINE_DOWN
+			  || targetId == IDT_WORKSPACE_PAGE_UP
+			  || targetId == IDT_WORKSPACE_PAGE_DOWN )
+		{
+			if( scrollVert )
+			{
+				static SjWheelHelper s_vscrollWheelHelper;
+				long actions, dir; s_vscrollWheelHelper.PushRotationNPopAction(event, actions, dir);
+				while( actions-- )
+				{
+					SjSkinValue dummy;
+					g_mainFrame->OnSkinTargetEvent(dir>0?IDT_WORKSPACE_LINE_UP:IDT_WORKSPACE_LINE_DOWN, dummy, 0); // needed to allow vertical scrolling if SJ_ACCEL_WHEEL_HORZ_IN_ALBUMVIEW is set
+				}
+				return;
+			}
 		}
 	}
 
-	// find out scrolling orientation
+	// give the event to the current view
 
 	g_mainFrame->GotBrowserInputFromUser();
-
-	bool scrollVert = true;
-
-	if( m_currView == m_views[SJ_BROWSER_ALBUM_VIEW] )
-	{
-		scrollVert = (g_accelModule->m_flags&SJ_ACCEL_VERT_WHEEL_HORZ)? false : true;
-	}
-
-	if( event.ShiftDown()
-	        || event.ControlDown()
-	        || event.RightIsDown() )
-	{
-		// toggle direction if shift, ctrl or the right mouse button is down
-		scrollVert = !scrollVert;
-	}
-	else if( g_accelModule->m_flags&SJ_ACCEL_CONTEXT_SENSITIVE_WHEEL ) // if "scroll display" is false, the user seems not to like the scroll wheel to react to mouse positions
-	{
-		// regard the scrollbars directions if the mouse is over them
-		if( targetId == IDT_WORKSPACE_H_SCROLL
-		        || targetId == IDT_WORKSPACE_LINE_LEFT
-		        || targetId == IDT_WORKSPACE_LINE_RIGHT
-		        || targetId == IDT_WORKSPACE_PAGE_LEFT
-		        || targetId == IDT_WORKSPACE_PAGE_RIGHT )
-		{
-			scrollVert = FALSE;
-		}
-		else if(
-		    targetId == IDT_WORKSPACE_V_SCROLL
-		    || targetId == IDT_WORKSPACE_LINE_UP
-		    || targetId == IDT_WORKSPACE_LINE_DOWN
-		    || targetId == IDT_WORKSPACE_PAGE_UP
-		    || targetId == IDT_WORKSPACE_PAGE_DOWN )
-		{
-			scrollVert = TRUE;
-		}
-	}
-
-	/* give the event to the current view
-	 */
 	m_currView->OnMouseWheel(event, scrollVert);
-
-	if( event.RightIsDown() )
-	{
-		m_skipContextMenuEvent = 1; // skip WM_RBUTTONUP and WM_CONTEXTMENU
-	}
 }
 
 
-void SjBrowserWindow::OnMouseRight(wxMouseEvent& event)
+void SjBrowserWindow::OnMouseRight(wxContextMenuEvent& event)
 {
 	#if SJ_USE_TOOLTIPS
 		g_tools->m_toolTipManager.ClearToolTipProvider();
@@ -326,7 +328,8 @@ void SjBrowserWindow::OnMouseRight(wxMouseEvent& event)
 
 	/* give the event to the current view
 	 */
-	m_currView->OnContextMenu(event);
+	wxPoint clickPoint = ScreenToClient(event.GetPosition());
+	m_currView->OnContextMenu(clickPoint.x, clickPoint.y);
 }
 void SjBrowserWindow::OnModuleUserId(int id)
 {
@@ -393,6 +396,7 @@ void SjBrowserWindow::OnSkinTargetEvent (int targetId, SjSkinValue& value, long
 			int newView = (GetView()+test)%SJ_BROWSER_VIEW_COUNT;
 			if( IsViewAvailable(newView) )
 			{
+				g_visModule->StopVisIfOverWorkspace();
 				SetView_(newView, true, true);
 				break;
 			}
@@ -400,18 +404,21 @@ void SjBrowserWindow::OnSkinTargetEvent (int targetId, SjSkinValue& value, long
 	}
 	else if( targetId == IDT_WORKSPACE_ALBUM_VIEW )
 	{
-		// if the view is not available, nothing happens
-		SetView_(SJ_BROWSER_ALBUM_VIEW, true, true);
+		if( IsViewAvailable(SJ_BROWSER_ALBUM_VIEW) )
+			g_visModule->StopVisIfOverWorkspace();
+		SetView_(SJ_BROWSER_ALBUM_VIEW, true, true); // needed anyway for button updates; if the view is not available, nothing happen
 	}
 	else if( targetId == IDT_WORKSPACE_COVER_VIEW )
 	{
-		// if the view is not available, nothing happens
-		SetView_(SJ_BROWSER_COVER_VIEW, true, true);
+		if( IsViewAvailable(SJ_BROWSER_COVER_VIEW) )
+			g_visModule->StopVisIfOverWorkspace();
+		SetView_(SJ_BROWSER_COVER_VIEW, true, true); // needed anyway for button updates; if the view is not available, nothing happen
 	}
 	else if( targetId == IDT_WORKSPACE_LIST_VIEW )
 	{
-		// if the view is not available, nothing happens
-		SetView_(SJ_BROWSER_LIST_VIEW, true, true);
+		if( IsViewAvailable(SJ_BROWSER_LIST_VIEW) )
+			g_visModule->StopVisIfOverWorkspace();
+		SetView_(SJ_BROWSER_LIST_VIEW, true, true); // needed anyway for button updates; if the view is not available, nothing happen
 	}
 	else if( m_currView )
 	{
@@ -420,8 +427,14 @@ void SjBrowserWindow::OnSkinTargetEvent (int targetId, SjSkinValue& value, long
 			// toggle covers
 			if( g_mainFrame->IsOpAvailable(SJ_OP_TOGGLE_ELEMENTS) )
 			{
+				g_visModule->StopVisIfOverWorkspace();
 				SjTools::ToggleFlag(m_currView->m_flags, SJ_BROWSER_VIEW_COVER);
 				RefreshAll();
+
+				if( g_mainFrame->m_viewMenu )
+				{
+					g_mainFrame->m_viewMenu->Check(IDT_WORKSPACE_SHOW_COVERS, AreCoversShown());
+				}
 			}
 		}
 		else
@@ -434,7 +447,7 @@ void SjBrowserWindow::OnSkinTargetEvent (int targetId, SjSkinValue& value, long
 					// "enter" not used by the current view, play/enqueue the files
 					int action = IDT_ENQUEUE_LAST;
 					if(  g_mainFrame->IsOpAvailable(SJ_OP_EDIT_QUEUE)
-					        && (g_accelModule->m_flags&SJ_ACCEL_PLAY_NOW_ON_DBL_CLICK) )
+					 && (g_accelModule->m_flags&SJ_ACCEL_PLAY_NOW_ON_DBL_CLICK) )
 					{
 						action = IDT_ENQUEUE_NOW;
 					}
@@ -508,7 +521,7 @@ void SjBrowserWindow::OnPaint(wxPaintEvent& event)
 		{
 			drawStub = true;
 			if(  g_mainFrame->m_libraryModule->GetUnmaskedTrackCount() <= 0
-			        || !g_mainFrame->HasAnySearch() )
+			 || !g_mainFrame->HasAnySearch() )
 			{
 				// the condition above is not perfect, however it works in most cases
 				// (not if the windows is redrawn during the _first_ update with any search set)
@@ -718,7 +731,9 @@ void SjBrowserWindow::RefreshAll()
 void SjBrowserWindow::RefreshSelection()
 {
 	if( m_currView )
+	{
 		m_currView->RefreshSelection();
+	}
 }
 
 
@@ -727,19 +742,20 @@ int SjBrowserWindow::GetView() const
 	for( int i = 0; i < SJ_BROWSER_VIEW_COUNT; i++ )
 	{
 		if( m_views[i] == m_currView )
+		{
 			return i;
+		}
 	}
 
-	wxASSERT( 0 ); // should not happen!
-	return 0;
+	return 0; // may happen on startup (eg. if called by a script or implicit via InitMainMenu())
 }
 
 
 bool SjBrowserWindow::IsViewAvailable(int i)
 {
 	if( (i == SJ_BROWSER_ALBUM_VIEW && !g_mainFrame->IsOpAvailable(SJ_OP_ALBUM_VIEW))
-	        || (i == SJ_BROWSER_COVER_VIEW && !g_mainFrame->IsOpAvailable(SJ_OP_COVER_VIEW))
-	        || (i == SJ_BROWSER_LIST_VIEW  && !g_mainFrame->IsOpAvailable(SJ_OP_LIST_VIEW)) )
+	 || (i == SJ_BROWSER_COVER_VIEW && !g_mainFrame->IsOpAvailable(SJ_OP_COVER_VIEW))
+	 || (i == SJ_BROWSER_LIST_VIEW  && !g_mainFrame->IsOpAvailable(SJ_OP_LIST_VIEW)) )
 	{
 		return false;
 	}
@@ -751,19 +767,23 @@ bool SjBrowserWindow::IsViewAvailable(int i)
 void SjBrowserWindow::SetView_(int i, bool keepPosition, bool redraw)
 {
 	wxString        viewPos;
-	long            viewOffset, j;
+	long            viewOffset = 0, j;
 	SjSkinValue value;
 
 	// corect index
 	if( i < 0 || i >= SJ_BROWSER_VIEW_COUNT )
+	{
 		i = SJ_BROWSER_ALBUM_VIEW;
+	}
 
 	// is the requested view available? anything to change?
 	if( IsViewAvailable(i) && m_currView != m_views[i] )
 	{
 		// get the old position
 		if( m_currView == NULL )
+		{
 			keepPosition = false;
+		}
 
 		if( keepPosition )
 		{
@@ -836,19 +856,30 @@ void SjBrowserWindow::SetZoom_(int targetIdOrAbs)
 	if( g_accelModule->m_flags & SJ_ACCEL_SAME_ZOOM_IN_ALL_VIEWS )
 	{
 		for( int i = 0; i < SJ_BROWSER_VIEW_COUNT; i++ )
+		{
 			m_views[i]->m_zoom = newZoom;
+		}
 	}
 	g_mainFrame->SetZoom__(newZoom);
 }
 
 
+void SjBrowserWindow::AddItemsToColMenu(SjMenu* m)
+{
+	if( m_currView )
+	{
+		m_currView->AddItemsToColMenu(m);
+	}
+}
+
+
 /*******************************************************************************
  * Constructor / Destructor
  ******************************************************************************/
 
 
 SjBrowserWindow::SjBrowserWindow(SjMainFrame* mainFrame)
-	: wxWindow(mainFrame, -1, wxDefaultPosition, wxDefaultSize, 0)
+	: wxWindow(mainFrame, -1, wxDefaultPosition, wxDefaultSize, wxFULL_REPAINT_ON_RESIZE)
 {
 	g_mainFrame = mainFrame;
 	#if SJ_USE_TOOLTIPS
@@ -882,7 +913,9 @@ SjBrowserWindow::SjBrowserWindow(SjMainFrame* mainFrame)
 	{
 		m_views[i]->m_zoom = SjMainFrame::CorrectZoom(ser.GetLong());
 		if( ser.HasErrors() )
+		{
 			m_views[i]->m_zoom = 3; // default
+		}
 	}
 }
 
@@ -890,7 +923,7 @@ SjBrowserWindow::SjBrowserWindow(SjMainFrame* mainFrame)
 bool SjBrowserWindow::AreCoversShown() const
 {
 	if(  m_currView
-	        && (m_currView->m_flags&SJ_BROWSER_VIEW_COVER) )
+	 && (m_currView->m_flags&SJ_BROWSER_VIEW_COVER) )
 	{
 		return true;
 	}
@@ -914,13 +947,17 @@ void SjBrowserWindow::Exit()
 	{
 		ser.AddLong(m_views[i]->m_flags);
 	}
+
 	for( i = 0; i < SJ_BROWSER_VIEW_COUNT; i++ )
 	{
 		ser.AddLong(m_views[i]->m_zoom);
 		m_views[i]->Exit();
 	}
+
 	g_tools->m_config->Write(wxT("main/browserFlags"), ser.GetResult());
 }
+
+
 SjBrowserWindow::~SjBrowserWindow()
 {
 	#ifdef __WXDEBUG__
@@ -928,12 +965,14 @@ SjBrowserWindow::~SjBrowserWindow()
 	#endif
 
 	for( int i = 0; i < SJ_BROWSER_VIEW_COUNT; i++ )
+	{
 		delete m_views[i];
+	}
 }
 
 
 /*******************************************************************************
- *  Tools for our friends :-)
+ * Tools for our friends :-)
  ******************************************************************************/
 
 
@@ -1064,7 +1103,7 @@ void SjBrowserWindow::PaintCover(wxDC& dc, SjImgThreadObj* obj, long x, long y,
 
 	// show the drag image again
 	if( dragImageHidden
-	        && g_mainFrame->m_dragImage )
+	 && g_mainFrame->m_dragImage )
 	{
 		g_mainFrame->m_dragImage->Show();
 	}
@@ -1086,10 +1125,14 @@ void SjBrowserWindow::DrawUpText(wxDC& dc, const wxString& textup, long x, long
 	textw += 2;
 
 	if( texth > w )
+	{
 		texth = w;
+	}
 
 	if( textw > h )
+	{
 		textw = h;
+	}
 
 	wxBitmap memBitmap1(textw, texth);
 	wxMemoryDC memDc;
@@ -1137,7 +1180,9 @@ void SjBrowserWindow::DrawUpText(wxDC& dc, const wxString& textup, long x, long
 
 					// space abottom
 					if( h > textw )
+					{
 						dc.DrawRectangle(x, y+textw, w, h-textw);
+					}
 				}
 			}
 		}
