@@ -50,7 +50,7 @@
 
 static const long s_possibleCols[] =
 {
-	SJ_TI_TRACKNAME
+	 SJ_TI_TRACKNAME
 	,SJ_TI_PLAYTIMEMS
 
 	,SJ_TI_LEADARTISTNAME
@@ -164,23 +164,23 @@ void SjListBrowser::LoadConfig()
 	// read sort field
 	long l = 0;
 	int i;
-	data[0].ToLong(&l, 10);
+	if( !data[0].ToLong(&l, 10) ) { l = 0; }
 	if( !isPossibleCol(l) )
 		goto LoadConfig_Failed;
 	m_sortField = l;
 
-	data[1].ToLong(&l, 10);
+	if( !data[1].ToLong(&l, 10) ) { l = 0; }
 	m_sortDesc = l!=0;
 
 	// read columns
 	for( i = 4; i < (int)data.GetCount(); i += 2 )
 	{
-		data[i].ToLong(&l, 10);
+		if( !data[i].ToLong(&l, 10) ) { l = 0; }
 		if( !isPossibleCol(l) )
 			goto LoadConfig_Failed;
 		m_columns.Add(l);
 
-		data[i+1].ToLong(&l, 10);
+		if( !data[i+1].ToLong(&l, 10) ) { l = 0; }
 		if( l < MIN_COLUMN_WIDTH || l > MAX_COLUMN_WIDTH)
 			l = MIN_COLUMN_WIDTH;
 		m_columnWidths.Add(l);
@@ -201,10 +201,10 @@ LoadConfig_Failed:
 
 void SjListBrowser::SaveConfig()
 {
-	wxString data = wxString::Format(wxT("%i,%i,0,0"), m_sortField, m_sortDesc? 1L : 0L);
+	wxString data = wxString::Format(wxT("%i,%i,0,0"), (int)m_sortField, m_sortDesc? 1 : 0);
 	for( int i = 0; i < (int)m_columns.GetCount(); i++ )
 	{
-		data += wxString::Format(wxT(",%i,%i"), m_columns[i], m_columnWidths[i]);
+		data += wxString::Format(wxT(",%i,%i"), (int)m_columns[i], (int)m_columnWidths[i]);
 	}
 	g_tools->m_config->Write(wxT("main/columns"), data);
 }
@@ -439,6 +439,11 @@ void SjListBrowser::CalculatePositions(bool calculateFontHeight)
 	m_headerRect.width = m_window->m_clientW - m_headerRect.x;
 	m_headerRect.height = m_fontHeight;
 
+	if( m_headerRect.width < 0 )
+	{
+		m_headerRect.width = 0; // may get negative on window sizes close to zero; as the horizontal thumb rely on this value, we correct it here
+	}
+
 	// calculate the tracks rect
 	m_tracksRect.x = m_headerRect.x;
 	m_tracksRect.y = m_headerRect.y + m_headerRect.height;
@@ -691,6 +696,8 @@ void SjListBrowser::OnMouseSelect(wxMouseEvent& event)
 		g_mainFrame->m_columnMixer.SelectAll(FALSE);
 		RefreshSelection();
 	}
+
+	g_mainFrame->m_libraryModule->UpdateMenuBar();
 }
 
 
@@ -771,8 +778,7 @@ void SjListBrowser::OnMouseLeftUp(wxMouseEvent& event)
 	}
 	else if( m_toggleCoversRect.Contains(event.GetX(), event.GetY()) )
 	{
-		wxCommandEvent cmd(wxEVT_COMMAND_MENU_SELECTED, IDT_WORKSPACE_SHOW_COVERS);
-		g_mainFrame->GetEventHandler()->AddPendingEvent(cmd);
+		g_mainFrame->GetEventHandler()->QueueEvent(new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, IDT_WORKSPACE_SHOW_COVERS));
 		return;
 	}
 
@@ -799,10 +805,6 @@ bool SjListBrowser::ResetSpecialMouseAction()
 			m_columnDragIndex = -1;
 			CalcRefreshNUpdateHeader();
 		}
-		else
-		{
-			m_window->SetCursor(SjVirtKeybdModule::GetStandardCursor());
-		}
 
 		m_window->m_mouseAction = SJ_ACTION_NONE;
 		return true; // resetted
@@ -875,6 +877,8 @@ void SjListBrowser::OnMouseMiddleUp(wxMouseEvent& event)
 	{
 		event.Skip();
 	}
+
+	g_mainFrame->m_libraryModule->UpdateMenuBar();
 }
 
 
@@ -931,7 +935,6 @@ void SjListBrowser::OnMouseMotion(wxMouseEvent& event)
 				m_dragScrollOrgHScroll = m_tracksHScroll;
 				m_dragScrollOrgScrollPos = m_scrollPos;
 				m_window->m_mouseAction = SJ_ACTION_DRAGSCROLL;
-				m_window->SetCursor(g_tools->m_staticMovehandCursor);
 			}
 		}
 	}
@@ -1028,20 +1031,30 @@ void SjListBrowser::OnMouseMotion(wxMouseEvent& event)
 
 void SjListBrowser::OnMouseWheel(wxMouseEvent& event, bool scrollVert)
 {
-	long zDelta = event.GetWheelRotation();
-	long wheelDelta = event.GetWheelDelta();
+	long rotation = event.GetWheelRotation();
 
-	// scroll!
-	if( wheelDelta>0 )
+	if( rotation != 0 )
 	{
 		if( scrollVert )
 		{
-			OnVScroll(IDT_WORKSPACE_V_SCROLL, m_scrollPos + (zDelta*-1 * 4/* *m_visibleTrackCount */)/wheelDelta, TRUE/*redraw*/);
-			//                  ^^^ may be used to scroll one page - but I think this is too much
+			// add multiple small rotations (smaller than the delta to take action) to bigger ones
+			static SjWheelHelper s_coverViewWheelHelper;
+			long rotateLines, dir; s_coverViewWheelHelper.PushRotationNPopAction(event, rotateLines, dir);
+			if( rotateLines != 0 )
+			{
+				// We take action 4 times faster as normal to make things more comparable with
+				// the scrolling in the album view (line-by-line scrolling is too slow and page scrolling is too fast)
+				float multiplier = m_fontHeight > 0? (event.GetWheelDelta()/m_fontHeight) : 1;
+				if( multiplier < 1 ) multiplier = 1;
+				if( multiplier > 8 ) multiplier = 8;
+				rotateLines = (long)((float)rotateLines * multiplier);
+
+				OnVScroll(IDT_WORKSPACE_V_SCROLL, m_scrollPos + rotateLines*dir*-1, TRUE/*redraw*/);
+			}
 		}
 		else
 		{
-			OnHScroll(IDT_WORKSPACE_H_SCROLL, m_tracksHScroll + (zDelta*-1  * (g_mainFrame->m_currFontSize*2))/wheelDelta, TRUE/*redraw*/);
+			OnHScroll(IDT_WORKSPACE_H_SCROLL, m_tracksHScroll + rotation, TRUE/*redraw*/);
 		}
 	}
 }
@@ -1062,13 +1075,33 @@ void SjListBrowser::OnDropImage(SjDataObject* data, int mouseX, int mouseY)
 }
 
 
-void SjListBrowser::OnContextMenu(wxMouseEvent& event)
+void SjListBrowser::AddItemsToColMenu(SjMenu* m)
+{
+	m->AppendSeparator();
+	for( int i = 0; s_possibleCols[i]; i++ )
+	{
+		m->AppendCheckItem(IDC_FIRST_COL_ID+i, SjTrackInfo::GetFieldDescr(s_possibleCols[i]));
+	}
+	m->AppendSeparator();
+	m->Append(IDC_RESET_COL, _("Reset to default values"));
+	UpdateItemsInColMenu(m);
+}
+
+
+void SjListBrowser::UpdateItemsInColMenu(SjMenu* m)
+{
+	for( int i = 0; s_possibleCols[i]; i++ )
+	{
+		m->Check(IDC_FIRST_COL_ID+i, m_columns.Index(s_possibleCols[i]) != wxNOT_FOUND);
+	}
+}
+
+
+void SjListBrowser::OnContextMenu(int clickX, int clickY)
 {
 	SjMenu  mainMenu(0);
-	bool prependOpen = true, inSizer;
+	bool    inSizer;
 
-	int clickX = event.GetX();
-	int clickY = event.GetY();
 	long index;
 	m_columnDragIndex = -1;
 	m_lastClickedCover = NULL;
@@ -1086,7 +1119,6 @@ void SjListBrowser::OnContextMenu(wxMouseEvent& event)
 
 		// build the context menu
 		m_listView->CreateContextMenu(index, mainMenu);
-		prependOpen = false;
 		m_lastContextMenuTrackIndex = index;
 	}
 	else if( MouseInHeader(clickX, clickY, index, inSizer) )
@@ -1094,14 +1126,7 @@ void SjListBrowser::OnContextMenu(wxMouseEvent& event)
 		// build the header context menu
 		if( g_mainFrame->IsOpAvailable(SJ_OP_TOGGLE_ELEMENTS) /*toggle columns?*/ )
 		{
-			prependOpen = false;
-			for( int i = 0; s_possibleCols[i]; i++ )
-			{
-				mainMenu.AppendCheckItem(IDC_FIRST_COL_ID+i, SjTrackInfo::GetFieldDescr(s_possibleCols[i]));
-				if( m_columns.Index(s_possibleCols[i]) != wxNOT_FOUND )
-					mainMenu.Check(IDC_FIRST_COL_ID+i, true);
-			}
-			mainMenu.Append(IDC_RESET_COL, _("Reset to default values"));
+			AddItemsToColMenu(&mainMenu);
 		}
 
 		m_lastContextMenuColIndex = index;
@@ -1112,23 +1137,15 @@ void SjListBrowser::OnContextMenu(wxMouseEvent& event)
 	{
 		cover->m_rows[0]->CreateContextMenu(mainMenu);
 		m_lastClickedCover = cover;
-		prependOpen = false;
-	}
-	else
-	{
-		if( g_mainFrame->IsAllAvailable() )
-		{
-			mainMenu.Append(IDO_SELECTALL);
-		}
 	}
 
 	// add main items to menu
-	g_mainFrame->CreateContextMenu_(mainMenu, prependOpen);
+	g_mainFrame->CreateContextMenu_(mainMenu);
 
 	// show menu
 	if( mainMenu.GetMenuItemCount() )
 	{
-		m_window->PopupMenu(&mainMenu, clickX, clickY);
+		m_window->PopupMenu(&mainMenu);
 	}
 
 	// deselect header (if selected before)
@@ -1137,6 +1154,8 @@ void SjListBrowser::OnContextMenu(wxMouseEvent& event)
 		m_columnDragIndex = -1;
 		m_window->Refresh(false, &m_headerRect);
 	}
+
+	g_mainFrame->m_libraryModule->UpdateMenuBar();
 }
 void SjListBrowser::OnContextMenuSelect(int id)
 {
@@ -1152,6 +1171,11 @@ void SjListBrowser::OnContextMenuSelect(int id)
 			InitCols();
 			CalcRefreshNUpdateHeaderNTracks();
 		}
+
+		if( g_mainFrame->m_viewMenu )
+		{
+			UpdateItemsInColMenu(g_mainFrame->m_viewMenu);
+		}
 	}
 	else if( id>=IDC_FIRST_COL_ID && id<=IDC_LAST_COL_ID )
 	{
@@ -1178,6 +1202,11 @@ void SjListBrowser::OnContextMenuSelect(int id)
 			}
 			CalcRefreshNUpdateHeaderNTracks();
 		}
+
+		if( g_mainFrame->m_viewMenu )
+		{
+			UpdateItemsInColMenu(g_mainFrame->m_viewMenu);
+		}
 	}
 	else
 	{
@@ -1569,6 +1598,7 @@ bool SjListBrowser::DoChangeSelection(long dir, bool selectShifted)
 
 		ScrollOneLineInView(newPos);
 		RefreshSelection();
+		g_mainFrame->m_libraryModule->UpdateMenuBar();
 		return true;
 	}
 
@@ -1619,6 +1649,7 @@ bool SjListBrowser::DoChangeSelection(long dir, bool selectShifted)
 
 	m_listView->SelectTrack(newPos, true);
 	RefreshSelection();
+	g_mainFrame->m_libraryModule->UpdateMenuBar();
 
 	return true;
 }
@@ -1885,7 +1916,7 @@ void SjListBrowser::DoPaintTrack(wxDC& dc, long x, long y, long w, long h, long
 	if( isAzPossibleForCol(m_sortField) ) // can sort by A-Z?
 	{
 		str = SjNormaliseString(ti.GetFormattedValue(m_sortField), 0);
-		thisAz = str[0];
+		thisAz = str.Len()? str[0] : 'z'+1;
 		if( thisAz < 'a' || thisAz > 'z' )
 		{
 			thisAz = 'z'+1;
@@ -1893,8 +1924,8 @@ void SjListBrowser::DoPaintTrack(wxDC& dc, long x, long y, long w, long h, long
 	}
 
 	if( lastAz != NULL
-	        && thisAz
-	        && thisAz != *lastAz )
+	 && thisAz
+	 && thisAz != *lastAz )
 	{
 		if( thisAz != 'z'+1 )
 		{
@@ -1905,7 +1936,7 @@ void SjListBrowser::DoPaintTrack(wxDC& dc, long x, long y, long w, long h, long
 	}
 
 	if(  setAz
-	        && !g_mainFrame->HasSimpleSearch())
+	 && !g_mainFrame->HasSimpleSearch())
 	{
 		g_mainFrame->SetSkinAzValues(thisAz);
 	}
@@ -2029,7 +2060,7 @@ void SjListBrowser::DoPaintHeaderNTracks(wxDC& dc, long x, long y_, long w, long
 		m_listView->GetTrack(m_scrollPos-1, ti, tiAlbumId, tiSpecial);
 
 		wxString str = SjNormaliseString(ti.GetFormattedValue(m_sortField), 0);
-		lastAz = str[0];
+		lastAz = str.Len()? str[0] : 'z'+1;
 		if( lastAz < 'a' || lastAz > 'z' )
 		{
 			lastAz = 'z'+1;
