@@ -56,6 +56,8 @@
 #define IDT_LAYOUT_LAST             96  // range end, max. 49 layouts
 #define IDT_DISPLAY_LINE_FIRST      97  // range start
 #define IDT_DISPLAY_LINE_LAST       146 // range end, max. 50 lines
+#define IDT_PRELISTEN_VOL_DOWN      147
+#define IDT_PRELISTEN_VOL_UP        148
 #define IDT_DISPLAY_UP              149
 #define IDT_DISPLAY_DOWN            150
 #define IDT_DISPLAY_V_SCROLL        151
@@ -98,10 +100,10 @@
 #define IDT_UNQUEUE                 195
 #define IDT_UNQUEUE_ALL             196
 #define IDT_MAINMENU                197
-#define IDT_START_VIS               198
+#define IDT_VIS_TOGGLE              198
 #define IDT_UPDATE_INDEX            199
 #define IDT_DEEP_UPDATE_INDEX       200
-#define IDT_SETTINGS_JUKEBOX        201
+#define IDT_SETTINGS                201
 #define IDT_WORKSPACE_GOTO_RANDOM   202
 #define IDT_STOP_AFTER_THIS_TRACK   203
 #define IDT_SHUFFLE                 204
@@ -135,6 +137,7 @@
 #define IDT_NUMPAD_RESERVED_08      240
 #define IDT_NUMPAD_LAST          240    // Range end
 #define IDT_PLAY_NOW_ON_DBL_CLICK   241
+#define IDT_PRELISTEN               242
 #define IDT_ADD_CREDIT_FIRST     243    // Range start
 #define IDT_ADD_CREDIT_01           243
 #define IDT_ADD_CREDIT_16           258
@@ -223,6 +226,19 @@
 /* [O]ther (Menu) [ID]s, IDO_*, as they're not used as a target or
  * by a modules.
  */
+#define IDO_VIS_FIRST__         4800 /* range start */
+#define IDO_VIS_STARTFIRST      4800    /* range start */
+#define IDO_VIS_STARTLAST       4848    /* range end */
+#define IDO_VIS_STOP            4849
+#define IDO_VIS_OPTIONFIRST     4850    /* range start */
+#define IDO_VIS_OPTIONLAST      4899    /* range end */
+#define IDO_VIS_HALFSIZE        4901
+#define IDO_VIS_AUTOSWITCHOVER  4902
+#define IDO_VIS_NEXTPRESET      4903
+#define IDO_VIS_PREVPRESET      4904
+#define IDO_VIS_LAST__          4920 /* range end */
+#define IDO_wxID_LOWEST         4999 /* range start, used by wx */
+#define IDO_wxID_HIGHEST        5999 /* range end, used by wx */
 #define IDO_SEARCHGENRE000      6000 /* range start */
 #define IDO_SEARCHGENRE999      6999 /* range end */
 #define IDO_SEARCHMUSICSEL000   7000 /* range start */
@@ -230,10 +246,19 @@
 #define IDO_SAMEZOOMINALLVIEWS  8000
 #define IDO_START_PB_ON_ENQUEUE 8001
 #define IDO_CORNERCLICK         8002
-#define IDO_SETTINGS_ADV        8003
 #define IDO_SETTINGS_ADDFILES   8004
 #define IDO_ESC                 8005
 #define IDO_DEBUGSKIN_RELOAD    8006
+#define IDO_DISPLAY_TRACKNR     8007
+#define IDO_DISPLAY_ARTIST      8008
+#define IDO_DISPLAY_TOTAL_TIME  8009
+#define IDO_DISPLAY_AUTOPLAY    8010
+#define IDO_DISPLAY_PREFERALBCV 8011
+#define IDO_TOGGLE_TIME_MODE2   8012
+#define IDO_SETTINGS_QUEUE      8013
+#define IDO_SETTINGS_AUTOVOL    8014
+#define IDO_SETTINGS_SKINS      8015
+#define IDO_SETTINGS_FONTNCOVER 8016
 #define IDO_SMOOTH              8109
 #define IDO_SEARCHINPUT         8110
 #define IDO_TAB                 8111
@@ -265,16 +290,18 @@
 #define IDO_DND_ONDATA          8400
 #define IDO_VIRTKEYBDFRAME      8401
 #define IDO_GOTOCURRAUTO        8402
-#define IDO_OPENSETTINGSASYNC   8403 /* SPACE Here! */
+#define IDO_OPENSETTINGSASYNC   8403
+#define IDO_SCRIPTCONFIG_MENU00 8404 /* range start */
+#define IDO_SCRIPTCONFIG_MENU99 8503 /* range end */
 #define IDO_ONLINE_HELP         8606
 #define IDO_EXPLOREQUEUE        8607
 #define IDO_BROWSER_RELOAD_VIEW 8609
 #define IDO_ABOUT_OPEN_WWW      8610
 #define IDO_ABOUT               8611
-#define IDO_EXTRAS_MENU00       8613 /* range start */
-#define IDO_EXTRAS_MENU99       8712 /* range end */
+#define IDO_SCRIPT_MENU00       8613 /* range start */
+#define IDO_SCRIPT_MENU99       8712 /* range end */
 #define IDO_CONSOLE             8713
-/* take care, we're close to end!*/
+/* take care, we're close to end! At 8800 the IDPLAYER_ IDs start! */
 
 /* [PLAYER] [ID]s, IDPLAYER_*, posted from SjPlayer -> SjMainFrame -> SjPlayer.OnPostBack()
  */
@@ -286,12 +313,12 @@
  */
 #define IDTIMER_SEARCHINPUT     8900
 #define IDTIMER_ELAPSEDTIME     8903
-#define IDTIMER_STARTUPDISPLAY  8904
 #define IDTIMER_TOOLTIPTIMER    8905
 #define IDTIMER_EFFECTINFO      8906
 #define IDTIMER_VIRTKEYBD       8907
 #define IDTIMER_TRIGGERBALLOON  8908
 #define IDTIMER_CLOSEBALLOON    8909
+#define IDTIMER_SETSIZEHACK     8910
 
 #define ID_HTTP_SERVER          8980
 #define ID_HTTP_SOCKET          8981
@@ -337,6 +364,9 @@
 #define IDC_PLUGIN_FREEDB       9229
 #define IDC_PLUGIN_LAST         9250 /* range end */
 
+#define IDC_HOOK_FIRST          9260 /* range start */
+#define IDC_HOOK_LAST           9299 /* range end*/
+
 
 /* [MOD]ule [M]e[S]sa[G]e [ID]s, IDMODMSG_*
  * send via a SjModuleSystem::BroadcastMsg() from silverjuke --> all modules
@@ -345,12 +375,8 @@
 
 #define IDMODMSG_WINDOW_ICONIZED                    11000
 #define IDMODMSG_WINDOW_UNICONIZED                  11001
-#define IDMODMSG_WINDOW_MAXIMIZED                   11002
-#define IDMODMSG_WINDOW_UNMAXIMIZED                 11003
 #define IDMODMSG_WINDOW_CLOSE                       11004 /* sent if the program is about to terminate; objects are valid, player is already stopped, window is already hidden */
-#define IDMODMSG_WINDOW_SIZE_MOVE_BEGIN             11005
 #define IDMODMSG_WINDOW_SIZED_MOVED                 11006
-#define IDMODMSG_WINDOW_SIZE_MOVE_END               11007
 #define IDMODMSG_WINDOW_BEFORE_CLOSE_HIDE_N_STOP    11008 /* send a moment before IDMODMSG_WINDOW_CLOSE is send; objects are valid, player is still playing, window is still visible */
 
 #define IDMODMSG_APP_ACTIVATED                      11010
@@ -359,8 +385,8 @@
 #define IDMODMSG_SETTINGS_CLOSE                     11020 /* sent if the settings dialog is about to be closed, needed only for very special tasks */
 #define IDMODMSG_ADV_SEARCH_CONFIG_CHANGED          11021 /* sent if adv. searches are created/deleted/modified */
 
-#define IDMODMSG_OUTPUT_CHANGED                     11031
-#define IDMODMSG_TRACK_ON_AIR_CHANGED               11032 /* also send if only the player state changes */
+#define IDMODMSG_TRACK_ON_AIR_CHANGED               11030 /* also send if only the player state changes */
+#define IDMODMSG_VIDEO_DETECTED                     11031
 #define IDMODMSG_VIS_STATE_CHANGED                  11033
 #define IDMODMSG_KIOSK_STARTING                     11034
 #define IDMODMSG_KIOSK_STARTED                      11035
@@ -374,10 +400,9 @@
 
 #define IDMODMSG__VIS_MOD_PRIVATE_1__               11051
 #define IDMODMSG__VIS_MOD_PRIVATE_2__               11052
-#define IDMODMSG__VIS_MOD_PRIVATE_3__               11053
 #define IDMODMSG__VIS_MOD_PRIVATE_4__               11054
 
-#define IDMODMSG__SEE_PROGRAM_LOADED                11060
+#define IDMODMSG_PROGRAM_LOADED                     11060 /* send to indicate, the program is loaded and the main window is shown*/
 
 #define IDMODMSG_LAST                               11999 /* range end */
 
