@@ -40,6 +40,7 @@
 #include <wx/snglinst.h>
 #include <wx/cmdline.h>
 #include <wx/tokenzr.h>
+#include <wx/socket.h>
 
 
 /*******************************************************************************
@@ -56,7 +57,7 @@ public:
 		m_isServer = isServer;
 	}
 
-	bool OnExecute(const wxString& topic, wxChar* data__, int size, wxIPCFormat format);
+	bool OnExecute(const wxString& topic, const void*, size_t, wxIPCFormat format);
 
 	bool OnDisconnect()
 	{
@@ -80,19 +81,18 @@ void SjConnection::Raise()
 	{
 		g_mainFrame->Show();
 		g_mainFrame->Iconize(FALSE);
-		wxCommandEvent fwd(wxEVT_COMMAND_MENU_SELECTED, IDMODMSG_WINDOW_UNICONIZED);
-		g_mainFrame->GetEventHandler()->AddPendingEvent(fwd);
+		g_mainFrame->GetEventHandler()->QueueEvent(new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, IDMODMSG_WINDOW_UNICONIZED));
 		g_mainFrame->Raise();
 	}
 }
 
 
-bool SjConnection::OnExecute(const wxString& topic, wxChar* data_, int size_, wxIPCFormat format_)
+bool SjConnection::OnExecute(const wxString& topic, const void* data_, size_t size_, wxIPCFormat format_)
 {
 	// can we handle the request?
 	if( SjMainApp::IsInShutdown()
-	        || g_mainFrame ==NULL
-	        || (SjMainFrame*)wxWindow::FindWindowById(IDC_MAINFRAME) == NULL )
+	 || g_mainFrame ==NULL
+	 || (SjMainFrame*)wxWindow::FindWindowById(IDC_MAINFRAME) == NULL )
 	{
 		return FALSE;
 	}
@@ -101,7 +101,7 @@ bool SjConnection::OnExecute(const wxString& topic, wxChar* data_, int size_, wx
 	wxArrayString data;
 	if( data_ )
 	{
-		wxStringTokenizer tkz(data_, wxT("\n\r"), wxTOKEN_RET_EMPTY_ALL);
+		wxStringTokenizer tkz(GetTextFromData(data_, size_, format_), "\n\r", wxTOKEN_RET_EMPTY_ALL);
 		while( tkz.HasMoreTokens() )
 		{
 			wxString token = tkz.GetNextToken();
@@ -134,7 +134,7 @@ bool SjConnection::OnExecute(const wxString& topic, wxChar* data_, int size_, wx
 	}
 	else if( topic==wxT("toggle") )
 	{
-		g_mainFrame->PlayOrPause(false /*no fade to play/pause*/);
+		g_mainFrame->PlayOrPause();
 	}
 	else if( topic==wxT("togglevis") )
 	{
@@ -153,7 +153,7 @@ bool SjConnection::OnExecute(const wxString& topic, wxChar* data_, int size_, wx
 	}
 	else if( topic==wxT("prev") )
 	{
-		g_mainFrame->GotoPrev(false /*no fade to next*/);
+		g_mainFrame->GotoPrev();
 	}
 	else if( topic==wxT("next") )
 	{
@@ -177,7 +177,7 @@ bool SjConnection::OnExecute(const wxString& topic, wxChar* data_, int size_, wx
 			data0.Replace(wxT("'"), wxT(""));   // data into a binary form otherwise.
 
 			long addCredit = 0;
-			data0.ToLong(&addCredit, 10);
+			if( !data0.ToLong(&addCredit, 10) ) { addCredit = 0; }
 			if( g_kioskModule )
 			{
 				g_kioskModule->m_creditBase.AddCredit(addCredit,
@@ -187,10 +187,17 @@ bool SjConnection::OnExecute(const wxString& topic, wxChar* data_, int size_, wx
 			}
 		}
 	}
+	else if( topic=="displaymsg" ) // this is mainly for testing IPC
+	{
+		if( data.GetCount() )
+		{
+			g_mainFrame->SetDisplayMsg(data[0], 10000);
+		}
+	}
 	else if( topic==wxT("execute") )
 	{
 		#if SJ_USE_SCRIPTS
-			g_mainFrame->CmdLineAndDdeSeeExecute(data_);
+			g_mainFrame->CmdLineAndDdeSeeExecute(GetTextFromData(data_, size_, format_));
 		#else
 			wxLogError(wxT("Scripts are not supported in this build."));
 		#endif
@@ -254,26 +261,30 @@ bool SjMainApp::OnInit()
 	// call OnFatalException()
 	//::wxHandleFatalExceptions(true);
 
+	// init HTTP stuff - absolutely neccessary before any thread can use HTTP - eg. SjHttp or SjImgThread or maybe the player
+	// see also http://www.litwindow.com/Knowhow/wxSocket/wxsocket.html
+	wxSocketBase::Initialize();
+
 	// set our logging routines
 	s_logGui = new SjLogGui();
 
 	// log silverjuke and platform version and release information
-	wxLogInfo(wxT("Silverjuke %s Rev. %i started (%i Bit%s%s%s on %s (%i Bit), %s, sqlite %s)"),
-	          SJ_VERSION_STR, SJ_VERSION_REVISION, sizeof(void*)*8,
+	wxLogInfo(wxT("Silverjuke %i.%i.%i-%ibit-%s%s%s started on %s-%ibit, %s, sqlite %s"),
+	          SJ_VERSION_MAJOR, SJ_VERSION_MINOR, SJ_VERSION_REVISION, (int)(sizeof(void*)*8),
 	          #ifdef wxUSE_UNICODE
-	              wxT(" Unicode"),
+	              wxT("u"),
+	          #else
+	              wxT("a"),
+	          #endif
+	          #ifdef __WXDEBUG__
+                  wxT("d"),
 	          #else
 	              wxT(""),
 	          #endif
-	          #ifdef __WXDEBUG__
-                  wxT(" Debug"),
-	          #else
-				wxT(""),
-	          #endif
 	          #if SJ_USE_SCRIPTS
-	            wxT(" Scriptable"),
+	              wxT("s"),
 	          #else
-				wxT(""),
+	              wxT(""),
 	          #endif
 	          ::wxGetOsDescription().c_str(), ::wxIsPlatform64Bit()? 64 : 32,
 	          wxVERSION_STRING,
@@ -304,12 +315,14 @@ bool SjMainApp::OnInit()
 		{ wxCMD_LINE_SWITCH, NULL, wxT_2("enqueue"),     wxT_2("Enqueue the given file(s)") },
 		{ wxCMD_LINE_OPTION, NULL, wxT_2("setcredit"),   wxT_2("Set the number of credits in the credit system"), wxCMD_LINE_VAL_NUMBER },
 		{ wxCMD_LINE_OPTION, NULL, wxT_2("addcredit"),   wxT_2("Add the number of credits to the credit system"), wxCMD_LINE_VAL_NUMBER },
+		{ wxCMD_LINE_OPTION, NULL, wxT_2("displaymsg"),  wxT_2("Show the given message on the display"), wxCMD_LINE_VAL_STRING }, // this is mainly for testing IPC
 		{ wxCMD_LINE_OPTION, NULL, wxT_2("execute"),     wxT_2("Execute the given scripting commands") },
 		// environment settings
 		{ wxCMD_LINE_SWITCH, NULL, wxT_2("skiperrors"),  wxT_2("Do not show startup errors") },
 		{ wxCMD_LINE_SWITCH, NULL, wxT_2("minimize"),    wxT_2("Start minimized") },
-		{ wxCMD_LINE_OPTION, NULL, wxT_2("kioskrect"),   wxT_2("The window rectangle for the kiosk mode as [<x>,<y>,]<w>,<h>[,clipmouse]") },
-		{ wxCMD_LINE_OPTION, NULL, wxT_2("visrect"),     wxT_2("The window rectangle for the vis. in kiosk mode as [<x>,<y>,]<w>,<h>") },
+		{ wxCMD_LINE_OPTION, NULL, wxT_2("kioskrect"),   wxT_2("Where to show the kiosk: DISPLAY|X,Y,W,H[,clipmouse]") },
+		{ wxCMD_LINE_OPTION, NULL, wxT_2("visrect"),     wxT_2("Where to show the video screen: DISPLAY|X,Y,W,H") },
+		{ wxCMD_LINE_OPTION, NULL, wxT_2("blackrect"),   wxT_2("Add black areas: DISPLAY|X,Y,W,H[;DISPLAY,X,Y,W,H;...]") },
 		{ wxCMD_LINE_OPTION, NULL, wxT_2("instance"),    wxT_2("Set the configuration file and the instance to use") },
 		{ wxCMD_LINE_OPTION, NULL, wxT_2("ini"),         wxT_2("Set the configuration file to use") },
 		{ wxCMD_LINE_OPTION, NULL, wxT_2("jukebox"),     wxT_2("Set the jukebox file to use") },
@@ -323,7 +336,11 @@ bool SjMainApp::OnInit()
 	{
 		FatalError();
 	}
-	s_cmdLine->Parse();
+
+	if( s_cmdLine->Parse() != 0 /*-1: help option shown, >0 syntax error*/ )
+	{
+		return FALSE;
+	}
 
 	// create tools to use, the tools are deleted if SjMainFrame is deleted
 	g_tools = new SjTools;
@@ -369,11 +386,11 @@ bool SjMainApp::OnInit()
 
 				// get topic ("raise", "open" or one of the command line switches)
 				wxString topic(data.IsEmpty()? wxT("raise") : wxT("open")), valString;
-				long valLong;
+				long valLong = 0;
 				for( i = 0; i < (int)(sizeof(s_cmdLineDesc)/sizeof(wxCmdLineEntryDesc)); i++ )
 				{
 					if( s_cmdLineDesc[i].kind == wxCMD_LINE_SWITCH
-					        && s_cmdLine->Found(s_cmdLineDesc[i].longName) )
+					 && s_cmdLine->Found(s_cmdLineDesc[i].longName) )
 					{
 						topic = s_cmdLineDesc[i].longName;
 						break;
@@ -381,7 +398,7 @@ bool SjMainApp::OnInit()
 					else if( s_cmdLineDesc[i].kind == wxCMD_LINE_OPTION )
 					{
 						if( s_cmdLineDesc[i].type == wxCMD_LINE_VAL_NUMBER
-						        && s_cmdLine->Found(s_cmdLineDesc[i].longName, &valLong) )
+						 && s_cmdLine->Found(s_cmdLineDesc[i].longName, &valLong) )
 						{
 							topic = s_cmdLineDesc[i].longName;
 							data = wxString::Format(wxT("%i"), (int)valLong);
@@ -400,7 +417,7 @@ bool SjMainApp::OnInit()
 				wxConnectionBase* connection = client->MakeConnection(wxT("localhost"), serviceName, topic);
 				if( connection )
 				{
-					executedSuccessfully = connection->Execute(static_cast<const wxChar*>(data.c_str()), -1);
+					executedSuccessfully = connection->Execute(data);
 					connection->Disconnect();
 					delete connection;
 				}
@@ -424,8 +441,8 @@ bool SjMainApp::OnInit()
 			// There's nothing more we can do here.  We check IsAnotherRunning() again as the prev.
 			// instance may be terminted completly from our last check (see above).
 			if( executedSuccessfully
-			        || s_isRunningChecker == NULL
-			        || s_isRunningChecker->IsAnotherRunning() )
+			 || s_isRunningChecker == NULL
+			 || s_isRunningChecker->IsAnotherRunning() )
 			{
 				if( s_isRunningChecker ) { delete s_isRunningChecker; s_isRunningChecker = NULL; }
 				delete g_tools;
@@ -471,10 +488,6 @@ int SjMainApp::OnExit()
 	 */
 	SjExitID3Etc();
 
-	/* shutdown HTTP-services
-	 */
-	SjHttp::OnSilverjukeShutdown();
-
 	/* client and server
 	 */
 	if( s_server )
@@ -516,6 +529,10 @@ int SjMainApp::OnExit()
 	delete SjModuleSystem::s_delayedDbDelete;
 	SjModuleSystem::s_delayedDbDelete = NULL;
 
+	/* shutdown HTTP-services
+	 */
+	wxSocketBase::Shutdown();
+
 	/* done.
 	 */
 	return 0;
@@ -539,7 +556,7 @@ void SjMainApp::OnQueryEndSession(wxCloseEvent& event)
 		SjMainFrame* mainFrame = (SjMainFrame*)GetTopWindow();
 		if( mainFrame )
 		{
-			if( mainFrame->QueryEndSession(TRUE/*onShutdown*/) )
+			if( !event.CanVeto() || mainFrame->QueryEndSession(TRUE/*onShutdown*/) )
 			{
 				mainFrame->DoEndSession();
 			}
@@ -573,7 +590,7 @@ void SjMainApp::DoShutdownEtc(SjShutdownEtc action, long restoreOrgVol)
 	if( action>=SJ_SHUTDOWN_USER_DEF_SCRIPT && action<=SJ_SHUTDOWN_USER_DEF_SCRIPT_LAST )
 	{
 		#if SJ_USE_SCRIPTS
-			SjSee::OnGlobalEmbedding(SJ_PERSISTENT_EXIT_OPTION, action-SJ_SHUTDOWN_USER_DEF_SCRIPT);
+			SjSee::OnGlobalEmbedding(SJ_PERSISTENT_EXIT_OPTION_deprecated, action-SJ_SHUTDOWN_USER_DEF_SCRIPT);
 		#endif
 		return;
 	}
