@@ -79,7 +79,7 @@ public:
 	void            Play                (long ms=0) { m_player.Play(ms); m_haltedManually=FALSE; UpdateDisplay(); }
 	void            Pause               ()       { m_player.Pause(); m_haltedManually=TRUE; UpdateDisplay(); }
 	void            Stop                () { m_player.Stop(); m_haltedManually=TRUE; UpdateDisplay(); }
-	void            PlayOrPause         (bool fadeToPlayOrPause) { m_player.PlayOrPause(fadeToPlayOrPause); m_haltedManually=m_player.IsPaused(); UpdateDisplay(); }
+	void            PlayOrPause         () { m_player.PlayOrPause(); m_haltedManually=m_player.IsPaused(); UpdateDisplay(); }
 	void            ReplayIfPlaying     ();
 	void            SeekAbs             (long m) { m_player.SeekAbs(m); UpdateDisplay(); }
 	void            SeekRel             (long m) { m_player.SeekRel(m); UpdateDisplay(); }
@@ -90,8 +90,8 @@ public:
 	void            UpdateEnqueuedUrl   (const wxString& url, bool urlVerified, long playtimeMs) { m_player.m_queue.UpdateUrl(url, urlVerified, playtimeMs); }
 	void            GotoAbsPos          (long p) { m_player.GotoAbsPos(p); m_display.m_scrollPos=-1; }
 	void            GotoUrl             (const wxString& url) { m_player.GotoUrl(url); m_display.m_scrollPos=-1; if(!IsPlaying()) {UpdateDisplay();} }
-	void            GotoPrev            (bool fadeToPrev) { m_player.GotoPrev(fadeToPrev); m_display.m_scrollPos=-1; if(!IsPlaying()) {UpdateDisplay();} }
-	void            GotoNextRegardAP    (bool fadeToNext);
+	void            GotoPrev            () { m_player.GotoPrev(); m_display.m_scrollPos=-1; if(!IsPlaying()) {UpdateDisplay();} }
+	bool            GotoNextRegardAP    (bool fadeToNext, bool ignoreTimeouts=true);
 	void            SetAbsMainVol       (long v);
 	void            SetRelMainVol       (long v) { SetAbsMainVol(m_player.GetMainVol()+v); }
 	long            GetMainVol          () const { return m_player.GetMainVol(); }
@@ -164,7 +164,7 @@ public:
 	long            GetBaseColumnWidth  () const { return m_baseColumnWidth; }
 	long            GetBaseCoverHeight  () const { return m_baseCoverHeight; }
 	void            SetFontNCoverBase   (const wxString& fontFace, long fontSize, long columnWidth, long coverHeight);
-	void            SetDefaultWindowSize(bool init=FALSE);
+	void            SetDefaultWindowSize();
 
 	long            m_currColumnWidth,
 	                m_currCoverWidth,
@@ -194,29 +194,23 @@ public:
 
 	// Menu Stuff
 public:
-	void            AllocMainMenu       ();
-	void            InitMainMenu        ();
-	void            CreateContextMenu_  (SjMenu&, bool prependOpen, int idmSettings=IDT_SETTINGS_JUKEBOX, bool appendGotoCurrMark=FALSE, bool embedFastSearch=FALSE);
-	void            CreatePlaybackMenu  (SjMenu* playbackMenu, bool createMainMenu);
-	void            CreateKioskMenu     (SjMenu* extrasMenu);
-	void            CreateExtrasMenu    (SjMenu* extrasMenu);
-	void            UpdateExtrasMenu    ();
-	void            CreateViewMenu      (SjMenu* viewMenu, bool createMainMenu, bool appendGotoCurrMark=FALSE);
+	void            CreateMainMenu      ();
+	void            UpdateMainMenu      ();
+	void            CreateContextMenu_  (SjMenu&, bool embedFastSearch=FALSE);
+	void            CreatePlaybackMenu  (SjMenu*);
+	void            UpdateViewMenu      ();
 	void            CreateUnqueueMenu   (SjMenu&);
 	void            CreateSearchMenu    (SjMenu&);
+	void            AddScriptMenuEntries(SjMenu&);
 	#if SJ_USE_TOOLTIPS
-	SjMainFrameToolTipProvider
-	m_toolTipProvider;
-	SjToolTipProvider*
-	GetToolTipProvider  (long targetId, long subitem, const wxRect& rect) { m_toolTipProvider.m_targetId = targetId; m_toolTipProvider.m_subitem = subitem; m_toolTipProvider.m_rect = rect; return &m_toolTipProvider; }
+	SjMainFrameToolTipProvider m_toolTipProvider;
+	SjToolTipProvider* GetToolTipProvider  (long targetId, long subitem, const wxRect& rect) { m_toolTipProvider.m_targetId = targetId; m_toolTipProvider.m_subitem = subitem; m_toolTipProvider.m_rect = rect; return &m_toolTipProvider; }
 	#endif
-	SjMenu          *m_fileMenu, *m_editMenu, *m_viewMenu, *m_playbackMenu, *m_kioskMenu, *m_extrasMenu, *m_helpMenu;
-private:
+	SjMenu          *m_fileMenu, *m_editMenu, *m_editExtrasMenu, *m_viewMenu, *m_viewColMenu, *m_playbackMenu, *m_visMenu, *m_kioskMenu, *m_helpMenu;
 	wxMenuBar*      m_menuBar;
-	bool            m_menuBarComplete;
+private:
 	void            UpdateMenuBarValue  (int targetId, const SjSkinValue& v);
 	void            UpdateMenuBarQueue  ();
-	void            UpdateMenuBarView   ();
 
 	// Allowed Operations (in Kiosk Mode), see SJ_OP_* in skin.h
 public:
@@ -256,8 +250,6 @@ public:
 	SjDisplay       m_display;
 private:
 	// Display stuff - Private
-	bool            DisplayBusyInfo     (const wxString& text, bool forceUpdateForLongOp);
-	void            OnStartupDisplayTimer(wxTimerEvent&) { m_display.m_showStartupDisplay=FALSE; UpdateDisplay(); }
 	void            MarkDisplayTrack    (int targetId, bool mouseDown, long accelFlags);
 	void            OnSkinTargetMotion  (int targetId, int motionAmount);
 	void            OnSkinDisplayEvent  (int targetId, SjSkinValue&, long accelFlags);
@@ -345,20 +337,18 @@ private:
 	void            OnCloseWindow       (wxCloseEvent&);
 	void            OnIconizeWindow     (wxIconizeEvent&);
 	void            OnElapsedTimeTimer  (wxTimerEvent&);
+	void            OnMouseWheel        (wxMouseEvent&);
 
 	DECLARE_EVENT_TABLE ();
 
 	friend class    SjMainFrameToolTipProvider;
-	friend class    SjBusyInfo; // for calling DisplayBusyInfo()
 	friend class    SjBasicSettingsConfigPage; // for m_locale
 	friend class    SjKioskModule;
 	friend class    SjDisplayEditDlg;
 	friend class    SjAutoCtrl;
 	friend class    SjDisplay;
 	friend class    SjAutoFader;
-#ifdef __WXDEBUG__
 	friend class    SjTagEditorDlg;
-#endif
 };
 
 
