@@ -40,154 +40,141 @@
  ******************************************************************************/
 
 
-void SjMainFrame::AllocMainMenu()
+void SjMainFrame::CreateMainMenu()
 {
-	// This function just sets the menu titles,
-	// so that they are visible on load directly after showing the window.
-	// This function is called very soon - don't assume any modules to be loaded.
-	//
-	// More menu entries are set in InitMainMenu() when eg. all modules are
-	// loaded.
+	// set up operating-system specific stuff, should be done before the menu bar is really created
+	#ifdef __WXMAC__
+		wxApp::s_macHelpMenuTitleName = _("Help");
+		wxApp::s_macAboutMenuItemId = IDO_ABOUT;
+		wxApp::s_macPreferencesMenuItemId = IDT_SETTINGS;
+		wxApp::s_macExitMenuItemId = IDT_QUIT;
+	#endif
 
+	// create menu bar
 	m_menuBar = new wxMenuBar();
 
+	// create menus
 	m_fileMenu = new SjMenu(SJ_SHORTCUTS_LOCAL);
-	m_menuBar->Append(m_fileMenu, _("File"));
-
 	m_editMenu = new SjMenu(SJ_SHORTCUTS_LOCAL);
-	m_menuBar->Append(m_editMenu, _("Edit"));
-
 	m_viewMenu = new SjMenu(SJ_SHORTCUTS_LOCAL);
-	m_menuBar->Append(m_viewMenu, _("View"));
-
 	m_playbackMenu = new SjMenu(SJ_SHORTCUTS_LOCAL);
-	m_menuBar->Append(m_playbackMenu, _("Playback"));
-
+	m_visMenu = new SjMenu(SJ_SHORTCUTS_LOCAL);
 	m_kioskMenu = new SjMenu(SJ_SHORTCUTS_LOCAL);
-	m_menuBar->Append(m_kioskMenu, _("Kiosk mode"));
-
-	m_extrasMenu = new SjMenu(SJ_SHORTCUTS_LOCAL);
-	m_menuBar->Append(m_extrasMenu, _("Extras"));
-
 	m_helpMenu = new SjMenu(SJ_SHORTCUTS_LOCAL);
+
+	// create "file" menu
+	m_fileMenu->Append(IDO_SETTINGS_ADDFILES, _("Add folders and files")+wxString("..."));
+	m_fileMenu->Append(IDT_UPDATE_INDEX);
+	m_fileMenu->AppendSeparator();
+	m_fileMenu->Append(IDT_OPEN_FILES);
+	m_fileMenu->Append(IDT_SAVE_PLAYLIST);
+	m_fileMenu->Append(IDT_UNQUEUE_ALL);
+	m_fileMenu->AppendSeparator();
+	m_fileMenu->Append(IDT_QUIT);
+
+	// create "edit" menu
+	m_libraryModule->CreateMenu(m_playbackMenu, m_editMenu, TRUE);
+	m_editExtrasMenu = new SjMenu(SJ_SHORTCUTS_LOCAL);
+	m_editMenu->Append(0, _("Extensions"), m_editExtrasMenu);
+	m_editMenu->AppendSeparator();
+	m_editMenu->Append(IDO_SELECTALL);
+	m_editMenu->AppendSeparator();
+	m_editMenu->Append(IDT_SEARCH_BUTTON);
+	m_editMenu->Append(IDT_ADV_SEARCH);
+	m_editMenu->Append(IDO_REALLYENDSEARCH, _("End search"));
+	m_editMenu->AppendSeparator();
+	m_editMenu->Append(IDT_SETTINGS);
+
+	// create "view" menu
+	m_viewMenu->AppendRadioItem(IDT_WORKSPACE_ALBUM_VIEW);
+	m_viewMenu->AppendRadioItem(IDT_WORKSPACE_COVER_VIEW);
+	m_viewMenu->AppendRadioItem(IDT_WORKSPACE_LIST_VIEW);
+	m_viewMenu->Append(IDT_WORKSPACE_TOGGLE_VIEW);
+	m_viewMenu->AppendSeparator();
+	SjMenu* submenu = new SjMenu(SJ_SHORTCUTS_LOCAL);
+		submenu->AppendCheckItem(IDT_TOGGLE_TIME_MODE, _("Show remaining time"));
+		submenu->AppendCheckItem(IDO_TOGGLE_TIME_MODE2, _("Show elapsed time"));
+		submenu->AppendCheckItem(IDO_DISPLAY_TOTAL_TIME, _("Show total time"));
+		submenu->AppendCheckItem(IDO_DISPLAY_TRACKNR, _("Show track number"));
+		submenu->AppendCheckItem(IDO_DISPLAY_ARTIST, _("Show artist name"));
+		submenu->AppendCheckItem(IDO_DISPLAY_AUTOPLAY, _("Show AutoPlay"));
+		submenu->AppendCheckItem(IDO_DISPLAY_PREFERALBCV, _("Prefer album- to track-cover"));
+	m_viewMenu->Append(0, _("Display"), submenu);
+	m_viewColMenu = new SjMenu(SJ_SHORTCUTS_LOCAL);
+	m_viewMenu->Append(0, _("Columns"), m_viewColMenu);
+	submenu = new SjMenu(SJ_SHORTCUTS_LOCAL);
+		submenu->Append(IDT_ZOOM_IN);
+		submenu->Append(IDT_ZOOM_OUT);
+		submenu->Append(IDT_ZOOM_NORMAL);
+		submenu->AppendSeparator();
+		submenu->AppendCheckItem(IDO_SAMEZOOMINALLVIEWS, _("Same zoom in all views"));
+		submenu->Append(IDO_SETTINGS_FONTNCOVER, _("Fonts and covers")+wxString("..."));
+	m_viewMenu->Append(0, _("Zoom"), submenu);
+	m_viewMenu->Append(IDO_SETTINGS_SKINS, _("Skins")+wxString("..."));
+	m_viewMenu->AppendSeparator();
+	m_viewMenu->Append(IDT_GOTO_CURR);
+	m_viewMenu->Append(IDT_WORKSPACE_GOTO_RANDOM);
+	m_viewMenu->Append(IDT_WORKSPACE_GOTO_PREV_AZ);
+	m_viewMenu->Append(IDT_WORKSPACE_GOTO_NEXT_AZ);
+	m_viewMenu->AppendSeparator();
+	m_viewMenu->AppendCheckItem(IDT_ALWAYS_ON_TOP);
+
+	// init "playback" menu
+	m_playbackMenu->AppendSeparator();
+	CreatePlaybackMenu(m_playbackMenu);
+
+	// init "video screen" menu is done in UpdateVisMenu() below.
+
+	// create "kiosk" menu
+	m_kioskMenu->Append(IDT_TOGGLE_KIOSK, _("Start kiosk mode..."));
+
+	// create "help" menu
+	m_helpMenu->Append(IDO_ABOUT_OPEN_WWW, wxString::Format(_("%s on the web"), SJ_PROGRAM_NAME)+wxString(wxT("...")));
+	m_helpMenu->Append(IDO_ONLINE_HELP, _("All files")+wxString(wxT("...")));
+	m_helpMenu->AppendSeparator();
+	m_helpMenu->Append(IDO_CONSOLE);
+	m_helpMenu->AppendSeparator();
+	m_helpMenu->Append(IDO_ABOUT, wxString::Format(_("About %s"), SJ_PROGRAM_NAME)+wxString(wxT("...")));
+	#ifdef SJHOOK_INIT_MAIN_MENU
+	SJHOOK_INIT_MAIN_MENU
+	#endif
+
+	// append menus to menu bar
+	// (wxMenuBar::Append() should be called with all items added to the menu to append; this allows eg. OS X to move menu items around)
+	m_menuBar->Append(m_fileMenu, _os(_("File")));
+	m_menuBar->Append(m_editMenu, _("Edit"));
+	m_menuBar->Append(m_viewMenu, _os(_("View")));
+	m_menuBar->Append(m_playbackMenu, _("Playback"));
+	m_menuBar->Append(m_visMenu, _("Video screen"));
+	m_menuBar->Append(m_kioskMenu, _("Kiosk mode"));
 	m_menuBar->Append(m_helpMenu, _("Help"));
 
-	#ifndef __WXMAC__
-		SetMenuBar(m_menuBar);
-	#endif
 }
 
 
-void SjMainFrame::InitMainMenu()
+void SjMainFrame::UpdateMainMenu()
 {
-	// Add the menu entries to the menu titles allocated in AllocMainMenu().
+	if( m_menuBar == NULL || m_fileMenu == NULL || m_libraryModule == NULL || m_editMenu == NULL || m_visMenu == NULL || g_visModule == NULL ) return;
 
-	if( m_menuBar )
-	{
-		// mac specific
+    bool enableQueue = m_player.m_queue.GetCount()!=0;
+    m_fileMenu->Enable(IDT_SAVE_PLAYLIST, enableQueue);
+    m_fileMenu->Enable(IDT_UNQUEUE_ALL, enableQueue);
 
-		#ifdef __WXMAC__
-		wxApp::s_macHelpMenuTitleName = _("Help");
-		wxApp::s_macAboutMenuItemId = IDO_ABOUT_SILVERJUKE;
-		wxApp::s_macExitMenuItemId = IDT_QUIT;
-		#endif
+    m_libraryModule->UpdateMenuBar();
 
-		// file menu - do not update as there are problems with the MAC-specific items
+	m_editMenu->Enable(IDO_REALLYENDSEARCH, HasAnySearch());
 
-		if( !m_menuBarComplete )
-		{
-			bool enableQueue = m_player.m_queue.GetCount()!=0;
+	UpdateMenuBarQueue();
+	UpdateViewMenu();
 
-			m_fileMenu->Append(IDO_SETTINGS_ADDFILES, _("Add folders and files")+wxString(wxT("..."))); // just a second menu entry with the same funktionality to make things clearer
-			m_fileMenu->Append(IDT_UPDATE_INDEX);
+	g_visModule->UpdateVisMenu(m_visMenu);
 
-			m_fileMenu->AppendSeparator();
-
-			m_fileMenu->Append(IDT_OPEN_FILES);
-			m_fileMenu->Append(IDT_SAVE_PLAYLIST);
-			m_fileMenu->Enable(IDT_SAVE_PLAYLIST, enableQueue);
-
-			m_fileMenu->Append(IDT_UNQUEUE_ALL);
-			m_fileMenu->Enable(IDT_UNQUEUE_ALL, enableQueue);
-
-			m_fileMenu->AppendSeparator();
-
-			m_fileMenu->Append(IDT_SETTINGS_JUKEBOX);
-
-			m_fileMenu->AppendSeparator();
-
-			m_fileMenu->Append(IDT_QUIT);
-		}
-
-		// edit menu
-
-		m_editMenu->Clear();
-		m_playbackMenu->Clear(); // clear here as partly initalized with m_libraryModule->CreateMenu()
-
-		m_libraryModule->CreateMenu(m_playbackMenu, m_editMenu, TRUE);
-		m_libraryModule->UpdateMenuBar();
-
-		m_editMenu->AppendSeparator();
-
-		m_editMenu->Append(IDO_SELECTALL);
-
-		m_editMenu->AppendSeparator();
-
-		m_editMenu->Append(IDT_SEARCH_BUTTON);
-
-		m_editMenu->Append(IDT_ADV_SEARCH);
-
-		m_editMenu->Append(IDO_REALLYENDSEARCH, _("End search"));
-		m_editMenu->Enable(IDO_REALLYENDSEARCH, HasAnySearch());
-
-		m_editMenu->AppendSeparator();
-
-		m_editMenu->Append(IDT_SETTINGS_JUKEBOX);
-
-		// view menu
-
-		m_viewMenu->Clear();
-
-		CreateViewMenu(m_viewMenu, TRUE);
-
-		// playback menu
-
-		m_playbackMenu->AppendSeparator();
-
-		CreatePlaybackMenu(m_playbackMenu, TRUE);
-
-		// kiosk menu
-		if( !m_menuBarComplete )
-		{
-			CreateKioskMenu(m_kioskMenu);
-		}
-
-		// extras menu
-		m_extrasMenu->Clear();
-		CreateExtrasMenu(m_extrasMenu);
-
-		// help menu - do not update as there are problems with the MAC-specific items
-
-		if( !m_menuBarComplete )
-		{
-			m_helpMenu->Append(IDO_ABOUT_OPEN_WWW, wxString::Format(_("%s on the web"), SJ_PROGRAM_NAME)+wxString(wxT("...")));
-			m_helpMenu->Append(IDO_ONLINE_HELP, _("Online help")+wxString(wxT("...")));
-			m_helpMenu->AppendSeparator();
-			m_helpMenu->Append(IDO_ABOUT, wxString::Format(_("About %s"), SJ_PROGRAM_NAME)+wxString(wxT("...")));
-		}
-
-		#ifdef __WXMAC__
-		if( !m_menuBarComplete )
-		{
-			SetMenuBar(m_menuBar);
-		}
-		#endif
-
-		m_menuBarComplete = TRUE;
-
-		m_libraryModule->UpdateMenuBar();
-
-		UpdateMenuBarQueue();
+	// update scripts menu
+    m_editExtrasMenu->Clear();
+	AddScriptMenuEntries(*m_editExtrasMenu);
+	if( m_editExtrasMenu->GetMenuItemCount() == 0 ) {
+		m_editExtrasMenu->Append(IDO_SCRIPT_MENU99, _("None"));
+		m_editExtrasMenu->Enable(IDO_SCRIPT_MENU99, false);
 	}
 }
 
@@ -195,7 +182,7 @@ void SjMainFrame::InitMainMenu()
 void SjMainFrame::UpdateMenuBarValue(int targetId, const SjSkinValue& v)
 {
 	// update the menu bar - if any
-	if( !m_menuBarComplete ) return;
+	if( m_menuBar == NULL ) return;
 
 	switch( targetId )
 	{
@@ -231,14 +218,22 @@ void SjMainFrame::UpdateMenuBarValue(int targetId, const SjSkinValue& v)
 			break;
 
 		case IDT_REPEAT:
-			if( v.value==1 ) { m_playbackMenu->SetLabel(IDT_REPEAT, _("Repeat one")); }
-			else if( v.value==2 ) { m_playbackMenu->SetLabel(IDT_REPEAT, _("Repeat all")); }
-			else                  { m_playbackMenu->SetLabel(IDT_REPEAT, _("Repeat playlist")); }
-			m_playbackMenu->Check(IDT_REPEAT, v.value!=0);
+			if( m_playbackMenu )
+			{
+					 if( v.value==1 ) { m_playbackMenu->SetLabel(IDT_REPEAT, _("Repeat one")); }
+				else if( v.value==2 ) { m_playbackMenu->SetLabel(IDT_REPEAT, _("Repeat all")); }
+				else                  { m_playbackMenu->SetLabel(IDT_REPEAT, _("Repeat playlist")); }
+				m_playbackMenu->Check(IDT_REPEAT, v.value!=0);
+			}
 			break;
 
 		case IDT_WORKSPACE_ALBUM_VIEW: // IDT_WORKSPACE_ALBUM_VIEW, IDT_WORKSPACE_COVER_VIEW and IDT_WORKSPACE_LIST_VIEW always come "together"; so catching one event is sufficient here
-			m_viewMenu->SetLabel(IDT_WORKSPACE_SHOW_COVERS, m_browser->GetView()==SJ_BROWSER_COVER_VIEW? _("Show album name") : _("Show covers") );
+			UpdateViewMenu();
+			UpdateMenuBarQueue();
+			if( m_libraryModule )
+			{
+				m_libraryModule->UpdateMenuBar();
+			}
 			break;
 
 		case IDT_SEARCH_BUTTON:
@@ -246,12 +241,13 @@ void SjMainFrame::UpdateMenuBarValue(int targetId, const SjSkinValue& v)
 			break;
 
 		case IDT_TOGGLE_TIME_MODE:
+		case IDO_TOGGLE_TIME_MODE2:
 			UpdateMenuBarQueue();
 			break;
 
-		case IDT_START_VIS:
+		case IDT_VIS_TOGGLE:
 			if( g_visModule ) {
-				m_menuBar->Check(IDT_START_VIS, g_visModule->IsVisStarted());
+				g_visModule->UpdateVisMenu(m_visMenu);
 			}
 			break;
 	}
@@ -261,94 +257,65 @@ void SjMainFrame::UpdateMenuBarValue(int targetId, const SjSkinValue& v)
 void SjMainFrame::UpdateMenuBarQueue()
 {
 	// update the menu bar - if any
-	if( !m_menuBarComplete ) return;
+	if( m_menuBar == NULL || m_viewMenu == NULL ) return;
 
 	bool enableQueue = m_player.m_queue.GetCount()!=0;
 
-	m_viewMenu->SetLabel(IDT_TOGGLE_TIME_MODE, m_showRemainingTime? _("Show elapsed time") : _("Show remaining time"));
-	m_viewMenu->Enable(IDT_TOGGLE_TIME_MODE, enableQueue);
-
 	m_menuBar->Enable(IDT_GOTO_CURR, enableQueue);
+
+	m_viewMenu->Check (IDT_TOGGLE_TIME_MODE, m_showRemainingTime);
+	m_viewMenu->Check (IDO_TOGGLE_TIME_MODE2, !m_showRemainingTime);
+	m_viewMenu->Check (IDO_DISPLAY_TOTAL_TIME, (m_skinFlags&SJ_SKIN_SHOW_DISPLAY_TOTAL_TIME)!=0);
+	m_viewMenu->Check (IDO_DISPLAY_TRACKNR, (m_skinFlags&SJ_SKIN_SHOW_DISPLAY_TRACKNR)!=0);
+	m_viewMenu->Check (IDO_DISPLAY_ARTIST, (m_skinFlags&SJ_SKIN_SHOW_DISPLAY_ARTIST)!=0);
+	m_viewMenu->Check (IDO_DISPLAY_AUTOPLAY, (m_skinFlags&SJ_SKIN_SHOW_DISPLAY_AUTOPLAY)!=0);
+	m_viewMenu->Check (IDO_DISPLAY_PREFERALBCV, (m_skinFlags&SJ_SKIN_PREFER_TRACK_COVER)==0);
 }
 
 
-void SjMainFrame::UpdateMenuBarView()
-{
-	m_viewMenu->Check(IDO_SAMEZOOMINALLVIEWS, (g_accelModule->m_flags&SJ_ACCEL_SAME_ZOOM_IN_ALL_VIEWS)!=0);
-}
-
 
 /*******************************************************************************
  * The view menu
  ******************************************************************************/
 
 
-void SjMainFrame::CreateViewMenu(SjMenu* viewMenu, bool createMainMenu, bool appendGotoCurrMark)
+void SjMainFrame::UpdateViewMenu()
 {
+	if( m_viewMenu == NULL || m_viewColMenu == NULL ) return;
+
 	bool enableQueue = m_player.m_queue.GetCount()!=0;
 
-	if( appendGotoCurrMark )
+	m_viewMenu->Enable(IDT_GOTO_CURR, enableQueue);
+
+	if( m_browser )
 	{
-		viewMenu->Append(IDO_GOTO_CURR_MARK);
+		int view = m_browser->GetView();
+		m_viewMenu->Check(IDT_WORKSPACE_ALBUM_VIEW, (view==SJ_BROWSER_ALBUM_VIEW));
+		m_viewMenu->Check(IDT_WORKSPACE_COVER_VIEW, (view==SJ_BROWSER_COVER_VIEW));
+		m_viewMenu->Check(IDT_WORKSPACE_LIST_VIEW, (view==SJ_BROWSER_LIST_VIEW));
+
+		m_viewColMenu->Clear();
+		m_viewColMenu->AppendCheckItem(IDT_WORKSPACE_SHOW_COVERS, (m_browser->GetView()==SJ_BROWSER_COVER_VIEW)? _("Show cover titles") : _("Show covers"));
+		m_viewColMenu->Check(IDT_WORKSPACE_SHOW_COVERS, m_browser->AreCoversShown());
+		m_browser->AddItemsToColMenu(m_viewColMenu);
 	}
 
-	viewMenu->Append(IDT_GOTO_CURR);
-	viewMenu->Enable(IDT_GOTO_CURR, enableQueue);
-
-	viewMenu->Append(IDT_WORKSPACE_GOTO_RANDOM);
-
-	viewMenu->AppendSeparator();
-
-	viewMenu->Append(IDT_WORKSPACE_TOGGLE_VIEW);
-
-	if( createMainMenu || IsOpAvailable(SJ_OP_ZOOM) )
+	if( g_accelModule )
 	{
-		SjMenu* zoomMenu = new SjMenu(viewMenu->ShowShortcuts());
-		zoomMenu->Append(IDT_ZOOM_IN);
-		zoomMenu->Append(IDT_ZOOM_OUT);
-		zoomMenu->Append(IDT_ZOOM_NORMAL);
-		zoomMenu->AppendSeparator();
-		zoomMenu->AppendCheckItem(IDO_SAMEZOOMINALLVIEWS, _("Same zoom in all views"));
-		zoomMenu->Check(IDO_SAMEZOOMINALLVIEWS, (g_accelModule->m_flags&SJ_ACCEL_SAME_ZOOM_IN_ALL_VIEWS)!=0);
-		viewMenu->Append(0, _("Zoom"), zoomMenu);
+		m_viewMenu->Check(IDO_SAMEZOOMINALLVIEWS, (g_accelModule->m_flags&SJ_ACCEL_SAME_ZOOM_IN_ALL_VIEWS)!=0);
 	}
 
-	if( createMainMenu || IsAllAvailable() )
-	{
-		wxString showCoverText; // default by SjAccelModule
-		if( m_browser->GetView() == SJ_BROWSER_COVER_VIEW ) showCoverText = _("Show album name");
-		viewMenu->AppendCheckItem(IDT_WORKSPACE_SHOW_COVERS, showCoverText);
-		viewMenu->Check(IDT_WORKSPACE_SHOW_COVERS, m_browser->AreCoversShown());
-	}
-
-	viewMenu->Append(IDT_TOGGLE_TIME_MODE, m_showRemainingTime? _("Show elapsed time") : _("Show remaining time"));
-	viewMenu->Enable(IDT_TOGGLE_TIME_MODE, enableQueue);
-
-
-	if( createMainMenu || !IsKioskStarted() )
-	{
-		viewMenu->AppendSeparator();
-
-		viewMenu->AppendCheckItem(IDT_ALWAYS_ON_TOP);
-		viewMenu->Check(IDT_ALWAYS_ON_TOP, IsAlwaysOnTop());
-	}
-
-	viewMenu->AppendSeparator();
-
-	// add vis. toggle
-	if( g_visModule ) {
-		viewMenu->AppendCheckItem(IDT_START_VIS, _("Video screen"));
-		viewMenu->Check(IDT_START_VIS, g_visModule->IsVisStarted());
-	}
+	m_viewMenu->Check(IDT_ALWAYS_ON_TOP, IsAlwaysOnTop());
 }
 
 
+
 /*******************************************************************************
  *  The playback menu
  ******************************************************************************/
 
 
-void SjMainFrame::CreatePlaybackMenu(SjMenu* playbackMenu, bool createMainMenu)
+void SjMainFrame::CreatePlaybackMenu(SjMenu* playbackMenu)
 {
 	bool anythingInQueue = GetQueueCount()>0;
 	playbackMenu->Append(IDT_MORE_FROM_CURR_ALBUM);
@@ -357,7 +324,7 @@ void SjMainFrame::CreatePlaybackMenu(SjMenu* playbackMenu, bool createMainMenu)
 	playbackMenu->Enable(IDT_MORE_FROM_CURR_ARTIST, anythingInQueue);
 	playbackMenu->AppendSeparator();
 
-	if( createMainMenu || IsOpAvailable(SJ_OP_PLAYPAUSE) )
+	if( IsOpAvailable(SJ_OP_PLAYPAUSE) )
 	{
 		playbackMenu->AppendRadioItem(IDT_PLAY);
 		playbackMenu->Check(IDT_PLAY, m_player.IsPlaying());
@@ -375,7 +342,7 @@ void SjMainFrame::CreatePlaybackMenu(SjMenu* playbackMenu, bool createMainMenu)
 		playbackMenu->Check(IDT_STOP_AFTER_EACH_TRACK, m_player.StopAfterEachTrack());
 	}
 
-	if( createMainMenu || IsOpAvailable(SJ_OP_EDIT_QUEUE) )
+	if( IsOpAvailable(SJ_OP_EDIT_QUEUE) )
 	{
 		if( !IsOpAvailable(SJ_OP_PLAYPAUSE) ) playbackMenu->AppendSeparator();
 
@@ -391,25 +358,11 @@ void SjMainFrame::CreatePlaybackMenu(SjMenu* playbackMenu, bool createMainMenu)
 
 	}
 
-	if( createMainMenu || IsOpAvailable(SJ_OP_MAIN_VOL) )
-	{
-		SjMenu* volMenu = new SjMenu(playbackMenu->ShowShortcuts());
-
-		volMenu->Append(IDT_MAIN_VOL_UP);
-
-		volMenu->Append(IDT_MAIN_VOL_DOWN);
-
-		volMenu->AppendCheckItem(IDT_MAIN_VOL_MUTE);
-		volMenu->Check(IDT_MAIN_VOL_MUTE, m_player.GetMainVolMute());
-
-		playbackMenu->Append(0, _("Volume"), volMenu);
-	}
-
-	if( createMainMenu || IsOpAvailable(SJ_OP_EDIT_QUEUE) || IsOpAvailable(SJ_OP_REPEAT) || IsOpAvailable(SJ_OP_PLAYPAUSE) )
+	if( IsOpAvailable(SJ_OP_EDIT_QUEUE) || IsOpAvailable(SJ_OP_REPEAT) || IsOpAvailable(SJ_OP_PLAYPAUSE) )
 	{
 		playbackMenu->AppendSeparator();
 
-		if( createMainMenu || IsOpAvailable(SJ_OP_REPEAT) )
+		if( IsOpAvailable(SJ_OP_REPEAT) )
 		{
 			wxString repeatText; // default by SjAccelModule
 			if( m_player.m_queue.GetRepeat()==1 ) repeatText = _("Repeat one");
@@ -418,13 +371,13 @@ void SjMainFrame::CreatePlaybackMenu(SjMenu* playbackMenu, bool createMainMenu)
 			playbackMenu->Check(IDT_REPEAT, m_player.m_queue.GetRepeat()!=0);
 		}
 
-		if( createMainMenu || IsOpAvailable(SJ_OP_EDIT_QUEUE) )
+		if( IsOpAvailable(SJ_OP_EDIT_QUEUE) )
 		{
 			playbackMenu->AppendCheckItem(IDT_SHUFFLE);
 			playbackMenu->Check(IDT_SHUFFLE, m_player.m_queue.GetShuffle());
 		}
 
-		if( createMainMenu || IsOpAvailable(SJ_OP_EDIT_QUEUE) || IsOpAvailable(SJ_OP_PLAYPAUSE) )
+		if( IsOpAvailable(SJ_OP_EDIT_QUEUE) || IsOpAvailable(SJ_OP_PLAYPAUSE) )
 		{
 			SjMenu* queueMenu = new SjMenu(playbackMenu->ShowShortcuts());
 
@@ -440,74 +393,40 @@ void SjMainFrame::CreatePlaybackMenu(SjMenu* playbackMenu, bool createMainMenu)
 				queueMenu->Check(IDT_PLAY_NOW_ON_DBL_CLICK, (g_accelModule->m_flags&SJ_ACCEL_PLAY_NOW_ON_DBL_CLICK)!=0);
 			}
 
+			if( IsAllAvailable() )
+			{
+				queueMenu->Append(IDO_SETTINGS_QUEUE, _("Further options")+wxString("..."));
+			}
+
 			playbackMenu->Append(0, _("Queue"), queueMenu);
 		}
 	}
 
-}
-
-
-/*******************************************************************************
- * The Kiosk menu
- ******************************************************************************/
-
-
-void SjMainFrame::CreateKioskMenu(SjMenu* kioskMenu)
-{
-	kioskMenu->Append(IDT_TOGGLE_KIOSK, _("Start kiosk mode..."));
-}
-
-
-/*******************************************************************************
- * The Extras menu
- ******************************************************************************/
-
-
-void SjMainFrame::UpdateExtrasMenu()
-{
-	if( m_extrasMenu )
+	if( IsOpAvailable(SJ_OP_MAIN_VOL) )
 	{
-		// this function is for the main menu, it is useless for popup or context menus ...
-		// ... delete all items
-		int i, iCount = m_extrasMenu->GetMenuItemCount();
-		if( iCount > (IDO_EXTRAS_MENU99-IDO_EXTRAS_MENU00)+1 ) iCount = IDO_EXTRAS_MENU99-IDO_EXTRAS_MENU00+1;
-		for( i = 0; i < iCount; i++ )
+		playbackMenu->AppendSeparator();
+
+		SjMenu* volMenu = new SjMenu(playbackMenu->ShowShortcuts());
+
+		volMenu->Append(IDT_MAIN_VOL_UP);
+		volMenu->Append(IDT_MAIN_VOL_DOWN);
+
+		volMenu->AppendCheckItem(IDT_MAIN_VOL_MUTE);
+		volMenu->Check(IDT_MAIN_VOL_MUTE, m_player.GetMainVolMute());
+
+		volMenu->AppendSeparator();
+
+		volMenu->Append(IDT_PRELISTEN_VOL_UP);
+		volMenu->Append(IDT_PRELISTEN_VOL_DOWN);
+
+		playbackMenu->Append(0, _("Volume"), volMenu);
+
+		if( IsAllAvailable() )
 		{
-			wxMenuItem* item = m_extrasMenu->FindItemByPosition(0/*always the first!*/);
-			if( item )
-				m_extrasMenu->Destroy(item);
+			playbackMenu->Append(IDO_SETTINGS_AUTOVOL, _("Automatic control")+wxString("..."));
 		}
-		wxASSERT( m_extrasMenu->GetMenuItemCount() == 0 );
-
-		// ... add current items
-		CreateExtrasMenu(m_extrasMenu);
-
-		wxASSERT( m_menuBar );
-		if( m_menuBar )
-			m_menuBar->Refresh();
 	}
 }
-void SjMainFrame::CreateExtrasMenu(SjMenu* extrasMenu)
-{
-	#if SJ_USE_SCRIPTS
-		wxArrayString arr = SjSee::GetGlobalEmbeddings(SJ_PERSISTENT_MENU_ENTRY);
-		int i, iCount = arr.GetCount();
-		if( icount > 0 )
-		{
-			if( iCount > (IDO_EXTRAS_MENU99-IDO_EXTRAS_MENU00)+1 ) {
-				iCount = IDO_EXTRAS_MENU99-IDO_EXTRAS_MENU00+1;
-			}
-			for( i = 0; i<iCount; i++ ) {
-				extrasMenu->Append(IDO_EXTRAS_MENU00+i, arr[i], SJ_ICON_MODULE);
-			}
-			extrasMenu->AppendSeparator();
-		}
-	#endif
-
-	extrasMenu->Append(IDO_CONSOLE);
-	extrasMenu->AppendSeparator();
-	extrasMenu->Append(IDO_SETTINGS_ADV);
-}
 
 
 /*******************************************************************************
@@ -515,6 +434,40 @@ void SjMainFrame::CreateExtrasMenu(SjMenu* extrasMenu)
  ******************************************************************************/
 
 
+void SjMainFrame::AddScriptMenuEntries(SjMenu& m)
+{
+	// add the menu entries creted by the scripts to the given menu; the function is used in the main menu and
+	// for the context menus.  Before any entry is added, a separator is added (if there are no entries, no separator is added)
+	#if SJ_USE_SCRIPTS
+		wxArrayString arrMenu   = SjSee::GetGlobalEmbeddings(SJ_PERSISTENT_MENU_ENTRY);
+		wxArrayString arrConfig = SjSee::GetGlobalEmbeddings(SJ_PERSISTENT_CONFIG_BUTTON);
+		int iCountMenu   = arrMenu.GetCount(); if( iCountMenu   > (IDO_SCRIPT_MENU99-IDO_SCRIPT_MENU00)+1 ) { iCountMenu = IDO_SCRIPT_MENU99-IDO_SCRIPT_MENU00+1; }
+		int iCountConfig = arrConfig.GetCount(); if( iCountConfig > (IDO_SCRIPTCONFIG_MENU99-IDO_SCRIPTCONFIG_MENU00)+1 ) { iCountConfig = IDO_SCRIPTCONFIG_MENU99-IDO_SCRIPTCONFIG_MENU00+1; }
+
+		if( iCountMenu > 0 )
+		{
+			for( int i = 0; i<iCountMenu; i++ )
+			{
+				m.Append(IDO_SCRIPT_MENU00+i, arrMenu[i]);
+			}
+
+			if( iCountConfig > 0 )
+			{
+				m.AppendSeparator();
+			}
+		}
+
+		if( iCountConfig > 0 )
+		{
+			for( int i = 0; i<iCountConfig; i++ )
+			{
+				m.Append(IDO_SCRIPTCONFIG_MENU00+i, arrConfig[i]);
+			}
+		}
+	#endif
+}
+
+
 wxString SjMainFrame::GetNextMenuTitle()
 {
 	if( !HasNextIgnoreAP()
@@ -541,29 +494,8 @@ wxString SjMainFrame::GetNextMenuTitle()
 
 
 void SjMainFrame::CreateContextMenu_(SjMenu& mainMenu,
-                                     bool prependOpen, int idmSettings, bool appendGotoCurrMark,
                                      bool embedFastSearch)
 {
-	// prepend open/save items (reverse order!)
-	/* -- as we have a normal menu bar since 15.1, the context menu can be more focused
-	if( prependOpen && IsAllAvailable() )
-	{
-		if(  mainMenu.GetMenuItemCount() )
-		{
-			mainMenu.InsertSeparator(0);
-		}
-
-		bool enableQueue = m_player.m_queue.GetCount()!=0;
-		mainMenu.Insert(0, IDT_UNQUEUE_ALL);
-		mainMenu.Enable(IDT_UNQUEUE_ALL, enableQueue);
-
-		mainMenu.Insert(0, IDT_SAVE_PLAYLIST);
-		mainMenu.Enable(IDT_SAVE_PLAYLIST, enableQueue);
-
-		mainMenu.Insert(0, IDT_OPEN_FILES);
-	}
-	*/
-
 	// search
 	// -- as we have a normal menu bar since 15.1, the context menu can be more focused (search only added if embedFastSearch set, formally this was always the case)
 	if( embedFastSearch && IsOpAvailable(SJ_OP_SEARCH) )
@@ -590,32 +522,6 @@ void SjMainFrame::CreateContextMenu_(SjMenu& mainMenu,
 		mainMenu.Enable(IDO_REALLYENDSEARCH, HasAnySearch());
 	}
 
-	// settings / view  / control
-	/* -- as we have a normal menu bar since 15.1, the context menu can be more focused
-	if( IsAllAvailable() )
-	{
-
-		// seperator abottom (sth. will follow in any case, at least "Go to random album")
-		if( mainMenu.GetMenuItemCount() )
-		{
-			mainMenu.AppendSeparator();
-		}
-
-		// settings
-		mainMenu.Append(idmSettings);
-
-		// view menu
-		SjMenu* viewMenu = new SjMenu(mainMenu.ShowShortcuts());
-		CreateViewMenu(viewMenu, false, appendGotoCurrMark);
-		mainMenu.Append(0, _("View"), viewMenu);
-
-		// control menu
-		SjMenu* playbackMenu = new SjMenu(mainMenu.ShowShortcuts());
-		CreatePlaybackMenu(playbackMenu, false);
-		mainMenu.Append(0, _("Playback"), playbackMenu);
-	}
-	*/
-
 	// help
 	if( IsKioskStarted() )
 	{
@@ -719,9 +625,6 @@ void SjMainFrame::CreateSearchMenu(SjMenu& m)
 void SjMainFrame::OnSkinTargetContextMenu(int targetId, long x, long y)
 {
 	SjMenu      mainMenu(0);
-	int         idtSettings = IDT_SETTINGS_JUKEBOX;
-	bool        appendGotoCurrMark = FALSE;
-	bool        prependOpen = TRUE;
 	bool        embedFastSearch = FALSE;
 	long        unmarkQueueId = 0;
 
@@ -737,8 +640,7 @@ void SjMainFrame::OnSkinTargetContextMenu(int targetId, long x, long y)
 	 ||  targetId==IDT_NEXT_TRACK )
 	{
 		// queue menu items
-		if(  IsAllAvailable()
-		        && (targetId==IDT_CURR_TRACK || targetId==IDT_NEXT_TRACK) )
+		if( IsAllAvailable() )
 		{
 			if( targetId==IDT_CURR_TRACK || targetId==IDT_NEXT_TRACK )
 			{
@@ -783,25 +685,37 @@ void SjMainFrame::OnSkinTargetContextMenu(int targetId, long x, long y)
 					}
 
 					m_contextMenuClickedUrls = m_player.m_queue.GetUrlsByIds(m_display.m_selectedIds);
-
-					appendGotoCurrMark = TRUE;
+					if( m_contextMenuClickedUrls.GetCount() )
+					{
+						mainMenu.Append(IDO_GOTO_CURR_MARK);
+					}
 				}
 			}
 
 			long markedCount = m_contextMenuClickedUrls.GetCount();
+			if( markedCount > 0 )
+			{
+				CreateUnqueueMenu(mainMenu);
 
-			CreateUnqueueMenu(mainMenu);
+				mainMenu.AppendSeparator();
 
-			mainMenu.AppendSeparator();
+				mainMenu.Append(IDO_EDITQUEUE, _("Edit tracks/Get info")+wxString(wxT("...")));
 
-			mainMenu.Append(IDO_EDITQUEUE, _("Edit tracks/Get info")+wxString(wxT("...")));
-			mainMenu.Enable(IDO_EDITQUEUE, (markedCount>0));
+				m_libraryModule->CreateRatingMenu(mainMenu, IDO_RATINGQUEUE00, m_contextMenuClickedUrls);
+				m_libraryModule->CreateArtistInfoMenu(mainMenu, IDO_ARTISTINFQUEUE00, m_contextMenuClickedUrls);
 
-			m_libraryModule->CreateRatingMenu(mainMenu, IDO_RATINGQUEUE00, m_contextMenuClickedUrls);
-			m_libraryModule->CreateArtistInfoMenu(mainMenu, IDO_ARTISTINFQUEUE00, m_contextMenuClickedUrls);
+				mainMenu.Append(IDO_EXPLOREQUEUE, _os(_("Show file")));
+				mainMenu.Enable(IDO_EXPLOREQUEUE, (markedCount==1));
 
-			mainMenu.Append(IDO_EXPLOREQUEUE, _("Show file"));
-			mainMenu.Enable(IDO_EXPLOREQUEUE, (markedCount==1));
+				SjMenu* submenu = new SjMenu(0);
+				AddScriptMenuEntries(*submenu);
+				if( submenu->GetMenuItemCount() ) {
+					mainMenu.Append(0, _("Extensions"), submenu);
+				}
+				else {
+					delete submenu;
+				}
+			}
 		}
 	}
 	else
@@ -814,7 +728,7 @@ void SjMainFrame::OnSkinTargetContextMenu(int targetId, long x, long y)
 					mainMenu.Append(IDO_DISPLAY_COVER, _("Cover editor"));
 					if( IsAllAvailable() )
 					{
-						mainMenu.Append(IDO_DISPLAY_COVER_EXPLR, _("Show file"));
+						mainMenu.Append(IDO_DISPLAY_COVER_EXPLR, _os(_("Show file")));
 					}
 				}
 				break;
@@ -833,7 +747,6 @@ void SjMainFrame::OnSkinTargetContextMenu(int targetId, long x, long y)
 			case IDT_SEARCH_BUTTON:
 			case IDT_SEARCH_INFO:
 				// "Search" menu
-				prependOpen = FALSE;
 				if( IsAllAvailable() )
 				{
 					embedFastSearch = TRUE;
@@ -846,7 +759,7 @@ void SjMainFrame::OnSkinTargetContextMenu(int targetId, long x, long y)
 		}
 	}
 
-	CreateContextMenu_(mainMenu, prependOpen, idtSettings, appendGotoCurrMark, embedFastSearch);
+	CreateContextMenu_(mainMenu, embedFastSearch);
 
 	if( targetId == IDT_MAINMENU && !IsKioskStarted() )
 	{
@@ -856,7 +769,7 @@ void SjMainFrame::OnSkinTargetContextMenu(int targetId, long x, long y)
 
 	if( mainMenu.GetMenuItemCount() )
 	{
-		PopupMenu(&mainMenu, x, y);
+		PopupMenu(&mainMenu);
 	}
 
 	if(  unmarkQueueId
