@@ -19,7 +19,7 @@
  *
  *******************************************************************************
  *
- * File:    playlistsj.cpp ("sj" added to avoid double file names)
+ * File:    playlist.cpp
  * Authors: Björn Petersen
  * Purpose: Silverjuke playlist handling
  *
@@ -30,11 +30,19 @@
  *
  *  Further notes:
  * - Relative URLs supported on load
+ * - We do a very lazy but _fast_ load: We just take the strings as given and
+ *   remember the containing playlist file (if any), later on, we verify the
+ *   entry as needed.  This allows us to load playlists with thousands tracks
+ *   in a fragment of a second.
  * - We're using arist and title information in *.m3u and *.pls files if the URL
  *   is not found.  This allows moving playlists with relative paths if the
  *   title is in the library.
- * - Hack: The artist/title is added after a tab to the unverified URL
- * - NERO does not like spaces in CUE filenames :-(
+ * - The playlistLocation/artist/album/track is added after a tab to the
+ *   unverified URL.  We use the tab as a separator as it should cause less
+ *   problems with the information stored; using eg. the pipe ("|") may cause
+ *   problems with some URLs (although http://www.ietf.org/rfc/rfc2396.txt
+ *   stated the use of the pipe in URLs "unwise").  So, the tab is it.
+ * - Nero does not like spaces in CUE filenames
  *
  ******************************************************************************/
 
@@ -82,8 +90,8 @@ void SjPlaylistEntry::LoadAddInfo(long what)
 	}
 
 	// load track, artist and album name, if needed
-	if(               (what&SJ_ADDINFO_MISC)
-	                  && !(m_addInfo->m_what&SJ_ADDINFO_MISC) )
+	if(  (what&SJ_ADDINFO_MISC)
+	 && !(m_addInfo->m_what&SJ_ADDINFO_MISC) )
 	{
 		// try to get them from the library
 		if( !g_mainFrame->m_columnMixer.GetQuickInfo(GetUrl(), m_addInfo->m_trackName, m_addInfo->m_leadArtistName, m_addInfo->m_albumName, m_addInfo->m_playtimeMs) )
@@ -94,8 +102,8 @@ void SjPlaylistEntry::LoadAddInfo(long what)
 			{
 				wxString testUrl = GetUrl();
 				if( !testUrl.StartsWith(wxT("http:")) // this may be a steam - in this case (or in others) we get into an endless loop
-				        && !testUrl.StartsWith(wxT("https:"))
-				        && !testUrl.StartsWith(wxT("ftp:")) )
+				 && !testUrl.StartsWith(wxT("https:"))
+				 && !testUrl.StartsWith(wxT("ftp:")) )
 				{
 					SjTrackInfo trackInfo;
 					wxFileSystem fs;
@@ -132,21 +140,17 @@ void SjPlaylistEntry::LoadAddInfo(long what)
 }
 
 
-wxString SjPlaylistEntry::GetLocalUrl(const wxString& containerUrl)
+wxString SjPlaylistEntry::GetLocalFile(const wxString& containerFile__)
 {
-	wxString temp = GetUrl();
-	#ifdef __WXMSW__
-		temp.Replace(wxT("/"), wxT("\\"));
-	#endif
-	wxFileName urlFn(temp, wxPATH_NATIVE);
+	wxFileName urlFn = wxFileSystem::URLToFileName(GetUrl());
 
-	if( !containerUrl.IsEmpty() )
+	if( !containerFile__.IsEmpty() )
 	{
-		temp = containerUrl;
+		wxString containerFile(containerFile__);
 		#ifdef __WXMSW__
-			temp.Replace(wxT("/"), wxT("\\"));
+			containerFile.Replace(wxT("/"), wxT("\\"));
 		#endif
-		wxFileName containerFn(temp, wxPATH_NATIVE);
+		wxFileName containerFn(containerFile);
 
 		urlFn.MakeRelativeTo(containerFn.GetPath(wxPATH_GET_VOLUME|wxPATH_GET_SEPARATOR));
 	}
@@ -163,13 +167,19 @@ void SjPlaylistEntry::SetRealtimeInfo(const wxString& info__)
 	wxString info(info__);
 	info.Replace(wxT("--"), wxT("-"));
 	if( info.Upper() == info || info.Lower() == info )
+	{
 		info = SjTools::Capitalize(info);
+	}
 
 	while( info.Len() > 0 && (info[0] == wxT('-') || info[0] == wxT(' ')) )
+	{
 		info = info.Mid(1);
+	}
 
 	while( info.Len() > 0 && (info.Last() == wxT('-') || info.Last() == wxT(' ')) )
+	{
 		info = info.Left(info.Len()-1);
+	}
 
 	// set the normalized info string as
 	CheckAddInfo(SJ_ADDINFO_MISC);
@@ -221,75 +231,58 @@ void SjPlaylistEntry::VerifyUrl()
 	wxASSERT( !m_urlVerified );
 	m_urlVerified = TRUE;
 
-	// copy the original url as it will be modified;
-	// the original url should only be overwritten on total success
+	// the unverified URL has the format "url.mp3 \t playlist.m3u \t Artist \t Album \t Track" (without spaces around tabs);
+	// copy the original url as it will be modified; the original url should only be overwritten on total success
 	wxString url(m_url.BeforeFirst('\t'));
 
 	// get the long and absolute version of the URL
-	if( !url.StartsWith(wxT("stub:")) )
+	if( url.StartsWith(wxT("file:")) )
+	{
+		wxFileName urlFn = wxFileSystem::URLToFileName(url);
+		url = urlFn.GetLongPath();
+	}
+	else if( !url.StartsWith(wxT("stub:")) )
 	{
 		wxFileName urlFn(url, wxPATH_NATIVE);
 		if( !urlFn.IsAbsolute() )
 		{
-			// try relative paths from m_playlist->GetContainerUrls()
-			wxArrayString   containerUrls = m_playlist->GetContainerUrls();
-			for( int containerIndex = (int)containerUrls.GetCount()-1; containerIndex >=0; containerIndex-- )
+			// try relative paths from the second part of the unverified URL
+			wxString containerPath = m_url.AfterFirst('\t').BeforeFirst('\t');
+			if( !containerPath.IsEmpty() )
 			{
 				// re-assign the relatice path to urlFn - needed if for() has more than one iteration
 				urlFn.Assign(url, wxPATH_NATIVE);
 
 				// make urlFn absolute using MakeAbsolute(GetPath()) (GetPath() does not return the name, so this should work just fine)
-				wxString tempStr(containerUrls[containerIndex]);
 				#ifdef __WXMSW__
-					tempStr.Replace(wxT("/"), wxT("\\")); // needed as wxPATH_NATIVE obviously expects native paths ... see http://www.silverjuke.net/forum/post.php?p=14207#14207
+					containerPath.Replace(wxT("/"), wxT("\\")); // needed as wxPATH_NATIVE obviously expects native paths ... see http://www.silverjuke.net/forum/post.php?p=14207#14207
 				#endif
-				wxFileName tempFn(tempStr, wxPATH_NATIVE);
+				wxFileName tempFn(containerPath, wxPATH_NATIVE);
 				urlFn.MakeAbsolute(tempFn.GetPath(wxPATH_GET_VOLUME));
 
 				// success?
 				if( urlFn.FileExists() )
 				{
 					url = urlFn.GetLongPath();
-					break;
 				}
 			}
 		}
-		else if( url.StartsWith(wxT("file:")) )
-		{
-			urlFn = wxFileSystem::URLToFileName(url);
-			url = urlFn.GetLongPath();
-		}
 		else
 		{
 			url = urlFn.GetLongPath();
 		}
 	}
 
-	// open file - as we also support eg. ZIP archives this is needed for validating,
+	// open file - as we also support eg. ZIP archives this is needed for validating
 	// relative paths are not valid at this moment
 	wxString fsFileLocation;
 	{
-		if(  url.Len()>2
-		        &&
-			#ifdef __WXMSW__
-		        url[1u]==wxT(':')
-			#else
-		        url[0]=='/'
-			#endif
-		        && ::wxFileExists(url) )
-		{
-			// some speed improvements for "normal" files
-			fsFileLocation = url;
-			fsFileLocation.Replace(wxT("\\"), wxT("/"));
-		}
-		else
-		{
 			wxFSFile* fsFile = NULL;
 
 			if( !url.StartsWith(wxT(".."))
-			        && !url.StartsWith(wxT("./"))
-			        && !url.StartsWith(wxT(".\\"))
-			        && !url.StartsWith(wxT("stub:")) )
+			 && !url.StartsWith(wxT("./"))
+			 && !url.StartsWith(wxT(".\\"))
+			 && !url.StartsWith(wxT("stub:")) )
 			{
 				wxFileSystem fileSystem;
 				fsFile = fileSystem.OpenFile(url);
@@ -298,8 +291,8 @@ void SjPlaylistEntry::VerifyUrl()
 			if( fsFile == NULL )
 			{
 				// try to lookup the URL by artist/album/track
-				wxString artistName = m_url.AfterFirst('\t').BeforeFirst('\t');
-				wxString albumName  = m_url.AfterFirst('\t').AfterFirst('\t').BeforeFirst('\t');
+				wxString artistName = m_url.AfterFirst('\t').AfterFirst('\t').BeforeFirst('\t');
+				wxString albumName  = m_url.AfterFirst('\t').AfterFirst('\t').AfterFirst('\t').BeforeFirst('\t');
 				wxString trackName  = m_url.AfterLast('\t');
 				if( !artistName.IsEmpty() && !trackName.IsEmpty() /*album may be empty, eg. for m3u*/)
 				{
@@ -320,7 +313,16 @@ void SjPlaylistEntry::VerifyUrl()
 
 			fsFileLocation = fsFile->GetLocation();
 			delete fsFile;
-		}
+	}
+
+	// convert the file name to a URL
+	if( !fsFileLocation.StartsWith("file:")
+	 && !fsFileLocation.StartsWith("http:")
+	 && !fsFileLocation.StartsWith("https:")
+	 && !fsFileLocation.StartsWith("ftp:") )
+	{
+		wxFileName fn(fsFileLocation);
+		fsFileLocation = wxFileSystem::FileNameToURL(fsFileLocation);
 	}
 
 	// make sure, we're using the correct case, see
@@ -422,7 +424,12 @@ void SjPlaylist::OnUrlChanged(const wxString& oldUrl, const wxString& newUrl)
 		{
 			if( m_array[i].GetUnverifiedUrl()==oldUrl )
 			{
-				m_array[i].UrlChanged();
+				SjPlaylistEntry& e = m_array[i];
+				long playCount = e.GetPlayCount(); // as UrlChanged() simply forgets everything about the URL, preserve some data manually
+				long flags = e.GetFlags();
+				e.UrlChanged();
+				e.SetPlayCount(playCount);
+				e.SetFlags(flags);
 			}
 		}
 	}
@@ -667,12 +674,6 @@ void SjPlaylist::MergeMetaData(const SjPlaylist& o)
 	{
 		m_playlistUrl = o.m_playlistUrl;
 	}
-
-	int oContainerIndex, oContainerCount = o.m_containerUrls.GetCount();
-	for( oContainerIndex = 0; oContainerIndex < oContainerCount; oContainerIndex++ )
-	{
-		AddContainerUrl(o.m_containerUrls[oContainerIndex]);
-	}
 }
 
 
@@ -681,13 +682,26 @@ void SjPlaylist::MergeMetaData(const SjPlaylist& o)
  ******************************************************************************/
 
 
-bool SjPlaylist::AddFromM3u(wxFSFile* fsFile, long addMax, long flags)
+bool SjPlaylist::AddFromM3uFile(const wxString& nativePath, long addMax, long flags)
 {
+	// open file
+	wxFileSystem fileSystem;
+	wxFSFile* fsFile = fileSystem.OpenFile(nativePath, wxFS_READ|wxFS_SEEKABLE);
+	if( fsFile == NULL )
+	{
+		wxLogError(_("Cannot open \"%s\"."), nativePath.c_str());
+		return false;
+	}
+
 	// get file content
-	wxString ext = SjTools::GetExt(fsFile->GetLocation());
+	wxString ext = SjTools::GetExt(nativePath);
+
 	wxMBConv* fileContentMbConv = &wxConvISO8859_1;
 	if( ext == wxT("m3u8") )
+	{
 		fileContentMbConv = &wxConvUTF8;
+	}
+
 	wxString content = SjTools::GetFileContent(fsFile->GetStream(), fileContentMbConv); // GetFileContent() will also check for the BOM (Byte order mark)
 
 	// process
@@ -712,12 +726,14 @@ bool SjPlaylist::AddFromM3u(wxFSFile* fsFile, long addMax, long flags)
 				currTitle = currTitle.AfterFirst(',');              // skip seconds parameter from "#EXTINF:seconds,artiest ..."
 
 				if( currTitle.Replace(wxT(" - "), wxT("\t\t")) < 1 )// normally, the format ist "Artist - Title" ...
-					currTitle.Replace(wxT("-"), wxT("\t\t"));       // ... however, since 3.02, we also allow "Artist-Title" ...
-			}                                                       // ... and, later in VerifyUrl() also "Title - Artist" and "Title-Artist" :-)
+				{                                                   // ... however, since 3.02, we also allow "Artist-Title" ...
+					currTitle.Replace(wxT("-"), wxT("\t\t"));       // ... and, later in VerifyUrl() also "Title - Artist" and "Title-Artist" :-)
+				}
+			}
 			continue;
 		}
 
-		Add(currLinePtr + (wxT("\t") + currTitle), FALSE, 0);
+		Add(wxString(currLinePtr) + "\t" + nativePath + "\t" + currTitle, FALSE, 0);
 		currTitle.Empty();
 
 		filesAdded++;
@@ -728,11 +744,12 @@ bool SjPlaylist::AddFromM3u(wxFSFile* fsFile, long addMax, long flags)
 		}
 	}
 
+	delete fsFile;
 	return TRUE;
 }
 
 
-wxString SjPlaylist::SaveAsM3u(const wxString& containerUrl, long flags)
+wxString SjPlaylist::SaveAsM3u(const wxString& containerFile, long flags)
 {
 	wxString    ret;
 	wxString    linebreak = SjTools::GetLineBreak();
@@ -746,7 +763,7 @@ wxString SjPlaylist::SaveAsM3u(const wxString& containerUrl, long flags)
 	long i, iCount = GetCount(), seconds;
 	for( i = 0; i < iCount; i++ )
 	{
-		urlToSave = Item(i).GetLocalUrl(containerUrl);
+		urlToSave = Item(i).GetLocalFile(containerFile);
 		if( Item(i).IsUrlOk() )
 		{
 			if( !(flags & SJ_M3U_NO_EXT) )
@@ -770,8 +787,18 @@ wxString SjPlaylist::SaveAsM3u(const wxString& containerUrl, long flags)
  ******************************************************************************/
 
 
-bool SjPlaylist::AddFromPls(wxFSFile* fsFile, long addMax, long flags)
+bool SjPlaylist::AddFromPlsFile(const wxString& nativePath, long addMax, long flags)
 {
+	// open file
+	wxFileSystem fileSystem;
+	wxFSFile* fsFile = fileSystem.OpenFile(nativePath, wxFS_READ|wxFS_SEEKABLE);
+	if( fsFile == NULL )
+	{
+		wxLogError(_("Cannot open \"%s\"."), nativePath.c_str());
+		return false;
+	}
+
+	// parse file
 	wxString            content = SjTools::GetFileContent(fsFile->GetStream(), &wxConvISO8859_1);
 	SjLineTokenizer     tkz(content);
 	wxChar*             currLinePtr;
@@ -836,7 +863,7 @@ bool SjPlaylist::AddFromPls(wxFSFile* fsFile, long addMax, long flags)
 		{
 			if( urlIndex < titleCount )
 			{
-				currLine += wxT("\t") + titles[urlIndex] /*may be empty*/;
+				currLine += "\t" + nativePath + "\t" + titles[urlIndex] /*may be empty*/;
 			}
 
 			Add(currLine, FALSE/*not verified*/, 0);
@@ -846,11 +873,12 @@ bool SjPlaylist::AddFromPls(wxFSFile* fsFile, long addMax, long flags)
 		}
 	}
 
+	delete fsFile;
 	return TRUE;
 }
 
 
-wxString SjPlaylist::SaveAsPls(const wxString& containerUrl, long flags)
+wxString SjPlaylist::SaveAsPls(const wxString& containerFile, long flags)
 {
 	wxString    ret;
 	wxString    linebreak = SjTools::GetLineBreak();
@@ -868,7 +896,7 @@ wxString SjPlaylist::SaveAsPls(const wxString& containerUrl, long flags)
 	long i, iCount = GetCount(), savedCount = 0, seconds;
 	for( i = 0; i < iCount; i++ )
 	{
-		urlToSave = Item(i).GetLocalUrl(wxEmptyString/*always save abs. path*/);
+		urlToSave = Item(i).GetLocalFile(wxEmptyString/*always save abs. path*/);
 
 		if( Item(i).IsUrlOk() )
 		{
@@ -899,8 +927,18 @@ wxString SjPlaylist::SaveAsPls(const wxString& containerUrl, long flags)
  ******************************************************************************/
 
 
-bool SjPlaylist::AddFromCue(wxFSFile* fsFile, long addMax, long flags)
+bool SjPlaylist::AddFromCueFile(const wxString& nativePath, long addMax, long flags)
 {
+	// open file
+	wxFileSystem fileSystem;
+	wxFSFile* fsFile = fileSystem.OpenFile(nativePath, wxFS_READ|wxFS_SEEKABLE);
+	if( fsFile == NULL )
+	{
+		wxLogError(_("Cannot open \"%s\"."), nativePath.c_str());
+		return false;
+	}
+
+	// parse file
 	wxString            content = SjTools::GetFileContent(fsFile->GetStream(), &wxConvISO8859_1);
 	SjLineTokenizer     tkz(content);
 	wxChar*             currLinePtr;
@@ -937,17 +975,18 @@ bool SjPlaylist::AddFromCue(wxFSFile* fsFile, long addMax, long flags)
 		if( GetPosByUrl(currLine) != wxNOT_FOUND ) continue;
 
 		// add file
-		Add(currLine, FALSE/*not verified*/, 0);
+		Add(currLine + "\t" + nativePath, FALSE/*not verified*/, 0);
 		filesAdded++;
 
 		if( filesAdded >= addMax ) break;
 	}
 
+	delete fsFile;
 	return TRUE;
 }
 
 
-wxString SjPlaylist::SaveAsCue(const wxString& containerUrl, long flags)
+wxString SjPlaylist::SaveAsCue(const wxString& containerFile, long flags)
 {
 	wxString    ret;
 	wxString    linebreak = SjTools::GetLineBreak();
@@ -959,7 +998,7 @@ wxString SjPlaylist::SaveAsCue(const wxString& containerUrl, long flags)
 	long i, iCount = GetCount();
 	for( i = 0; i < iCount; i++ )
 	{
-		urlToSave = Item(i).GetLocalUrl(wxEmptyString/*always save abs. path*/);
+		urlToSave = Item(i).GetLocalFile(wxEmptyString/*always save abs. path*/);
 
 		if( Item(i).IsUrlOk() )
 		{
@@ -990,8 +1029,17 @@ wxString SjPlaylist::SaveAsCue(const wxString& containerUrl, long flags)
  ******************************************************************************/
 
 
-bool SjPlaylist::AddFromXspfOrXmlOrWpl(wxFSFile* fsFile, long addMax, long flags)
+bool SjPlaylist::AddFromXspfXmlWplFile(const wxString& nativePath, long addMax, long flags)
 {
+	// open file
+	wxFileSystem fileSystem;
+	wxFSFile* fsFile = fileSystem.OpenFile(nativePath, wxFS_READ|wxFS_SEEKABLE);
+	if( fsFile == NULL )
+	{
+		wxLogError(_("Cannot open \"%s\"."), nativePath.c_str());
+		return false;
+	}
+
 	/* desired XSPF-Format ...
 	<track>
 	    <creator>We Are Scientists</creator>
@@ -1107,7 +1155,7 @@ bool SjPlaylist::AddFromXspfOrXmlOrWpl(wxFSFile* fsFile, long addMax, long flags
 
 			if( !lastLocation.IsEmpty() )
 			{
-				Add(lastLocation + wxT("\t") + lastArtistName + wxT("\t") + lastAlbumName + wxT("\t") + lastTrackName, FALSE/*not verified*/, 0);
+				Add(lastLocation + "\t" + nativePath + "\t" + lastArtistName + "\t" + lastAlbumName + "\t" + lastTrackName, FALSE/*not verified*/, 0);
 				filesAdded++;
 				if( filesAdded >= addMax )
 					break;
@@ -1120,11 +1168,12 @@ bool SjPlaylist::AddFromXspfOrXmlOrWpl(wxFSFile* fsFile, long addMax, long flags
 		}
 	}
 
+	delete fsFile;
 	return TRUE;
 }
 
 
-wxString SjPlaylist::SaveAsXspf(const wxString& containerUrl, long flags)
+wxString SjPlaylist::SaveAsXspf(const wxString& containerFile, long flags)
 {
 	wxString    ret, url, realUrl;
 	wxString    linebreak = SjTools::GetLineBreak();
@@ -1137,7 +1186,7 @@ wxString SjPlaylist::SaveAsXspf(const wxString& containerUrl, long flags)
 	ret << wxT("<?xml version=\"1.0\" encoding=\"UTF-8\"?>") << linebreak;
 	ret << wxT("<playlist version=\"1\" xmlns=\"http://xspf.org/ns/0/\">") << linebreak;
 	ret << wxT("<date>") << dtString << wxT("</date>") << linebreak;
-	ret << wxT("<meta rel=\"generator\">") << SJ_PROGRAM_NAME << wxT(" ") << SJ_VERSION_STR << wxT("</meta>") << linebreak;
+	ret << wxT("<meta rel=\"generator\">") << wxString::Format(wxT("%s %i.%i"), SJ_PROGRAM_NAME, SJ_VERSION_MAJOR, SJ_VERSION_MINOR) << wxT("</meta>") << linebreak;
 	ret << wxT("<trackList>") << linebreak;
 
 	// write the tracks - the recommended order is location-title-creator-album, see http://wiki.xiph.org/index.php/XSPF_v1_Notes_and_Errata
@@ -1146,24 +1195,8 @@ wxString SjPlaylist::SaveAsXspf(const wxString& containerUrl, long flags)
 	{
 		ret << wxT("\t<track>") << linebreak;
 
-		// get url
-		url = Item(i).GetUrl();
-
-		// convert the url to sth. like file: ...
-		realUrl = url;
-		if( !realUrl.StartsWith(wxT("http:")) // this may be a steam - in this case (or in others) we get into an endless loop
-		        && !realUrl.StartsWith(wxT("https:"))
-		        && !realUrl.StartsWith(wxT("ftp:")) )
-		{
-			#ifdef __WXMSW__
-				realUrl.Replace(wxT("/"), wxT("\\")); // needed as wxPATH_NATIVE obviously expects native paths ... see http://www.silverjuke.net/forum/post.php?p=14207#14207
-			#endif
-			realUrl = wxFileSystem::FileNameToURL(wxFileName(realUrl, wxPATH_NATIVE));
-		}
-		realUrl.Replace(wxT(" "), wxT("%20"));
-
 		// write url
-		ret << wxT("\t\t<location>") << SjTools::Htmlentities(realUrl) << wxT("</location>") << linebreak;
+		ret << wxT("\t\t<location>") << SjTools::Htmlentities(Item(i).GetUrl()) << wxT("</location>") << linebreak;
 
 		// write title
 		ret << wxT("\t\t<title>") << SjTools::Htmlentities(Item(i).GetTrackName()) << wxT("</title>") << linebreak;
@@ -1196,7 +1229,7 @@ bool SjPlaylist::SaveAsDlg(wxWindow* parentWindow)
 {
 	bool                ret;
 	SjBusyInfo*         busyInfo = NULL;
-	wxWindowDisabler    disabler(parentWindow);
+	SJ_WINDOW_DISABLER  (parentWindow);
 	SjExtList           extList = g_mainFrame->m_moduleSystem.GetAssignedExt(SJ_EXT_PLAYLISTS_WRITE);
 
 	// create the dialog
@@ -1309,7 +1342,7 @@ bool SjPlaylist::SaveAsFile(const wxString& path, const wxString& type, long fla
 
 bool SjPlaylist::AddFromFileDlg(wxWindow* parentWindow)
 {
-	wxWindowDisabler    disabler(parentWindow);
+	SJ_WINDOW_DISABLER(parentWindow);
 
 	// create the dialog
 	wxFileDialog dlg(parentWindow, _("Open playlist"), wxT(""),
@@ -1326,25 +1359,9 @@ bool SjPlaylist::AddFromFileDlg(wxWindow* parentWindow)
 }
 
 
-bool SjPlaylist::AddFromFile(const wxString& path, long addMax, long flags)
+bool SjPlaylist::AddFromFile(const wxString& nativePath, long addMax, long flags)
 {
-	wxFileSystem fileSystem;
-	wxFSFile* fsFile = fileSystem.OpenFile(path, wxFS_READ|wxFS_SEEKABLE);
-	if( fsFile == NULL )
-	{
-		wxLogError(_("Cannot open \"%s\"."), path.c_str());
-		return FALSE;
-	}
-
-	bool ret = AddFromFile(fsFile, addMax, flags);
-	delete fsFile;
-	return ret;
-}
-
-
-bool SjPlaylist::AddFromFile(wxFSFile* playlistFsFile, long addMax, long flags)
-{
-	wxString        ext = SjTools::GetExt(playlistFsFile->GetLocation());
+	wxString        ext = SjTools::GetExt(nativePath);
 	bool            ret;
 
 	if( !g_mainFrame ) return FALSE;
@@ -1353,30 +1370,27 @@ bool SjPlaylist::AddFromFile(wxFSFile* playlistFsFile, long addMax, long flags)
 	// load basic urls - the AddFrom*() function should not validate the files!
 	if( ext == wxT("pls") )
 	{
-		ret = AddFromPls(playlistFsFile, addMax, flags);
+		ret = AddFromPlsFile(nativePath, addMax, flags);
 	}
 	else if( ext == wxT("cue") )
 	{
-		ret = AddFromCue(playlistFsFile, addMax, flags);
+		ret = AddFromCueFile(nativePath, addMax, flags);
 	}
 	else if( ext == wxT("xspf") || ext == wxT("xml") || ext == wxT("wpl") )
 	{
-		ret = AddFromXspfOrXmlOrWpl(playlistFsFile, addMax, flags);
+		ret = AddFromXspfXmlWplFile(nativePath, addMax, flags);
 	}
 	else /* "m3u", "m3u8" */
 	{
-		ret = AddFromM3u(playlistFsFile, addMax, flags);
+		ret = AddFromM3uFile(nativePath, addMax, flags);
 	}
 
 	if( !ret )
 	{
-		wxLogError(_("Cannot open \"%s\"."), playlistFsFile->GetLocation().c_str());
+		wxLogError(_("Cannot open \"%s\"."), nativePath.c_str());
 		return FALSE;
 	}
 
-	AddContainerUrl(playlistFsFile->GetLocation());
-
 	return TRUE;
 }
 
-
