@@ -184,7 +184,7 @@ long SjQueue::GetNextShufflePos(int flags, unsigned long currTimestamp)
 		wxASSERT( m_nextShufflePosFor == m_pos );
 	}
 
-	// return the next shuffle position, this may increase the repeat rounf
+	// return the next shuffle position, this may increase the repeat round
 	long newPos = m_nextShufflePos;
 	if( !(flags&SJ_PREVNEXT_LOOKUP_ONLY) )
 	{
@@ -290,7 +290,9 @@ long SjQueue::GetNextPos(int flags)
 				// however, do not pop up a message box, this may disturb alot as this may happen _any_time, not only just after enqueing
 				long markPosAsMoved;
 				for( markPosAsMoved = newPos; markPosAsMoved < betterPos; markPosAsMoved++ )
+				{
 					m_playlist.Item(markPosAsMoved).SetFlag(SJ_PLAYLISTENTRY_MOVED_DOWN);
+				}
 
 				wxLogInfo(wxT("%s moved up due to avoid bordedom settings"), m_playlist.Item(betterPos).GetUrl().c_str());
 
@@ -978,9 +980,9 @@ long SjQueue::UnqueueByPos(long pos, SjPlayer* player, int* replayRet)
 	if( pos < m_pos )
 	{
 		m_pos--;   // if the currently playing item is removed,
-		// m_queue.pos points to the next item which
-		// will have the same index.
-		// a call to SetCurrPos() is not needed (and not good...)
+		           // m_queue.pos points to the next item which
+		           // will have the same index.
+		           // a call to SetCurrPos() is not needed (and not good...)
 	}
 	else if( pos == m_pos )
 	{
@@ -1016,6 +1018,8 @@ long SjQueue::UnqueueByPos(long pos, SjPlayer* player, int* replayRet)
 		}
 	}
 
+	CleanupNextShufflePos();
+
 	return restUrls;
 }
 
@@ -1151,8 +1155,8 @@ bool SjQueue::MoveToTopOnEoq() const
 	// to select the first queue item (this is useful eg. if the user hits "play" again)
 
 	if( !m_isInitialized
-	        || !g_mainFrame->IsOpAvailable(SJ_OP_PLAYPAUSE)
-	        ||  GetCount()<=0 )
+	 || !g_mainFrame->IsOpAvailable(SJ_OP_PLAYPAUSE)
+	 ||  GetCount()<=0 )
 	{
 		return FALSE;   // we recomment the caller to leave the queue position as is
 		// (as "play" is not avalable the user cannot play the song again,
@@ -1160,7 +1164,7 @@ bool SjQueue::MoveToTopOnEoq() const
 	}
 
 	if( (g_mainFrame->m_autoCtrl.m_flags&SJ_AUTOCTRL_AUTOPLAY_ENABLED)
-	        &&  g_mainFrame->m_autoCtrl.m_autoPlayWaitMinutes==0 )
+	 &&  g_mainFrame->m_autoCtrl.m_autoPlayWaitMinutes==0 )
 	{
 		return FALSE;   // we recomment the caller to leave the queue position as is
 		// (autoplay will enqueue the next song at once)
@@ -1170,3 +1174,5 @@ bool SjQueue::MoveToTopOnEoq() const
 	// (the user may hit "play" and does not want to hear the last
 	// song again)
 }
+
+
