@@ -36,10 +36,12 @@
 
 #include <sjbase/base.h>
 #include <sjtools/imgthread.h>
+#include <sjtools/msgbox.h>
 #include <sjbase/skin.h>
 #include <sjbase/skinml.h>
 #include <sjmodules/kiosk/kiosk.h>
 #include <sjmodules/kiosk/virtkeybd.h>
+#include <sjmodules/vis/vis_module.h>
 #include <sjmodules/vis/vis_bg.h>
 #include <see_dom/sj_see.h>
 #include <wx/display.h>
@@ -222,7 +224,7 @@ void SjSkinItem::HideDragImage()
 	if( m_skinWindow->m_dragImage || s_globalDragImageHidden )
 	{
 		if( s_globalDragImageHidden == 0
-		        && m_skinWindow->m_dragRect.Intersects(GetScreenRect()) )
+		 && m_skinWindow->m_dragRect.Intersects(GetScreenRect()) )
 		{
 			m_skinWindow->m_dragImage->Hide();
 		}
@@ -257,7 +259,7 @@ void SjSkinItem::RedrawMe()
 
 	// anything to redraw?
 	if( m_rect.width == 0 || m_rect.height == 0
-	 || m_skinWindow == NULL || m_skinWindow->m_currLayout == NULL /*see https://mail.google.com/a/b44t.com/#all/11fa3299de85ce8f*/ )
+	 || m_skinWindow == NULL || m_skinWindow->m_currLayout == NULL )
 	{
 		return;
 	}
@@ -319,9 +321,10 @@ void SjSkinItem::RedrawMe()
 
 		if( !drawDone )
 		{
-			// ...drawing onscreen, faster but with flickering
-			dc.DestroyClippingRegion();
-			dc.SetClippingRegion(m_rect);
+			// ...drawing onscreen, faster but with flickering.
+			// We do not call dc.SetClippingRegion(m_rect) as nested clippings via GetClippingBox() do not work well
+			// and the dc.SetClippingRegion() is needed by the called classes
+			// (dc.SetClippingRegion() should only be used in the last iteration before _really_ drawing).
 			HideDragImage();
 			m_skinWindow->RedrawAll(dc, &m_rect);
 			m_skinWindow->RedrawFinalLines(dc);
@@ -415,7 +418,6 @@ bool SjSkinBoxItem::Create(const wxHtmlTag& tag, wxString& error)
 
 	m_alwaysRedrawBackground = !m_colours[SJ_COLOUR_NORMAL].bgSet;
 
-
 	if( !m_width.IsSet() )
 	{
 		m_width.SetAbs(16);
@@ -437,9 +439,9 @@ void SjSkinBoxItem::SetValue(const SjSkinValue& value)
 	long totalMs = (flags&SJ_VFLAG_VMAX_IS_TIME)? value.vmax : 0;
 
 	if( m_runningMs != runningMs
-	        || m_totalMs != totalMs
-	        || m_flags != flags
-	        || m_text != value.string )
+	 || m_totalMs != totalMs
+	 || m_flags != flags
+	 || m_text != value.string )
 	{
 		m_text = value.string;
 		m_flags = flags;
@@ -456,20 +458,20 @@ int SjSkinBoxItem::FindSubitem(long x, long y, wxRect& subitemRect)
 	subitemRect.height--;
 
 	if( x >= m_rect.x
-	        && y >= m_rect.y
-	        && x < (m_rect.x + m_rect.width)
-	        && y < (m_rect.y + m_rect.height) )
+	 && y >= m_rect.y
+	 && x < (m_rect.x + m_rect.width)
+	 && y < (m_rect.y + m_rect.height) )
 	{
 		if( x > m_rect.x+m_timeXrel
-		        && x < m_rect.x+m_timeXrel+m_timeW
-		        && m_flags & SJ_VFLAG_TIME_CLICKABLE )
+		 && x < m_rect.x+m_timeXrel+m_timeW
+		 && m_flags & SJ_VFLAG_TIME_CLICKABLE )
 		{
 			subitemRect.x = m_rect.x+m_timeXrel;
 			subitemRect.width = m_timeW;
 			return SJ_SUBITEM_TIME;
 		}
 		else if( x > m_rect.x+m_iconRightXrel
-		         && x < m_rect.x+m_iconRightXrel+m_iconRightW  )
+		      && x < m_rect.x+m_iconRightXrel+m_iconRightW  )
 		{
 			subitemRect.x = m_rect.x+m_iconRightXrel;
 			subitemRect.width = m_iconRightW;
@@ -536,7 +538,7 @@ bool SjSkinBoxItem::OnImageThere(wxDC& dc, SjImgThreadObj* obj)
 void SjSkinBoxItem::DrawBackground(wxDC& dc)
 {
 	if( (m_border && m_colours[SJ_COLOUR_NORMAL].fgSet)
-	        ||  m_colours[SJ_COLOUR_NORMAL].bgSet )
+	 ||  m_colours[SJ_COLOUR_NORMAL].bgSet )
 	{
 		dc.SetPen((m_border&&m_colours[SJ_COLOUR_NORMAL].fgSet)? m_colours[SJ_COLOUR_NORMAL].fgPen : *wxTRANSPARENT_PEN);
 		dc.SetBrush(m_colours[SJ_COLOUR_NORMAL].bgSet? m_colours[SJ_COLOUR_NORMAL].bgBrush : *wxTRANSPARENT_BRUSH);
@@ -604,9 +606,6 @@ void SjSkinBoxItem::DrawText(wxDC& dc)
 
 	// set clipping
 	#ifdef SJ_BOXTEXT_WITH_CLIPPING
-		wxRect oldClipping;
-		dc.GetClippingBox(&oldClipping.x, &oldClipping.y, &oldClipping.width, &oldClipping.height);
-		dc.DestroyClippingRegion();
 		dc.SetClippingRegion(m_rect);
 	#endif
 
@@ -800,7 +799,7 @@ void SjSkinBoxItem::DrawText(wxDC& dc)
 
 	// strike?
 	if(  m_mouseSubitem==SJ_SUBITEM_ICONRIGHT
-	        && (m_flags&SJ_VFLAG_ICONR_DELETE) )
+	 && (m_flags&SJ_VFLAG_ICONR_DELETE) )
 	{
 		dc.SetPen(m_colours[SJ_COLOUR_NORMAL].fgPen);
 
@@ -811,10 +810,6 @@ void SjSkinBoxItem::DrawText(wxDC& dc)
 	// restore clipping/font
 	#ifdef SJ_BOXTEXT_WITH_CLIPPING
 		dc.DestroyClippingRegion();
-		if( oldClipping.width && oldClipping.height )
-		{
-			dc.SetClippingRegion(oldClipping);
-		}
 	#endif
 
 	// set normal font, release our font from DC
@@ -887,7 +882,7 @@ void SjSkinBoxItem::OnMouseLeftDown(long x, long y, bool doubleClick, long accel
 			m_mouseDownY    = y;
 
 			if( doubleClick
-			        && m_mouseSubitem == SJ_SUBITEM_TEXT )
+			 && m_mouseSubitem == SJ_SUBITEM_TEXT )
 			{
 				m_mouseState    = SJ_MOUSE_STATE_NORMAL;
 				RedrawMe();
@@ -968,7 +963,6 @@ SjMouseUsed SjSkinBoxItem::OnMouseLeftUp(long x, long y, long accelFlags, bool c
 	// always reset the cursor
 	if( m_skinWindow->m_mouseInDisplayMove )
 	{
-		m_skinWindow->SetCursor(SjVirtKeybdModule::GetStandardCursor());
 		m_skinWindow->m_mouseInDisplayMove = FALSE;
 	}
 
@@ -1004,7 +998,7 @@ void SjSkinBoxItem::OnMouseMotion(long x, long y, bool leftDown)
 			{
 				// report the derived class that the item is moved up/down if not yet done
 				if(  motionItem != this
-				        && !m_mouseMoveReported )
+				 && !m_mouseMoveReported )
 				{
 					m_mouseResumeX = x;
 					m_mouseResumeY = y;
@@ -1014,10 +1008,10 @@ void SjSkinBoxItem::OnMouseMotion(long x, long y, bool leftDown)
 
 						long lineDifference;
 						if( m_targetId >= IDT_DISPLAY_LINE_FIRST
-						        && m_targetId <= IDT_DISPLAY_LINE_LAST
-						        && motionItem // may be NULL!
-						        && motionItem->m_targetId >= IDT_DISPLAY_LINE_FIRST
-						        && motionItem->m_targetId <= IDT_DISPLAY_LINE_LAST )
+						 && m_targetId <= IDT_DISPLAY_LINE_LAST
+						 && motionItem // may be NULL!
+						 && motionItem->m_targetId >= IDT_DISPLAY_LINE_FIRST
+						 && motionItem->m_targetId <= IDT_DISPLAY_LINE_LAST )
 						{
 							lineDifference = motionItem->m_targetId - m_targetId;
 						}
@@ -1043,13 +1037,12 @@ void SjSkinBoxItem::OnMouseMotion(long x, long y, bool leftDown)
 			}
 			else if( ( m_mouseSubitem == SJ_SUBITEM_TEXT )
 			         && ( m_flags & SJ_VFLAG_MOVABLE )
-			         && ( motionItem != this
+			         && (    motionItem != this
 			              || hDifference >  MOVESTART_DELTA
 			              || hDifference < -MOVESTART_DELTA
 			              || vDifference >  MOVESTART_DELTA
 			              || vDifference < -MOVESTART_DELTA ) )
 			{
-				m_skinWindow->SetCursor(g_tools->m_staticMovehandCursor);
 				m_skinWindow->m_mouseInDisplayMove = TRUE;
 				m_mouseMoveReported = FALSE;
 				m_timerLastMoveMs = 0;
@@ -1074,7 +1067,7 @@ void SjSkinBoxItem::OnMouseMotion(long x, long y, bool leftDown)
 		else
 		{
 			if( motionSubitem != m_mouseSubitem
-			        || m_mouseState != SJ_MOUSE_STATE_HOVER )
+			 || m_mouseState != SJ_MOUSE_STATE_HOVER )
 			{
 				m_mouseSubitem  = motionSubitem;
 				m_mouseState    = SJ_MOUSE_STATE_HOVER;
@@ -1095,14 +1088,16 @@ void SjSkinBoxItem::OnMouseMotion(long x, long y, bool leftDown)
 		inHere = FALSE;
 	}
 }
+
+
 void SjSkinWindow::ResumeSkinTargetMotion(int clickedTargetId, int resumeTargetId)
 {
 	// contined from (***)
 
 	if( clickedTargetId >= IDT_DISPLAY_LINE_FIRST
-	        && clickedTargetId <= IDT_DISPLAY_LINE_LAST
-	        && resumeTargetId  >= IDT_DISPLAY_LINE_FIRST
-	        && resumeTargetId  <= IDT_DISPLAY_LINE_LAST )
+	 && clickedTargetId <= IDT_DISPLAY_LINE_LAST
+	 && resumeTargetId  >= IDT_DISPLAY_LINE_FIRST
+	 && resumeTargetId  <= IDT_DISPLAY_LINE_LAST )
 	{
 		SjSkinBoxItem* clickedItem = (SjSkinBoxItem*)FindFirstItemByTargetId(clickedTargetId);
 		SjSkinBoxItem* resumeItem  = (SjSkinBoxItem*)FindFirstItemByTargetId(resumeTargetId );
@@ -1138,10 +1133,14 @@ void SjSkinWindow::ResumeSkinTargetMotion(int clickedTargetId, int resumeTargetI
 		}
 	}
 }
+
+
 void SjSkinBoxItem::OnTimer()
 {
 	OnMouseMotion(m_mouseResumeX, m_mouseResumeY, TRUE);
 }
+
+
 bool SjSkinBoxItem::CheckMovementTimer()
 {
 	unsigned long thisMs = SjTools::GetMsTicks();
@@ -1447,7 +1446,7 @@ SjMouseUsed SjSkinButtonItem::OnMouseLeftUp(long x, long y, long accelFlags, boo
 	SjMouseUsed ret = SJ_MOUSE_NOT_USED;
 
 	if( m_mouseState == SJ_MOUSE_STATE_CLICKED
-	        || m_mouseState == SJ_MOUSE_STATE_HOVER )
+	 || m_mouseState == SJ_MOUSE_STATE_HOVER )
 	{
 		// First, set mouse state to "normal".
 		m_mouseState = SJ_MOUSE_STATE_NORMAL;
@@ -1493,11 +1492,10 @@ SjMouseUsed SjSkinButtonItem::OnMouseLeftUp(long x, long y, long accelFlags, boo
 			{
 				ret = SJ_MOUSE_USE_DELAYED;
 
-				if( !m_onclick.IsEmpty() )
-				{
-					#if SJ_USE_SCRIPTS
-						SjSee* see = m_skinWindow->m_currSkin->m_see;
-
+				#if SJ_USE_SCRIPTS
+					SjSee* see = m_skinWindow->m_currSkin->m_see;
+					if( see && !m_onclick.IsEmpty() )
+					{
 						see->ExecuteAsFunction(m_onclick);
 						// ExecuteAsFunction() is a little hack as long as we have no real DOM for the skinning tree
 						// ExecuteAsFunction() allows to use eg. "return false;" from the handler - a simple
@@ -1506,7 +1504,9 @@ SjMouseUsed SjSkinButtonItem::OnMouseLeftUp(long x, long y, long accelFlags, boo
 						if( see->IsResultDefined() )
 						{
 							if( !see->GetResultLong() )
+							{
 								ret = SJ_MOUSE_USED;
+							}
 
 							if( ret == SJ_MOUSE_USED && m_delayedRedraw )
 							{
@@ -1515,10 +1515,8 @@ SjMouseUsed SjSkinButtonItem::OnMouseLeftUp(long x, long y, long accelFlags, boo
 								RedrawMe();
 							}
 						}
-					#else
-                        wxLogError(wxT("Scripts are not supported in this build."));
-					#endif
-				}
+					}
+				#endif
 			}
 		}
 		else
@@ -1567,7 +1565,7 @@ void SjSkinButtonItem::OnMouseMotion(long x, long y, bool leftDown)
 	else
 	{
 		if( m_mouseState != SJ_MOUSE_STATE_HOVER
-		        && m_bitmaps[m_buttonState][SJ_MOUSE_STATE_HOVER] )
+		 && m_bitmaps[m_buttonState][SJ_MOUSE_STATE_HOVER] )
 		{
 			m_mouseState = SJ_MOUSE_STATE_HOVER;
 			RedrawMe();
@@ -1848,9 +1846,9 @@ void SjSkinScrollbarItem::SetValue(const SjSkinValue& value)
 
 	// any changes?
 	if( m_value     != newValue
-	        || m_vmin      != newMin
-	        || m_vmax      != newMax
-	        || m_thumbSize != value.thumbSize )
+	 || m_vmin      != newMin
+	 || m_vmax      != newMax
+	 || m_thumbSize != value.thumbSize )
 	{
 		// save settings
 		m_value     = newValue;
@@ -1859,7 +1857,7 @@ void SjSkinScrollbarItem::SetValue(const SjSkinValue& value)
 		m_vrange    = newRange;
 		m_thumbSize = value.thumbSize;
 
-		//wxLogDebug("min=%i max=%i range=%i value=%i thumbSize=%i", m_vmin, m_vmax, m_vrange, m_value, m_thumbSize);
+		//wxLogDebug("min=%i max=%i range=%i value=%i thumbSize=%i", (int)m_vmin, (int)m_vmax, (int)m_vrange, (int)m_value, (int)m_thumbSize);
 
 		if( m_thumbSize > m_vrange )
 		{
@@ -1971,7 +1969,7 @@ void SjSkinScrollbarItem::OnMouseLeftDown(long x, long y, bool doubleClick, long
 		if( m_trackPart )
 		{
 			if( m_trackPart == &m_thumbPart
-			        || m_thumbSize )
+			 || m_thumbSize )
 			{
 				if( m_hoverPart )
 				{
@@ -2108,7 +2106,7 @@ void SjSkinScrollbarItem::OnMouseLeave()
 void SjSkinScrollbarItem::OnTimer()
 {
 	if( m_trackPart == &m_pageLeftPart
-	        || m_trackPart == &m_pageRightPart )
+	 || m_trackPart == &m_pageRightPart )
 	{
 		if( !m_inTimer )
 		{
@@ -2177,9 +2175,13 @@ void SjSkinScrollbarItem::OnPaint(wxDC& dc)
 
 	if( !m_hideScrollbar )
 	{
-		SwapNDrawPart(dc, m_pageLeftPart);
 		SwapNDrawPart(dc, m_thumbPart);
 		SwapNDrawPart(dc, m_pageRightPart, TRUE);
+		SwapNDrawPart(dc, m_pageLeftPart); // is there a but in wxMac's wxDC::DestroyClippingRegion()? Or is it
+			// just me? If we draw the left part first, there are clipping bugs if the scrollbar is leftmost/topmost
+			// then useing wxClientDC (wxPaintDC is fine). See also SjTools::DrawBitmapHBg() and SjTools::DrawBitmapVBg().
+			// If we encounter other errors, we should avoid clipping in these functions and use wxDC::GetSubBitmap()
+			// instead.
 	}
 }
 
@@ -2189,8 +2191,8 @@ void SjSkinScrollbarItem::SwapNDrawPart(wxDC& dc, SjSkinScrollbarItemPart& part,
 	wxASSERT(g_tools);
 
 	if( part.m_bitmapPrologue[part.m_mouseState]
-	        || part.m_bitmapRepeat  [part.m_mouseState]
-	        || part.m_bitmapEpilogue[part.m_mouseState] )
+	 || part.m_bitmapRepeat  [part.m_mouseState]
+	 || part.m_bitmapEpilogue[part.m_mouseState] )
 	{
 		if( m_horizontal )
 		{
@@ -2359,7 +2361,7 @@ void SjSkinInputItem::OnSize()
 	{
 		// update colour
 		if( m_skinWindow->m_inputWindowBgColour != m_colours[SJ_COLOUR_NORMAL].bgColour
-		        || m_skinWindow->m_inputWindowFgColour != m_colours[SJ_COLOUR_NORMAL].fgColour )
+		 || m_skinWindow->m_inputWindowFgColour != m_colours[SJ_COLOUR_NORMAL].fgColour )
 		{
 			iw->SetForegroundColour(m_colours[SJ_COLOUR_NORMAL].fgColour);
 			iw->SetBackgroundColour(m_colours[SJ_COLOUR_NORMAL].bgColour);
@@ -2431,16 +2433,16 @@ bool SjSkinDivItem::Create(const wxHtmlTag& tag, wxString& error)
 			wxString s = tag.GetParam(wxT("INDENT"));
 			long l;
 
-			s.BeforeFirst(wxT(',')).ToLong(&l); s = s.AfterFirst(wxT(','));
+			if( !s.BeforeFirst(wxT(',')).ToLong(&l) ) { l = 0; } s = s.AfterFirst(wxT(','));
 			m_indent.x = l;
 
-			s.BeforeFirst(wxT(',')).ToLong(&l); s = s.AfterFirst(wxT(','));
+			if( !s.BeforeFirst(wxT(',')).ToLong(&l) ) { l = 0; } s = s.AfterFirst(wxT(','));
 			m_indent.y = l;
 
-			s.BeforeFirst(wxT(',')).ToLong(&l); s = s.AfterFirst(wxT(','));
+			if( !s.BeforeFirst(wxT(',')).ToLong(&l) ) { l = 0; } s = s.AfterFirst(wxT(','));
 			m_indent.width = l;
 
-			s.ToLong(&l);
+			if( !s.ToLong(&l) ) { l = 0; }
 			m_indent.height = l;
 		}
 
@@ -2448,103 +2450,19 @@ bool SjSkinDivItem::Create(const wxHtmlTag& tag, wxString& error)
 		if( tag.GetParamAsInt(wxT("VISAUTOSTART"), &test) )
 		{
 			if( test == 1 )
+			{
 				m_prop |= SJ_SKIN_PROP_AUTO_START_VIS;
+			}
 		}
 	}
 
 	m_usesPaint     = FALSE;
-	m_inMove        = FALSE;
-	m_inMotion      = FALSE;
 	m_itemType      = SJ_DIVITEM;
-	m_cursorChanged = FALSE;
 
 	return TRUE;
 }
 
 
-void SjSkinDivItem::OnMouseLeftDown(long x, long y, bool doubleClick, long accelFlags)
-{
-	wxASSERT(m_skinWindow);
-}
-
-
-void SjSkinDivItem::OnMouseMotion(long x, long y, bool leftDown)
-{
-	wxASSERT(m_skinWindow);
-
-	if( leftDown
-	        && m_inMove
-	        && !m_inMotion )
-	{
-		m_inMotion = TRUE;
-
-		// get screen position of the mouse cursor
-		wxPoint screenMousePoint = ::wxGetMousePosition();
-		long hDiff = screenMousePoint.x - m_onDownMouseScreenX,
-		     vDiff = screenMousePoint.y - m_onDownMouseScreenY;
-
-		// change cursor if not yet done
-		if( !m_cursorChanged )
-		{
-			if( hDiff >  SJ_DRAGMOVE_DELTA
-			        || hDiff < -SJ_DRAGMOVE_DELTA
-			        || vDiff >  SJ_DRAGMOVE_DELTA
-			        || vDiff < -SJ_DRAGMOVE_DELTA )
-			{
-				wxASSERT(g_tools);
-				m_skinWindow->SetCursor(g_tools->m_staticMovehandCursor);
-				m_cursorChanged = TRUE;
-
-				SjSkinValue dummy;
-				m_skinWindow->OnSkinTargetEvent(IDMODMSG_WINDOW_SIZE_MOVE_BEGIN, dummy, 0);
-			}
-		}
-
-		// move window
-		if( m_cursorChanged )
-		{
-			// get old size
-			int windowW, windowH;
-			m_skinWindow->GetSize(&windowW, &windowH);
-
-			// calc new position
-			long newWindowX = m_onDownWindowX + hDiff;
-			long newWindowY = m_onDownWindowY + vDiff;
-
-			// set new size and position
-			m_skinWindow->SetSize(newWindowX, newWindowY, windowW, windowH);
-		}
-
-		m_inMotion = FALSE;
-	}
-}
-
-
-SjMouseUsed SjSkinDivItem::OnMouseLeftUp(long x, long y, long accelFlags, bool captureLost)
-{
-	wxASSERT(m_skinWindow);
-
-	SjMouseUsed ret = SJ_MOUSE_NOT_USED;
-	if( m_inMove )
-	{
-		if( m_cursorChanged )
-		{
-			m_skinWindow->SetCursor(SjVirtKeybdModule::GetStandardCursor());
-			m_cursorChanged = FALSE;
-
-			SjSkinValue dummy;
-			m_skinWindow->OnSkinTargetEvent(IDMODMSG_WINDOW_SIZE_MOVE_END, dummy, accelFlags);
-
-			ret = SJ_MOUSE_USED; // don't send a delayed event
-		}
-
-		m_inMove = FALSE;
-	}
-
-	return ret;
-}
-
-
 /*******************************************************************************
  * SjSkin - Loading And Selecting Skins
  ******************************************************************************/
@@ -2557,18 +2475,17 @@ BEGIN_EVENT_TABLE(SjSkinWindow, wxFrame)
 	EVT_LEFT_DOWN           (SjSkinWindow::OnMouseLeftDown      )
 	EVT_LEFT_DCLICK         (SjSkinWindow::OnMouseLeftDown      )
 	EVT_LEFT_UP             (SjSkinWindow::OnMouseLeftUp        )
-	EVT_MOUSE_CAPTURE_LOST  (SjSkinWindow::OnMouseCaptureLost       )
-#ifdef __WXMAC__ // the context menu MUST be opened on down on MAC
-	EVT_RIGHT_DOWN          (SjSkinWindow::OnMouseRight         )
-#else
-	EVT_RIGHT_UP            (SjSkinWindow::OnMouseRight         )
-#endif
+	EVT_MOUSE_CAPTURE_LOST  (SjSkinWindow::OnMouseCaptureLost   )
+	EVT_CONTEXT_MENU        (SjSkinWindow::OnMouseRight         )
 	EVT_MIDDLE_UP           (SjSkinWindow::OnMouseMiddleUp      )
-	EVT_MOTION              (SjSkinWindow::OnMouseMotion            )
+	EVT_MOTION              (SjSkinWindow::OnMouseMotion        )
 	EVT_LEAVE_WINDOW        (SjSkinWindow::OnMouseLeave         )
 	EVT_PAINT               (SjSkinWindow::OnPaint              )
-	EVT_ERASE_BACKGROUND    (SjSkinWindow::OnEraseBackground        )
+	EVT_ERASE_BACKGROUND    (SjSkinWindow::OnEraseBackground    )
 	EVT_IMAGE_THERE         (SjSkinWindow::OnImageThere         )
+	#ifdef __WXGTK__
+	EVT_TIMER               (IDTIMER_SETSIZEHACK, SjMainFrame::OnSetSizeHackTimer)
+	#endif
 END_EVENT_TABLE()
 
 
@@ -2674,22 +2591,22 @@ void SjSkinWindow::SaveSizes()
 		{
 			SjSkinLayout* dependingLayout = m_currSkin->GetLayout(l);
 			if( dependingLayout
-			        && dependingLayout != m_currLayout )
+			 && dependingLayout != m_currLayout )
 			{
 				if( !dependingLayout->m_useWidth.IsEmpty()
-				        &&  dependingLayout->m_useWidth == m_currLayout->m_useWidth )
+				 &&  dependingLayout->m_useWidth == m_currLayout->m_useWidth )
 				{
 					dependingLayout->m_currRect.width = currRect.width;
 				}
 
 				if( !dependingLayout->m_useHeight.IsEmpty()
-				        &&  dependingLayout->m_useHeight == m_currLayout->m_useHeight )
+				 &&  dependingLayout->m_useHeight == m_currLayout->m_useHeight )
 				{
 					dependingLayout->m_currRect.height = currRect.height;
 				}
 
 				if( !dependingLayout->m_usePos.IsEmpty()
-				        &&  dependingLayout->m_usePos == m_currLayout->m_usePos )
+				 &&  dependingLayout->m_usePos == m_currLayout->m_usePos )
 				{
 					dependingLayout->m_currRect.x   = currRect.x;
 					dependingLayout->m_currRect.y   = currRect.y;
@@ -2767,12 +2684,12 @@ void SjSkinWindow::LoadLayout(SjSkinLayout* newLayout /*may be NULL*/,
 			{
 				m_targets[item->m_targetId].m_itemList.Append(item);
 
-#ifdef SJ_SKIN_USE_HIDE
+				#ifdef SJ_SKIN_USE_HIDE
 				if( m_targets[item->m_targetId].m_hidden )
 				{
 					HideSkinTarget(item->m_targetId, TRUE/*hide*/, FALSE/*redraw*/);
 				}
-#endif
+				#endif
 
 				item->SetValue(m_targets[item->m_targetId].m_value);
 			}
@@ -2781,9 +2698,9 @@ void SjSkinWindow::LoadLayout(SjSkinLayout* newLayout /*may be NULL*/,
 		}
 	}
 
-#ifdef SJ_SKIN_USE_HIDE
+	#ifdef SJ_SKIN_USE_HIDE
 	HidingSkinTargetsDone(FALSE/*redraw*/);
-#endif
+	#endif
 
 	// create a direct link to the workspace colours;
 	// if the current layout has no workspace, we leave the pointer unchanged.
@@ -2803,8 +2720,8 @@ void SjSkinWindow::LoadLayout(SjSkinLayout* newLayout /*may be NULL*/,
 	if( sizeChangeFlag != SJ_NO_SIZE_CHANGE )
 	{
 		bool doSizeChange = (sizeChangeFlag==SJ_FORCE_SIZE_CHANGE
-		                     || g_kioskModule==NULL
-		                     || !g_kioskModule->KioskStarted());
+		                  || g_kioskModule==NULL
+		                  || !g_kioskModule->KioskStarted());
 		wxRect wantedRect = GetRect();
 		if( m_currLayout )
 		{
@@ -2822,7 +2739,7 @@ void SjSkinWindow::LoadLayout(SjSkinLayout* newLayout /*may be NULL*/,
 			}
 
 			// set the new tooltip colours
-#if SJ_USE_TOOLTIPS
+			#if SJ_USE_TOOLTIPS
 			if( m_currSkin->HasTooltipColours() )
 			{
 				g_tools->m_toolTipManager.SetColours(m_currSkin->GetTooltipFgColour(), m_currSkin->GetTooltipBgColour(), m_currSkin->GetTooltipBorderColour());
@@ -2831,7 +2748,7 @@ void SjSkinWindow::LoadLayout(SjSkinLayout* newLayout /*may be NULL*/,
 			{
 				g_tools->m_toolTipManager.SetDefColours();
 			}
-#endif
+			#endif
 
 			// set "always on top"
 			if( doSizeChange )
@@ -2843,7 +2760,14 @@ void SjSkinWindow::LoadLayout(SjSkinLayout* newLayout /*may be NULL*/,
 		if( doSizeChange )
 		{
 			SjDialog::EnsureRectDisplayVisibility(wantedRect);
-			SetSkinWindowRect(wantedRect);
+			wxRect rectToSet = CheckLayoutWindowRect(m_currLayout, wantedRect);
+			SetSize(rectToSet);
+			#ifdef __WXGTK__
+				m_setSizeHackRect = rectToSet; // SETSIZEHACK, Hack the bad SetSize() implementation
+				m_setSizeHackCnt = 0;
+				m_setSizeHackTimer.SetOwner(this, IDTIMER_SETSIZEHACK);
+				m_setSizeHackTimer.Start(50);
+			#endif
 		}
 	}
 
@@ -2852,6 +2776,15 @@ void SjSkinWindow::LoadLayout(SjSkinLayout* newLayout /*may be NULL*/,
 
 	CalcItemRectangles(clientSize.x, clientSize.y);
 
+	// set minimal size - the maximal size is ignored there seems not to be a good reason for this (eg. maximizing the window should always be possible)
+	if( m_currLayout )
+	{
+		wxSize skinMinSize, skinMaxSize;
+		GetLayoutMinMax(m_currLayout, skinMinSize, skinMaxSize);
+		SetMinSize(skinMinSize);
+	}
+
+
 	// redraw the window
 	if( IsShown() )
 	{
@@ -2860,6 +2793,28 @@ void SjSkinWindow::LoadLayout(SjSkinLayout* newLayout /*may be NULL*/,
 }
 
 
+#ifdef __WXGTK__
+void SjSkinWindow::OnSetSizeHackTimer(wxTimerEvent& event)
+{
+	// the first moments, GetRect() is simelar to the wanted rect, but after realisation, it is different.
+	// exactly, at this moment, we call SetSize() again with the wanted rect.
+	// if all this takes longer than 1 seconds, we give up (and we do not want to disturb systems that have no bug).
+	if( GetRect() != m_setSizeHackRect )
+	{
+		m_setSizeHackTimer.Stop();
+		SetSize(m_setSizeHackRect);
+		return;
+	}
+
+	m_setSizeHackCnt++;
+	if( m_setSizeHackCnt > 20 )
+	{
+		m_setSizeHackTimer.Stop();
+	}
+}
+#endif
+
+
 void SjSkinWindow::ShowAlwaysOnTop(bool alwaysOnTop)
 {
 	if( m_currLayout )
@@ -2875,12 +2830,17 @@ void SjSkinWindow::ShowAlwaysOnTop(bool alwaysOnTop)
 			SetWindowStyle(GetWindowStyle() & ~wxSTAY_ON_TOP);
 		}
 
+		if( g_visModule )
+		{
+			g_visModule->ShowVisAlwaysOnTop(alwaysOnTop);
+		}
+
 		SetSkinTargetValue(IDT_ALWAYS_ON_TOP, IsAlwaysOnTop()? 1 : 0);
 	}
 }
 
 
-bool SjSkinWindow::LoadSkin(const wxString& path, long conditions, const wxString& skinSettings, bool reloadScripts)
+bool SjSkinWindow::LoadSkin(const wxString& path, long conditions, const wxString& skinSettings, bool reloadScripts, wxWindow* askForScriptExecution)
 {
 	SjSkinMlParser parser(NULL, conditions);
 
@@ -2888,20 +2848,7 @@ bool SjSkinWindow::LoadSkin(const wxString& path, long conditions, const wxStrin
 	g_tools->UpdateFacenames();
 
 	// load the new skin - if reloadScripts is false, SjSee of the current skin is reused and the scripts are not parsed again.
-	#if SJ_USE_SCRIPTS
-		SjSee* see = NULL;
-		if( reloadScripts || m_currSkin == NULL )
-		{
-			see = new SjSee();
-			see->SetExecutionScope(path);
-		}
-	#endif
-
-	SjSkinSkin* newSkin = parser.ParseFile(path, false
-											#if SJ_USE_SCRIPTS
-	                                       , see
-											#endif
-	                                      );
+	SjSkinSkin* newSkin = parser.ParseFile(path, false);
 	if( !newSkin )
 	{
 		wxLogError(_("Cannot open \"%s\"."), path.c_str());
@@ -2909,12 +2856,37 @@ bool SjSkinWindow::LoadSkin(const wxString& path, long conditions, const wxStrin
 	}
 
 	#if SJ_USE_SCRIPTS
-	if( see == NULL )
-	{
-		wxASSERT( m_currSkin );
-		newSkin->m_see = m_currSkin->m_see;
-		m_currSkin->m_see = NULL;
-	}
+		if( reloadScripts || m_currSkin == NULL )
+		{
+			// this is the normal case, just load a new skin with a new scripting engine
+			if( newSkin->m_hasScripts )
+			{
+				if( askForScriptExecution )
+				{
+					if( SjMessageBox(wxString::Format(_("Do you want to execute the scripts embedded in the skin \"%s\"?")+"\n\n"+
+					                 _("CAUTION: Scripts may slow down Silverjuke or damage your data. Please use only scripts you trust."),
+					                 newSkin->GetName().c_str()),
+					                 SJ_PROGRAM_NAME, wxYES_NO|wxNO_DEFAULT|wxICON_QUESTION, askForScriptExecution) != wxYES )
+					{
+						delete newSkin;
+						return false;
+					}
+				}
+
+				newSkin->m_see = new SjSee();
+				newSkin->m_see->SetExecutionScope(path);
+				if( !newSkin->m_globalScript.IsEmpty() ) // if m_globalScript is unset, m_hasScripts may be true due to onclick-handlers
+				{
+					newSkin->m_see->Execute(newSkin->m_globalScript);
+				}
+			}
+		}
+		else
+		{
+			// re-use the existing scripting engine, if any
+			newSkin->m_see = m_currSkin->m_see;
+			m_currSkin->m_see = NULL;
+		}
 	#endif
 
 	// deselect the old layout (if any)
@@ -2931,16 +2903,16 @@ bool SjSkinWindow::LoadSkin(const wxString& path, long conditions, const wxStrin
 	{
 		// remember, m_currLayout is not yet set; therefore functions as
 		// this->GetLayoutCount() do not work - use m_currSkin->GetLayoutCount() instead
-#define SAVABLE_SETTINGS_VER 0L
+		#define SAVABLE_SETTINGS_VER 0L
 		SjStringSerializer ser(skinSettings);
 		long        serVersion = ser.GetLong();
 		wxString    serSkinName = ser.GetString();
 		long        serLayoutCount = ser.GetLong();
 		wxString    serDefLayoutName = ser.GetString();
 		if(  serVersion == SAVABLE_SETTINGS_VER
-		        &&  serSkinName == m_currSkin->GetName()
-		        &&  serLayoutCount == m_currSkin->GetLayoutCount()
-		        && !ser.HasErrors() )
+		 &&  serSkinName == m_currSkin->GetName()
+		 &&  serLayoutCount == m_currSkin->GetLayoutCount()
+		 && !ser.HasErrors() )
 		{
 			// load settings as saved from GetSavableSkinSettings()
 			int              l;
@@ -2954,11 +2926,11 @@ bool SjSkinWindow::LoadSkin(const wxString& path, long conditions, const wxStrin
 				serLayoutName = ser.GetString();
 				serRect = SjTools::ParseRect(ser.GetString());
 				if(  serLayout
-				        &&  serLayoutName == serLayout->GetName()
-				        && !ser.HasErrors() )
+				 &&  serLayoutName == serLayout->GetName()
+				 && !ser.HasErrors() )
 				{
 					if( serRect.width > 0
-					        && serRect.height > 0 )
+					 && serRect.height > 0 )
 					{
 						serRect = CheckLayoutWindowRect(serLayout, serRect, &serBadSize);
 						if( !serBadSize )
@@ -3044,12 +3016,6 @@ wxRect SjSkinWindow::CheckLayoutWindowRect(const SjSkinLayout* layout, const wxR
 }
 
 
-void SjSkinWindow::SetSkinWindowRect(const wxRect& wantedRect)
-{
-	SetSize(CheckLayoutWindowRect(m_currLayout, wantedRect));
-}
-
-
 void SjSkinWindow::ReloadSkin(long conditions, bool reloadScripts, SjLoadLayoutFlag sizeChangeFlag)
 {
 	if( m_currLayout )
@@ -3142,25 +3108,23 @@ void SjSkinWindow::CalcItemRectangles(long width, long height)
 
 	// move away unused windows
 	if(   m_workspaceWindow
-	        && (       !m_currLayout->m_hasWorkspace
-#ifdef SJ_SKIN_USE_HIDE
-	                   ||  m_targets[IDT_WORKSPACE].m_hidden
-#endif
-	                   ||  m_workspaceMovedAway
-	           )
-	  )
+	 && (   !m_currLayout->m_hasWorkspace
+	      #ifdef SJ_SKIN_USE_HIDE
+	      ||  m_targets[IDT_WORKSPACE].m_hidden
+	      #endif
+          ||  m_workspaceMovedAway
+	  ) )
 	{
 		wxSize oldSize = m_workspaceWindow->GetSize();
 		m_workspaceWindow->SetSize(-1000-oldSize.x, 0, oldSize.x, oldSize.y, wxSIZE_ALLOW_MINUS_ONE);
 	}
 
 	if(   m_inputWindow
-	        && (!m_currLayout->m_hasInput
-#ifdef SJ_SKIN_USE_HIDE
-	            || m_targets[IDT_SEARCH].m_hidden
-#endif
-	           )
-	  )
+	 && (   !m_currLayout->m_hasInput
+          #ifdef SJ_SKIN_USE_HIDE
+	      || m_targets[IDT_SEARCH].m_hidden
+          #endif
+	  ) )
 	{
 		m_inputWindow->SetSize(-1000, -1000, 100, 100, wxSIZE_ALLOW_MINUS_ONE);
 	}
@@ -3185,15 +3149,15 @@ SjSkinItem* SjSkinWindow::FindClickableItem(long x, long y) const
 			wxASSERT(item);
 
 			if(  item->m_usesMouse
-#ifdef SJ_SKIN_USE_HIDE
-			        && !item->m_hidden
-#endif
+			 #ifdef SJ_SKIN_USE_HIDE
+			 && !item->m_hidden
+			 #endif
 			  )
 			{
 				if( x >= item->m_rect.x
-				        && y >= item->m_rect.y
-				        && x < (item->m_rect.x + item->m_rect.width)
-				        && y < (item->m_rect.y + item->m_rect.height) )
+				 && y >= item->m_rect.y
+				 && x < (item->m_rect.x + item->m_rect.width)
+				 && y < (item->m_rect.y + item->m_rect.height) )
 				{
 					return item;
 				}
@@ -3231,7 +3195,7 @@ void SjSkinWindow::SetSkinTargetValue(int targetId, const SjSkinValue& value, bo
 
 	if(targetId <= 0 || targetId > IDT_LAST )
 	{
-		wxLogDebug(wxT("Invalid target ID %i")/*n/t*/, targetId);
+		wxLogDebug(wxT("Invalid target ID %i")/*n/t*/, (int)targetId);
 		return;
 	}
 
@@ -3290,7 +3254,7 @@ void SjSkinWindow::SetSkinText(const wxString& userId, const wxString& text)
 				wxASSERT(item);
 
 				if(  item->m_userId
-				        && *item->m_userId == userId )
+				 && *item->m_userId == userId )
 				{
 					if( item->m_itemType == SJ_BOXITEM )
 					{
@@ -3313,7 +3277,7 @@ bool SjSkinWindow::HideSkinTarget(int targetId, bool hide, bool redraw)
 {
 	if(targetId <= 0 || targetId > IDT_LAST )
 	{
-		wxLogDebug("Invalid target ID %i"/*n/t*/, targetId);
+		wxLogDebug("Invalid target ID %i"/*n/t*/, (int)targetId);
 		return FALSE;
 	}
 
@@ -3404,10 +3368,11 @@ void SjSkinWindow::OnSize(wxSizeEvent& event_doNotUse_mayBeUnsetByOurForwardings
 	mouseEvent.m_y = mousePos.y;
 	OnMouseMotion(mouseEvent);
 
-#ifdef __WXMAC__
-	Refresh(FALSE /*eraseBackground*/);
-	Update();
-#endif
+	// we added these line for wx2.x/Silverjuke2.x, however, it seems as if they're no longer needed in wx3.x/Sj15.x
+	//#ifdef __WXMAC__
+	//	Refresh(FALSE /*eraseBackground*/);
+	//	Update();
+	//#endif
 }
 
 
@@ -3435,9 +3400,9 @@ void SjSkinWindow::OnMouseLeftDown(wxMouseEvent& event)
 		OnMouseMotion(event);
 	}
 
-#if SJ_USE_TOOLTIPS
-	g_tools->m_toolTipManager.ClearToolTipProvider();
-#endif
+	#if SJ_USE_TOOLTIPS
+		g_tools->m_toolTipManager.ClearToolTipProvider();
+	#endif
 
 	if( m_mouseItem )
 	{
@@ -3451,12 +3416,12 @@ static int findCorner(const wxRect& r, const wxSize& delta, int x, int y)
 {
 	if( x >= r.x && x < r.x+delta.x )
 	{
-		if( y > r.y && y < r.y+delta.y )                       { return 1; } // top-left
+		     if( y > r.y && y < r.y+delta.y )                       { return 1; } // top-left
 		else if( y >= r.y+r.height-delta.y && y < r.y+r.height )    { return 3; } // bottom-left
 	}
 	else if( x >= r.x+r.width-delta.x && x < r.x+r.width )
 	{
-		if( y > r.y && y < r.y+delta.y )                       { return 2; } // top-right
+		     if( y > r.y && y < r.y+delta.y )                       { return 2; } // top-right
 		else if( y >= r.y+r.height-delta.y && y < r.y+r.height )    { return 4; } // bottom-right
 	}
 
@@ -3491,7 +3456,7 @@ void SjSkinWindow::OnMouseLeftUp(wxMouseEvent& event)
 		}
 	}
 
-#ifdef __WXDEBUG__
+	#ifdef __WXDEBUG__
 	switch(mouseUsed)
 	{
 		case SJ_MOUSE_NOT_USED:     wxLogDebug(wxT("SJ_MOUSE_NOT_USED"));       break;
@@ -3499,7 +3464,7 @@ void SjSkinWindow::OnMouseLeftUp(wxMouseEvent& event)
 		case SJ_MOUSE_USE_DELAYED:  wxLogDebug(wxT("SJ_MOUSE_USE_DELAYED"));    break;
 		default:                    wxASSERT(0);                                break;
 	}
-#endif
+	#endif
 
 	// check for "corner clicks"
 	//
@@ -3523,13 +3488,13 @@ void SjSkinWindow::OnMouseLeftUp(wxMouseEvent& event)
 		bool hotPartOfCorner = (findCorner(clientRect.Deflate(10), cornerSize, x, y)==0);
 		if( hotPartOfCorner || mouseUsed == SJ_MOUSE_NOT_USED )
 		{
-#define                 CORNER_TIMEOUT_MS 3500
+			#define                 CORNER_TIMEOUT_MS 3500
 			static unsigned long    lastCornerTime = 0;
 			unsigned long           thisCornerTime = SjTools::GetMsTicks();
 
 			if( thisCornerTime < lastCornerTime+CORNER_TIMEOUT_MS
-			        && thisCorner != lastCorner
-			        && lastCorner != 0 )
+			 && thisCorner != lastCorner
+			 && lastCorner != 0 )
 			{
 				SjSkinValue value;
 				OnSkinTargetEvent(IDO_CORNERCLICK, value, accelFlags);
@@ -3557,25 +3522,24 @@ void SjSkinWindow::OnMouseCaptureLost(wxMouseCaptureLostEvent& event)
 }
 
 
-void SjSkinWindow::OnMouseRight(wxMouseEvent& event)
+void SjSkinWindow::OnMouseRight(wxContextMenuEvent& event)
 {
 	if( !HasCapture() )
 	{
-		long    x = event.GetX(),
-		        y = event.GetY();
+		wxPoint clickPoint = ScreenToClient(event.GetPosition());
 
-#if SJ_USE_TOOLTIPS
-		g_tools->m_toolTipManager.ClearToolTipProvider();
-#endif
+		#if SJ_USE_TOOLTIPS
+			g_tools->m_toolTipManager.ClearToolTipProvider();
+		#endif
 
-		SjSkinItem* item = FindClickableItem(x, y);
+		SjSkinItem* item = FindClickableItem(clickPoint.x, clickPoint.y);
 		if( item )
 		{
-			OnSkinTargetContextMenu(item->m_targetId, x, y);
+			OnSkinTargetContextMenu(item->m_targetId, clickPoint.x, clickPoint.y);
 		}
 		else
 		{
-			OnSkinTargetContextMenu(IDT_NONE, x, y);
+			OnSkinTargetContextMenu(IDT_NONE, clickPoint.x, clickPoint.y);
 		}
 	}
 }
@@ -3588,9 +3552,9 @@ void SjSkinWindow::OnMouseMiddleUp(wxMouseEvent& event)
 		long    x = event.GetX(),
 		        y = event.GetY();
 
-#if SJ_USE_TOOLTIPS
-		g_tools->m_toolTipManager.ClearToolTipProvider();
-#endif
+		#if SJ_USE_TOOLTIPS
+			g_tools->m_toolTipManager.ClearToolTipProvider();
+		#endif
 
 		SjSkinItem* item = FindClickableItem(x, y);
 		if( item )
@@ -3639,7 +3603,7 @@ void SjSkinWindow::OnMouseMotion(wxMouseEvent& event)
 				m_mouseItem = item;
 				m_mouseItem->OnMouseMotion(x, y, FALSE);
 
-#if SJ_USE_TOOLTIPS
+				#if SJ_USE_TOOLTIPS
 				if( item->m_itemType == SJ_BOXITEM )
 				{
 					; // nothing to do, the box items handle the tooltips theirselved,
@@ -3658,15 +3622,14 @@ void SjSkinWindow::OnMouseMotion(wxMouseEvent& event)
 				{
 					g_tools->m_toolTipManager.ClearToolTipProvider();
 				}
-#endif
+				#endif
 			}
-#if SJ_USE_TOOLTIPS
+			#if SJ_USE_TOOLTIPS
 			else
 			{
-
 				g_tools->m_toolTipManager.ClearToolTipProvider();
 			}
-#endif
+			#endif
 		}
 	}
 }
@@ -3741,7 +3704,7 @@ void SjSkinWindow::OnImageThere(SjImageThereEvent& event)
 
 	SjSkinItem*           item;
 	SjSkinItemList::Node* itemnode = m_currLayout->m_itemList.GetFirst();
-	SjImgThreadObj*          obj = event.GetObj();
+	SjImgThreadObj*       obj = event.GetObj();
 	while( itemnode )
 	{
 		item = itemnode->GetData();
@@ -3785,7 +3748,7 @@ void SjSkinWindow::RedrawAll(wxDC& dc,
 		if( item->m_usesPaint )
 		{
 			if( rect == NULL
-			        || rect->Intersects(item->m_rect) )
+			 || rect->Intersects(item->m_rect) )
 			{
 				if( finalMoveX || finalMoveY )
 				{
@@ -3794,16 +3757,16 @@ void SjSkinWindow::RedrawAll(wxDC& dc,
 					item->OnSize();
 				}
 
-#ifdef SJ_SKIN_USE_HIDE
+				#ifdef SJ_SKIN_USE_HIDE
 				if( !item->m_hidden )
 				{
-#endif
+				#endif
 					item->HideDragImage();
 					item->OnPaint(dc);
 					item->ShowDragImage();
-#ifdef SJ_SKIN_USE_HIDE
+				#ifdef SJ_SKIN_USE_HIDE
 				}
-#endif
+				#endif
 
 				if( finalMoveX || finalMoveY )
 				{
@@ -3837,8 +3800,8 @@ void SjSkinWindow::RedrawFinalLines(wxDC& dc, long finalMoveX, long finalMoveY)
 				item = itemnode->GetData();
 				wxASSERT(item);
 
-				if( item->m_usesPaint
-				        && (item->m_alwaysRedrawBackground || item->m_hasOverlayingItems==1/*not:-1*/) )
+				if(  item->m_usesPaint
+				 && (item->m_alwaysRedrawBackground || item->m_hasOverlayingItems==1/*not:-1*/) )
 				{
 					dc.SetPen(redPen); // red to indicate complex and slow drawing
 				}
@@ -3854,6 +3817,10 @@ void SjSkinWindow::RedrawFinalLines(wxDC& dc, long finalMoveX, long finalMoveY)
 				itemnode = itemnode->GetNext();
 			}
 		}
+
+		#ifdef SJHOOK_FINALIZE_PAINTING
+		SJHOOK_FINALIZE_PAINTING
+		#endif
 	}
 }
 
@@ -3882,7 +3849,7 @@ long SjSkinWindow::GetTargetProp(int targetId)
 }
 
 
-bool SjSkinWindow::GetVisEmbedRect(wxRect* retRect, bool* retIsOverWorkspace, bool* retVisAutoStart) const
+void SjSkinWindow::GetVisEmbedRect(wxRect* retRect, bool* retIsOverWorkspace, bool* retVisAutoStart) const
 {
 	wxRect dummy1; if( retRect == NULL ) retRect = &dummy1;
 	bool   dummy2; if( retVisAutoStart == NULL ) retVisAutoStart = &dummy2;
@@ -3947,5 +3914,12 @@ bool SjSkinWindow::GetVisEmbedRect(wxRect* retRect, bool* retIsOverWorkspace, bo
 		}
 	}
 
-	return retRectOk;
+	// just use upper left right part
+	if( !retRectOk )
+	{
+		retRect->x      = 0;
+		retRect->y      = 0;
+		retRect->width  = 160;
+		retRect->height = 90;
+	}
 }
