@@ -209,10 +209,10 @@ static SjSkinMlParserRaw s_target2IdTable[] =
 	{ wxT("unqueue"),               IDT_UNQUEUE                                      },
 	{ wxT("unqueueall"),            IDT_UNQUEUE_ALL                                  },
 	{ wxT("mainmenu"),              IDT_MAINMENU                                     },
-	{ wxT("startvis"),              IDT_START_VIS                                    },
+	{ wxT("startvis"),              IDT_VIS_TOGGLE                                   },
 	{ wxT("updateindex"),           IDT_UPDATE_INDEX                                 },
 	{ wxT("deepupdateindex"),       IDT_DEEP_UPDATE_INDEX                            },
-	{ wxT("settings"),              IDT_SETTINGS_JUKEBOX                             },
+	{ wxT("settings"),              IDT_SETTINGS                                     },
 	{ wxT("gotorandom"),            IDT_WORKSPACE_GOTO_RANDOM                        },
 	{ wxT("stopafterthistrack"),    IDT_STOP_AFTER_THIS_TRACK                        },
 	{ wxT("stopaftereachtrack"),    IDT_STOP_AFTER_EACH_TRACK                        },
@@ -228,6 +228,7 @@ static SjSkinMlParserRaw s_target2IdTable[] =
 	{ wxT("togglekiosk"),           IDT_TOGGLE_KIOSK                                 },
 	{ wxT("doubleclickaction"),     IDT_PLAY_NOW_ON_DBL_CLICK                        },
 	{ wxT("removeplayed"),          IDT_TOGGLE_REMOVE_PLAYED                         },
+	{ wxT("prelisten"),             IDT_PRELISTEN                                    },
 
 	{ NULL, 0 }
 };
@@ -408,6 +409,7 @@ long SjSkinMlParserData::ParseCond(const wxString& str__, bool& notFlag)
 			flags |= SJ_OP_CREDIT_SYS__;
 		}
 		else if( token == wxT("volume")                             )   { flags |= SJ_OP_MAIN_VOL;          }
+		else if( token == wxT("prelisten")                          )   { flags |= SJ_OP_PRELISTEN;         }
 		else if( token == wxT("playpause")                          )   { flags |= SJ_OP_PLAYPAUSE;         }
 		else if( token == wxT("search")                             )   { flags |= SJ_OP_SEARCH;            }
 		else if( token == wxT("musicsel")                           )   { flags |= SJ_OP_MUSIC_SEL;         }
@@ -453,7 +455,7 @@ bool SjSkinMlParserData::CheckCond(const wxHtmlTag* tag)
 	str = tag->GetParam(wxT("VERSION"));
 	if( !str.IsEmpty() )
 	{
-		if( SjTools::VersionString2Long(wxT(SJ_VERSION_ASCII)) >= SjTools::VersionString2Long(str) )
+		if( ((SJ_VERSION_MAJOR<<24)|(SJ_VERSION_MINOR<<16)|(SJ_VERSION_REVISION<<8)) >= SjTools::VersionString2Long(str) )
 		{
 			return true;
 		}
@@ -859,12 +861,8 @@ bool SjSkinMlTagHandler::HandleTag(const wxHtmlTag& tag)
 		/* Handle <SCRIPT>
 		 ***********************************************************************************/
 
-		#if SJ_USE_SCRIPTS
-			if( skin->m_see == NULL )
-			{
-				return FALSE; // not needed for names loading
-			}
-
+		if( !m_skinMlParser->m_data->m_loadNameOnly )
+		{
 			wxString scriptContent;
 
 			// first, execute external file
@@ -872,11 +870,14 @@ bool SjSkinMlTagHandler::HandleTag(const wxHtmlTag& tag)
 			{
 				wxString scriptFile = tag.GetParam(wxT("SRC"));
 				if( skin->m_debugInfo )
+				{
 					wxLogInfo(wxT("Including \"%s\" [%s]")/*n/t*/, scriptFile.c_str(), m_skinMlParser->m_data->GetUrl().c_str());
+				}
 
 				scriptContent = m_skinMlParser->m_data->LoadFile_(scriptFile);
 
-				skin->m_see->Execute(scriptContent);
+				skin->m_globalScript += scriptContent + "\n\n";
+				skin->m_hasScripts = true;
 			}
 
 			// second, execute stuff between <script> and </script>
@@ -893,12 +894,11 @@ bool SjSkinMlTagHandler::HandleTag(const wxHtmlTag& tag)
 					if( scriptContent.Right(3) == wxT("-->") )
 						scriptContent = scriptContent.Left(scriptContent.Len()-3);
 
-					skin->m_see->Execute(scriptContent);
+					skin->m_globalScript += scriptContent + "\n\n";
+					skin->m_hasScripts = true;
 				}
 			}
-		#else
-			wxLogError(wxT("Scripts are not supported in this build."));
-		#endif
+		}
 
 		return FALSE; // parse inner not called
 	}
@@ -952,7 +952,13 @@ bool SjSkinMlTagHandler::HandleTag(const wxHtmlTag& tag)
 			return FALSE;
 		}
 
-		// initalize the colours
+		// check for scripting
+		if( tag.HasParam(wxT("ONCLICK")) )
+		{
+			skin->m_hasScripts = true;
+		}
+
+		// initialize the colours
 		if( tag.HasParam(wxT("FGCOLOR")) || tag.HasParam(wxT("BGCOLOR")) )
 		{
 			currItem->m_colours = new SjSkinColour[SJ_COLOUR_COUNT];
@@ -1254,15 +1260,10 @@ SjSkinMlParser::~SjSkinMlParser()
 
 
 SjSkinSkin* SjSkinMlParser::ParseFile(const wxString& url,
-                                      bool loadNameOnly
-                                      #if SJ_USE_SCRIPTS
-                                      , SjSee* see /*NULL if scripts should not be executed*/
-                                      #endif
-                                     )
+                                      bool loadNameOnly)
 {
 	wxASSERT(m_deleteData==TRUE);
 
-
 	// In versions before 1.11 silverjuke crashed if an erroneous skin was loaded;
 	// the reason for this was an uninitialized m_currTag pointer used in LogError,
 	// so we do not save a "current" tag any longer.
@@ -1282,11 +1283,7 @@ SjSkinSkin* SjSkinMlParser::ParseFile(const wxString& url,
 	}
 
 	// create and setup new skin
-	m_data->m_skin = new SjSkinSkin(
-	    #if SJ_USE_SCRIPTS
-	    see
-	    #endif
-	);
+	m_data->m_skin = new SjSkinSkin();
 	if( !m_data->m_skin )
 	{
 		return NULL;
@@ -1351,8 +1348,8 @@ SjSkinSkin* SjSkinMlParser::ParseFile(const wxString& url,
 					wxASSERT(item);
 
 					if( item->m_targetId == IDT_LAYOUT_FIRST
-					        && item->m_targetName
-					        && item->m_targetName->StartsWith(wxT("layout:"), &layoutName) )
+					 && item->m_targetName
+					 && item->m_targetName->StartsWith(wxT("layout:"), &layoutName) )
 					{
 						layoutTarget = m_data->m_skin->GetLayout(layoutName);
 						if( layoutTarget )
@@ -1370,8 +1367,8 @@ SjSkinSkin* SjSkinMlParser::ParseFile(const wxString& url,
 					}
 
 					if( item->m_doubleClickTargetId == IDT_LAYOUT_FIRST
-					        && item->m_doubleClickTargetName != NULL
-					        && item->m_doubleClickTargetName->StartsWith(wxT("layout:"), &layoutName) )
+					 && item->m_doubleClickTargetName != NULL
+					 && item->m_doubleClickTargetName->StartsWith(wxT("layout:"), &layoutName) )
 					{
 						layoutTarget = m_data->m_skin->GetLayout(layoutName);
 						if( layoutTarget )
@@ -1572,9 +1569,9 @@ SjSkinImage::~SjSkinImage()
 wxBitmap* SjSkinImage::GetSubimage(int indexX, int indexY)
 {
 	if( indexX >= 0
-	        && indexX < m_subimageXCount
-	        && indexY >= 0
-	        && indexY < m_subimageYCount )
+	 && indexX < m_subimageXCount
+	 && indexY >= 0
+	 && indexY < m_subimageYCount )
 	{
 		return m_subimages[indexY*m_subimageXCount + indexX]; // may be null!
 	}
@@ -1773,7 +1770,7 @@ SjSkinImage* SjSkinMlParserData::LoadSkinImage(const wxString& file, const wxHtm
 			}
 			else
 			{
-				LogError(wxString::Format(wxT("\"%s\": Subimage at %i/%i has a width or a height of null."), file.c_str(), x, y), tagPosition);
+				LogError(wxString::Format(wxT("\"%s\": Subimage at %i/%i has a width or a height of null."), file.c_str(), (int)x, (int)y), tagPosition);
 			}
 
 			if( y == 0 )
@@ -1800,7 +1797,7 @@ SjSkinImage* SjSkinMlParserData::LoadSkinImage(const wxString& file, const wxHtm
 	if( m_skin->m_debugInfo )
 	{
 		wxLogInfo(wxT("%s loaded with %ix%i subimage(s), %i skipped subimage(s), %i mask or alpha channel(s) [%s]")/*n/t*/,
-		          file.c_str(), subimageXCount, subimageYCount, (int)skippedCount, (int)image->m_hasMaskOrAlpha, GetUrl().c_str());
+		          file.c_str(), (int)subimageXCount, (int)subimageYCount, (int)skippedCount, (int)image->m_hasMaskOrAlpha, GetUrl().c_str());
 	}
 
 	return image;
@@ -1856,15 +1853,12 @@ SjSkinLayout::~SjSkinLayout()
  ******************************************************************************/
 
 
-SjSkinSkin::SjSkinSkin(
-    #if SJ_USE_SCRIPTS
-    SjSee* see
-    #endif
-)
+SjSkinSkin::SjSkinSkin()
 {
 	#if SJ_USE_SCRIPTS
-	m_see           = see;
+	m_see               = NULL;
 	#endif
+	m_hasScripts        = FALSE;
 	m_debugInfo         = FALSE;
 	m_debugOutline      = FALSE;
 	m_tooltipColoursSet = FALSE;
