@@ -100,10 +100,14 @@ bool SjAccelModule::FirstLoad()
 	OrgCmd(_("Paste"),                          IDO_PASTE_USING_COORD,     0, IDO_PASTE);
 	OrgCmd(_("Search"),                         IDT_SEARCH_BUTTON,         SJA_MAIN); OrgKey(wxACCEL_CTRL, 'F');
 	OrgCmd(_("Music selection..."),             IDT_ADV_SEARCH,            SJA_MAIN); OrgKey(wxACCEL_ALT, 'F');
-	OrgCmd(_("Jukebox settings..."),            IDT_SETTINGS_JUKEBOX,      SJA_MAIN); OrgKey(wxACCEL_ALT, 'P'); OrgKey(wxACCEL_ALT, WXK_RETURN);
-	OrgCmd(_("Advanced settings..."),           IDO_SETTINGS_ADV,          SJA_MAIN);
-	OrgCmd(wxString::Format(_("Exit %s"), SJ_PROGRAM_NAME),
-	                                            IDT_QUIT,                  SJA_MAIN);        OrgKey(wxACCEL_CTRL, 'Q'); OrgKey(wxACCEL_ALT, 'X');
+	OrgCmd(_os(_("Settings"))+wxT("..."),       IDT_SETTINGS,              SJA_MAIN); OrgKey(wxACCEL_ALT, 'P'); OrgKey(wxACCEL_ALT, WXK_RETURN);
+	OrgCmd(wxString::Format(_os(_("Exit %s")), SJ_PROGRAM_NAME),
+	                                            IDT_QUIT,                  SJA_MAIN);
+                                                                                             #ifdef __WXMSW__
+	                                                                                         OrgKey(wxACCEL_ALT, 'X');
+																							 #else
+	                                                                                         OrgKey(wxACCEL_CTRL, 'Q');
+                                                                                             #endif
 	OrgCmd(_("Update music library"),           IDT_UPDATE_INDEX,          SJA_MAIN);        OrgKey(0, WXK_F5);
 	OrgCmd(_("Recreate music library"),         IDT_DEEP_UPDATE_INDEX,     SJA_MAIN);        OrgKey(wxACCEL_SHIFT, WXK_F5);
 	OrgCmd(_("Enqueue tracks"),                 IDT_ENQUEUE_LAST,          SJA_MAIN|SJA_ADVSEARCH);
@@ -111,6 +115,11 @@ bool SjAccelModule::FirstLoad()
 	OrgCmd(_("Play tracks next"),               IDT_ENQUEUE_NEXT,          SJA_MAIN);        OrgKey(wxACCEL_CTRL, 'N');
 	OrgCmd(_("Play tracks now"),                IDT_ENQUEUE_NOW,           SJA_MAIN|SJA_ADVSEARCH);
 																							 OrgKey(wxACCEL_CTRL, 'P');
+	OrgCmd(_("Prelisten"),                      IDT_PRELISTEN,             SJA_MAIN);        OrgKey(wxACCEL_CTRL, 'L');
+	OrgCmd(_("Prelisten")+wxString(wxT(": "))+_("Volume up"),
+	                                            IDT_PRELISTEN_VOL_UP,      SJA_MAIN);        OrgKey(wxACCEL_CTRL|wxACCEL_SHIFT, WXK_UP);
+	OrgCmd(_("Prelisten")+wxString(wxT(": "))+_("Volume down"),
+	                                            IDT_PRELISTEN_VOL_DOWN,    SJA_MAIN);        OrgKey(wxACCEL_CTRL|wxACCEL_SHIFT, WXK_DOWN);
 	OrgCmd(_("Double click play tracks at once"),
 	                                            IDT_PLAY_NOW_ON_DBL_CLICK, SJA_MAIN);		 OrgKey(wxACCEL_CTRL, 'D');
 	OrgCmd(_("Remove played tracks from queue"),IDT_TOGGLE_REMOVE_PLAYED,  SJA_MAIN);
@@ -118,7 +127,11 @@ bool SjAccelModule::FirstLoad()
 	OrgCmd(_("More from current album"),        IDT_MORE_FROM_CURR_ALBUM,  SJA_MAIN);        OrgKey(wxACCEL_CTRL, 'J');
 	OrgCmd(_("More from current artist"),       IDT_MORE_FROM_CURR_ARTIST, SJA_MAIN);        OrgKey(wxACCEL_CTRL, 'K');
 	OrgCmd(_("Edit tracks/Get info..."),        IDM_EDITSELECTION,         SJA_MAIN|SJA_EDIT);OrgKey(wxACCEL_CTRL, 'I');
-	OrgCmd(_("Play"),                           IDT_PLAY,                  SJA_MAIN);        OrgKey(0, WXK_PAUSE); OrgKey(0, WXK_SPACE); // if we move this above WXK_PAUSE, entering spaced in the search field will fail - why?
+	OrgCmd(_("Play"),                           IDT_PLAY,                  SJA_MAIN);
+                                                                                             #ifndef __WXMAC__
+	                                                                                         OrgKey(0, WXK_PAUSE);
+																							 #endif
+	                                                                                         OrgKey(0, WXK_SPACE); // if we move this above WXK_PAUSE, entering spaced in the search field will fail - why?
 	OrgCmd(_("Pause"),                          IDT_PAUSE, SJA_UNEDITABLE); // same shortcut as IDT_PLAY
 	OrgCmd(_("Stop"),                           IDT_STOP,                  SJA_MAIN);        OrgKey(wxACCEL_SHIFT, WXK_SPACE);
 	OrgCmd(_("Stop after this track"),          IDT_STOP_AFTER_THIS_TRACK, SJA_MAIN);
@@ -134,7 +147,7 @@ bool SjAccelModule::FirstLoad()
 	OrgCmd(_("Shuffle"),                        IDT_SHUFFLE,               SJA_MAIN);
 	OrgCmd(_("Repeat playlist"),                IDT_REPEAT,                SJA_MAIN);
 	OrgCmd(_("Reload skin"),                    IDO_DEBUGSKIN_RELOAD,      SJA_MAIN);        OrgKey(wxACCEL_CTRL|wxACCEL_SHIFT, 'R');
-	OrgCmd(_("Video screen"),                   IDT_START_VIS,             SJA_MAIN);        OrgKey(0, WXK_F2);
+	OrgCmd(_("Toggle video screen"),            IDT_VIS_TOGGLE,            SJA_MAIN);        OrgKey(0, WXK_F2);
 	OrgCmd(_("Smooth"),                         IDO_SMOOTH,                SJA_MAIN|SJA_ART);
 	OrgCmd(_("Toggle time mode"),               IDT_TOGGLE_TIME_MODE,      SJA_MAIN);
 	OrgCmd(_("Select all"),                     IDO_SELECTALL,             SJA_MAIN);        OrgKey(wxACCEL_CTRL, 'A');
@@ -142,9 +155,13 @@ bool SjAccelModule::FirstLoad()
 	OrgCmd(_("Zoom out"),                       IDT_ZOOM_OUT,              SJA_MAIN);        OrgKey(0, WXK_SUBTRACT);
 	OrgCmd(_("Normal zoom"),                    IDT_ZOOM_NORMAL,           SJA_MAIN);        OrgKey(0, WXK_MULTIPLY);
 	OrgCmd(_("Always on top"),                  IDT_ALWAYS_ON_TOP,         SJA_MAIN);
-	OrgCmd(_("Show file"),                      IDM_EXPLORE,               SJA_MAIN|SJA_ART);
+	OrgCmd(_os(_("Show file")),                 IDM_EXPLORE,               SJA_MAIN|SJA_ART);
 	OrgCmd(_("Kiosk mode"),                     IDT_TOGGLE_KIOSK,          SJA_MAIN|SJA_KIOSKSETTINGS);
+                                                                                             #ifdef __WXMAC__
+	                                                                                         OrgKey(wxACCEL_ALT, 'K');
+                                                                                             #else
 	                                                                                         OrgKey(0, WXK_F11);
+																							 #endif
 	OrgCmd(_("Go to current track"),            IDT_GOTO_CURR,             SJA_MAIN);        OrgKey(wxACCEL_CTRL, 'T');
 	OrgCmd(_("Go to marked track"),             IDO_GOTO_CURR_MARK,        SJA_MAIN|SJA_UNEDITABLE); // edit may be possible but does not make much sense as marking tracks in the display is very temporary and mostly only possible using the mouse+context menu
 	OrgCmd(_("Go to random album"),             IDT_WORKSPACE_GOTO_RANDOM, SJA_MAIN);        OrgKey(wxACCEL_CTRL, 'R');
@@ -163,7 +180,7 @@ bool SjAccelModule::FirstLoad()
 
 	for( int idtCredit = IDT_ADD_CREDIT_01; idtCredit <= IDT_ADD_CREDIT_16; idtCredit++ )
 	{
-		OrgCmd(_("Add credit")+wxString::Format(wxT(" (+%i)"), (idtCredit-IDT_ADD_CREDIT_01)+1), idtCredit, SJA_MAIN);
+		OrgCmd(_("Add credit")+wxString::Format(wxT(" (+%i)"), (int)((idtCredit-IDT_ADD_CREDIT_01)+1)), idtCredit, SJA_MAIN);
 	}
 
 	// tools shortcuts
@@ -177,12 +194,12 @@ bool SjAccelModule::FirstLoad()
 		//  - all menu entries of ALL scripts are defined by a zero-based index
 		//  - therefore program.removeMenuEntry() or sth. like that will disturb the shortcuts and need a re-assign
 		// see also http://www.silverjuke.net/forum/topic-1726.html
-		int i, iCount = (IDO_EXTRAS_MENU99-IDO_EXTRAS_MENU00)+1, id;
+		int i, iCount = (IDO_SCRIPT_MENU99-IDO_SCRIPT_MENU00)+1, id;
 		for( i = 0; i < iCount; i++ )
 		{
-			id = IDO_EXTRAS_MENU00+i;
-			wxASSERT(id>=IDO_EXTRAS_MENU00 && id<=IDO_EXTRAS_MENU99);
-			OrgCmd(_("Tools")+wxString::Format(wxT(" #%i"), i+1), id, SJA_MAIN);
+			id = IDO_SCRIPT_MENU00+i;
+			wxASSERT(id>=IDO_SCRIPT_MENU00 && id<=IDO_SCRIPT_MENU99);
+			OrgCmd(_("Extensions")+wxString::Format(wxT(" #%i"), i+1), id, SJA_MAIN);
 
 		}
 	}
@@ -340,13 +357,13 @@ private:
 		long keycode = event.GetKeyCode();
 
 		if( keycode == WXK_LBUTTON
-				|| keycode == WXK_RBUTTON
-				|| keycode == WXK_MBUTTON
-				|| keycode == WXK_SHIFT
-				|| keycode == WXK_ALT
-				|| keycode == WXK_CONTROL
-				|| keycode == WXK_MENU
-				|| keycode == WXK_CAPITAL )
+		 || keycode == WXK_RBUTTON
+		 || keycode == WXK_MBUTTON
+		 || keycode == WXK_SHIFT
+		 || keycode == WXK_ALT
+		 || keycode == WXK_CONTROL
+		 || keycode == WXK_MENU
+		 || keycode == WXK_CAPITAL )
 		{
 			return;
 		}
@@ -356,13 +373,12 @@ private:
 		if( event.AltDown() ) modifiers |= wxACCEL_ALT;
 		if( event.ShiftDown() ) modifiers |= wxACCEL_SHIFT;
 		if( event.ControlDown() )  modifiers |= wxACCEL_CTRL;
-		wxLogDebug(wxT("meta.%i"), event.MetaDown());
+		wxLogDebug(wxT("meta.%i"), (int)event.MetaDown());
 
 		// save the key
 		m_key = (modifiers << 16) | keycode;
 
-		wxCommandEvent evt(wxEVT_COMMAND_MENU_SELECTED, IDC_NEWKEY);
-		GetParent()->GetEventHandler()->AddPendingEvent(evt);
+		GetParent()->GetEventHandler()->QueueEvent(new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, IDC_NEWKEY));
 	}
 	DECLARE_EVENT_TABLE ();
 };
@@ -474,7 +490,7 @@ bool SjLittleAccelOption::AreTempAndOrgEqual() const
 	if( m_cmdPtr->m_tempKeyCount==m_cmdPtr->m_orgKeyCount )
 	{
 		if( m_cmdPtr->m_tempKeyCount == 0
-		        || memcmp(m_cmdPtr->m_tempKey, m_cmdPtr->m_orgKey, m_cmdPtr->m_tempKeyCount*sizeof(long))==0 )
+		 || memcmp(m_cmdPtr->m_tempKey, m_cmdPtr->m_orgKey, m_cmdPtr->m_tempKeyCount*sizeof(long))==0 )
 		{
 			return TRUE;
 		}
@@ -509,8 +525,8 @@ wxString SjLittleAccelOption::GetDisplayValue() const
 	}
 
 	if( m_cmdPtr->m_id == IDT_NUMPAD_MENU
-	        && ret.IsEmpty()
-	        && g_kioskModule )
+	 && ret.IsEmpty()
+	 && g_kioskModule )
 	{
 		// if no numpad-"menu" key is defined, the menu can be opened
 		// by pressing "0" several times (more exact: the number of album digits)
@@ -582,7 +598,7 @@ bool SjLittleAccelOption::AddKey(long newKey, wxWindow* parent)
 		for( keyIndex = 0; keyIndex < cmd->m_tempKeyCount; keyIndex++ )
 		{
 			if(  (cmd->m_tempKey[keyIndex]&(~(wxACCEL_SYSTEMWIDE<<16))) == (newKey&(~(wxACCEL_SYSTEMWIDE<<16)))
-			        && ((cmd->m_flags&SJA_MASK) & (m_cmdPtr->m_flags&SJA_MASK)) ) // is the key used in the same part?
+			 && ((cmd->m_flags&SJA_MASK) & (m_cmdPtr->m_flags&SJA_MASK)) ) // is the key used in the same part?
 			{
 				if( cmd == m_cmdPtr )
 				{
@@ -594,7 +610,6 @@ bool SjLittleAccelOption::AddKey(long newKey, wxWindow* parent)
 				{
 					// if the parent is NOT set, this is a global reset action
 					// wheras we do NOT modify other keys
-					wxWindowDisabler disabler(parent);
 					if( SjMessageBox(
 					            wxString::Format(_("The shortcut \"%s\" is currently assigned to the command \"%s\".\n\nDo you want to assign it to the shortcut \"%s\" now?"),
 					                             g_accelModule->GetReadableShortcutByComprKey(newKey).c_str(),
@@ -647,7 +662,7 @@ bool SjLittleAccelOption::OnOption(wxWindow* parent, long optionIndex)
 		// ...wait for a key
 		long newKey = 0;
 		{
-			wxWindowDisabler disabler(SjDialog::FindTopLevel(parent));
+			SJ_WINDOW_DISABLER(SjDialog::FindTopLevel(parent));
 			SjWaitForKeyDlg dlg(parent, GetName());
 			if( dlg.ShowModal() == wxID_OK )
 			{
@@ -712,7 +727,7 @@ void SjLittleAccelOption::OnApply()
 	if( m_lastOption )
 	{
 		// save settings
-		wxString iniShortcuts;
+		wxString iniShortcuts, label;
 		int i, j;
 		for( i = 0; i < g_accelModule->m_cmdCount; i++ )
 		{
@@ -726,6 +741,31 @@ void SjLittleAccelOption::OnApply()
 					iniShortcuts += wxString::Format(wxT("%x,"), (int)cmd.m_userKey[j]);
 				}
 			}
+
+			// update the displayed shortcut
+			wxMenuItem* item = g_mainFrame->m_menuBar->FindItem(cmd.m_id);
+			if( item )
+			{
+				long key = 0;
+				if( cmd.m_linkId )
+				{
+					SjAccelCmd* linkCmd = &g_accelModule->m_cmd[g_accelModule->CmdId2CmdIndex(cmd.m_linkId)];
+					if( linkCmd->m_userKeyCount ) {
+						key = linkCmd->m_userKey[0];
+					}
+				}
+				else if( cmd.m_userKeyCount )
+				{
+					key = cmd.m_userKey[0];
+				}
+
+				wxString label = item->GetItemLabelText(); // get item label without shortcut
+				wxString shortcut = g_accelModule->GetReadableShortcutByComprKey(key, false);
+				if( !shortcut.IsEmpty() ) {
+					label += "\t" + shortcut;
+				}
+				item->SetItemLabel(label);
+			}
 		}
 
 		if( !iniShortcuts.IsEmpty() ) {
@@ -741,7 +781,7 @@ void SjLittleAccelOption::OnApply()
 
 		g_accelModule->UpdateSystemAccel(TRUE/*set*/);
 
-		g_mainFrame->InitMainMenu();
+		g_mainFrame->UpdateMainMenu();
 	}
 }
 
@@ -768,12 +808,15 @@ void SjAccelModule::GetLittleOptions(SjArrayLittleOption& lo)
 	#endif
 
 	// mouse wheel
-	SjLittleOption::ClearSection();
-	lo.Add(new SjLittleBit (_("Mouse wheel"), _("Scroll vertically")+SEP+_("Scroll horizontally"),
-	                        &m_flags, 0L, SJ_ACCEL_VERT_WHEEL_HORZ, wxT("main/accelFlags")));
 	SjLittleOption::SetSection(_("Mouse wheel"));
-	lo.Add(new SjLittleBit (_("Context sensitive"), wxT("yn"), //n/t
-	                        &m_flags, 1L, SJ_ACCEL_CONTEXT_SENSITIVE_WHEEL, wxT("main/accelFlags")));
+	lo.Add(new SjLittleBit (_("Scroll horizontally in album view"), "yn",
+	                        &m_flags, 0L, SJ_ACCEL_WHEEL_HORZ_IN_ALBUMVIEW, "main/accelFlags"));
+	lo.Add(new SjLittleBit (_("Modifier key toggles axis"), "yn",
+	                        &m_flags, 0L, SJ_ACCEL_WHEEL_MODIFIER_AXIS_TOGGLE, "main/accelFlags"));
+	lo.Add(new SjLittleBit (_("Right mouse button toggles axis"), "yn",
+	                        &m_flags, 0L, SJ_ACCEL_WHEEL_RMOUSE_AXIS_TOGGLE, "main/accelFlags"));
+	lo.Add(new SjLittleBit (_("Modify volume, scrollbars, letters etc."), "yn",
+	                        &m_flags, 0L, SJ_ACCEL_WHEEL_VALUE_INPUT, "main/accelFlags"));
 
 	// find out the extra menu items
 	#if SJ_USE_SCRIPTS
@@ -782,7 +825,7 @@ void SjAccelModule::GetLittleOptions(SjArrayLittleOption& lo)
 	#endif
 
 	// shortcuts (should be last as the last option will save all the stuff)
-	SjLittleOption::SetSection(_("Shortcut"));
+	SjLittleOption::ClearSection();
 	int cmdIndex;
 	SjAccelCmd* cmd;
 	bool addOption;
@@ -803,27 +846,27 @@ void SjAccelModule::GetLittleOptions(SjArrayLittleOption& lo)
 		}
 
 		if(  (cmd->m_id >= IDT_NUMPAD_FIRST && cmd->m_id <= IDT_NUMPAD_LAST)
-		        && !(g_accelModule->m_flags&SJ_ACCEL_USE_NUMPAD_IN_KIOSK) )
+		 && !(g_accelModule->m_flags&SJ_ACCEL_USE_NUMPAD_IN_KIOSK) )
 		{
 			wxASSERT( cmdIndex!=m_cmdCount-1 ); // ensure, the "last" flag gets set
 			addOption = false;
 		}
 
 		if( (cmd->m_id >= IDT_ADD_CREDIT_01 && cmd->m_id <= IDT_ADD_CREDIT_16)
-		        && (!g_kioskModule->m_creditBase.IsCreditSystemEnabled() || !g_kioskModule->m_creditBase.ListenToShortcuts()) )
+		 && (!g_kioskModule->m_creditBase.IsCreditSystemEnabled() || !g_kioskModule->m_creditBase.ListenToShortcuts()) )
 		{
 			wxASSERT( cmdIndex!=m_cmdCount-1 ); // ensure, the "last" flag gets set
 			addOption = false;
 		}
 
-		if( cmd->m_id >= IDO_EXTRAS_MENU00 && cmd->m_id <= IDO_EXTRAS_MENU99 )
+		if( cmd->m_id >= IDO_SCRIPT_MENU00 && cmd->m_id <= IDO_SCRIPT_MENU99 )
 		{
 			wxASSERT( cmdIndex!=m_cmdCount-1 ); // ensure, the "last" flag gets set
 			addOption = false;
 			#if SJ_USE_SCRIPTS
-			if( cmd->m_id-IDO_EXTRAS_MENU00 < extrasCount )
+			if( cmd->m_id-IDO_SCRIPT_MENU00 < extrasCount )
 			{
-				cmd->m_name = _("Tools") + wxString(wxT(": ")) + extrasArr[cmd->m_id-IDO_EXTRAS_MENU00];
+				cmd->m_name = _("Extensions") + wxString(wxT(": ")) + extrasArr[cmd->m_id-IDO_SCRIPT_MENU00];
 				addOption = true;
 			}
 			#endif
@@ -945,7 +988,7 @@ wxAcceleratorTable SjAccelModule::GetAccelTable(long flags, wxAcceleratorEntry*
 	{
 		// add numpad keys?
 		if( (flags & SJA_MAIN)
-		        &&  UseNumpad() )
+		 &&  UseNumpad() )
 		{
 			flags |= SJA_MAINNUMPAD;
 		}
@@ -982,8 +1025,8 @@ wxAcceleratorTable SjAccelModule::GetAccelTable(long flags, wxAcceleratorEntry*
 					}
 
 					if(  addToAccelTable(key)
-					        || (cmd->m_flags&SJA_MAINNUMPAD)
-					        || (flags&SJA_ADDNOMODIFIERKEYS) )
+					 || (cmd->m_flags&SJA_MAINNUMPAD)
+					 || (flags&SJA_ADDNOMODIFIERKEYS) )
 					{
 						if( !keysAdded.Lookup(key) )
 						{
@@ -1014,7 +1057,7 @@ wxAcceleratorTable SjAccelModule::GetAccelTable(long flags, wxAcceleratorEntry*
 }
 
 
-wxString SjAccelModule::GetReadableShortcutByKey(long modifier, long keycode)
+wxString SjAccelModule::GetReadableShortcutByKey(long modifier, long keycode, bool useNativeSymbols)
 {
 	wxString ret;
 
@@ -1022,17 +1065,32 @@ wxString SjAccelModule::GetReadableShortcutByKey(long modifier, long keycode)
 	{
 		if( (modifier & wxACCEL_CTRL) )
 		{
-			ret += wxT("Ctrl+");
+			#ifdef __WXMAC__
+			if( useNativeSymbols )
+				ret += "\u2318";
+			else
+			#endif
+				ret += wxT("Ctrl+");
 		}
 
 		if( (modifier & wxACCEL_ALT) )
 		{
-			ret += wxT("Alt+");
+			#ifdef __WXMAC__
+			if( useNativeSymbols )
+				ret += "\u2325";
+			else
+			#endif
+				ret += wxT("Alt+");
 		}
 
 		if( (modifier & wxACCEL_SHIFT) )
 		{
-			ret += wxT("Shift+");
+			#ifdef __WXMAC__
+			if( useNativeSymbols )
+				ret += "\u21e7";
+			else
+			#endif
+				ret += wxT("Shift+");
 		}
 
 		wxString keyStr;
@@ -1110,7 +1168,7 @@ wxString SjAccelModule::GetReadableShortcutsByPtr(const long userKey[], int user
 		modifier = key >> 16;
 
 		if( ( (modifier&wxACCEL_SYSTEMWIDE) && (flags&SJ_SHORTCUTS_SYSTEMWIDE))
-		        || (!(modifier&wxACCEL_SYSTEMWIDE) && (flags&SJ_SHORTCUTS_LOCAL)) )
+		 || (!(modifier&wxACCEL_SYSTEMWIDE) && (flags&SJ_SHORTCUTS_LOCAL)) )
 		{
 			if( !ret.IsEmpty() ) ret += wxT(", ");
 			ret += GetReadableShortcutByComprKey(key);
@@ -1155,15 +1213,7 @@ wxString SjAccelModule::GetCmdNameByIndex(int cmdIndex, bool shortName)
 
 	if( !shortName )
 	{
-		if( (cmd.m_id >= IDT_WORKSPACE_LINE_LEFT && cmd.m_id <= IDT_WORKSPACE_LINE_DOWN)
-		        || (cmd.m_id >= IDT_WORKSPACE_PAGE_LEFT && cmd.m_id <= IDT_WORKSPACE_ENTER)
-		        ||  cmd.m_id == IDT_WORKSPACE_HOME
-		        ||  cmd.m_id == IDT_WORKSPACE_END
-		        ||  cmd.m_id == IDT_WORKSPACE_SHOW_COVERS )
-		{
-			ret = SjLittleOption::ApplySection(_("Workspace"), ret);
-		}
-		else if( cmd.m_id == IDO_SMOOTH /*is a global command, but shown at the cover editor options*/ )
+		if( cmd.m_id == IDO_SMOOTH /*is a global command, but shown at the cover editor options*/ )
 		{
 			ret = SjLittleOption::ApplySection(_("Cover editor"), ret);
 		}
@@ -1185,7 +1235,7 @@ int SjAccelModule::KeyEvent2CmdIndex(wxKeyEvent& event, long flags)
 {
 	// add numpad keys?
 	if( (flags & SJA_MAIN)
-	        &&  UseNumpad() )
+	 &&  UseNumpad() )
 	{
 		flags |= SJA_MAINNUMPAD;
 	}
@@ -1224,7 +1274,7 @@ int SjAccelModule::KeyEvent2CmdIndex(wxKeyEvent& event, long flags)
 			for( keyIndex = 0; keyIndex < cmd.m_userKeyCount && cmdIndex == 0; keyIndex++ )
 			{
 				if( (cmd.m_userKey[keyIndex]&(~(wxACCEL_SYSTEMWIDE<<16))) == key
-				        && (cmd.m_flags & flags) )
+				 && (cmd.m_flags & flags) )
 				{
 					cmdIndex = c;
 					break;
@@ -1329,7 +1379,7 @@ wxMenuItem* SjMenu::CreateMenuItem(int id, const wxString& text__, wxItemKind ki
 	// add shortcut to the text ("Open..." becomes "Open...\tCtrl+O")
 	if( m_showShortcuts )
 	{
-		wxString shortcut = g_accelModule->GetReadableShortcutByComprKey(key);
+		wxString shortcut = g_accelModule->GetReadableShortcutByComprKey(key, false);
 		if( !shortcut.IsEmpty() )
 		{
 			text << wxT("\t") << shortcut;
@@ -1340,7 +1390,7 @@ wxMenuItem* SjMenu::CreateMenuItem(int id, const wxString& text__, wxItemKind ki
 	wxMenuItem* mi = new wxMenuItem(this, id, text, wxT(""), kind==wxITEM_RADIO? wxITEM_CHECK : kind, subMenu);
 
 	// set font (wxMenuItem::SetFont() is not available in GTK)
-    #if !defined(__WXGTK__)
+    #if defined(__WXMSW__)
 	if( g_accelModule->m_flags&SJ_ACCEL_USE_VIEW_FONT_IN_DLG )
 	{
 		mi->SetFont(g_mainFrame->m_baseStdFont);
