@@ -103,7 +103,7 @@ private:
 	void            OnMouseLeftDown     (wxMouseEvent&);
 	void            OnMouseLeftUp       (wxMouseEvent&);
 	void            OnMouseCaptureLost  (wxMouseCaptureLostEvent&);
-	void            OnMouseRight        (wxMouseEvent&);
+	void            OnMouseRight        (wxContextMenuEvent&);
 	void            OnMouseMotion       (wxMouseEvent&);
 	void            OnEraseBackground   (wxEraseEvent&) { }
 	void            OnPaint             (wxPaintEvent&);
@@ -122,11 +122,7 @@ BEGIN_EVENT_TABLE(SjArtEditor, wxFrame)
 	EVT_LEFT_UP             (                       SjArtEditor::OnMouseLeftUp      )
 	EVT_MOUSE_CAPTURE_LOST  (                       SjArtEditor::OnMouseCaptureLost )
 	EVT_MOTION              (                       SjArtEditor::OnMouseMotion      )
-	#ifdef __WXMAC__ // the context menu MUST be opened on down on MAC: TODO: We should use EVT_CONTEXT_MENU instead
-	EVT_RIGHT_DOWN          (                       SjArtEditor::OnMouseRight       )
-	#else
-	EVT_RIGHT_UP            (                       SjArtEditor::OnMouseRight       )
-	#endif
+	EVT_CONTEXT_MENU        (                       SjArtEditor::OnMouseRight       )
 	EVT_PAINT               (                       SjArtEditor::OnPaint            )
 	EVT_ERASE_BACKGROUND    (                       SjArtEditor::OnEraseBackground  )
 	EVT_ACTIVATE            (                       SjArtEditor::OnActivate         )
@@ -299,7 +295,6 @@ void SjArtEditor::OnCloseWindow(wxCloseEvent& event)
 void SjArtEditor::ShowCropMessage()
 {
 	m_stay++;
-	wxWindowDisabler disabler(this);
 
 	SjMessageBox(_("Please press and hold the left mouse button. Then, select the area to crop by moving the mouse."),
 	               SJ_PROGRAM_NAME, wxOK|wxICON_INFORMATION, this);
@@ -507,7 +502,7 @@ void SjArtEditor::OnMouseMotion(wxMouseEvent& event)
 }
 
 
-void SjArtEditor::OnMouseRight(wxMouseEvent& event)
+void SjArtEditor::OnMouseRight(wxContextMenuEvent& event)
 {
 	// stop cropping?
 	if( m_cropRectDrawn )
@@ -534,11 +529,11 @@ void SjArtEditor::OnMouseRight(wxMouseEvent& event)
 	}
 
 	if( g_mainFrame->IsAllAvailable()
-	        && menu.GetMenuItemCount() )
+	 && menu.GetMenuItemCount() )
 	{
 		m_mouseLeftDown = -1; // ignore next click as it will only close the menu
 		m_stay++;
-			PopupMenu(&menu, event.GetX(), event.GetY());
+			PopupMenu(&menu);
 		m_stay--;
 	}
 }
@@ -753,8 +748,8 @@ void SjArtEditor::CreateBitmapFromImage()
 	SetSize(imgW, imgH);
 
 	if( GetParent()==NULL
-	        || m_centerOnDisplay
-	        || g_mainFrame->IsKioskStarted() )
+	 || m_centerOnDisplay
+	 || g_mainFrame->IsKioskStarted() )
 	{
 		SjDialog::CenterOnDisplay(this, g_mainFrame);
 	}
@@ -1029,7 +1024,7 @@ void SjArtEditorModule::CreateArtMenu(
 		menu.Append(0, _("Effects/options"), submenu);
 
 		// show file
-		menu.Append(IDM_EXPLORE, _("Show file"));
+		menu.Append(IDM_EXPLORE, _os(_("Show file")));
 		menu.Enable(IDM_EXPLORE, g_tools->IsUrlExplorable(selUrl));
 	}
 
@@ -1132,7 +1127,7 @@ bool SjArtEditorModule::OnArtMenu(
 				if( albumId && g_mainFrame->IsAllAvailable() )
 				{
 					if( artEditor ) { artEditor->m_stay++; }
-					wxWindowDisabler disabler(parent);
+					SJ_WINDOW_DISABLER(parent);
 					wxFileDialog fileDialog(parent, _("Select image"), wxT(""), wxT(""),
 					                        g_mainFrame->m_moduleSystem.GetAssignedExt(SJ_EXT_IMAGEFILES).GetFileDlgStr(), wxFD_OPEN|wxFD_CHANGE_DIR);
 					int fileDialogRet = fileDialog.ShowModal();
@@ -1178,7 +1173,7 @@ bool SjArtEditorModule::OnArtMenu(
 				if( g_mainFrame->IsAllAvailable() )
 				{
 					if( artEditor ) { artEditor->m_stay++; }
-					wxWindowDisabler disabler(parent);
+					SJ_WINDOW_DISABLER(parent);
 
 					SjExtList extList(SjTools::GetExt(selUrl));
 					wxFileDialog dlg(parent, _("Save cover"), wxT(""),
@@ -1221,7 +1216,6 @@ bool SjArtEditorModule::OnArtMenu(
 				if( g_mainFrame->IsAllAvailable() )
 				{
 					if( artEditor ) { artEditor->m_stay++; }
-					wxWindowDisabler disabler(parent);
 
 					if( SjMessageBox(_("Reset all selected alternative images to their default value?"),
 					                   SJ_PROGRAM_NAME, wxYES_NO|wxNO_DEFAULT|wxICON_QUESTION, parent) == wxYES )
