@@ -21,7 +21,7 @@
  *
  * File:    basicsettings.cpp
  * Authors: Björn Petersen
- * Purpose: The "Basic settings" module
+ * Purpose: Shortcuts and further options
  *
  ******************************************************************************/
 
@@ -34,23 +34,18 @@
 #include <see_dom/sj_see.h>
 #include <wx/notebook.h>
 
-#define IDC_REGISTERWWW             (IDM_LASTPRIVATE-1)   // to avoid conflicts with embedded pages, we use "high" IDs
-#define IDC_REGISTER                (IDM_LASTPRIVATE-2)
-#define IDC_SEARCHPATHS             (IDM_LASTPRIVATE-3)
+#define IDC_SEARCHPATHS             (IDM_LASTPRIVATE-3)   // to avoid conflicts with embedded pages, we use "high" IDs
 #define IDC_SEARCHPATHADD           (IDM_LASTPRIVATE-4)
 #define IDC_SEARCHPATHREMOVE        (IDM_LASTPRIVATE-5)
-#define IDC_LANGSEL                 (IDM_LASTPRIVATE-6)
 #define IDC_SHOWSEARCHPATH          (IDM_LASTPRIVATE-16)
 #define IDC_OPTIONLAST              (IDM_LASTPRIVATE-18)  // range end (remember, we're subtracting the offsets)
 #define IDC_OPTIONFIRST             (IDM_LASTPRIVATE-180) // range start (remember, we're subtracting the offsets)
-#define IDC_LOADMODULESMENU         (IDM_LASTPRIVATE-182)
 #define IDC_LITTLELIST              (IDM_LASTPRIVATE-183)
 #define IDC_LITTLEMENUBUTTON        (IDM_LASTPRIVATE-184)
 #define IDC_OPTIONRESET             (IDM_LASTPRIVATE-185)
-#define IDC_DUMMYINTERFACE          (IDM_LASTPRIVATE-186)
 
-#define PAGE_FIRSTEMBEDDED      2
-#define PAGE_LITTLEOPTIONS      -1 // the IDs 666, 667 and 668 may also be used for this
+#define PAGE_SHORTCUTS      0 // the IDs 666, 667 and 668 may also be used for this
+#define PAGE_FURTHEROPTIONS 1
 
 
 /*******************************************************************************
@@ -61,7 +56,7 @@
 class SjSearchPathDlg : public SjDialog
 {
 public:
-	SjSearchPathDlg     (wxWindow* parent, const wxArrayString& paths);
+	                SjSearchPathDlg     (wxWindow* parent, const wxArrayString& paths);
 	wxArrayString   GetPaths            () const;
 
 private:
@@ -70,12 +65,11 @@ private:
 	void            UpdateButtons       ();
 	void            OnSearchPathAdd     (wxCommandEvent&);
 	void            OnSearchPathRemove  (wxCommandEvent&);
-	void            OnSearchPathSelectionChange
-	(wxListEvent&) { UpdateButtons(); }
+	void            OnSearchPathSelectionChange (wxListEvent&) { UpdateButtons(); }
 	void            OnContextMenu       (wxListEvent&);
 	void            OnShowSearchPath    (wxCommandEvent&);
 	void            OnSize              (wxSizeEvent&);
-	DECLARE_EVENT_TABLE ()
+	                DECLARE_EVENT_TABLE ()
 };
 
 
@@ -191,9 +185,9 @@ void SjSearchPathDlg::OnContextMenu(wxListEvent&)
 	m.Append(IDC_SEARCHPATHREMOVE, _("Remove"));
 	m.Enable(IDC_SEARCHPATHREMOVE, m_removeButton->IsEnabled());
 	m.AppendSeparator();
-	m.Append(IDC_SHOWSEARCHPATH, _("Show file"));
+	m.Append(IDC_SHOWSEARCHPATH, _os(_("Show file")));
 
-	PopupMenu(&m, ScreenToClient(::wxGetMousePosition()));
+	PopupMenu(&m);
 }
 
 
@@ -289,7 +283,7 @@ public:
 	bool OnOption(wxWindow* parent, long i) { return OnDoubleClick(parent); }
 	bool OnDoubleClick(wxWindow* parent)
 	{
-		wxWindowDisabler disabler(SjDialog::FindTopLevel(parent));
+		SJ_WINDOW_DISABLER(SjDialog::FindTopLevel(parent));
 		SjSearchPathDlg dlg(SjDialog::FindTopLevel(parent), m_paths);
 		if( dlg.ShowModal() == wxID_OK )
 		{
@@ -299,7 +293,7 @@ public:
 			for( size_t i = 0; i < m_paths.GetCount(); i++ )
 			{
 				if( ::wxDirExists(m_paths[i])
-				        && !g_tools->IsStaticSearchPath(m_paths[i]) )
+				 && !g_tools->IsStaticSearchPath(m_paths[i]) )
 				{
 					g_tools->m_config->Write(wxString::Format(wxT("main/searchPath%i"), (int)userCount++), m_paths[i]);
 				}
@@ -325,7 +319,7 @@ private:
 
 
 /*******************************************************************************
- * SjBasicSettingsConfigPage
+ * SjFutherOptPanel
  ******************************************************************************/
 
 
@@ -337,200 +331,41 @@ enum SjPreselect
 };
 
 
-class SjBasicSettingsConfigPage : public wxPanel
+class SjFurtherOptPanel : public wxPanel
 {
 public:
-	                SjBasicSettingsConfigPage (SjBasicSettingsModule* basicSettingsModule, wxWindow* parent, int selectedPage);
-	                ~SjBasicSettingsConfigPage();
+					SjFurtherOptPanel   (wxWindow* parent, SjArrayLittleOption&, int page, SjPreselect);
 
 private:
-	// further options
-	wxPanel*        CreateLittlePage    (wxWindow* parent);
-	void            InitLittlePage      (SjPreselect);
-	void            UpdateLittleOption  (SjLittleOption*);
-	void            UpdateLittleColWidth();
-	void            ShowLittleContextMenu (wxWindow*, const wxPoint&);
 	wxArrayLong     GetSelectedOptions  ();
 	SjLittleOption* GetSelectedOption   ();
-	bool            m_littlePageInitialized;
-	wxListCtrl*     m_littleListCtrl;
-	wxButton*       m_littleCustomizeButton;
-	SjArrayLittleOption m_littleOptions; // needed by compare function
-	static long     s_littleListSelection;
+
 	void            OnLittleDoubleClick (wxListEvent&);
 	void            OnLittleOptionsMenu (wxCommandEvent&) { ShowLittleContextMenu(m_littleCustomizeButton, wxPoint(0, 0)); }
 	void            OnLittleContextMenu (wxListEvent&) { ShowLittleContextMenu(this, ScreenToClient(::wxGetMousePosition())); }
 	void            OnLittleOption      (wxCommandEvent&);
 	void            OnLittleReset       (wxCommandEvent&);
-
-	// little "Misc" settings
-	void            GetLittleMiscOptions(SjArrayLittleOption&);
-	void            ApplyOrCancelLittleMisc (bool apply, bool& wantsToBeRestarted);
-	long            m_miscOldIdxCacheIndex, m_miscNewIdxCacheIndex,
-	                m_miscOldIdxSync, m_miscNewIdxSync,
-	                m_miscIndexImgDiskCache,
-	                m_miscIndexImgRamCache,
-	                m_miscIndexImgRegardTimestamp;
-	wxString		m_oldLanguageValue, m_newLanguageValue;
-
-	// other
-	SjBasicSettingsModule*
-	m_basicSettingsModule;
-	wxNotebook*     m_notebook;
-	bool            m_constructorDone;
-	void            OnNotebookChange    (wxNotebookEvent&);
 	void            OnSize              (wxSizeEvent& e) { UpdateLittleColWidth(); e.Skip(); }
-	DECLARE_EVENT_TABLE ()
 
-	friend class    SjBasicSettingsModule;
+	void            UpdateLittleOption  (SjLittleOption*);
+	void            UpdateLittleColWidth();
+	void            ShowLittleContextMenu (wxWindow*, const wxPoint&);
+	wxListCtrl*     m_littleListCtrl;
+	wxButton*       m_littleCustomizeButton;
+	                DECLARE_EVENT_TABLE ()
 };
 
 
-BEGIN_EVENT_TABLE(SjBasicSettingsConfigPage, wxPanel)
-	EVT_NOTEBOOK_PAGE_CHANGED   (IDC_NOTEBOOK,          SjBasicSettingsConfigPage::OnNotebookChange    )
-	EVT_LIST_ITEM_RIGHT_CLICK   (IDC_LITTLELIST,        SjBasicSettingsConfigPage::OnLittleContextMenu )
-	EVT_LIST_ITEM_ACTIVATED     (IDC_LITTLELIST,        SjBasicSettingsConfigPage::OnLittleDoubleClick )
-	EVT_BUTTON                  (IDC_LITTLEMENUBUTTON,  SjBasicSettingsConfigPage::OnLittleOptionsMenu )
-	EVT_COMMAND_RANGE           (IDC_OPTIONFIRST,
-	                             IDC_OPTIONLAST,
-	                             wxEVT_COMMAND_MENU_SELECTED,
-	                             SjBasicSettingsConfigPage::OnLittleOption      )
-	EVT_MENU                    (IDC_OPTIONRESET,       SjBasicSettingsConfigPage::OnLittleReset       )
-	EVT_SIZE                    (                       SjBasicSettingsConfigPage::OnSize              )
+BEGIN_EVENT_TABLE(SjFurtherOptPanel, wxPanel)
+	EVT_LIST_ITEM_RIGHT_CLICK   (IDC_LITTLELIST,        SjFurtherOptPanel::OnLittleContextMenu )
+	EVT_LIST_ITEM_ACTIVATED     (IDC_LITTLELIST,        SjFurtherOptPanel::OnLittleDoubleClick )
+	EVT_BUTTON                  (IDC_LITTLEMENUBUTTON,  SjFurtherOptPanel::OnLittleOptionsMenu )
+	EVT_COMMAND_RANGE           (IDC_OPTIONFIRST, IDC_OPTIONLAST, wxEVT_COMMAND_MENU_SELECTED, SjFurtherOptPanel::OnLittleOption      )
+	EVT_MENU                    (IDC_OPTIONRESET,       SjFurtherOptPanel::OnLittleReset       )
+	EVT_SIZE                    (                       SjFurtherOptPanel::OnSize              )
 END_EVENT_TABLE()
 
 
-static SjBasicSettingsConfigPage* g_configPage = NULL;
-
-
-SjBasicSettingsConfigPage::SjBasicSettingsConfigPage(SjBasicSettingsModule* basicSettingsModule, wxWindow* parent, int selectedPage)
-	: wxPanel(parent) // wxCLIP_CHILDREN has problems with wxListCtrl
-{
-	// save given objects
-	m_basicSettingsModule   = basicSettingsModule;
-	m_littlePageInitialized = FALSE;
-	m_constructorDone       = FALSE;
-	SjPreselect preselectKeys= SJ_PRESELECT_NONE;
-
-	// create notebook
-	wxSizer* dialogSizer = new wxBoxSizer(wxVERTICAL);
-	SetSizer(dialogSizer);
-
-	m_notebook = new wxNotebook(this, IDC_NOTEBOOK, wxDefaultPosition, wxDefaultSize, 0/*wxCLIP_CHILDREN - problems with wxChoice/wxComboBox*/);
-
-	wxNotebook* notebookSizer = m_notebook; // wxNotebookSizer is no longer needed in 2.6.0
-
-	SjModuleList* moduleList = g_mainFrame->m_moduleSystem.GetModules(SJ_MODULETYPE_COMMON);
-	SjModuleList::Node* moduleNode = moduleList->GetFirst();
-	while( moduleNode )
-	{
-		SjCommonModule* commonModule = (SjCommonModule*)moduleNode->GetData();
-		if( commonModule->EmbedTo() == SJ_EMBED_TO_BASICSETTINGS )
-		{
-			m_notebook->AddPage(commonModule->GetConfigPage(m_notebook, 0), commonModule->m_name);
-		}
-		moduleNode = moduleNode->GetNext();
-	}
-
-	m_notebook->AddPage(CreateLittlePage(m_notebook),  _("Further options"));
-
-	if( selectedPage == 666 /*further options*/ )
-	{
-		selectedPage = (int)m_notebook->GetPageCount()+PAGE_LITTLEOPTIONS;
-	}
-	else if( selectedPage == 667 /*further options*/ )
-	{
-		selectedPage = (int)m_notebook->GetPageCount()+PAGE_LITTLEOPTIONS;
-		preselectKeys = SJ_PRESELECT_NUMPAD;
-	}
-	else if( selectedPage == 668 /*further options*/ )
-	{
-		selectedPage = (int)m_notebook->GetPageCount()+PAGE_LITTLEOPTIONS;
-		preselectKeys = SJ_PRESELECT_ADDCREDIT;
-	}
-
-	if( selectedPage < 0
-	        || selectedPage >= (int)m_notebook->GetPageCount() )
-	{
-		selectedPage = 0;
-	}
-
-
-	if( selectedPage == (int)m_notebook->GetPageCount()+PAGE_LITTLEOPTIONS )
-	{
-		InitLittlePage(preselectKeys);
-		m_littlePageInitialized = TRUE;
-		UpdateLittleColWidth();
-	}
-
-	m_notebook->SetSelection(selectedPage);
-
-	dialogSizer->Add(notebookSizer, 1, wxALL|wxGROW, SJ_DLG_SPACE);
-
-	// init done, center dialog
-	dialogSizer->SetSizeHints(this);
-	m_constructorDone = TRUE;
-	g_configPage = this;
-}
-
-
-SjBasicSettingsConfigPage::~SjBasicSettingsConfigPage()
-{
-	g_configPage = NULL;
-}
-
-
-void SjBasicSettingsConfigPage::OnNotebookChange(wxNotebookEvent& event)
-{
-	if( m_constructorDone )
-	{
-		if( event.GetSelection() == (int)m_notebook->GetPageCount()+PAGE_LITTLEOPTIONS )
-		{
-			if( !m_littlePageInitialized )
-			{
-				wxBusyCursor busy;
-				InitLittlePage(SJ_PRESELECT_NONE);
-				m_littlePageInitialized = TRUE;
-				UpdateLittleColWidth();
-			}
-		}
-	}
-}
-
-
-/*******************************************************************************
- *  SjBasicSettingsConfigPage - Little Options
- ******************************************************************************/
-
-
-long SjBasicSettingsConfigPage::s_littleListSelection = -1;
-
-
-wxPanel* SjBasicSettingsConfigPage::CreateLittlePage(wxWindow* parent)
-{
-	wxPanel* page = new wxPanel(parent, -1);
-	wxSizer* sizer1 = new wxBoxSizer(wxVERTICAL);
-	page->SetSizer(sizer1);
-
-	sizer1->Add(1, SJ_DLG_SPACE); // some space
-
-	wxStaticText* staticText = new wxStaticText(page, -1,
-	        _("Beside several options, you can change the shortcuts to use here.\nThis page is for experienced users only."));
-	sizer1->Add(staticText, 0, wxALL, SJ_DLG_SPACE);
-
-	m_littleListCtrl = new wxListCtrl(page, IDC_LITTLELIST, wxDefaultPosition, wxSize(300, 100),
-	                                  wxLC_REPORT | wxSUNKEN_BORDER);
-	m_littleListCtrl->InsertColumn(0, _("Command or option"));
-	m_littleListCtrl->InsertColumn(1, _("Setting"));
-	m_littleListCtrl->SetImageList(g_tools->GetIconlist(FALSE), wxIMAGE_LIST_SMALL);
-	sizer1->Add(m_littleListCtrl, 1/*grow*/, wxGROW|wxALL, SJ_DLG_SPACE);
-
-	m_littleCustomizeButton = new wxButton(page, IDC_LITTLEMENUBUTTON, _("Customize")+wxString(SJ_BUTTON_MENU_ARROW));
-	sizer1->Add(m_littleCustomizeButton, 0, wxLEFT|wxRIGHT|wxBOTTOM, SJ_DLG_SPACE);
-	return page;
-}
-
-
 static int sortableIcon(SjIcon icon)
 {
 	switch( icon )
@@ -572,91 +407,82 @@ static int wxCALLBACK LittleCompareFunction(long item1__, long item2__, long sor
 }
 
 
-void SjBasicSettingsConfigPage::InitLittlePage(SjPreselect preselectKeys)
+SjFurtherOptPanel::SjFurtherOptPanel(wxWindow* parent, SjArrayLittleOption& littleOptions, int page, SjPreselect preselectKeys)
+	: wxPanel(parent, -1)
 {
-	wxBusyCursor busy;
+	m_littleListCtrl = NULL;
 
-	// get "little" settings from the modules
+	wxSizer* sizer1 = new wxBoxSizer(wxVERTICAL);
+	this->SetSizer(sizer1);
+
+	sizer1->Add(1, SJ_DLG_SPACE); // some space
+
+	wxString col1Title, col2Title;
+	if( page == PAGE_SHORTCUTS )
 	{
-		SjModuleList* listOfModules = g_mainFrame->m_moduleSystem.GetModules(SJ_MODULETYPE_ALL);
-		SjModuleList::Node* moduleNode = listOfModules->GetFirst();
-		while( moduleNode )
-		{
-			SjModule* module = moduleNode->GetData();
-
-			SjLittleOption::ClearSection();
-			module->GetLittleOptions(m_littleOptions);
-
-			moduleNode = moduleNode->GetNext();
-		}
+		col1Title = _("Command");
+		col2Title = _("Shortcut");
+	}
+	else if( page == PAGE_FURTHEROPTIONS )
+	{
+		col1Title = _("Option");
+		col2Title = _("Value");
+		sizer1->Add(new wxStaticText(this, -1, _("The following settings are for experienced users only.")), 0, wxALL, SJ_DLG_SPACE);
 	}
 
-	// get "little" misc. options
-	GetLittleMiscOptions(m_littleOptions);
+	m_littleListCtrl = new wxListCtrl(this, IDC_LITTLELIST, wxDefaultPosition, wxSize(550, 180),
+									  wxLC_REPORT | wxSUNKEN_BORDER);
+	m_littleListCtrl->InsertColumn(0, col1Title);
+	m_littleListCtrl->InsertColumn(1, col2Title);
+	m_littleListCtrl->SetImageList(g_tools->GetIconlist(FALSE), wxIMAGE_LIST_SMALL);
+	sizer1->Add(m_littleListCtrl, 1/*grow*/, wxGROW|wxALL, SJ_DLG_SPACE);
 
-	// add all options to the list control
-	int i, iCount = m_littleOptions.GetCount();
+	m_littleCustomizeButton = new wxButton(this, IDC_LITTLEMENUBUTTON, _("Customize")+wxString(SJ_BUTTON_MENU_ARROW));
+	sizer1->Add(m_littleCustomizeButton, 0, wxLEFT|wxRIGHT|wxBOTTOM, SJ_DLG_SPACE);
+
+	// ... add all options to the list control
+	int i, iCount = littleOptions.GetCount();
 	{
+		wxASSERT( sizeof(long) >= sizeof(void*) ); // we store the pointers in long-user-data, make sure, this will fit!
 		wxListItem listitem;
 		listitem.m_mask = wxLIST_MASK_TEXT | wxLIST_MASK_DATA;
 		for( i = 0; i < iCount; i++ )
 		{
-			listitem.m_itemId   = i;
-			listitem.m_data     = (long)&m_littleOptions[i];
-			listitem.m_text     = m_littleOptions[i].GetName();
-			m_littleListCtrl->InsertItem(listitem);
+			SjIcon icon = littleOptions[i].GetIcon();
+			if( ( page == PAGE_SHORTCUTS      && (icon==SJ_ICON_NORMALKEY||icon==SJ_ICON_SYSTEMKEY) )
+			 || ( page == PAGE_FURTHEROPTIONS && (icon!=SJ_ICON_NORMALKEY&&icon!=SJ_ICON_SYSTEMKEY) ) )
+			{
+				listitem.m_itemId   = i;
+				listitem.m_data     = (long)&littleOptions[i];
+				listitem.m_text     = littleOptions[i].GetName();
+				m_littleListCtrl->InsertItem(listitem);
+			}
 		}
 
 		UpdateLittleOption(NULL);
 	}
 
-	// sort listbox, init listbox selection
+	// ... sort listbox, init listbox selection
 	m_littleListCtrl->SortItems(LittleCompareFunction, 0);
-
 	if( preselectKeys != SJ_PRESELECT_NONE )
 	{
-		s_littleListSelection = 0;
-		wxString searchFor = SjLittleOption::ApplySection(_("Shortcut"), preselectKeys==SJ_PRESELECT_NUMPAD? _("Numpad") : _("Add credit"));
+		wxString searchFor = preselectKeys==SJ_PRESELECT_NUMPAD? _("Numpad") : _("Add credit");
 		for( i = 0; i < iCount; i++ )
 		{
-			if( m_littleOptions[i].GetName().StartsWith(searchFor) )
+			if( littleOptions[i].GetName().StartsWith(searchFor) )
 			{
-				s_littleListSelection = m_littleListCtrl->FindItem(-1, (long)&m_littleOptions[i]);
+				long littleListSelection = m_littleListCtrl->FindItem(-1, (long)&littleOptions[i]);
+				m_littleListCtrl->SetItemState(littleListSelection, wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED, wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED);
 				break;
 			}
 		}
 	}
-	else if( s_littleListSelection >= 0 && s_littleListSelection < iCount )
-	{
-		s_littleListSelection = m_littleListCtrl->FindItem(-1, (long)&m_littleOptions[s_littleListSelection]);
-	}
-	else
-	{
-		s_littleListSelection = 0;
-	}
 
-	m_littleListCtrl->SetItemState(s_littleListSelection, wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED, wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED);
+	SjDialog::EnsureSelListCtrlItemVisible(m_littleListCtrl);
 }
 
 
-void SjBasicSettingsConfigPage::UpdateLittleColWidth()
-{
-	if( m_littlePageInitialized )
-	{
-		wxSize size;
-
-		size = m_littleListCtrl->GetClientSize();
-
-		int w0 = (size.x)/2;
-		m_littleListCtrl->SetColumnWidth(0, w0);
-		m_littleListCtrl->SetColumnWidth(1, size.x-w0);
-
-		SjDialog::EnsureSelListCtrlItemVisible(m_littleListCtrl);
-	}
-}
-
-
-wxArrayLong SjBasicSettingsConfigPage::GetSelectedOptions()
+wxArrayLong SjFurtherOptPanel::GetSelectedOptions()
 {
 	wxArrayLong ret;
 	long i, iCount = m_littleListCtrl->GetItemCount();
@@ -671,29 +497,27 @@ wxArrayLong SjBasicSettingsConfigPage::GetSelectedOptions()
 }
 
 
-SjLittleOption* SjBasicSettingsConfigPage::GetSelectedOption()
+SjLittleOption* SjFurtherOptPanel::GetSelectedOption()
 {
 	wxArrayLong selectedOptions = GetSelectedOptions();
 	return selectedOptions.GetCount()==1? (SjLittleOption*)(selectedOptions[0]) : NULL;
 }
 
 
-void SjBasicSettingsConfigPage::UpdateLittleOption(SjLittleOption* updatePtr)
+void SjFurtherOptPanel::UpdateLittleOption(SjLittleOption* updatePtr)
 {
 	int             i, iCount = m_littleListCtrl->GetItemCount();
 	SjLittleOption* o;
 
-
 	wxColour    colourWhite = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW);
 	wxColour    colourBlack = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT);
-	wxFont      normalFont = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
+	wxFont      normalFont = GetFont(); // GetFont() seems to be a more generic approach than wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT) which returns too small fonts eg. on OS X
 	if( g_accelModule->m_flags&SJ_ACCEL_USE_VIEW_FONT_IN_DLG )
 	{
 		normalFont = g_mainFrame->m_baseStdFont;
 	}
 	wxFont      boldFont = normalFont; if(boldFont.GetWeight()==wxBOLD) {boldFont.SetStyle(wxITALIC);} else {boldFont.SetWeight(wxBOLD);}
 
-
 	for( i = 0; i < iCount; i++ )
 	{
 		o = (SjLittleOption*)m_littleListCtrl->GetItemData(i);
@@ -718,7 +542,19 @@ void SjBasicSettingsConfigPage::UpdateLittleOption(SjLittleOption* updatePtr)
 }
 
 
-void SjBasicSettingsConfigPage::ShowLittleContextMenu(wxWindow* window, const wxPoint& pt)
+void SjFurtherOptPanel::UpdateLittleColWidth()
+{
+	wxSize size;
+
+	size = m_littleListCtrl->GetClientSize();
+	size.x -= 8;
+
+	int w0 = (size.x)/2;
+	m_littleListCtrl->SetColumnWidth(0, w0);
+	m_littleListCtrl->SetColumnWidth(1, size.x-w0);
+}
+
+void SjFurtherOptPanel::ShowLittleContextMenu(wxWindow* window, const wxPoint& pt)
 {
 	SjMenu          m(0);
 	wxArrayLong     selectedOptions = GetSelectedOptions();
@@ -742,9 +578,9 @@ void SjBasicSettingsConfigPage::ShowLittleContextMenu(wxWindow* window, const wx
 				else
 				{
 					long checkable = o->IsOptionCheckable(i);
-					if( checkable==2 ) { m.AppendRadioItem (IDC_OPTIONFIRST+i, optStr);    }
-					else if( checkable==1 ) { m.AppendCheckItem (IDC_OPTIONFIRST+i, optStr);    }
-					else                    { m.Append          (IDC_OPTIONFIRST+i, optStr);    }
+					     if( checkable==2 ) { m.AppendRadioItem (IDC_OPTIONFIRST+i, optStr); }
+					else if( checkable==1 ) { m.AppendCheckItem (IDC_OPTIONFIRST+i, optStr); }
+					else                    { m.Append          (IDC_OPTIONFIRST+i, optStr); }
 
 					m.Enable(IDC_OPTIONFIRST+i, o->IsOptionEnabled(i));
 
@@ -778,7 +614,7 @@ void SjBasicSettingsConfigPage::ShowLittleContextMenu(wxWindow* window, const wx
 }
 
 
-void SjBasicSettingsConfigPage::OnLittleDoubleClick(wxListEvent&)
+void SjFurtherOptPanel::OnLittleDoubleClick(wxListEvent&)
 {
 	SjLittleOption* o = GetSelectedOption();
 	if( o )
@@ -796,7 +632,7 @@ void SjBasicSettingsConfigPage::OnLittleDoubleClick(wxListEvent&)
 }
 
 
-void SjBasicSettingsConfigPage::OnLittleOption(wxCommandEvent& event)
+void SjFurtherOptPanel::OnLittleOption(wxCommandEvent& event)
 {
 	SjLittleOption* o = GetSelectedOption();
 	if( o )
@@ -807,7 +643,7 @@ void SjBasicSettingsConfigPage::OnLittleOption(wxCommandEvent& event)
 }
 
 
-void SjBasicSettingsConfigPage::OnLittleReset(wxCommandEvent&)
+void SjFurtherOptPanel::OnLittleReset(wxCommandEvent&)
 {
 	wxWindow*   topLevelWindow = SjDialog::FindTopLevel(this);
 	wxArrayLong selectedOptions = GetSelectedOptions();
@@ -815,12 +651,8 @@ void SjBasicSettingsConfigPage::OnLittleReset(wxCommandEvent&)
 
 	if( selectedOptionsCount > 1 )
 	{
-		wxWindowDisabler disabler(topLevelWindow);
-
-		if( SjMessageBox(
-		            wxString::Format(_("Do you really want to reset all %i selected commands and options to their default values?"), selectedOptionsCount),
-		            SJ_PROGRAM_NAME,
-		            wxYES_NO|wxNO_DEFAULT|wxICON_QUESTION, topLevelWindow) == wxNO )
+		if( SjMessageBox(wxString::Format(_("Do you really want to reset all %i selected commands and options to their default values?"), (int)selectedOptionsCount),
+		                 SJ_PROGRAM_NAME, wxYES_NO|wxNO_DEFAULT|wxICON_QUESTION, topLevelWindow) == wxNO )
 		{
 			return;
 		}
@@ -867,57 +699,127 @@ void SjBasicSettingsConfigPage::OnLittleReset(wxCommandEvent&)
 
 
 /*******************************************************************************
- * SjBasicSettingsConfigPage - Little "Misc" Options
+ * SjBasicSettingsConfigPage
  ******************************************************************************/
 
 
-class SjLittleBitSkinUpdate : public SjLittleBit
+class SjBasicSettingsConfigPage : public wxPanel
 {
 public:
-	SjLittleBitSkinUpdate(const wxString& name, const wxString& options, long bitInBitfield, SjIcon icon=SJ_ICON_LITTLEDEFAULT, SjBasicSettingsConfigPage* pleaseRestart=NULL)
-		: SjLittleBit(name, options, &g_mainFrame->m_skinFlags, SJ_SKIN_DEFAULT_FLAGS&bitInBitfield, bitInBitfield, wxT("main/skinFlags"), icon)
-	{
-		m_pleaseRestart = pleaseRestart;
-	}
-
-	void OnFeedback()
-	{
-		if( m_pleaseRestart )
-			SjDialog::PleaseRestartMsg(m_pleaseRestart);
-		else
-			g_mainFrame->UpdateDisplay();
-		m_pleaseRestart = NULL; // show the message only once
-	}
+	                SjBasicSettingsConfigPage (SjBasicSettingsModule* basicSettingsModule, wxWindow* parent, int selectedPage);
+	                ~SjBasicSettingsConfigPage();
 
 private:
-	SjBasicSettingsConfigPage* m_pleaseRestart;
+	// further options
+	SjArrayLittleOption m_littleOptions; // needed by compare function
+
+	// little "Misc" settings
+	void            GetLittleMiscOptions(SjArrayLittleOption&);
+	void            ApplyOrCancelLittleMisc (bool apply, bool& wantsToBeRestarted);
+	long            m_miscOldIdxCacheIndex, m_miscNewIdxCacheIndex,
+	                m_miscOldIdxSync, m_miscNewIdxSync,
+	                m_miscIndexImgDiskCache,
+	                m_miscIndexImgRamCache,
+	                m_miscIndexImgRegardTimestamp;
+	wxString		m_oldLanguageValue, m_newLanguageValue;
+
+	// other
+	SjBasicSettingsModule* m_basicSettingsModule;
+	wxNotebook*     m_notebook;
+	bool            m_constructorDone;
+	                DECLARE_EVENT_TABLE ()
+
+	friend class    SjBasicSettingsModule;
 };
 
 
-#if SJ_USE_SCRIPTS
-class SjLittleScript : public SjLittleOption
+BEGIN_EVENT_TABLE(SjBasicSettingsConfigPage, wxPanel)
+END_EVENT_TABLE()
+
+
+static SjBasicSettingsConfigPage* g_configPage = NULL;
+
+
+SjBasicSettingsConfigPage::SjBasicSettingsConfigPage(SjBasicSettingsModule* basicSettingsModule, wxWindow* parent, int selectedPage)
+	: wxPanel(parent) // wxCLIP_CHILDREN has problems with wxListCtrl
 {
-public:
-	SjLittleScript(const wxString& name, int index)
-		: SjLittleOption(name, SJ_ICON_MODULE)
+	wxBusyCursor busy;
+
+	// save given objects
+	m_basicSettingsModule   = basicSettingsModule;
+	m_constructorDone       = FALSE;
+
+
+	// init the little options array
 	{
-		m_scriptIndex = index;
+		SjModuleList* listOfModules = g_mainFrame->m_moduleSystem.GetModules(SJ_MODULETYPE_ALL);
+		SjModuleList::Node* moduleNode = listOfModules->GetFirst();
+		while( moduleNode )
+		{
+			SjModule* module = moduleNode->GetData();
+
+			SjLittleOption::ClearSection();
+			module->GetLittleOptions(m_littleOptions);
+
+			moduleNode = moduleNode->GetNext();
+		}
 	}
 
-	wxString GetDisplayValue() const { return wxT("..."); }
-	long GetOptionCount() const { return 1; }
-	wxString GetOption(long i) const { return _("Edit..."); }
-	bool OnOption(wxWindow* parent, long i) { return OnDoubleClick(parent); }
-	bool OnDoubleClick(wxWindow* parent)
+	GetLittleMiscOptions(m_littleOptions);
+
+	// create notebook
+	wxSizer* dialogSizer = new wxBoxSizer(wxVERTICAL);
+	SetSizer(dialogSizer);
+
+	m_notebook = new wxNotebook(this, IDC_NOTEBOOK, wxDefaultPosition, wxDefaultSize, 0/*wxCLIP_CHILDREN - problems with wxChoice/wxComboBox*/);
+
+	wxNotebook* notebookSizer = m_notebook; // wxNotebookSizer is no longer needed in 2.6.0
+
+	SjPreselect preselectKeys= SJ_PRESELECT_NONE;
+	if( selectedPage == 666 /*further options*/ )
 	{
-		SjSee::OnGlobalEmbedding(SJ_PERSISTENT_CONFIG_BUTTON, m_scriptIndex);
-		return false; // other options are not affected
+		selectedPage = PAGE_SHORTCUTS;
+	}
+	else if( selectedPage == 667 /*further options*/ )
+	{
+		selectedPage = PAGE_SHORTCUTS;
+		preselectKeys = SJ_PRESELECT_NUMPAD;
+	}
+	else if( selectedPage == 668 /*further options*/ )
+	{
+		selectedPage = PAGE_SHORTCUTS;
+		preselectKeys = SJ_PRESELECT_ADDCREDIT;
 	}
 
-private:
-	int m_scriptIndex;
-};
-#endif
+	m_notebook->AddPage(new SjFurtherOptPanel(m_notebook, m_littleOptions, PAGE_SHORTCUTS, preselectKeys), _("Shortcuts"));
+	m_notebook->AddPage(new SjFurtherOptPanel(m_notebook, m_littleOptions, PAGE_FURTHEROPTIONS, preselectKeys), _("Further options"));
+
+	if( selectedPage < 0
+	 || selectedPage >= (int)m_notebook->GetPageCount() )
+	{
+		selectedPage = 0;
+	}
+
+	m_notebook->SetSelection(selectedPage);
+
+	dialogSizer->Add(notebookSizer, 1, wxALL|wxGROW, SJ_DLG_SPACE);
+
+	// init done, center dialog
+	dialogSizer->SetSizeHints(this);
+	m_constructorDone = TRUE;
+	g_configPage = this;
+}
+
+
+SjBasicSettingsConfigPage::~SjBasicSettingsConfigPage()
+{
+	g_configPage = NULL;
+}
+
+
+/*******************************************************************************
+ * SjBasicSettingsConfigPage - Little "Misc" Options
+ ******************************************************************************/
 
 
 void SjBasicSettingsConfigPage::GetLittleMiscOptions(SjArrayLittleOption& lo)
@@ -925,18 +827,8 @@ void SjBasicSettingsConfigPage::GetLittleMiscOptions(SjArrayLittleOption& lo)
 	// init special commands...
 	#define SEP wxString(wxT("|"))
 
-	// ...scripts
-	SjLittleOption::ClearSection();
-	#if SJ_USE_SCRIPTS
-	{
-		wxArrayString arr = SjSee::GetGlobalEmbeddings(SJ_PERSISTENT_CONFIG_BUTTON);
-		int i, iCount = arr.GetCount();
-		for( i = 0; i < iCount; i++ )
-			lo.Add(new SjLittleScript(arr[i], i));
-	}
-	#endif
-
 	// ...language
+	SjLittleOption::ClearSection();
 	{
 		const wxLanguageInfo* info = wxLocale::GetLanguageInfo(wxLocale::GetSystemLanguage());
 		wxString defaultLanguageValue = info? info->CanonicalName : wxString(wxT("en_GB"));
@@ -975,7 +867,6 @@ void SjBasicSettingsConfigPage::GetLittleMiscOptions(SjArrayLittleOption& lo)
 	                        _("Fast")+SEP+_("Save but slower")+SEP+_("Very save and slow"),
 	                        &m_miscNewIdxSync, 0L, 0L, wxT(""), SJ_ICON_LITTLEDEFAULT, FALSE));
 
-
 	// ...files: temp. directory
 	g_tools->m_cache.GetLittleOptions(lo);
 
@@ -1004,7 +895,6 @@ void SjBasicSettingsConfigPage::GetLittleMiscOptions(SjArrayLittleOption& lo)
 	tempLong2 = g_mainFrame->m_imgThread->GetRegardTimestamp()? 1L : 0L;
 	lo.Add(new SjLittleBit (_("Regard file changes"), wxT("yn"), &tempLong2, 0L, 0L, wxT(""), SJ_ICON_LITTLEDEFAULT, FALSE));
 
-
 	// ...files: search paths
 	SjLittleOption::ClearSection();
 	{
@@ -1016,19 +906,6 @@ void SjBasicSettingsConfigPage::GetLittleMiscOptions(SjArrayLittleOption& lo)
 		}
 		lo.Add(new SjLittlePathList(_("Search paths"), paths, defPaths, wxT("main/searchPath")));
 	}
-
-	// ...display
-	SjLittleOption::SetSection(_("Display"));
-	lo.Add(new SjLittleBitSkinUpdate (_("Show total time"), wxT("yn"),
-	                                  SJ_SKIN_SHOW_DISPLAY_TOTAL_TIME));
-	lo.Add(new SjLittleBitSkinUpdate (_("Show track number"), wxT("yn"),
-	                                  SJ_SKIN_SHOW_DISPLAY_TRACKNR));
-	lo.Add(new SjLittleBitSkinUpdate (_("Show artist name"), wxT("yn"),
-	                                  SJ_SKIN_SHOW_DISPLAY_ARTIST));
-	lo.Add(new SjLittleBitSkinUpdate (_("Show AutoPlay"), wxT("yn"),
-	                                  SJ_SKIN_SHOW_DISPLAY_AUTOPLAY));
-	lo.Add(new SjLittleBitSkinUpdate (_("Preferred cover"), _("Album cover")+SEP+_("Track cover"),
-	                                  SJ_SKIN_SHOW_TRACK_COVER));
 }
 
 
@@ -1103,55 +980,24 @@ void SjBasicSettingsModule::DoneConfigPage(wxWindow* configPage__, int doneCode_
 	bool                        apply = (doneCode__!=SJ_CONFIGPAGE_DONE_CANCEL_CLICKED);
 
 	// cancel / apply embedded "little" options
-	if( configPage->m_littlePageInitialized )
 	{
 		int i, iCount = configPage->m_littleOptions.GetCount();
 		if( apply )
 		{
-			for( i = 0; i < iCount; i++ ) configPage->m_littleOptions[i].OnApply();
+			for( i = 0; i < iCount; i++ ) { configPage->m_littleOptions[i].OnApply(); }
 		}
 		else
 		{
-			for( i = 0; i < iCount; i++ ) configPage->m_littleOptions[i].OnCancel();
+			for( i = 0; i < iCount; i++ ) { configPage->m_littleOptions[i].OnCancel(); }
 		}
 		configPage->ApplyOrCancelLittleMisc(apply, wantsToBeRestarted);
-
-		// remember listbox selection
-		SjLittleOption* o = configPage->GetSelectedOption();
-		SjBasicSettingsConfigPage::s_littleListSelection = o? configPage->m_littleOptions.Index(*o) : -1;
-	}
-
-	// cancel / apply embedded pages
-	SjModuleList* moduleList = g_mainFrame->m_moduleSystem.GetModules(SJ_MODULETYPE_COMMON);
-	SjModuleList::Node* moduleNode = moduleList->GetFirst();
-	int embeddedIndex = PAGE_FIRSTEMBEDDED;
-	while( moduleNode )
-	{
-		SjColModule* embeddedModule = (SjColModule*)moduleNode->GetData();
-		if( embeddedModule->EmbedTo() == SJ_EMBED_TO_BASICSETTINGS )
-		{
-			wxWindow* embeddedPage = configPage->m_notebook->GetPage(embeddedIndex);
-			if( embeddedPage )
-			{
-				embeddedModule->DoneConfigPage(embeddedPage, doneCode__);
-				embeddedIndex++;
-			}
-		}
-
-		// next
-		moduleNode = moduleNode->GetNext();
 	}
 
 	// restart?
 	if( wantsToBeRestarted )
 	{
-		wxWindowDisabler disabler(SjDialog::FindTopLevel(configPage__));
 		SjMessageBox(wxString::Format(_("Please restart %s so that the changes can take effect."), SJ_PROGRAM_NAME),
 		             SJ_PROGRAM_NAME, wxOK|wxICON_INFORMATION, SjDialog::FindTopLevel(configPage__));
 	}
 }
 
-
-
-
-
