@@ -83,6 +83,30 @@ SjModuleSystem::~SjModuleSystem()
 }
 
 
+static void fileName2Url__(wxSqlt& sql, const wxString& table)
+{
+	wxArrayLong   ids;
+	wxArrayString urls;
+	sql.Query("SELECT id, url FROM "+table);
+	while( sql.Next() )
+	{
+		wxString url = sql.GetString(1);
+		if( url.Left(5) != "file:" )
+		{
+			ids.Add(sql.GetLong(0));
+			urls.Add(url);
+		}
+	}
+
+	for( size_t i = 0; i < ids.GetCount(); i++ )
+	{
+		wxFileName filename(urls.Item(i));
+		wxString url = wxFileSystem::FileNameToURL(filename);
+		sql.Query("UPDATE "+table+" SET url='"+sql.QParam(url)+"' WHERE id="+wxString::Format("%i", (int)ids.Item(i)));
+	}
+}
+
+
 void SjModuleSystem::Init()
 {
 	// add extensions read by wxImage
@@ -117,7 +141,6 @@ void SjModuleSystem::Init()
 	// init database...
 	{
 		wxLogInfo(wxT("Loading %s"), g_tools->m_dbFile.c_str());
-		SjBusyInfo::Set(g_tools->m_dbFile, TRUE);
 
 		// ...open database
 		wxSqltDb* db = new wxSqltDb(g_tools->m_dbFile);
@@ -128,7 +151,7 @@ void SjModuleSystem::Init()
 		// _larger_, the database cannot be opened.  However, the version
 		// normally does not change at all as we can add tables and fields as
 		// needed.
-		#define CURR_DB_VERSION 1L
+		#define CURR_DB_VERSION 2L
 
 		// ...init database...
 		if( !db->ExistsBeforeOpening() )
@@ -152,7 +175,25 @@ void SjModuleSystem::Init()
 		{
 			// subsequent opening
 			wxSqlt sql;
-			if( sql.ConfigRead(wxT("dbversion"), -1) != CURR_DB_VERSION ) {
+			long dbversion = sql.ConfigRead(wxT("dbversion"), -1);
+			if( dbversion == 1 )
+			{
+				// in dbversion1 there were some bugs in the file system; most tracks were store using file names, tracks with problems may be stored using file://.  This lead to many confusing situations.
+				// in dbversion2, we expect all tracks to use file://-URLs
+				// this coversion was added 11/2015 for upgrading Silverjuke 15.4-15.8 to 15.9, thus the conversion is only used by a very small part of users
+				wxBusyCursor busy;
+				{
+					wxSqltTransaction transaction;
+					fileName2Url__(sql, "tracks");
+					g_mainFrame->UpdateIndexAfterConstruction(); // to update the arts table
+					sql.ConfigWrite(wxT("dbversion"), 2);
+					transaction.Commit();
+				}
+				dbversion = sql.ConfigRead(wxT("dbversion"), -1);
+			}
+
+			if( dbversion != CURR_DB_VERSION )
+			{
 				// normally, this should not happen; the database format should be stable.
 				wxMessageBox(wxString::Format(wxT("Bad version of the jukebox file \"%s\". Delete the file and try over; we'll recreate a more correct version then. For now, the program will terminate.")/*n/t*/, g_tools->m_dbFile.c_str()));
 				SjMainApp::FatalError();
@@ -302,19 +343,6 @@ int SjModuleSystem_CmpModulesByAll(const SjModule** m1, const SjModule** m2)
 }
 
 
-int SjModuleSystem_CmpModulesByName(const SjModule** m1, const SjModule** m2)
-{
-	wxASSERT(m1 && *m1 && m2 && *m2);
-
-	// in versions before 1.23beta1, the internal interface was compared by a name of " ".
-	// why? to put it up in the list?
-	wxString interf1 = (*m1)->m_interface->GetName();
-	wxString interf2 = (*m2)->m_interface->GetName();
-
-	return (*m1)->m_name.CmpNoCase((*m2)->m_name);
-}
-
-
 void SjModuleSystem::LoadModules()
 {
 	// This function may only be called from the main thread.
@@ -360,8 +388,6 @@ void SjModuleSystem::LoadModules()
 			moduleNode = moduleNode->GetNext();
 		}
 	}
-
-	m_listOfModules2[SJ_MODULETYPE_VIS_RENDERER].Sort(SjModuleSystem_CmpModulesByName);
 }
 
 
@@ -408,10 +434,9 @@ SjScannerModule* SjModuleSystem::FindScannerModuleByUrl(const wxString& url)
 {
 	SjModuleList*       scannerList = GetModules(SJ_MODULETYPE_SCANNER);
 	SjModuleList::Node* scannerNode = scannerList->GetFirst();
-	SjScannerModule*    scannerModule;
 	while( scannerNode )
 	{
-		scannerModule = (SjScannerModule*)scannerNode->GetData();
+		SjScannerModule* scannerModule = (SjScannerModule*)scannerNode->GetData();
 		wxASSERT( scannerModule );
 		wxASSERT( scannerModule->IsLoaded() );
 
@@ -419,6 +444,8 @@ SjScannerModule* SjModuleSystem::FindScannerModuleByUrl(const wxString& url)
 		{
 			return scannerModule;
 		}
+
+		scannerNode = scannerNode->GetNext();
 	}
 	return NULL;
 }
@@ -438,6 +465,7 @@ SjExtList SjModuleSystem::GetAssignedExt(long flags)
 	// files types read along with the playable files
 	if( flags & SJ_EXT_ARCHIVES )
 	{
+		ret.AddExt(wxT("tar"));
 		ret.AddExt(wxT("zip"));
 	}
 
@@ -487,12 +515,14 @@ void SjModuleSystem::BroadcastMsg(int msg)
 
 	if( inSendMsg == msg )
 	{
-		wxLogError(wxT("Recursive call of SjModuleSystem::SendMsg (msg=%i).")/*n/t*/, msg);
+		wxLogError(wxT("Recursive call of SjModuleSystem::SendMsg (msg=%i).")/*n/t*/, (int)msg);
 	}
 	else
 	{
 		inSendMsg = msg;
 
+		// send message to all interfaces
+		#if 0
 		SjInterfaceList::Node* interfaceNode = m_listOfInterfaces.GetFirst();
 		while( interfaceNode )
 		{
@@ -503,6 +533,7 @@ void SjModuleSystem::BroadcastMsg(int msg)
 
 			interfaceNode = interfaceNode->GetNext();
 		}
+		#endif
 
 		// send message to all modules
 		SjModuleList::Node* moduleNode = m_listOfModules.GetFirst();
@@ -585,7 +616,7 @@ void SjModuleSystem::UnloadPending(bool ignoreTimestamp)
 		wxASSERT( m->m_pushPendingTimestamp != 0 );
 
 		if( ignoreTimestamp
-		        || SjTimestampDiff(m->m_pushPendingTimestamp, thisTimestamp) > SJ_PENDING_MODULES_MS )
+		 || SjTimestampDiff(m->m_pushPendingTimestamp, thisTimestamp) > SJ_PENDING_MODULES_MS )
 		{
 			m->m_pushPendingTimestamp = 0; // prepare for the next pending
 			m->LastUnload();
@@ -626,48 +657,9 @@ void SjInterfaceBase::AddModulesFromDir(SjModuleList& list, const wxString& dirN
 	wxFileSystem        fs;
 	wxString            entryStr;
 	wxArrayString       entryStrings;
-	size_t              e;
 
 	fs.ChangePathTo(dirName, TRUE);
 
-	// first, go through some special subdirectories.
-	// we don't recurse all directories for speed reasons
-	// as the program path is also in the search path and we don't know
-	// where it is and how many thousands file we have to scan.
-
-	{
-		// Non-privileged users may not have access to the directory.
-		// Do not log errors in this case.
-		SjLogString logToString(suppressNoAccessErrors);
-
-		#ifdef __WXMSW__
-			entryStr = fs.FindFirst(wxT("*.*"), wxDIR);
-		#else
-			entryStr = fs.FindFirst(wxT("*"), wxDIR);
-		#endif
-	}
-
-	while( !entryStr.IsEmpty() )
-	{
-		wxString lastDir = g_tools->GetLastDir(entryStr).Lower();
-		if( lastDir == wxT("plugins")           // common
-		        || lastDir == wxT("plug-ins")          // common
-		        || lastDir == wxT("modules")           // common
-		        || lastDir == wxT("input")             // used eg. by XMMS
-		        || lastDir == wxT("visualization")     // used eg. by XMMS
-		  )
-		{
-			entryStrings.Add(entryStr);
-		}
-
-		entryStr = fs.FindNext();
-	}
-
-	for( e = 0; e < entryStrings.GetCount(); e++ )
-	{
-		AddModulesFromDir(list, entryStrings.Item(e), suppressNoAccessErrors);
-	}
-
 	// search for DLLs
 
 	entryStrings.Clear();
@@ -692,15 +684,18 @@ void SjInterfaceBase::AddModulesFromDir(SjModuleList& list, const wxString& dirN
 		entryStr = fs.FindNext();
 	}
 
-	for( e = 0; e < entryStrings.GetCount(); e++ )
-		AddModulesFromFile(list, entryStrings.Item(e), suppressNoAccessErrors);
+	for( size_t e = 0; e < entryStrings.GetCount(); e++ )
+	{
+		wxFileName fn = wxFileSystem::URLToFileName(entryStrings.Item(e));
+		AddModulesFromFile(list, fn, suppressNoAccessErrors);
+	}
 
 	// search for scripts
 
 	if( !s_searchedForScripts )
 	{
 		entryStrings.Clear();
-		entryStr = fs.FindFirst(wxT("*.sj"), wxFILE);
+		entryStr = fs.FindFirst(wxT("*.js"), wxFILE);
 		while( !entryStr.IsEmpty() )
 		{
 			m_moduleSystem->m_scripts.Add(entryStr);
@@ -723,6 +718,7 @@ void SjInterfaceBase::AddModulesFromSearchPaths(SjModuleList& list, bool suppres
 }
 
 
+#if 0
 bool SjInterfaceBase::IsModuleAdded(SjModuleList& list,
                                     const wxString& file, int fileIndex, const wxString& name)
 {
@@ -755,8 +751,10 @@ bool SjInterfaceBase::IsModuleAdded(SjModuleList& list,
 
 	return FALSE;
 }
+#endif // 0
 
 
+#if 0
 void SjInterfaceBase::WriteToCache(const wxString& file, const wxString& info__, unsigned long fileTimestamp)
 {
 	// This function may only be called from the main thread.
@@ -818,7 +816,7 @@ bool SjInterfaceBase::ReadFromCache(const wxString& file, wxArrayString& retInfo
 
 	// get cache timestamp
 	long l;
-	info.BeforeFirst(wxT(':')).ToLong(&l, 10);
+	if( !info.BeforeFirst(wxT(':')).ToLong(&l, 10) ) { l = 0; }
 	if( (unsigned long)l != fileTimestamp )
 	{
 		return FALSE; // cache out of date
@@ -847,6 +845,7 @@ wxString SjInterfaceBase::ReadFromCache(const wxString& file, unsigned long file
 	ReadFromCache(file, a, fileTimestamp);
 	return a.GetCount()? a.Item(0) : wxString();
 }
+#endif
 
 
 /*******************************************************************************
@@ -1062,7 +1061,7 @@ wxString SjModule::PackFileName(const wxString& file, int fileIndex)
 {
 	if( fileIndex )
 	{
-		return wxString::Format(wxT("%s,%i"), file.c_str(), fileIndex);
+		return wxString::Format(wxT("%s,%i"), file.c_str(), (int)fileIndex);
 	}
 	else
 	{
@@ -1091,6 +1090,7 @@ void SjModule::UnpackFileName(const wxString& inFileNIndex, wxString& retFile, i
 }
 
 
+#if 0
 wxString SjModule::GetUniqueStrId(const wxString& file, int fileIndex)
 {
 	wxString str(PackFileName(file, fileIndex));
@@ -1102,6 +1102,7 @@ wxString SjModule::GetUniqueStrId(const wxString& file, int fileIndex)
 
 	return SjNormaliseString(str, 0);
 }
+#endif
 
 
 /*******************************************************************************
@@ -1270,13 +1271,13 @@ wxString SjTrackInfo::GetFormattedValue(long ti) const
 			for( long i = 0; i < queueCount; i++ )
 			{
 				if( i ) ret += wxT(", ");
-				ret += wxString::Format(wxT("%i"), pos[i]+1);
+				ret += wxString::Format(wxT("%i"), (int)(pos[i]+1));
 			}
 			return ret;
 		}
 
 		case SJ_TI_RATING:
-			if( m_rating > 0 )
+			if( m_rating >= 1 && m_rating <= 5 )
 			{
 				wxString chars;
 				for( long i = 0; i < m_rating; i++)
@@ -1444,7 +1445,7 @@ wxString SjTrackInfo::GetFieldDbName(long ti)
 bool SjTrackInfo::IsEqualTo(const SjTrackInfo& o) const
 {
 	if( // compare longs
-	    m_id            != o.m_id
+	       m_id            != o.m_id
 	    || m_updatecrc     != o.m_updatecrc
 	    || m_timeAdded     != o.m_timeAdded
 	    || m_timeModified  != o.m_timeModified
