@@ -46,17 +46,17 @@ class SjListView;
 
 enum SjResult
 {
-    SJ_ERROR = 0
-               ,   SJ_SUCCESS = 1
-                                ,   SJ_SUCCESS_BUT_NO_DATA = 2
+	 SJ_ERROR = 0
+	,SJ_SUCCESS = 1
+	,SJ_SUCCESS_BUT_NO_DATA = 2
 };
 
 
 class SjTrackInfo
 {
 public:
-	SjTrackInfo         () { ClearLongs(); }
-	void            Clear  () { ClearLongs(); ClearStrings(); }
+	                SjTrackInfo         () { ClearLongs(); }
+	void            Clear               () { ClearLongs(); ClearStrings(); }
 
 	// Flags that may be used by functions taking SjTrackInfo as arguments.
 	// They are not used by SjTrackInfo itself.
@@ -71,7 +71,7 @@ public:
 
 	wxString        m_url;          // eg. a file
 	long            m_id;           // internal, optional use, normally the URL should be used to identify a track
-	unsigned long   m_updatecrc;    // any number that changes if the track was modified
+	uint32_t        m_updatecrc;    // any number that changes if the track was modified
 	unsigned long   m_timeAdded;
 	unsigned long   m_timeModified;
 	unsigned long   m_timesPlayed;
@@ -124,6 +124,7 @@ public:
 	#define         SJ_TI_RATING            0x00004000L
 	#define         SJ_TI_YEAR              0x00008000L
 	#define         SJ_TI_PLAYTIMEMS        0x00010000L
+	#define         SJ_TI_BITS_COUNT                17  // the number of used bits above - as we may iterate the fields, there should be no gaps!
 	#define         SJ_TI_X_TIMEADDED       0x0000001FL // the SJ_TI_X_* values are only used by the list view, but they're stored in the db, no bit-tests are possible!
 	#define         SJ_TI_X_TIMEMODIFIED    0x0000002FL
 	#define         SJ_TI_X_LASTPLAYED      0x0000003FL
@@ -168,8 +169,8 @@ private:
 
 enum SjModuleType
 {
-    SJ_MODULETYPE_ALL = 0
-                        ,SJ_MODULETYPE_COMMON       // common module
+     SJ_MODULETYPE_ALL = 0
+	,SJ_MODULETYPE_COMMON       // common module
     ,SJ_MODULETYPE_COL          // COLUMN GENERATOR module
     ,SJ_MODULETYPE_SCANNER      // SCANNER module (normally for internal use only)
     ,SJ_MODULETYPE_VIS_RENDERER // VISUALIZATION module
@@ -182,11 +183,11 @@ class SjModule
 public:
 	// Constructor / destructor.
 	// The destructor has no real implementation, but "virtual" is important
-	SjModule(SjInterfaceBase*, SjModuleType type);
-	virtual ~SjModule() { wxASSERT(m_usage==0); }
+	                SjModule            (SjInterfaceBase*, SjModuleType type);
+	virtual         ~SjModule           () { wxASSERT(m_usage==0); }
 
 	// pointer back to the interface with this module was found
-	SjInterfaceBase*    m_interface;
+	SjInterfaceBase* m_interface;
 
 	// the module type
 	SjModuleType    m_type;
@@ -224,8 +225,10 @@ public:
 	static void     UnpackFileName      (const wxString& inFileNIndex, wxString& retFile, int& retIndex);
 
 	// Get Unique String IDs for identifying a module.  This also works for unloaded modules.
+	#if 0
 	wxString        GetUniqueStrId      () const { return GetUniqueStrId(m_file, m_fileIndex); }
 	static wxString GetUniqueStrId      (const wxString& file, int fileIndex);
+	#endif
 
 	// Is this module a plugin?
 	virtual bool    IsPlugin            () { return false; }
@@ -271,7 +274,7 @@ enum SjDragNDropAction
 class SjDataObject : public wxDataObjectComposite
 {
 public:
-	SjDataObject        (wxDragResult);
+	                SjDataObject        (wxDragResult);
 	void            AddFileData         ();
 	void            AddFile             (const wxString&);
 	void            AddFiles            (const wxArrayString&);
@@ -287,7 +290,6 @@ enum SjEmbedTo
 {
     SJ_EMBED_NONE=0,
     SJ_EMBED_TO_MAIN=1,
-    SJ_EMBED_TO_BASICSETTINGS=2,
     SJ_EMBED_TO_MUSICLIB=3
 };
 
@@ -347,8 +349,7 @@ public:
 	// If "deepSearch" is set, the module should not use anything
 	// from its cache but really search again.  If the module does
 	// not cache any searches, this flag can be ignored.
-	virtual SjSearchStat
-	SetSearch           (const SjSearch&, bool deepSearch) = 0;
+	virtual SjSearchStat SetSearch      (const SjSearch&, bool deepSearch) = 0;
 
 	// called if "del" or "ins" is hit, the function should return the number
 	// of DELETED tracks/rows, if any
@@ -384,23 +385,20 @@ public:
 	// it does not exist or is out of date.
 	// if you return TRUE, you should mark the URL as updated as you
 	// ReceiveTrackInfo() won't be called.
-	virtual bool    Callback_CheckTrackInfo
-	(const wxString& url, unsigned long actualCrc32) = 0;
+	virtual bool    Callback_CheckTrackInfo(const wxString& url, uint32_t actualCrc32) = 0;
 
 	// ...receiving track information, the given object is owned by
 	// the function and should be deleted from it when no longer needed
-	virtual bool    Callback_ReceiveTrackInfo
-	(SjTrackInfo* trackInfo) = 0;
+	virtual bool    Callback_ReceiveTrackInfo(SjTrackInfo* trackInfo) = 0;
 
-	virtual bool    Callback_MarkAsUpdated
-	(const wxString& urlBegin, long checkTrackCount) = 0;
+	virtual bool    Callback_MarkAsUpdated(const wxString& urlBegin, long checkTrackCount) = 0;
 };
 
 
 class SjListView
 {
 public:
-	SjListView          (long order, bool desc, long minAlbumRows) { m_currOrderField=order; m_currOrderDesc=desc; m_minAlbumRows = minAlbumRows; }
+	                SjListView          (long order, bool desc, long minAlbumRows) { m_currOrderField=order; m_currOrderDesc=desc; m_minAlbumRows = minAlbumRows; }
 	virtual         ~SjListView         () {}
 
 	// all stuff is always "masked" (regards music selections and searched)
@@ -521,7 +519,7 @@ public:
 	int             m_roughType;                // the rough type of the row
 
 	wxString        m_textl, m_textm, m_textr;  // left/mid/right text, highlited text is remarked as
-	// "normal text \thighlited text\t normal text"
+	                                            // "normal text \thighlited text\t normal text"
 
 	int             m_top, m_bottom;            // the OS can save some calculated positions in these fields
 
@@ -581,7 +579,7 @@ public:
  ******************************************************************************/
 
 
-class SjVisImpl;
+class SjVisWindow;
 
 
 class SjVisRendererModule : public SjModule
@@ -593,9 +591,8 @@ public:
 	}
 
 	// Start the visualisation. The module should use the
-	// public interface of SjVisModule and SjVisImpl
-	// "justContinue" ist just a hint, set if the vis. window was attached/detached and is started therefore.
-	virtual bool    Start               (SjVisImpl*, bool justContinue) = 0;
+	// public interface of SjVisModule and SjVisWindow.
+	virtual bool    Start               (SjVisWindow*) = 0;
 
 	// Stop the visualisation. After Stop() is called, the
 	// player object given to Start() is no longer valid.
@@ -605,8 +602,12 @@ public:
 	virtual void    AddMenuOptions      (SjMenu&) {}
 	virtual void    OnMenuOption        (int i) {}
 
-	// when the size has changed ... the module should call SjVisImpl::GetRendererClientRect() or SjVisImpl::GetRendererScreenRect()
-	virtual void    PleaseUpdateSize    (SjVisImpl*) = 0;
+	// when the size has changed ... the module should call SjVisWindow::GetRendererClientRect() or SjVisImpl::GetRendererScreenRect()
+	virtual void    PleaseUpdateSize    (SjVisWindow*) = 0;
+
+	// AddVisData() function is called from without the audio DSP output, so please be fast and do not do
+	// weird things here!
+	virtual void    AddVisData          (const float* buffer, long bytes) {}
 };
 
 
@@ -619,10 +620,10 @@ class SjInterfaceBase
 {
 public:
 	// constructor
-	SjInterfaceBase(const wxString& name);
+	                SjInterfaceBase     (const wxString& name);
 
 	// the destructor has no implementation, but "virtual" is important
-	virtual         ~SjInterfaceBase() {};
+	virtual         ~SjInterfaceBase    () {};
 
 	// pointers back to the main frame and to the module system
 	SjModuleSystem* m_moduleSystem;
@@ -632,17 +633,21 @@ public:
 
 	// get modules. the returned modules are owned by the caller,
 	// the function returns TRUE if any modules are added or deleted from the list.
-	virtual void    LoadModules          (SjModuleList&) = 0;
+	virtual void    LoadModules         (SjModuleList&) = 0;
 
 	// message handling
+	#if 0
 	virtual void    ReceiveMsg          (int) { }
+	#endif
 
 	// the cache, the module is only identified by m_file and NOT by m_fileIndex,
 	// so if a file contains several modules and should be written to the cache, all
 	// information about all modules should be placed in addInfo
+	#if 0
 	void            WriteToCache        (const wxString& file, const wxString& info, unsigned long fileTimestamp=0);
 	bool            ReadFromCache       (const wxString& file, wxArrayString& info, unsigned long fileTimestamp=0);
 	wxString        ReadFromCache       (const wxString& file, unsigned long fileTimestamp=0);
+	#endif
 
 protected:
 
@@ -653,18 +658,21 @@ protected:
 	// AddModulesFromDir() recurses into some special directories as
 	// "plugins" or "modules".
 	void            AddModulesFromDir   (SjModuleList&, const wxString& dirName, bool suppressNoAccessErrors=FALSE);
-	virtual void    AddModulesFromFile  (SjModuleList&, const wxString& file, bool suppressNoAccessErrors) {  }
+	virtual void    AddModulesFromFile  (SjModuleList&, const wxFileName& fn, bool suppressNoAccessErrors) {  }
 
 	// AddModulesFromSearchPaths() calls AddModulesFromDir() for each search path
 	// and returns TRUE if sth. was changed.
-	void            AddModulesFromSearchPaths
-	(SjModuleList&, bool suppressNoAccessErrors=FALSE);
+	void            AddModulesFromSearchPaths(SjModuleList&, bool suppressNoAccessErrors=FALSE);
 
+	#if 0
 	bool            IsModuleAdded       (SjModuleList&, const wxString& file, int fileIndex=0, const wxString& name=wxEmptyString);
+	#endif
 
 private:
 	wxString        m_name;
+	#if 0
 	wxString        GetUniqueStrId      () const { return SjNormaliseString(m_name, 0); }
+	#endif
 
 	friend class    SjModuleSystem;
 };
@@ -682,8 +690,8 @@ class SjModuleSystem
 {
 public:
 	// constructor / destructor / init / exit
-	SjModuleSystem      ();
-	~SjModuleSystem     ();
+	                SjModuleSystem      ();
+	                ~SjModuleSystem     ();
 	void            Init                ();
 	void            Exit                ();
 
@@ -713,12 +721,12 @@ public:
 
 	// searching modules
 	SjModule*        FindModuleByFile            (const wxString& file, int fileIndex = 0);
-	SjScannerModule* FindScannerModuleByUrl     (const wxString& url);
+	SjScannerModule* FindScannerModuleByUrl      (const wxString& url);
 	bool             FindImageHandlerByExt       (const wxString& ext) { wxASSERT( ext.Cmp(ext.Lower())==0 ); return m_imageExtList.LookupExt(ext); }
 	bool             FindPlaylistHandlerByExt    (const wxString& ext) { wxASSERT( ext.Cmp(ext.Lower())==0 ); return m_playlistExtListRead.LookupExt(ext); }
 
 	// get the list of interfaces
-	SjInterfaceList* GetInterfaces       () { return &m_listOfInterfaces; }
+	SjInterfaceList* GetInterfaces      () { return &m_listOfInterfaces; }
 
 	// BroadcastMsg() send a IDMODMSG_* message to all modules and
 	// to all module interfaces
