@@ -73,15 +73,14 @@ WX_DEFINE_LIST(SjSettingsSourceItemList);
 class SjMyMusicConfigPage : public wxPanel
 {
 public:
-	SjMyMusicConfigPage (SjMyMusicModule* module, wxWindow* parent, int selectedPage);
+	                SjMyMusicConfigPage (SjMyMusicModule* module, wxWindow* parent, int selectedPage);
 
 	bool            m_idxChanged;
 
 private:
 	wxPanel*        CreatePage          (wxWindow* parent);
 	void            InitPage            (const wxString& selSourceName);
-	SjSettingsSourceItem*
-	GetSelFromDialog    ();
+	SjSettingsSourceItem* GetSelFromDialog ();
 	void            OnColClick          (wxListEvent&);
 	void            OnSelectionChange   (wxListEvent&) { UpdateButtons(); }
 	void            OnDoubleClick       (wxListEvent&);
@@ -98,8 +97,7 @@ private:
 	void            OnUpdate            (wxCommandEvent&);
 	void            OnSize              (wxSizeEvent&);
 
-	SjSettingsSourceItemList
-	m_listOfSources;
+	SjSettingsSourceItemList m_listOfSources;
 	int             m_currSortCol;
 
 	wxNotebook*     m_notebook;
@@ -127,8 +125,7 @@ BEGIN_EVENT_TABLE(SjMyMusicConfigPage, wxPanel)
 	EVT_LIST_KEY_DOWN           (IDC_IDXLIST,           SjMyMusicConfigPage::OnListKeyDown      )
 	EVT_BUTTON                  (IDC_IDXUPDATEMENU,     SjMyMusicConfigPage::OnUpdateContextMenu)
 	EVT_BUTTON                  (IDC_IDXADDSOURCES,     SjMyMusicConfigPage::OnAddSourceContextMenu )
-	EVT_MENU_RANGE              (IDC_MODULE00, IDC_MODULE99,
-	                             SjMyMusicConfigPage::OnAddSources       )
+	EVT_MENU_RANGE              (IDC_MODULE00, IDC_MODULE99, SjMyMusicConfigPage::OnAddSources  )
 	EVT_BUTTON                  (IDC_IDXDELSOURCE,      SjMyMusicConfigPage::OnDelSource        )
 	EVT_MENU                    (IDC_IDXDELSOURCE,      SjMyMusicConfigPage::OnDelSource        )
 	EVT_BUTTON                  (IDC_IDXCONFIGSOURCEMENU,SjMyMusicConfigPage::OnOptionsContextMenu)
@@ -198,10 +195,6 @@ wxPanel* SjMyMusicConfigPage::CreatePage(wxWindow* parent)
 
 	// add supported files hint
 	SjExtList supportedExt = g_mainFrame->m_moduleSystem.GetAssignedExt(SJ_EXT_MUSICFILES); // equals to `g_mainFrame->m_player.GetExtList()`
-	if( supportedExt.GetCount() ) {
-		// _if_ there are media files, we read some other belonging files
-		supportedExt.AddExt(g_mainFrame->m_moduleSystem.GetAssignedExt(SJ_EXT_IMAGEFILES|SJ_EXT_ARCHIVES|SJ_EXT_KARAOKE));
-	}
 
 	wxArrayString arrayStr;
 	for( int i = supportedExt.GetCount()-1; i >= 0; i-- ) {
@@ -209,16 +202,22 @@ wxPanel* SjMyMusicConfigPage::CreatePage(wxWindow* parent)
 	}
 	arrayStr.Sort();
 
-	wxString str = _("Currently, the following file types are read:");
-	str += wxT("\n");
-	size_t i;
-	for( i = 0; i < arrayStr.GetCount(); i++ )
+	wxString line = _("Supported file types") + ": ", text, ext;
+	size_t i, i_cnt = arrayStr.GetCount();
+	bool hasMp3 = false, hasOgg = false;
+	for( i = 0; i < i_cnt; i++ )
 	{
-		if( i ) { str += wxT(", "); if( (i % 20) == 0 ) str += wxT("\n"); }
-		str += arrayStr.Item(i);
+		ext = arrayStr.Item(i);
+		line += ext;
+		if( i != i_cnt-1 ) { line += ", "; }
+		if( line.Len() > 75 ) { if( text.Len() ) { text += "\n"; } text += line; line = ""; }
+		if( ext == "mp3" ) { hasMp3 = true; }
+		if( ext == "ogg" ) { hasOgg = true; }
+        if( hasMp3 && hasOgg && i != i_cnt-1 && i >= 70 ) { line += wxString::Format("%i", (int)(i_cnt-i-1)) + "  more"; break; }
 	}
+	if( line.Len() ) { if( text.Len() ) { text += "\n"; } text += line; }
 
-	staticText = new wxStaticText(page, -1, str);
+	staticText = new wxStaticText(page, -1, text);
 	sizer1->Add(staticText, 0, wxALL, SJ_DLG_SPACE);
 
 	sizer1->Add(1, SJ_DLG_SPACE); // some space
@@ -263,7 +262,7 @@ SjMyMusicConfigPage::SjMyMusicConfigPage(SjMyMusicModule* myMusicModule, wxWindo
 	}
 
 	if( selectedPage < 0
-	        || selectedPage >= (int)m_notebook->GetPageCount() )
+	 || selectedPage >= (int)m_notebook->GetPageCount() )
 	{
 		selectedPage = 0;
 	}
@@ -337,7 +336,7 @@ void SjMyMusicConfigPage::OnColClick(wxListEvent& event)
 		m_currSortCol = newCol;
 	}
 
-	m_listCtrl->SortItems(ListCtrlCompareFunction, m_currSortCol);
+	m_listCtrl->SortItems(ListCtrlCompareFunction, m_currSortCol); // this may unselect Items on GTK, however, this should be fixed in wxWidgets/GTK
 }
 
 
@@ -418,7 +417,7 @@ void SjMyMusicConfigPage::InitPage(const wxString& selSourceUrl)
 		                         wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED);
 	}
 
-	m_listCtrl->SortItems(ListCtrlCompareFunction, m_currSortCol);
+	m_listCtrl->SortItems(ListCtrlCompareFunction, m_currSortCol); // this may unselect Items on GTK, however, this should be fixed in wxWidgets/GTK
 
 	m_listCtrl->Thaw();
 
@@ -464,7 +463,7 @@ void SjMyMusicConfigPage::OnAddSources(wxCommandEvent& event)
 
 		{
 			wxWindow* topLevelWindow = SjDialog::FindTopLevel(this);
-			wxWindowDisabler disabler(topLevelWindow);
+			SJ_WINDOW_DISABLER(topLevelWindow);
 			newIndex = scannerModule->AddSources(typeIndex, topLevelWindow);
 		}
 
@@ -483,7 +482,7 @@ void SjMyMusicConfigPage::OnDelSource(wxCommandEvent& event)
 	SjSettingsSourceItem* source = GetSelFromDialog();
 	if( source )
 	{
-		wxWindowDisabler disabler(SjDialog::FindTopLevel(this));
+		SJ_WINDOW_DISABLER(SjDialog::FindTopLevel(this));
 		if( source->GetScannerModule()->DeleteSource(source->GetIndex(), SjDialog::FindTopLevel(this)) )
 		{
 			InitPage(wxT(""));
@@ -499,7 +498,7 @@ void SjMyMusicConfigPage::OnConfigSource(wxCommandEvent& event)
 	SjSettingsSourceItem* source = GetSelFromDialog();
 	if( source )
 	{
-		wxWindowDisabler disabler(SjDialog::FindTopLevel(this));
+		SJ_WINDOW_DISABLER(SjDialog::FindTopLevel(this));
 
 		wxString sourceUrl = source->GetUrl(); // save as source gets invalid on InitPage()
 
@@ -540,8 +539,7 @@ void SjMyMusicConfigPage::OnListKeyDown(wxListEvent& event)
 		case WXK_DELETE:
 		case WXK_BACK:
 		{
-			wxCommandEvent fwd(wxEVT_COMMAND_MENU_SELECTED, IDC_IDXDELSOURCE);
-			AddPendingEvent(fwd);
+			QueueEvent(new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, IDC_IDXDELSOURCE));
 		}
 		break;
 	}
