@@ -74,8 +74,7 @@ SjIcon SjFolderScannerSource::GetIcon()
 class SjFolderSettingsDialog : public SjDialog
 {
 public:
-	SjFolderSettingsDialog
-	(SjFolderScannerModule*,SjFolderScannerSource* source, wxWindow* parent);
+	                SjFolderSettingsDialog (SjFolderScannerModule*,SjFolderScannerSource* source, wxWindow* parent);
 
 private:
 	bool            m_initDone;
@@ -134,7 +133,7 @@ SjFolderSettingsDialog::SjFolderSettingsDialog(SjFolderScannerModule* folderScan
 	m_enabledCheckBox->SetValue(source->m_flags&SJ_FOLDERSCANNER_ENABLED? TRUE : FALSE);
 	sizer3->Add(m_enabledCheckBox, 0, wxALIGN_CENTER_VERTICAL);
 
-	// ignore ext combobox / read ZIP archives checkbox
+	// ignore ext combobox
 	m_ignoreExtTextCtrl = NULL;
 	m_doUpdateCheckBox = NULL;
 	m_readHiddenFilesCheckBox = NULL;
@@ -198,8 +197,7 @@ SjFolderSettingsDialog::SjFolderSettingsDialog(SjFolderScannerModule* folderScan
 
 	// reset button
 	wxButton* button = new wxButton(this, IDC_RESET, _("Reset to default values"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT);
-	sizer2->Add(button,
-	            0, wxALL, SJ_DLG_SPACE);
+	sizer2->Add(button, 0, wxALL, SJ_DLG_SPACE);
 
 	// state stuff
 	{
@@ -237,16 +235,11 @@ void SjFolderSettingsDialog::EnableDisable()
 			wxWindow*   child = childNode->GetData();
 			int         childId = child->GetId();
 
-			if( child->GetClassInfo()->GetClassName() == wxString(wxT("wxStaticBox"))
-			 && child->GetLabel() == _("State") )
-			{
-				break;
-			}
-
 			if( childId != wxID_OK
 			 && childId != wxID_CANCEL
 			 && childId != IDC_ENABLECHECK
-			 && childId != IDC_STATICBOX )
+			 && childId != IDC_STATICBOX
+			 && !wxString(child->GetClassInfo()->GetClassName()).StartsWith("wxStatic") )
 			{
 				child->Enable(enable);
 			}
@@ -266,27 +259,27 @@ void SjFolderSettingsDialog::OnReset(wxCommandEvent&)
 
 	if( m_doUpdateCheckBox )
 	{
-		m_doUpdateCheckBox->SetValue(TRUE);
+		m_doUpdateCheckBox->SetValue((SJ_FOLDERSCANNER_DOUPDATE&SJ_FOLDERSCANNER_DEFFLAGS)!=0);
 	}
 
 	if( m_readHiddenFilesCheckBox )
 	{
-		m_readHiddenFilesCheckBox->SetValue(TRUE);
+		m_readHiddenFilesCheckBox->SetValue((SJ_FOLDERSCANNER_READHIDDENFILES&SJ_FOLDERSCANNER_DEFFLAGS)!=0);
 	}
 
 	if( m_readHiddenDirsCheckBox )
 	{
-		m_readHiddenDirsCheckBox->SetValue(TRUE);
+		m_readHiddenDirsCheckBox->SetValue((SJ_FOLDERSCANNER_READHIDDENDIRS&SJ_FOLDERSCANNER_DEFFLAGS)!=0);
 	}
 
 	if( m_readZipCheckBox )
 	{
-		m_readZipCheckBox->SetValue(TRUE);
+		m_readZipCheckBox->SetValue((SJ_FOLDERSCANNER_READZIP&SJ_FOLDERSCANNER_DEFFLAGS)!=0);
 	}
 
 	if( m_readId3CheckBox )
 	{
-		m_readId3CheckBox->SetValue(TRUE);
+		m_readId3CheckBox->SetValue((SJ_FOLDERSCANNER_READID3&SJ_FOLDERSCANNER_DEFFLAGS)!=0);
 	}
 
 	m_infoMaskTextCtrl->SetValue(SjTrackInfoMatcher::GetDefaultPattern());
@@ -327,7 +320,7 @@ bool SjFolderScannerModule::ConfigSource(long index, wxWindow* parent)
 		SjDialog::ApplyToBitfield(dlg.m_doUpdateCheckBox, currSourceObj->m_flags, SJ_FOLDERSCANNER_DOUPDATE);
 	}
 
-	// check HIDDEN / ZIP / ID3 read
+	// check HIDDEN / ID3 read
 	if( dlg.m_readHiddenFilesCheckBox )
 	{
 		if( SjDialog::ApplyToBitfield(dlg.m_readHiddenFilesCheckBox, currSourceObj->m_flags, SJ_FOLDERSCANNER_READHIDDENFILES) )
@@ -425,17 +418,18 @@ void SjFolderScannerModule::LoadSettings__()
 	SjFolderScannerSource*  currSourceObj;
 	for( currSourceIndex = 0; currSourceIndex < sourceCount; currSourceIndex++ )
 	{
-		currSourceStr = sql.ConfigRead(wxString::Format(wxT("folderscanner/url%i"), currSourceIndex), wxT(""));
+		currSourceStr = sql.ConfigRead(wxString::Format(wxT("folderscanner/url%i"), (int)currSourceIndex), wxT(""));
 		if( !currSourceStr.IsEmpty() )
 		{
+			currSourceStr = SjTools::EnsureTrailingSlash(currSourceStr);
 			currSourceObj = new SjFolderScannerSource;
 			if( currSourceObj )
 			{
 				currSourceObj->m_url        = currSourceStr;
-				currSourceObj->m_file       = sql.ConfigRead(wxString::Format(wxT("folderscanner/file%i"), currSourceIndex), wxT(""));
-				currSourceObj->m_ignoreExt  = sql.ConfigRead(wxString::Format(wxT("folderscanner/ignoreExt%i"), currSourceIndex), wxT(""));
-				currSourceObj->m_trackInfoMatcher.Compile(SJ_TI_URL, sql.ConfigRead(wxString::Format(wxT("folderscanner/pattern%i"), currSourceIndex), SjTrackInfoMatcher::GetDefaultPattern()));
-				currSourceObj->m_flags      =  sql.ConfigRead(wxString::Format(wxT("folderscanner/flags%i"), currSourceIndex), SJ_FOLDERSCANNER_DEFFLAGS);
+				currSourceObj->m_file       = sql.ConfigRead(wxString::Format(wxT("folderscanner/file%i"), (int)currSourceIndex), wxT(""));
+				currSourceObj->m_ignoreExt  = sql.ConfigRead(wxString::Format(wxT("folderscanner/ignoreExt%i"), (int)currSourceIndex), wxT(""));
+				currSourceObj->m_trackInfoMatcher.Compile(SJ_TI_URL, sql.ConfigRead(wxString::Format(wxT("folderscanner/pattern%i"), (int)currSourceIndex), SjTrackInfoMatcher::GetDefaultPattern()));
+				currSourceObj->m_flags      =  sql.ConfigRead(wxString::Format(wxT("folderscanner/flags%i"), (int)currSourceIndex), SJ_FOLDERSCANNER_DEFFLAGS);
 				m_listOfSources.Append(currSourceObj);
 			}
 		}
@@ -453,17 +447,17 @@ void SjFolderScannerModule::SaveSettings__()
 
 	SjFolderScannerSourceList::Node* currSourceNode = m_listOfSources.GetFirst();
 	SjFolderScannerSource*           currSourceObj;
-	int                             currSourceIndex = 0;
+	int                              currSourceIndex = 0;
 	while( currSourceNode )
 	{
 		// write source
 		currSourceObj = currSourceNode->GetData();
 		wxASSERT(currSourceObj);
-		sql.ConfigWrite(wxString::Format(wxT("folderscanner/url%i"), currSourceIndex), currSourceObj->m_url);
-		sql.ConfigWrite(wxString::Format(wxT("folderscanner/file%i"), currSourceIndex), currSourceObj->m_file);
-		sql.ConfigWrite(wxString::Format(wxT("folderscanner/ignoreExt%i"), currSourceIndex), currSourceObj->m_ignoreExt.GetExt());
-		sql.ConfigWrite(wxString::Format(wxT("folderscanner/pattern%i"), currSourceIndex), currSourceObj->m_trackInfoMatcher.GetPattern());
-		sql.ConfigWrite(wxString::Format(wxT("folderscanner/flags%i"), currSourceIndex), currSourceObj->m_flags);
+		sql.ConfigWrite(wxString::Format(wxT("folderscanner/url%i"), (int)currSourceIndex), currSourceObj->m_url);
+		sql.ConfigWrite(wxString::Format(wxT("folderscanner/file%i"), (int)currSourceIndex), currSourceObj->m_file);
+		sql.ConfigWrite(wxString::Format(wxT("folderscanner/ignoreExt%i"), (int)currSourceIndex), currSourceObj->m_ignoreExt.GetExt());
+		sql.ConfigWrite(wxString::Format(wxT("folderscanner/pattern%i"), (int)currSourceIndex), currSourceObj->m_trackInfoMatcher.GetPattern());
+		sql.ConfigWrite(wxString::Format(wxT("folderscanner/flags%i"), (int)currSourceIndex), currSourceObj->m_flags);
 
 		// next source
 		currSourceIndex++;
@@ -474,20 +468,20 @@ void SjFolderScannerModule::SaveSettings__()
 	while( 1 /*exit by break*/ )
 	{
 		#define MAX_DEL 1000
-		if( sql.ConfigRead(wxString::Format(wxT("folderscanner/url%i"), currSourceIndex), wxT("*"))==wxT("*") /*check for existance (`*` is an invalid URL)*/
-		        || currSourceIndex > MAX_DEL /*avoid deadlocks*/ )
+		if( sql.ConfigRead(wxString::Format(wxT("folderscanner/url%i"), (int)currSourceIndex), wxT("*"))==wxT("*") /*check for existance (`*` is an invalid URL)*/
+		 || currSourceIndex > MAX_DEL /*avoid deadlocks*/ )
 		{
 			break; // done
 		}
 
-		wxString url = sql.ConfigRead(wxString::Format(wxT("folderscanner/url%i"), currSourceIndex), wxT(""));
+		wxString url = sql.ConfigRead(wxString::Format(wxT("folderscanner/url%i"), (int)currSourceIndex), wxT(""));
 
 		sql.ConfigDeleteEntry(wxT("folderscanner/deepupdate/")+url);
 		sql.ConfigDeleteEntry(wxT("folderscanner/trackCount/")+url);
-		sql.ConfigDeleteEntry(wxString::Format(wxT("folderscanner/url%i"), currSourceIndex));
-		sql.ConfigDeleteEntry(wxString::Format(wxT("folderscanner/ignoreExt%i"), currSourceIndex));
-		sql.ConfigDeleteEntry(wxString::Format(wxT("folderscanner/pattern%i"), currSourceIndex));
-		sql.ConfigDeleteEntry(wxString::Format(wxT("folderscanner/flags%i"), currSourceIndex));
+		sql.ConfigDeleteEntry(wxString::Format(wxT("folderscanner/url%i"), (int)currSourceIndex));
+		sql.ConfigDeleteEntry(wxString::Format(wxT("folderscanner/ignoreExt%i"), (int)currSourceIndex));
+		sql.ConfigDeleteEntry(wxString::Format(wxT("folderscanner/pattern%i"), (int)currSourceIndex));
+		sql.ConfigDeleteEntry(wxString::Format(wxT("folderscanner/flags%i"), (int)currSourceIndex));
 
 		currSourceIndex++;
 	}
@@ -528,40 +522,6 @@ SjFolderScannerSource* SjFolderScannerModule::GetSourceObj__(long index)
 }
 
 
-SjFolderScannerSource* SjFolderScannerModule::GetSourceObj__(const wxString& fileUrl__)
-{
-	wxString    sourceUrl;
-	wxString    fileUrl(fileUrl__);
-
-	fileUrl.Replace(wxT("\\"), wxT("/"));
-
-	SjFolderScannerSourceList::Node*    currSourceNode = m_listOfSources.GetFirst();
-	SjFolderScannerSource*              currSource;
-
-	while( currSourceNode )
-	{
-		currSource = currSourceNode->GetData();
-		wxASSERT(currSource);
-
-		if( currSource->m_flags&SJ_FOLDERSCANNER_ENABLED )
-		{
-			sourceUrl = currSource->UrlPlusFile();
-			sourceUrl.Replace(wxT("\\"), wxT("/"));
-
-			if( fileUrl.Left(sourceUrl.Len()).CmpNoCase(sourceUrl)==0 )
-			{
-				return currSource;
-			}
-		}
-
-		// next source
-		currSourceNode = currSourceNode->GetNext();
-	}
-
-	return NULL;
-}
-
-
 wxString SjFolderScannerModule::GetSourceUrl(long index)
 {
 	SjFolderScannerSource* currSourceObj = GetSourceObj__(index);
@@ -673,8 +633,10 @@ long SjFolderScannerModule::AddSources(int sourceType, wxWindow* parent)
 }
 
 
-long SjFolderScannerModule::DoAddUrl(const wxString& newUrl, const wxString& newFile, bool& sthAdded)
+long SjFolderScannerModule::DoAddUrl(const wxString& newUrl__, const wxString& newFile, bool& sthAdded)
 {
+	wxString newUrl = SjTools::EnsureTrailingSlash(newUrl__);
+
 	long sourceCount = GetSourceCount();
 	SjFolderScannerSource* defSource = sourceCount>0? GetSourceObj__(sourceCount-1) : NULL;
 
@@ -684,7 +646,7 @@ long SjFolderScannerModule::DoAddUrl(const wxString& newUrl, const wxString& new
 	{
 		SjFolderScannerSource* currSourceObj = GetSourceObj__(i);
 		if( currSourceObj->m_url == newUrl
-		        && currSourceObj->m_file == newFile )
+		 && currSourceObj->m_file == newFile )
 		{
 			currSourceObj->m_flags |= SJ_FOLDERSCANNER_ENABLED;
 			sthAdded = FALSE;
@@ -727,14 +689,29 @@ bool SjFolderScannerModule::AddUrl(const wxString& url)
  ******************************************************************************/
 
 
-bool SjFolderScannerModule::IterateFile__(  const wxString&         urlDontRead, // should not be read as it may contain Backslashes instead of Slashes
-        bool                    deepUpdate,
-        const wxString&         arts,
-        unsigned long           crc32,
-        SjFolderScannerSource*  source,
-        SjColModule*            receiver,
-        long&                   retTrackCount   )
+static void FileNamesToURLs(wxArrayString& inOut)
 {
+	size_t i, i_cnt = inOut.GetCount();
+	for( i = 0; i < i_cnt; i++ )
+	{
+		wxFileName fn(inOut[i]);
+		inOut[i] = wxFileSystem::FileNameToURL(fn);
+	}
+}
+
+
+bool SjFolderScannerModule::IterateFile__(const wxString&        url,
+                                          bool                   deepUpdate,
+                                          const wxString&        arts,
+                                          uint32_t               crc32,
+                                          SjFolderScannerSource* source,
+                                          SjColModule*           receiver,
+                                          long&                  retTrackCount )
+{
+	wxASSERT( url.Left(5) == "file:" );
+	wxASSERT( url.Find('\\') ==  wxNOT_FOUND );
+	wxASSERT( url.Last()!='\\' && url.Last()!='/' );
+
 	bool                ret = FALSE;
 	wxFileSystem        fileSystem;
 	wxFSFile*           fsFile = NULL;
@@ -742,13 +719,13 @@ bool SjFolderScannerModule::IterateFile__(  const wxString&         urlDontRead,
 	SjTrackInfo*        trackInfo = NULL;
 
 	// update info
-	if( !SjBusyInfo::Set(urlDontRead, FALSE) )
+	if( !SjBusyInfo::Set(url, false) )
 	{
 		goto Cleanup; // user abort
 	}
 
 	// get wxFilesSystem object (must be deleted on return), get file size
-	fsFile = fileSystem.OpenFile(urlDontRead,
+	fsFile = fileSystem.OpenFile(url,
 	                             (source->m_flags & SJ_FOLDERSCANNER_READID3)? (wxFS_READ|wxFS_SEEKABLE) : wxFS_READ); // when ID3 reading is enabled, we need seeking
 	if( fsFile == NULL )
 	{
@@ -756,13 +733,14 @@ bool SjFolderScannerModule::IterateFile__(  const wxString&         urlDontRead,
 		goto Cleanup;
 	}
 	fileSize = fsFile->GetStream()->GetSize();
+	wxASSERT( fsFile->GetLocation() == url );
 
 	// check if the track or any arts was modified since the last update process,
 	// we don't catch the cases an art was deleted this way...
 	crc32 = SjTools::Crc32AddLong(crc32, fsFile->GetModificationTime().GetAsDOS());
 
 	if( deepUpdate==FALSE
-	        && receiver->Callback_CheckTrackInfo(fsFile->GetLocation(), crc32) )
+	 && receiver->Callback_CheckTrackInfo(url, crc32) )
 	{
 		ret = TRUE; // success, the file is already in the database
 		retTrackCount++;
@@ -770,7 +748,7 @@ bool SjFolderScannerModule::IterateFile__(  const wxString&         urlDontRead,
 	}
 
 	// check if the current extension can be handled by the player
-	if( !g_mainFrame->m_player.TestUrl(urlDontRead) )
+	if( !g_mainFrame->m_player.TestUrl(url) )
 	{
 		ret = TRUE; // error, but continue
 		goto Cleanup;
@@ -784,7 +762,7 @@ bool SjFolderScannerModule::IterateFile__(  const wxString&         urlDontRead,
 		goto Cleanup;
 	}
 
-	trackInfo->m_url        = fsFile->GetLocation();
+	trackInfo->m_url        = url;
 	trackInfo->m_updatecrc  = crc32;
 
 	{
@@ -800,10 +778,10 @@ bool SjFolderScannerModule::IterateFile__(  const wxString&         urlDontRead,
 		}
 
 		if( result == SJ_ERROR
-		        || trackInfo->m_trackName.IsEmpty()
-		        || trackInfo->m_leadArtistName.IsEmpty() )
+		 || trackInfo->m_trackName.IsEmpty()
+		 || trackInfo->m_leadArtistName.IsEmpty() )
 		{
-			m_trackInfoMatcherObj.m_url = fsFile->GetLocation();
+			m_trackInfoMatcherObj.m_url = url;
 			source->m_trackInfoMatcher.Match(m_trackInfoMatcherObj, *trackInfo);
 		}
 
@@ -856,15 +834,18 @@ Cleanup:
 }
 
 
-bool SjFolderScannerModule::IterateDir__(   const wxString&         url,
-        const wxString&         onlyThisFile,
-        bool                    deepUpdate,
-        SjFolderScannerSource*  source,
-        SjColModule*            receiver,
-        long&                   retTrackCount    )
+bool SjFolderScannerModule::IterateDir__(const wxString&        url, // may or may not terminate with a slash
+                                         const wxString&        onlyThisFile,
+                                         bool                   deepUpdate,
+                                         SjFolderScannerSource* source,
+                                         SjColModule*           receiver,
+                                         long&                  retTrackCount )
 {
+	wxASSERT( url.Left(5) == "file:" );
+	wxASSERT( onlyThisFile.Left(5) == "file:" || onlyThisFile.IsEmpty() );
+
 	// progress information
-	if( !SjBusyInfo::Set(url, FALSE) )
+	if( !SjBusyInfo::Set(url, false) )
 	{
 		return FALSE;
 	}
@@ -885,16 +866,24 @@ bool SjFolderScannerModule::IterateDir__(   const wxString&         url,
 		fileSystem.ChangePathTo(url, TRUE/*is dir*/);
 
 		// collect all FILES
-		wxFileName dirEntryFn  = wxFileSystem::URLToFileName(url);
-		dirEntryStr = dirEntryFn.GetFullPath();
-		if( dirEntryFn.IsOk() && wxDir::Exists(dirEntryStr) )
+		bool scanUsingFS = true;
+
+		if( source->m_flags&SJ_FOLDERSCANNER_READHIDDENFILES )
 		{
-			// ... collect FILES using wxDir (allows us to read HIDDEN files)
-			wxDir::GetAllFiles(dirEntryStr, &fileEntries, wxT("*"),
-			                   wxDIR_FILES
-			                   |   ((source->m_flags&SJ_FOLDERSCANNER_READHIDDENFILES)? wxDIR_HIDDEN : 0));
+			wxFileName dirEntryFn  = wxFileSystem::URLToFileName(url);
+			dirEntryStr = dirEntryFn.GetFullPath();
+			if( dirEntryFn.IsOk() && wxDir::Exists(dirEntryStr) )
+			{
+				// ... collect FILES using wxDir (allows us to read HIDDEN files)
+				wxDir::GetAllFiles(dirEntryStr, &fileEntries, wxT("*"),
+								   wxDIR_FILES
+								   |   ((source->m_flags&SJ_FOLDERSCANNER_READHIDDENFILES)? wxDIR_HIDDEN : 0));
+				FileNamesToURLs(fileEntries);
+				scanUsingFS = false;
+			}
 		}
-		else
+
+		if( scanUsingFS )
 		{
 			// ... collect FILES using wxFileSystem
 			dirEntryStr = fileSystem.FindFirst(wxT("*"), wxFILE);
@@ -907,22 +896,31 @@ bool SjFolderScannerModule::IterateDir__(   const wxString&         url,
 
 
 		// collect all DIRECTORIES
-		dirEntryStr = dirEntryFn.GetFullPath();
-		if( dirEntryFn.IsOk() && wxDir::Exists(dirEntryStr) )
+		scanUsingFS = true;
+
+		if( source->m_flags&SJ_FOLDERSCANNER_READHIDDENDIRS )
 		{
 			// ... collect all DIRECTORIES using wxDir (allows us to read HIDDEN files - see http://www.silverjuke.net/forum/topic-3765.html)
-			wxDir theDir(dirEntryStr);
-			wxString theEntry;
-			bool cont = theDir.GetFirst(&theEntry, wxT("*"),  wxDIR_DIRS
-			                            |   ((source->m_flags&SJ_FOLDERSCANNER_READHIDDENDIRS)? wxDIR_HIDDEN : 0));
-			while ( cont )
+			wxFileName dirEntryFn  = wxFileSystem::URLToFileName(url);
+			wxString dirEntryStr = dirEntryFn.GetFullPath();
+			if( dirEntryFn.IsOk() && wxDir::Exists(dirEntryStr) )
 			{
-				theEntry = dirEntryStr + wxT("\\") + theEntry;
-				subdirEntries.Add(theEntry);
-				cont = theDir.GetNext(&theEntry);
+				wxDir theDir(dirEntryStr);
+				wxString theEntry;
+				bool cont = theDir.GetFirst(&theEntry, wxT("*"),  wxDIR_DIRS
+						|   ((source->m_flags&SJ_FOLDERSCANNER_READHIDDENDIRS)? wxDIR_HIDDEN : 0));
+				while ( cont )
+				{
+					theEntry = SjTools::EnsureTrailingSlash(dirEntryStr) + theEntry;
+					subdirEntries.Add(SjTools::EnsureTrailingSlash(theEntry));
+					cont = theDir.GetNext(&theEntry);
+				}
+				FileNamesToURLs(subdirEntries);
+				scanUsingFS = false;
 			}
 		}
-		else
+
+		if( scanUsingFS )
 		{
 			// ... collect all DIRECTORIES using wxFileSystem
 			dirEntryStr = fileSystem.FindFirst(wxT("*"), wxDIR);
@@ -945,7 +943,7 @@ bool SjFolderScannerModule::IterateDir__(   const wxString&         url,
 	wxString        currUrl;
 	wxString        currExt;
 	wxString        arts;
-	unsigned long   crc32 = SjTools::Crc32Init();
+	uint32_t        crc32 = SjTools::Crc32Init();
 	wxFileSystem    fileSystem;
 	wxFSFile*       fsFile;
 	for( entryIndex = 0; entryIndex < entriesCount; entryIndex++ )
@@ -954,10 +952,10 @@ bool SjFolderScannerModule::IterateDir__(   const wxString&         url,
 		currExt = SjTools::GetExt(currUrl);
 
 		if( !::wxDirExists(currUrl)
-		        && !source->m_ignoreExt.LookupExt(currExt)
-		        &&  g_mainFrame->m_moduleSystem.FindImageHandlerByExt(currExt) )
+		 && !source->m_ignoreExt.LookupExt(currExt)
+		 &&  g_mainFrame->m_moduleSystem.FindImageHandlerByExt(currExt) )
 		{
-			if( !SjBusyInfo::Set(currUrl, FALSE) )
+			if( !SjBusyInfo::Set(currUrl, false) )
 			{
 				return FALSE;
 			}
@@ -1062,15 +1060,14 @@ bool SjFolderScannerModule::IterateTrackInfo(SjColModule* receiver)
 			{
 				// iterate just a single file.
 				wxFileName fn(currSource->m_url, currSource->m_file);
-				fn.Normalize();
-				onlyThisFile = fn.GetFullPath();
+				onlyThisFile = wxFileSystem::FileNameToURL(fn);
 			}
 			else if( !deepUpdate && !(currSource->m_flags&SJ_FOLDERSCANNER_DOUPDATE) )
 			{
 				// this folder should not be updated automatically;
 				// however, the column module may also decide that this is neccessary
-				wxString urlBegin = currSource->m_url;
-				urlBegin.Replace(wxT("\\"), wxT("/"));
+				wxFileName fn(currSource->m_url);
+				wxString urlBegin = wxFileSystem::FileNameToURL(fn);
 				if( urlBegin.Last()!='/' ) urlBegin += '/';
 				if( receiver->Callback_MarkAsUpdated(urlBegin, GetTrackCount__(currSource)) )
 				{
@@ -1081,8 +1078,9 @@ bool SjFolderScannerModule::IterateTrackInfo(SjColModule* receiver)
 			// start source iteration
 			if( doIterateDir )
 			{
+				wxFileName fn(currSource->m_url);
 				long trackCount = 0;
-				if( !IterateDir__(currSource->m_url, onlyThisFile, deepUpdate, currSource, receiver, trackCount) )
+				if( !IterateDir__(wxFileSystem::FileNameToURL(fn), onlyThisFile, deepUpdate, currSource, receiver, trackCount) )
 				{
 					ret = FALSE;  // user abort
 					break;
