@@ -79,18 +79,18 @@ void SjServerScannerModule::LoadSettings()
 	wxString                currServerName;
 	for( i = 0; i < sourceCount; i++ )
 	{
-		currServerName = sql.ConfigRead(wxString::Format(wxT("serverscanner/s%iname"), i), wxT(""));
+		currServerName = sql.ConfigRead(wxString::Format(wxT("serverscanner/s%iname"), (int)i), wxT(""));
 		if( !currServerName.IsEmpty() )
 		{
 			currSourceObj = new SjServerScannerSource;
 			if( currSourceObj )
 			{
 				currSourceObj->m_serverName     = currServerName;
-				currSourceObj->m_serverType     = (SjServerScannerType)sql.ConfigRead(wxString::Format(wxT("serverscanner/s%itype"), i), (long)SJ_SERVERSCANNER_TYPE_UNKNOWN);
-				currSourceObj->m_loginName      = sql.ConfigRead(wxString::Format(wxT("serverscanner/s%iloginName"), i), wxT(""));
-				currSourceObj->m_loginPassword  = SjTools::UnscrambleString(sql.ConfigRead(wxString::Format(wxT("serverscanner/s%iloginPw"), i), wxT("")));
-				currSourceObj->m_flags          = sql.ConfigRead(wxString::Format(wxT("serverscanner/s%iflags"), i), SJ_SERVERSCANNER_DEF_FLAGS);
-				currSourceObj->m_lastCfgFile    = sql.ConfigRead(wxString::Format(wxT("serverscanner/s%ilastCfgFile"), i), wxT(""));
+				currSourceObj->m_serverType     = (SjServerScannerType)sql.ConfigRead(wxString::Format(wxT("serverscanner/s%itype"), (int)i), (long)SJ_SERVERSCANNER_TYPE_UNKNOWN);
+				currSourceObj->m_loginName      = sql.ConfigRead(wxString::Format(wxT("serverscanner/s%iloginName"), (int)i), wxT(""));
+				currSourceObj->m_loginPassword  = SjTools::UnscrambleString(sql.ConfigRead(wxString::Format(wxT("serverscanner/s%iloginPw"), (int)i), wxT("")));
+				currSourceObj->m_flags          = sql.ConfigRead(wxString::Format(wxT("serverscanner/s%iflags"), (int)i), SJ_SERVERSCANNER_DEF_FLAGS);
+				currSourceObj->m_lastCfgFile    = sql.ConfigRead(wxString::Format(wxT("serverscanner/s%ilastCfgFile"), (int)i), wxT(""));
 
 				m_sources.Add(currSourceObj);
 
@@ -113,12 +113,12 @@ void SjServerScannerModule::SaveSettings()
 		sql.ConfigWrite(wxT("serverscanner/sCount"), sourceCount);
 		for( i = 0; i < sourceCount; i++ )
 		{
-			sql.ConfigWrite(wxString::Format(wxT("serverscanner/s%iname"), i), m_sources[i].m_serverName);
-			sql.ConfigWrite(wxString::Format(wxT("serverscanner/s%itype"), i), (long)m_sources[i].m_serverType);
-			sql.ConfigWrite(wxString::Format(wxT("serverscanner/s%iloginName"), i), m_sources[i].m_loginName);
-			sql.ConfigWrite(wxString::Format(wxT("serverscanner/s%iloginPw"), i), SjTools::ScrambleString(m_sources[i].m_loginPassword));
-			sql.ConfigWrite(wxString::Format(wxT("serverscanner/s%iflags"), i), (long)m_sources[i].m_flags);
-			sql.ConfigWrite(wxString::Format(wxT("serverscanner/s%ilastCfgFile"), i), m_sources[i].m_lastCfgFile);
+			sql.ConfigWrite(wxString::Format(wxT("serverscanner/s%iname"),        (int)i), m_sources[i].m_serverName);
+			sql.ConfigWrite(wxString::Format(wxT("serverscanner/s%itype"),        (int)i), (long)m_sources[i].m_serverType);
+			sql.ConfigWrite(wxString::Format(wxT("serverscanner/s%iloginName"),   (int)i), m_sources[i].m_loginName);
+			sql.ConfigWrite(wxString::Format(wxT("serverscanner/s%iloginPw"),     (int)i), SjTools::ScrambleString(m_sources[i].m_loginPassword));
+			sql.ConfigWrite(wxString::Format(wxT("serverscanner/s%iflags"),       (int)i), (long)m_sources[i].m_flags);
+			sql.ConfigWrite(wxString::Format(wxT("serverscanner/s%ilastCfgFile"), (int)i), m_sources[i].m_lastCfgFile);
 
 			SjInternetFSHandler::SetAuth(m_sources[i].m_serverName, m_sources[i].m_loginName, m_sources[i].m_loginPassword);
 		}
@@ -160,7 +160,7 @@ long SjServerScannerModule::AddSources(int sourceType, wxWindow* parent)
 	SjServerScannerConfigDialog dlg(parent, *newSource);
 
 	if(  dlg.ShowModal() != wxID_OK
-	        || !dlg.GetChanges(*newSource) )
+	 || !dlg.GetChanges(*newSource) )
 	{
 		delete newSource;
 		return -1; // dialog canceled, no update required
@@ -197,7 +197,7 @@ bool SjServerScannerModule::ConfigSource(long index, wxWindow* parent)
 	{
 		SjServerScannerConfigDialog dlg(parent, m_sources[index]);
 		if( dlg.ShowModal() == wxID_OK
-		        && dlg.GetChanges(m_sources[index]) )
+		 && dlg.GetChanges(m_sources[index]) )
 		{
 			SaveSettings();
 			return TRUE; // needs update
@@ -252,7 +252,7 @@ SjIcon SjServerScannerModule::GetSourceIcon(long index)
 
 
 bool SjServerScannerModule::IterateCsvOverHttp(SjColModule* receiver, SjServerScannerSource* currSource,
-        SjCfgTokenizer* options)
+                                               SjCfgTokenizer* options)
 {
 	bool            ret = FALSE;
 
@@ -307,21 +307,21 @@ bool SjServerScannerModule::IterateCsvOverHttp(SjColModule* receiver, SjServerSc
 		{
 			str = arr[fieldIndex];
 
-			if( str == wxT("<Nr>") )           { csvTrackInfo.Add(SJ_TI_TRACKNR);          }
+			     if( str == wxT("<Nr>") )           { csvTrackInfo.Add(SJ_TI_TRACKNR);          }
 			else if( str == wxT("<DiskNr>") )       { csvTrackInfo.Add(SJ_TI_DISKNR);           }
 			else if( str == wxT("<Title>") )        { csvTrackInfo.Add(SJ_TI_TRACKNAME);        }
 			else if( str == wxT("<Artist>") )       { csvTrackInfo.Add(SJ_TI_LEADARTISTNAME);   }
 			else if( str == wxT("<OrgArtist>") )    { csvTrackInfo.Add(SJ_TI_ORGARTISTNAME);    }
 			else if( str == wxT("<Composer>") )     { csvTrackInfo.Add(SJ_TI_COMPOSERNAME);     }
 			else if( str == wxT("<Album>") )        { csvTrackInfo.Add(SJ_TI_ALBUMNAME);        }
-			else if( str == wxT("<Album(DiskNr)>") ) { csvTrackInfo.Add(SJ_TI_ALBUMNAME); str = wxT("<Album>"); diskNrInAlbumName = TRUE; }
+			else if( str == wxT("<Album(DiskNr)>") ){ csvTrackInfo.Add(SJ_TI_ALBUMNAME); str = wxT("<Album>"); diskNrInAlbumName = TRUE; }
 			else if( str == wxT("<Year>") )         { csvTrackInfo.Add(SJ_TI_YEAR);             }
 			else if( str == wxT("<Comment>") )      { csvTrackInfo.Add(SJ_TI_COMMENT);          }
 			else if( str == wxT("<Genre>") )        { csvTrackInfo.Add(SJ_TI_GENRENAME);        }
 			else if( str == wxT("<Group>") )        { csvTrackInfo.Add(SJ_TI_GROUPNAME);        }
 			else                                    { csvTrackInfo.Add(0);                      }
 
-			if( str[0] == wxT('<') )           { csvPlaceholder.Add(str);                  }
+			     if( str[0] == wxT('<') )           { csvPlaceholder.Add(str);                  }
 			else                                    { csvPlaceholder.Add(wxT(""));              }
 
 		}
@@ -421,8 +421,8 @@ bool SjServerScannerModule::IterateCsvOverHttp(SjColModule* receiver, SjServerSc
 						suffix.Trim(FALSE);
 
 						if( SjTools::StripPrefix(suffix, wxT("cd"))
-						        || SjTools::StripPrefix(suffix, wxT("disk"))
-						        || SjTools::StripPrefix(suffix, wxT("disc")) )
+						 || SjTools::StripPrefix(suffix, wxT("disk"))
+						 || SjTools::StripPrefix(suffix, wxT("disc")) )
 						{
 							suffix.Trim(FALSE);
 							suffix.Replace(wxT("#"), wxT(""), FALSE/*only the first*/);
