@@ -459,7 +459,6 @@ void SjTagEditorDlg::OnButtonBarMenu(wxCommandEvent& event)
 		menu.Append(IDC_PLUGIN_REPLACE);
 		menu.Append(IDC_PLUGIN_SPLIT);
 		menu.Append(IDC_PLUGIN_RENAME);
-		menu.AppendSeparator();
 		menu.Append(IDC_PLUGIN_FREEDB);
 		menu.AppendSeparator();
 		menu.AppendCheckItem(IDC_WRITEID3TAGS, _("Write (ID3-)tags"));
@@ -481,7 +480,7 @@ void SjTagEditorDlg::OnPlugin(wxCommandEvent& event)
 	SjTagEditorPlugin* plugin = NULL;
 	int modalResult;
 	{
-		wxWindowDisabler disabler(this);
+		SJ_WINDOW_DISABLER(this);
 
 		SjTrackInfo exampleTrackInfo;
 		g_mainFrame->m_libraryModule->GetTrackInfo(m_dataUrls[0], exampleTrackInfo, SJ_TI_FULLINFO, FALSE);
@@ -668,7 +667,7 @@ bool SjTagEditorDlg::Dsk2Data_CopyAllData(int what, bool logErrors)
 		// supported if "multiEdit" was given to the constructor
 		urlCount = urls.GetCount();
 		if(  urlCount <= 0
-		        || (urlCount >  1 && !m_dataMultiEdit) )
+		 || (urlCount >  1 && !m_dataMultiEdit) )
 		{
 			return FALSE;
 		}
@@ -990,16 +989,32 @@ void SjTagEditorDlg::Data2Dlg_CopyInfo(bool showMoreInfo)
 	wxASSERT( (urlCount == 1 && !m_dataMultiEdit) || (urlCount > 1 && m_dataMultiEdit) );
 	if( !m_dataMultiEdit )
 	{
-		p.Add(_("File name"), m_dataStat.m_url, SJ_PROP_BOLD);
+		wxString filename = m_dataStat.m_url;
+		if( filename.StartsWith("file:") )
+		{
+			filename = wxFileSystem::URLToFileName(filename).GetFullPath();
+		}
+
+		p.Add(_("File name"), filename, SJ_PROP_BOLD);
+
 		cacheName = g_tools->m_cache.LookupCache(m_dataStat.m_url);
 		if( !cacheName.IsEmpty() )
 		{
 			m_dataStat.m_dataBytes = g_tools->GetFileSize(cacheName);
 		}
 	}
-	else for( i = 0; i < urlCount; i++ )
+	else
+	{
+		wxString filename;
+		for( i = 0; i < urlCount; i++ )
 		{
-			p.Add(i==0? _("File names") : wxT(""), m_dataUrls[i], SJ_PROP_BOLD);
+			filename = m_dataUrls[i];
+			if( filename.StartsWith("file:") )
+			{
+				filename = wxFileSystem::URLToFileName(filename).GetFullPath();
+			}
+
+			p.Add(i==0? _("File names") : wxT(""), filename, SJ_PROP_BOLD);
 
 			if( !showMoreInfo && i >= 2 && urlCount > 4 )
 			{
@@ -1010,6 +1025,7 @@ void SjTagEditorDlg::Data2Dlg_CopyInfo(bool showMoreInfo)
 
 			finalHtml = wxT("<p>") + SjTools::Htmlentities(_("The shown values are the sum or the average of all single values in the given files.")) + wxT("</p>");
 		}
+	}
 
 	// size
 	if( m_dataStat.m_dataBytes == 0 )
@@ -1048,12 +1064,13 @@ void SjTagEditorDlg::Data2Dlg_CopyInfo(bool showMoreInfo)
 		{
 			p.Add(_("Queue position"), SjTools::FormatNumbers(allQueuePositions, 1/*we want to show numbers starting at 1*/));
 
-			#ifdef __WXDEBUG__
+			if( g_debug )
+			{
 				long playCount = g_mainFrame->m_player.m_queue.GetPlayCount(allQueuePositions[0]);
 				long repeatRound = g_mainFrame->m_player.m_queue.GetRepeatRound();
-				p.Add(wxT("Play count / repeat round"),
-					  wxString::Format(wxT("%i / %i"), (int)playCount, (int)repeatRound));
-			#endif
+				p.Add(wxT("Queue play count"), playCount); // this has nothing to do with the "times played" from above
+				p.Add(wxT("Queue repeat round"), repeatRound);
+			}
 		}
 	}
 
@@ -1124,11 +1141,11 @@ void SjTagEditorDlg::Data2Dlg_CopyInfo(bool showMoreInfo)
 			wxString ext = SjTools::GetExt(m_dataStat.m_url);
 			p.Add(_("File type"), ext);
 
-			if( wxFileExists(m_dataStat.m_url)
-			        || (!cacheName.IsEmpty()&&wxFileExists(cacheName)) )
+			p.Add(_("URL"), m_dataStat.m_url);
+
 			{
 				wxFileSystem fs;
-				wxFSFile* fsFile = fs.OpenFile(cacheName.IsEmpty()? m_dataStat.m_url : cacheName, wxFS_READ|wxFS_SEEKABLE);
+				wxFSFile* fsFile = fs.OpenFile(m_dataStat.m_url, wxFS_READ|wxFS_SEEKABLE);
 				if( fsFile )
 				{
 					SjGetMoreInfoFromID3Etc(fsFile, p);
@@ -1227,7 +1244,7 @@ long SjTagEditorDlg::Dlg2Data_GetString(int id, long fieldFlag, wxString& oldAnd
 		newValue.Trim(FALSE);
 
 		if( newValue != oldAndRetValue
-		        || m_dataMultiEdit )
+		 || m_dataMultiEdit )
 		{
 			oldAndRetValue = newValue;
 			return fieldFlag;
@@ -1247,10 +1264,13 @@ long SjTagEditorDlg::Dlg2Data_GetLong(int id, long fieldFlag, long& oldAndRetVal
 		newValueString.Trim(FALSE);
 
 		long newValue = 0;
-		newValueString.ToLong(&newValue);
+		if( !newValueString.ToLong(&newValue) )
+		{
+			newValue = 0;
+		}
 
 		if( newValue != oldAndRetValue
-		        || m_dataMultiEdit )
+		 || m_dataMultiEdit )
 		{
 			oldAndRetValue = newValue;
 			return fieldFlag;
@@ -1310,8 +1330,8 @@ void SjTagEditorDlg::Dlg2Data_CopyAll(SjTagEditorPlugin* plugin, bool& reloadDat
 
 	SjLibraryModule* lib = g_mainFrame->m_libraryModule;
 	if( lib == NULL
-	        || !Dlg2Data_PrepareModify()
-	        || (plugin && !plugin->PrepareModify()) )
+	 || !Dlg2Data_PrepareModify()
+	 || (plugin && !plugin->PrepareModify()) )
 	{
 		m_dataStat = backupedStat;
 		canceled = TRUE;
@@ -1387,7 +1407,6 @@ void SjTagEditorDlg::Dlg2Data_CopyAll(SjTagEditorPlugin* plugin, bool& reloadDat
 		{
 			if( plugin && !postModifyMsg.IsEmpty() )
 			{
-				wxWindowDisabler disabler(this);
 				SjMessageBox(postModifyMsg, plugin->GetTitle(), wxOK|wxICON_INFORMATION, this);
 				canceled = TRUE;
 			}
@@ -1400,13 +1419,13 @@ void SjTagEditorDlg::Dlg2Data_CopyAll(SjTagEditorPlugin* plugin, bool& reloadDat
 	// let the user confirm the modification
 
 	{
-		bool askWriteId3 = FALSE, askDelEmptyDir = FALSE;
-		if( mod.LetConfirm(askWriteId3, askDelEmptyDir)
-		        || urlCount > 1
-		        || plugin )
+		bool askWriteId3, askDelEmptyDir, onlyUrlsModified;
+		if( mod.LetConfirm(askWriteId3, askDelEmptyDir, onlyUrlsModified)
+		 || urlCount > 1
+		 || plugin )
 		{
-			wxWindowDisabler disabler(this);
-			SjConfirmDlg dlg(this, mod, askWriteId3, askDelEmptyDir);
+			SJ_WINDOW_DISABLER(this);
+			SjConfirmDlg dlg(this, mod, false /*was: askWriteId3, but this is confusing, as the option is already in the menu*/, askDelEmptyDir, onlyUrlsModified);
 			if( dlg.ShowModal() != wxID_OK )
 			{
 				m_dataStat = backupedStat;
@@ -1429,7 +1448,7 @@ void SjTagEditorDlg::Dlg2Data_CopyAll(SjTagEditorPlugin* plugin, bool& reloadDat
 
 	// write the modifications
 
-	m_possiblyEmptyDirs.Clear();
+	m_possiblyEmptyDirUrls.Clear();
 
 	{
 		long                modCount = mod.GetCount(); // get again as it may be changed by the user in the confirmation dialog
@@ -1580,11 +1599,18 @@ void SjTagEditorDlg::Dlg2Data_CopyAll(SjTagEditorPlugin* plugin, bool& reloadDat
 		// delete possibly empty directories,
 		if( g_tagEditorModule->GetDelEmptyDir() )
 		{
-			wxString dir;
+			wxString dirUrl;
 			SjHashIterator iterator;
-			while( m_possiblyEmptyDirs.Iterate(iterator, dir) )
+			while( m_possiblyEmptyDirUrls.Iterate(iterator, dirUrl) )
 			{
-				wxString file = ::wxFindFirstFile(dir+wxT("*.*"));
+				dirUrl = SjTools::EnsureTrailingSlash(dirUrl)+"dummy.file";
+				wxString dir = wxFileSystem::URLToFileName(dirUrl).GetPath(wxPATH_GET_VOLUME|wxPATH_GET_SEPARATOR), file;
+
+				{
+					wxLogNull null;
+					file = ::wxFindFirstFile(dir+"*.*");
+				}
+
 				if( file.IsEmpty() )
 				{
 					::wxRmdir(dir);
@@ -1623,11 +1649,11 @@ void SjTagEditorDlg::RenameDone__(const wxString& oldUrl, const wxString& newUrl
 	{
 		wxSqlt sql;
 
-		wxString oldPath, newPath;
-		SjTools::GetFileNameFromUrl(oldUrl, &oldPath);
-		SjTools::GetFileNameFromUrl(newUrl, &newPath);
+		wxString oldPathUrl, newPathUrl;
+		SjTools::GetFileNameFromUrl(oldUrl, &oldPathUrl);
+		SjTools::GetFileNameFromUrl(newUrl, &newPathUrl);
 
-		if( oldPath != newPath )
+		if( oldPathUrl != newPathUrl )
 		{
 			// move all belonging covers if they're are also in the old directory
 			sql.Query(wxT("SELECT artids FROM tracks WHERE url='") + sql.QParam(oldUrl) + wxT("';"));
@@ -1640,11 +1666,11 @@ void SjTagEditorDlg::RenameDone__(const wxString& oldUrl, const wxString& newUrl
 					sql.Query(wxString::Format(wxT("SELECT url FROM arts WHERE id=%lu;"), currArtId));
 					if( sql.Next() )
 					{
-						wxString oldArtUrl = sql.GetString(0); oldArtUrl.Replace(wxT("\\"), wxT("/"));
+						wxString oldArtUrl = sql.GetString(0);
 						wxString oldArtPath; SjTools::GetFileNameFromUrl(oldArtUrl, &oldArtPath);
-						if( oldArtPath == oldPath )
+						if( oldArtPath == oldPathUrl )
 						{
-							wxString newArtUrl = newPath + SjTools::GetFileNameFromUrl(oldArtUrl);
+							wxString newArtUrl = newPathUrl + SjTools::GetFileNameFromUrl(oldArtUrl);
 
 							// rename or copy the art file
 							if( wxFileExists(oldArtUrl) )
@@ -1673,7 +1699,7 @@ void SjTagEditorDlg::RenameDone__(const wxString& oldUrl, const wxString& newUrl
 		}
 
 		// mark the old directory for deletion
-		m_possiblyEmptyDirs.Insert(oldPath, 1);
+		m_possiblyEmptyDirUrls.Insert(oldPathUrl, 1);
 
 		// update database
 		sql.Query(wxT("UPDATE tracks SET url='") + sql.QParam(newUrl) + wxT("' WHERE url='") + sql.QParam(oldUrl) + wxT("';"));
@@ -1695,14 +1721,18 @@ bool SjTagEditorDlg::RenameFile__(const wxString& oldUrl, const wxString& newUrl
 	// The caller should print the error
 	wxLogNull null;
 
+	// convert the given URLs to filenames
+	wxFileName oldFileName = wxFileSystem::URLToFileName(oldUrl);
+	wxFileName newFileName = wxFileSystem::URLToFileName(newUrl);
+
 	// If the dest. url exists, there is currently nothing we can do
-	if( ::wxFileExists(newUrl) )
+	if( newFileName.FileExists() )
 	{
 		return FALSE;
 	}
 
 	// Normal system call
-	if( wxRename(oldUrl, newUrl) == 0 )
+	if( wxRename(oldFileName.GetFullPath(), newFileName.GetFullPath()) == 0 )
 	{
 		RenameDone__(oldUrl, newUrl);
 		return TRUE;  // success
@@ -1710,29 +1740,28 @@ bool SjTagEditorDlg::RenameFile__(const wxString& oldUrl, const wxString& newUrl
 
 	// check if all needed directories exist; if not, create them
 	{
-		wxFileName fn1(newUrl);
-		wxFileName fn2(fn1.GetPath(wxPATH_GET_VOLUME|wxPATH_GET_SEPARATOR));
+		wxFileName fn2(newFileName.GetPath(wxPATH_GET_VOLUME|wxPATH_GET_SEPARATOR));
 		fn2.Mkdir(0777, wxPATH_MKDIR_FULL);
 	}
 
 	// Normal system call, second try with dirs created
-	if( wxRename(oldUrl, newUrl) == 0 )
+	if( wxRename(oldFileName.GetFullPath(), newFileName.GetFullPath()) == 0 )
 	{
 		RenameDone__(oldUrl, newUrl);
 		return TRUE;  // success
 	}
 
 	// Try to copy
-	if (wxCopyFile(oldUrl, newUrl))
+	if (wxCopyFile(oldFileName.GetFullPath(), newFileName.GetFullPath()))
 	{
-		if( wxRemoveFile(oldUrl) )
+		if( wxRemoveFile(oldFileName.GetFullPath()) )
 		{
 			RenameDone__(oldUrl, newUrl);
 			return TRUE;  // success
 		}
 		else
 		{
-			wxRemoveFile(newUrl);
+			wxRemoveFile(newFileName.GetFullPath());
 		}
 	}
 
@@ -1743,8 +1772,6 @@ bool SjTagEditorDlg::RenameFile__(const wxString& oldUrl, const wxString& newUrl
 
 void SjTagEditorDlg::WaitForWriteAccess__(const wxString& url)
 {
-	wxFileSystem    fs;
-	wxFSFile*       fsFile;
 	unsigned long   startWaiting = SjTools::GetMsTicks();
 	bool            hasWriteAccess = false;
 
@@ -1754,14 +1781,10 @@ void SjTagEditorDlg::WaitForWriteAccess__(const wxString& url)
 		wxThread::Sleep(150);
 
 		// try to access the file
-		if( (fsFile=fs.OpenFile(url, wxFS_READ|wxFS_SEEKABLE)) != NULL )
+		SjByteFile byteFile(url, NULL /*force write access*/);
+		if( !byteFile.ReadOnly() )
 		{
-			SjByteFile byteFile(fsFile, NULL);
-			if( !byteFile.ReadOnly() )
-			{
-				hasWriteAccess = true;
-			}
-			delete fsFile;
+			hasWriteAccess = true;
 		}
 	}
 }
@@ -1774,10 +1797,10 @@ bool SjTagEditorDlg::Data2Dsk_Write(const wxString& orgUrl, SjTrackInfo& ti, boo
 	// Stop the player?
 	// This is needed if the file is renamed or ID3 tags should be written.
 	bool stopped = FALSE;
-	long stoppedPos;
+	long stoppedPos = 0;
 	if( !g_mainFrame->IsStopped()
-	        &&  g_mainFrame->GetQueueUrl(-1) == orgUrl
-	        && (orgUrl != ti.m_url || g_tagEditorModule->GetWriteId3Tags()) )
+	 &&  g_mainFrame->GetQueueUrl(-1) == orgUrl
+	 && (orgUrl != ti.m_url || g_tagEditorModule->GetWriteId3Tags()) )
 	{
 		stoppedPos = g_mainFrame->GetElapsedTime();
 		g_mainFrame->Stop();
@@ -1795,8 +1818,14 @@ bool SjTagEditorDlg::Data2Dsk_Write(const wxString& orgUrl, SjTrackInfo& ti, boo
 
 		if( !RenameFile__(orgUrl, ti.m_url) )
 		{
+			wxString from = orgUrl;
+			if( from.StartsWith("file:") ) { from = wxFileSystem::URLToFileName(from).GetFullPath(); }
+
+			wxString to = ti.m_url;
+			if( to.StartsWith("file:") ) { to = wxFileSystem::URLToFileName(to).GetFullPath(); }
+
 			wxLogError(_("Cannot rename \"%s\" to \"%s\"."),
-			           orgUrl.c_str(), ti.m_url.c_str());
+			           from.c_str(), to.c_str());
 			ti.m_url = orgUrl;
 		}
 		ti.m_validFields &= ~SJ_TI_URL;
@@ -1859,9 +1888,8 @@ SjTagEditorModule::SjTagEditorModule(SjInterfaceBase* interf)
 {
 	m_file                  = wxT("memory:tageditor.lib");
 	m_name                  = _("Edit track");
+	m_selPage               = 0;
 	m_dlg                   = NULL;
-	m_dlgPos.x              = 0;
-	m_dlgPos.y              = 0;
 }
 
 
@@ -1901,7 +1929,6 @@ void SjTagEditorModule::SetDelEmptyDir(bool delEmptyDir)
 void SjTagEditorModule::OpenTagEditor(SjTagEditorDlg* newTagEditorDlg)
 {
 	// load settings
-	m_selPage       =  g_tools->m_config->Read(wxT("tageditor/selPage"), 0L);
 	m_writeId3Tags  = (g_tools->m_config->Read(wxT("tageditor/writeId3"), 1L)!=0);
 	m_delEmptyDir   = (g_tools->m_config->Read(wxT("tageditor/delEmptyDir"), 1L)!=0);
 
@@ -1912,27 +1939,13 @@ void SjTagEditorModule::OpenTagEditor(SjTagEditorDlg* newTagEditorDlg)
 	m_dlg = newTagEditorDlg;
 
 	if( m_dlg->m_dlgNotebook
-	        && g_tagEditorModule->m_selPage >= 0
-	        && g_tagEditorModule->m_selPage < (int)m_dlg->m_dlgNotebook->GetPageCount() )
+	 && m_selPage >= 0
+	 && m_selPage < (int)m_dlg->m_dlgNotebook->GetPageCount() )
 	{
-		m_dlg->m_dlgNotebook->SetSelection(g_tagEditorModule->m_selPage);
+		m_dlg->m_dlgNotebook->SetSelection(m_selPage);
 	}
 
-	wxRect storedRect = g_tools->ReadRect(wxT("tageditor/pos"));
-	if( storedRect.width > 0 && storedRect.width < 1500
-	        && storedRect.height > 0 && storedRect.height < 1000 )
-	{
-		m_dlg->SetSize(0, 0, storedRect.width,  storedRect.height);
-	}
-
-	if( g_tagEditorModule->m_dlgPos.x && g_tagEditorModule->m_dlgPos.y )
-	{
-		m_dlg->SetSize(g_tagEditorModule->m_dlgPos.x, g_tagEditorModule->m_dlgPos.y, -1, -1, wxSIZE_USE_EXISTING);
-	}
-	else
-	{
-		m_dlg->CentreOnParent();
-	}
+	m_dlg->CenterOnParent();
 
 	if( m_dlg->Init__() )
 	{
@@ -1957,17 +1970,7 @@ void SjTagEditorModule::CloseTagEditor()
 		// save position
 		if( m_dlg->m_dlgNotebook )
 		{
-			g_tagEditorModule->m_selPage = m_dlg->m_dlgNotebook->GetSelection();
-			g_tools->m_config->Write(wxT("tageditor/selPage"), g_tagEditorModule->m_selPage);
-		}
-
-		if( !m_dlg->IsMaximized() )
-		{
-			wxRect r = m_dlg->GetRect();
-			g_tools->WriteRect(wxT("tageditor/pos"), r);
-
-			g_tagEditorModule->m_dlgPos.x = r.x;
-			g_tagEditorModule->m_dlgPos.y = r.y;
+			m_selPage = m_dlg->m_dlgNotebook->GetSelection();
 		}
 
 		m_dlg->Destroy();
@@ -1986,7 +1989,7 @@ void SjTagEditorModule::GetLittleOptions(SjArrayLittleOption& lo)
 void SjTagEditorModule::ReceiveMsg(int msg)
 {
 	if( msg == IDMODMSG_KIOSK_STARTING
-	        || msg == IDMODMSG_WINDOW_CLOSE )
+	 || msg == IDMODMSG_WINDOW_CLOSE )
 	{
 		CloseTagEditor();
 	}
