@@ -46,8 +46,7 @@
 #define IDC_COVERHEIGHTSLIDER       (IDM_FIRSTPRIVATE+14)
 #define IDC_FONTDEFAULT             (IDM_FIRSTPRIVATE+23)
 #define IDC_LOADSKINSMENUBUTTON     (IDM_FIRSTPRIVATE+24)
-#define IDC_SCRIPT_CONFIG           (IDM_FIRSTPRIVATE+100)
-#define IDC_SCRIPT_CONFIG_LAST      (IDM_FIRSTPRIVATE+200)
+#define IDC_CANCELSKINSELECTION     (IDM_FIRSTPRIVATE+25)
 
 
 /*******************************************************************************
@@ -68,17 +67,15 @@ private:
 	// skin settings
 	wxPanel*        CreateSkinPage      (wxWindow* parent);
 
-	SjSkinEnumeratorItem*
-	GetSkinFromDialog   ();
-	void            SetSkinToDialog     (const wxString& skin);
+	SjSkinEnumeratorItem* GetSkinFromDialog   ();
 	void            UpdateSkinList      (const wxString& selSkin);
 
 	void            OnUpdateSkinList    (wxCommandEvent& event);
+	void            OnCancelSkinSelection(wxCommandEvent& event);
 	void            OnSkinContextMenu   (wxListEvent&) { ShowContextMenu(this, ScreenToClient(::wxGetMousePosition())); }
 	void            OnLoadSkinsContextMenu (wxCommandEvent&) { if(m_loadSkinsMenuButton) { ShowContextMenu(m_loadSkinsMenuButton, wxPoint(0,0)); } }
 	void            OnChangeSkin        (wxListEvent&);
 	void            OnDoubleClick       (wxListEvent&);
-	void            OnScriptConfig      (wxCommandEvent&);
 	void            OnSkinInfo          (wxCommandEvent&) {SkinInfo();}
 	void            SkinInfo            ();
 	void            OnSkinExplore       (wxCommandEvent&);
@@ -90,8 +87,7 @@ private:
 	int             m_skinChangeFromMe;
 	wxListCtrl*     m_listCtrl;
 	wxButton*       m_loadSkinsMenuButton;
-	SjSkinEnumerator*
-	m_skinEnumerator;
+	SjSkinEnumerator* m_skinEnumerator;
 	wxString        m_orgSkinPath;
 
 	// font settings
@@ -137,19 +133,15 @@ BEGIN_EVENT_TABLE(SjViewSettingsPage, wxPanel)
 	EVT_MENU                    (IDC_SKININFO,          SjViewSettingsPage::OnSkinInfo              )
 	EVT_MENU                    (IDC_SKINEXPLORE,       SjViewSettingsPage::OnSkinExplore           )
 	EVT_MENU                    (IDC_SKINUPDATELIST,    SjViewSettingsPage::OnUpdateSkinList        )
+	EVT_MENU                    (IDC_CANCELSKINSELECTION, SjViewSettingsPage::OnCancelSkinSelection   )
 	EVT_MENU                    (IDC_SKINWWW,           SjViewSettingsPage::OnSkinWWW               )
 	EVT_BUTTON                  (IDC_SKINWWW,           SjViewSettingsPage::OnSkinWWW               )
-	EVT_BUTTON                  (IDC_LOADSKINSMENUBUTTON,
-	                             SjViewSettingsPage::OnLoadSkinsContextMenu  )
+	EVT_BUTTON                  (IDC_LOADSKINSMENUBUTTON, SjViewSettingsPage::OnLoadSkinsContextMenu  )
 	EVT_CHOICE                  (IDC_FONTFACECHOICE,    SjViewSettingsPage::OnFontFaceChoice        )
 	EVT_COMMAND_SCROLL          (IDC_FONTPTSLIDER,      SjViewSettingsPage::OnFontPtSlider          )
 	EVT_BUTTON                  (IDC_FONTDEFAULT,       SjViewSettingsPage::OnFontDefault           )
 	EVT_COMMAND_SCROLL          (IDC_COLUMNWIDTHSLIDER, SjViewSettingsPage::OnColumnWidthSlider     )
 	EVT_COMMAND_SCROLL          (IDC_COVERHEIGHTSLIDER, SjViewSettingsPage::OnCoverHeightSlider     )
-	EVT_COMMAND_RANGE           (IDC_SCRIPT_CONFIG,
-	                             IDC_SCRIPT_CONFIG_LAST,
-	                             wxEVT_COMMAND_MENU_SELECTED,
-	                             SjViewSettingsPage::OnScriptConfig          )
 	EVT_SIZE                    (                       SjViewSettingsPage::OnSize                  )
 END_EVENT_TABLE()
 
@@ -278,6 +270,7 @@ void SjViewSettingsPage::OnUpdateSkinList(wxCommandEvent& event)
 }
 
 
+
 void SjViewSettingsPage::UpdateSkinList(const wxString& selSkin)
 {
 	m_skinChangeFromMe++;
@@ -340,29 +333,6 @@ SjSkinEnumeratorItem* SjViewSettingsPage::GetSkinFromDialog()
 }
 
 
-void SjViewSettingsPage::SetSkinToDialog(const wxString& skin)
-{
-	wxASSERT( m_skinEnumerator );
-
-	int i, itemCount = m_skinEnumerator->GetCount();
-	for( i = 0; i < itemCount; i++ )
-	{
-		SjSkinEnumeratorItem* item = m_skinEnumerator->GetSkin(i);
-		wxASSERT(item);
-		if( item->m_url.CmpNoCase(skin)==0 )
-		{
-			i = m_listCtrl->FindItem(-1, i);
-			if( i >= 0 )
-			{
-				m_listCtrl->SetItemState(i, wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED, wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED);
-				m_listCtrl->EnsureVisible(i);
-			}
-			return;
-		}
-	}
-}
-
-
 void SjViewSettingsPage::OnSkinExplore(wxCommandEvent& event)
 {
 	g_mainFrame->Enable(FALSE);
@@ -377,29 +347,15 @@ void SjViewSettingsPage::OnSkinExplore(wxCommandEvent& event)
 }
 
 
-void SjViewSettingsPage::OnScriptConfig(wxCommandEvent& e)
-{
-	wxASSERT( e.GetId() >= IDC_SCRIPT_CONFIG && e.GetId() <= IDC_SCRIPT_CONFIG_LAST );
-	#if SJ_USE_SCRIPTS
-		int index = e.GetId()-IDC_SCRIPT_CONFIG;
-		SjSee::OnGlobalEmbedding(SJ_PERSISTENT_SKINS_BUTTON, index);
-	#endif
-}
-
-
 void SjViewSettingsPage::OnDoubleClick(wxListEvent& event)
 {
-	#if SJ_USE_SCRIPTS
-		if( !SjSee::OnGlobalEmbedding(SJ_PERSISTENT_SKINS_BUTTON, -1/*def. action*/, g_mainFrame->GetSkinSee()) )
-	#endif
-			SkinInfo();
+	SkinInfo();
 }
 
 
 void SjViewSettingsPage::SkinInfo()
 {
 	wxWindow* parent = SjDialog::FindTopLevel(this);
-	wxWindowDisabler disabled(parent);
 
 	SjMessageBox(g_mainFrame->GetSkinName()
 	               + wxT("\n(") + g_mainFrame->GetSkinUrl() + wxT(")\n\n") + g_mainFrame->GetSkinAbout(),
@@ -416,33 +372,35 @@ void SjViewSettingsPage::OnChangeSkin(wxListEvent& event)
 		{
 			wxBusyCursor busy;
 
-			g_mainFrame->LoadSkin(currSkin->m_url, SJ_OP_DEF_NONKIOSK);
-			g_mainFrame->Refresh();
+			if( g_mainFrame->LoadSkin(currSkin->m_url, SJ_OP_DEF_NONKIOSK, wxEmptyString, true, this) )
+			{
+				g_tools->m_config->Write(wxT("main/skinFile"), g_mainFrame->GetSkinUrl());
+				g_tools->m_config->Flush();
+			}
+			else
+			{
+				QueueEvent(new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, IDC_CANCELSKINSELECTION));
+			}
 
-			g_tools->m_config->Write(wxT("main/skinFile"), g_mainFrame->GetSkinUrl());
-			g_tools->m_config->Flush();
+			g_mainFrame->Refresh();
+			g_mainFrame->UpdateMainMenu(); // skins menu entries may be deleted
 		}
 	}
 }
+void SjViewSettingsPage::OnCancelSkinSelection(wxCommandEvent& event)
+{
+	UpdateSkinList(g_mainFrame->GetSkinUrl());
+	SjDialog::EnsureSelListCtrlItemVisible(m_listCtrl);
+}
 
 
 void SjViewSettingsPage::ShowContextMenu(wxWindow* window, const wxPoint& pt)
 {
 	SjMenu menu(0);
 
-	#if SJ_USE_SCRIPTS
-		wxArrayString arr = SjSee::GetGlobalEmbeddings(SJ_PERSISTENT_SKINS_BUTTON);
-		int i, iCount = arr.GetCount();
-		if( iCount )
-		{
-			for( i = 0; i < iCount; i++ )
-				menu.Append(IDC_SCRIPT_CONFIG+i, arr[i], SJ_ICON_MODULE);
-		}
-	#endif
-
 	menu.Append(IDC_SKININFO, _("Info..."));
 
-	menu.Append(IDC_SKINEXPLORE, _("Show file"));
+	menu.Append(IDC_SKINEXPLORE, _os(_("Show file")));
 	menu.AppendSeparator();
 	menu.Append(IDC_SKINUPDATELIST, _("Update list"));
 	menu.Append(IDC_SKINWWW, _("More skins on the web..."));
@@ -690,7 +648,7 @@ SjViewSettingsModule::SjViewSettingsModule(SjInterfaceBase* interf)
 	m_file       = wxT("memory:viewsettings.lib");
 	m_name       = _("Skins");
 	m_guiIcon    = SJ_ICON_SKIN;
-	m_sort       = 40;
+	m_sort       = 30;
 }
 
 
@@ -719,6 +677,7 @@ void SjViewSettingsModule::DoneConfigPage(wxWindow* configPage__, int doneAction
 
 			g_mainFrame->LoadSkin(configPage->m_orgSkinPath, SJ_OP_DEF_NONKIOSK);
 			g_mainFrame->Refresh();
+			g_mainFrame->UpdateMainMenu(); // skins menu entries may be deleted
 
 			wxASSERT(g_tools);
 			g_tools->m_config->Write(wxT("main/skinFile"), g_mainFrame->GetSkinUrl());
