@@ -34,14 +34,15 @@
 #include <sjmodules/vis/vis_cdg_reader.h>
 #include <sjmodules/vis/vis_synctxt_reader.h>
 
-#define IDC_BG_DEFAULT_IMAGES           (IDM_FIRSTPRIVATE+2)
-#define IDC_BG_BLACK                    (IDM_FIRSTPRIVATE+3)
-#define IDC_BG_USERDEF_DIR_USE          (IDM_FIRSTPRIVATE+4)
-#define IDC_BG_USERDEF_DIR_CHANGE       (IDM_FIRSTPRIVATE+5)
-#define IDC_BG_SMOOTH                   (IDM_FIRSTPRIVATE+6)
-#define IDC_BG_KEEPASPECT               (IDM_FIRSTPRIVATE+7)
-#define IDC_BG_GRAYSCALE                (IDM_FIRSTPRIVATE+8)
-#define IDC_BG_USEBGJPG                 (IDM_FIRSTPRIVATE+9)
+#define IDC_BG_SUBMENU                  (IDO_VIS_OPTIONFIRST+1)
+#define IDC_BG_DEFAULT_IMAGES           (IDO_VIS_OPTIONFIRST+2)
+#define IDC_BG_BLACK                    (IDO_VIS_OPTIONFIRST+3)
+#define IDC_BG_USERDEF_DIR_USE          (IDO_VIS_OPTIONFIRST+4)
+#define IDC_BG_USERDEF_DIR_CHANGE       (IDO_VIS_OPTIONFIRST+5)
+#define IDC_BG_SMOOTH                   (IDO_VIS_OPTIONFIRST+6)
+#define IDC_BG_KEEPASPECT               (IDO_VIS_OPTIONFIRST+7)
+#define IDC_BG_GRAYSCALE                (IDO_VIS_OPTIONFIRST+8)
+#define IDC_BG_USEBGJPG                 (IDO_VIS_OPTIONFIRST+9)
 
 
 /*******************************************************************************
@@ -299,12 +300,12 @@ private:
 	   -- people shall use the menu button atop of the window
 	   Edit 3.04: well, but we'll need this for the kiosk mode */
 	// /*
-	void            OnMouseLeftDown     (wxMouseEvent& e)   { if(ImplOk()) m_karaokeModule->m_impl->OnMouseLeftDown(this, e); }
-	void            OnMouseLeftUp       (wxMouseEvent& e)   { if(ImplOk()) m_karaokeModule->m_impl->OnMouseLeftUp(this, e); }
-	void            OnMouseRightUp      (wxMouseEvent& e)   { if(ImplOk()) m_karaokeModule->m_impl->OnMouseRightUp(this, e); }
-	void            OnMouseLeftDClick   (wxMouseEvent& e)   { if(ImplOk()) m_karaokeModule->m_impl->OnMouseLeftDClick(this, e); }
+	void            OnMouseLeftDown     (wxMouseEvent& e)   { if(ImplOk()) m_karaokeModule->m_impl->OnMouseLeftDown(e); }
+	void            OnMouseLeftUp       (wxMouseEvent& e)   { if(ImplOk()) m_karaokeModule->m_impl->OnMouseLeftUp(e); }
+	void            OnMouseRightUp      (wxContextMenuEvent& e)   { if(ImplOk()) m_karaokeModule->m_impl->OnMouseRightUp(e); }
+	void            OnMouseLeftDClick   (wxMouseEvent& e)   { if(ImplOk()) m_karaokeModule->m_impl->OnMouseLeftDClick(e); }
 	// */
-	void            OnMouseEnter        (wxMouseEvent& e)   { if(ImplOk()) m_karaokeModule->m_impl->OnMouseEnter(this, e); }
+	void            OnMouseEnter        (wxMouseEvent& e)   { if(ImplOk()) m_karaokeModule->m_impl->OnMouseEnter(e); }
 
 	bool            m_inPaint;
 
@@ -330,7 +331,7 @@ BEGIN_EVENT_TABLE(SjKaraokeWindow, wxWindow)
 	EVT_LEFT_DOWN       (                       SjKaraokeWindow::OnMouseLeftDown    )
 	EVT_LEFT_UP         (                       SjKaraokeWindow::OnMouseLeftUp      )
 	EVT_LEFT_DCLICK     (                       SjKaraokeWindow::OnMouseLeftDClick  )
-	EVT_RIGHT_UP        (                       SjKaraokeWindow::OnMouseRightUp     )
+	EVT_CONTEXT_MENU    (                       SjKaraokeWindow::OnMouseRightUp     )
 	EVT_ENTER_WINDOW    (                       SjKaraokeWindow::OnMouseEnter       )
 	EVT_TIMER           (IDC_TIMER,             SjKaraokeWindow::OnTimer            )
 END_EVENT_TABLE()
@@ -522,6 +523,7 @@ SjKaraokeModule::SjKaraokeModule(SjInterfaceBase* interf)
 	m_name          = _("Karaoke Prompt");
 	m_karaokeWindow = NULL;
 	m_bg            = NULL;
+	m_sort          = 3000; // end of list, default is 1000
 }
 
 
@@ -687,18 +689,18 @@ void SjKaraokeModule::UpdateBg(bool keepImg)
 }
 
 
-bool SjKaraokeModule::Start(SjVisImpl* impl, bool justContinue)
+bool SjKaraokeModule::Start(SjVisWindow* impl)
 {
 	m_impl = impl;
 	m_currUrl = wxT(":*");  // something invalid, but not empty - otherwise the comparison for new tracks
 	// will fail if the url is empty!
 	if( m_karaokeWindow == NULL )
 	{
-		m_karaokeWindow = new SjKaraokeWindow(this, m_impl->GetWindow());
+		m_karaokeWindow = new SjKaraokeWindow(this, m_impl);
 
 		if( m_karaokeWindow  )
 		{
-			ReceiveMsgTrackOnAirChanged(justContinue);
+			ReceiveMsgTrackOnAirChanged();
 
 			wxRect visRect = impl->GetRendererClientRect();
 			m_karaokeWindow->SetSize(visRect);
@@ -736,7 +738,7 @@ void SjKaraokeModule::Stop()
 }
 
 
-void SjKaraokeModule::ReceiveMsgTrackOnAirChanged(bool justContinue)
+void SjKaraokeModule::ReceiveMsgTrackOnAirChanged()
 {
 	if( m_karaokeWindow )
 	{
@@ -749,7 +751,7 @@ void SjKaraokeModule::ReceiveMsgTrackOnAirChanged(bool justContinue)
 		{
 			m_currUrl = newUrl;
 
-			if( m_bg == NULL || !justContinue )
+			if( m_bg == NULL )
 				UpdateBg();
 
 			m_karaokeWindow->m_karaokeMaster.Init(newUrl, ti.m_leadArtistName, ti.m_trackName);
@@ -765,12 +767,12 @@ void SjKaraokeModule::ReceiveMsg(int msg)
 
 	if( msg == IDMODMSG_TRACK_ON_AIR_CHANGED )
 	{
-		ReceiveMsgTrackOnAirChanged(false);
+		ReceiveMsgTrackOnAirChanged();
 	}
 }
 
 
-void SjKaraokeModule::PleaseUpdateSize(SjVisImpl* impl)
+void SjKaraokeModule::PleaseUpdateSize(SjVisWindow* impl)
 {
 	if( m_karaokeWindow )
 	{
@@ -784,36 +786,32 @@ void SjKaraokeModule::PleaseUpdateSize(SjVisImpl* impl)
 void SjKaraokeModule::AddMenuOptions(SjMenu& m)
 {
 	SjMenu* submenu = new SjMenu(0);
+		submenu->AppendRadioItem(IDC_BG_DEFAULT_IMAGES, _("Default"));
+		submenu->Check(IDC_BG_DEFAULT_IMAGES, (m_bgType == SJ_KARAOKE_BG_DEFAULT_IMAGES));
 
-	submenu->AppendRadioItem(IDC_BG_DEFAULT_IMAGES, _("Default"));
-	submenu->Check(IDC_BG_DEFAULT_IMAGES, (m_bgType == SJ_KARAOKE_BG_DEFAULT_IMAGES));
+		submenu->AppendRadioItem(IDC_BG_BLACK, _("Black"));
+		submenu->Check(IDC_BG_BLACK, (m_bgType == SJ_KARAOKE_BG_BLACK));
 
-	submenu->AppendRadioItem(IDC_BG_BLACK, _("Black"));
-	submenu->Check(IDC_BG_BLACK, (m_bgType == SJ_KARAOKE_BG_BLACK));
+		if( !m_bgUserDefDir.IsEmpty() )
+		{
+			submenu->AppendRadioItem(IDC_BG_USERDEF_DIR_USE, SjTools::ShortenUrl(m_bgUserDefDir));
+			submenu->Check(IDC_BG_USERDEF_DIR_USE, (m_bgType == SJ_KARAOKE_BG_USERDEF_DIR));
+		}
 
-	if( !m_bgUserDefDir.IsEmpty() )
-	{
-		submenu->AppendRadioItem(IDC_BG_USERDEF_DIR_USE, SjTools::ShortenUrl(m_bgUserDefDir));
-		submenu->Check(IDC_BG_USERDEF_DIR_USE, (m_bgType == SJ_KARAOKE_BG_USERDEF_DIR));
-	}
+		submenu->Append(IDC_BG_USERDEF_DIR_CHANGE, _("Select..."));
+	m.Append(IDC_BG_SUBMENU, _("Background"), submenu);
 
-	submenu->Append(IDC_BG_USERDEF_DIR_CHANGE, _("Select..."));
+	m.AppendCheckItem(IDC_BG_USEBGJPG, wxString::Format(_("Use %s-files"), wxT("*.bg.jpg")));
+	m.Check(IDC_BG_USEBGJPG, (m_karFlags&SJ_KAR_USEBGJPG)!=0);
 
-	submenu->AppendSeparator();
+	m.AppendCheckItem(IDC_BG_KEEPASPECT, _("Fit to screen"));
+	m.Check(IDC_BG_KEEPASPECT, (m_karFlags&SJ_KAR_KEEPASPECT)==0);
 
-	submenu->AppendCheckItem(IDC_BG_USEBGJPG, wxString::Format(_("Use %s-files"), wxT("*.bg.jpg")));
-	submenu->Check(IDC_BG_USEBGJPG, (m_karFlags&SJ_KAR_USEBGJPG)!=0);
+	m.AppendCheckItem(IDC_BG_SMOOTH, _("Smooth"));
+	m.Check(IDC_BG_SMOOTH, (m_karFlags&SJ_KAR_SMOOTH)!=0);
 
-	submenu->AppendCheckItem(IDC_BG_KEEPASPECT, _("Fit to screen"));
-	submenu->Check(IDC_BG_KEEPASPECT, (m_karFlags&SJ_KAR_KEEPASPECT)==0);
-
-	submenu->AppendCheckItem(IDC_BG_SMOOTH, _("Smooth"));
-	submenu->Check(IDC_BG_SMOOTH, (m_karFlags&SJ_KAR_SMOOTH)!=0);
-
-	submenu->AppendCheckItem(IDC_BG_GRAYSCALE, _("Grayscale"));
-	submenu->Check(IDC_BG_GRAYSCALE, (m_karFlags&SJ_KAR_GRAYSCALE)!=0);
-
-	m.Append(0, _("Background"), submenu);
+	m.AppendCheckItem(IDC_BG_GRAYSCALE, _("Grayscale"));
+	m.Check(IDC_BG_GRAYSCALE, (m_karFlags&SJ_KAR_GRAYSCALE)!=0);
 }
 
 
@@ -838,10 +836,10 @@ void SjKaraokeModule::OnMenuOption(int i)
 		case IDC_BG_USERDEF_DIR_CHANGE:
 			g_visModule->SetModal(true);
 			{
-				wxWindowDisabler disabler(m_impl->GetWindow());
+				SJ_WINDOW_DISABLER(m_impl);
 
 				::wxBeginBusyCursor(wxHOURGLASS_CURSOR);
-				wxDirDialog dirDialog(m_impl->GetWindow(),
+				wxDirDialog dirDialog(m_impl,
 				                      _("Please select a directory with images"),
 				                      m_bgUserDefDir);
 				::wxEndBusyCursor();
