@@ -30,7 +30,7 @@
 #include <sjmodules/vis/vis_oscilloscope.h>
 #include <sjmodules/vis/vis_window.h>
 #include <math.h>
-#include <kiss_fft/kiss_fftr.h>
+#include <kiss_fft/tools/kiss_fftr.h>
 
 // you should not change SLEEP_MS without reasons.
 // IF you change it, also check if really all time-depending calculations are still correct.
@@ -560,7 +560,7 @@ SjOscHands::SjOscHands()
 void SjOscHands::Draw(wxDC& dc, const wxSize& clientSize,
                       long volume, long light, bool newTitle)
 {
-	long i, offset;
+	long i, offset = 0;
 
 	// (re-)calculate log. hand data
 	if( m_logHandMode == HAND_MODE_NOP )
@@ -791,8 +791,8 @@ void SjOscRotor::Draw(wxDC& dc, const wxSize& clientSize, bool otherRunning, boo
 class SjOscOscilloscope
 {
 public:
-	SjOscOscilloscope   (long sampleCount);
-	~SjOscOscilloscope  ();
+	                SjOscOscilloscope   (long sampleCount);
+	                ~SjOscOscilloscope  ();
 	void            Calc                (const wxSize& clientSize,
 	                                     const unsigned char* bufferStart,
 	                                     long& retVolume);
@@ -900,19 +900,29 @@ void SjOscOscilloscope::Draw(wxDC& dc, bool forceAnim)
 class SjOscSpectrumChData
 {
 public:
-#define         NUM_BOXES 20
-#define         SPEC_NUM        576
+	#define         NUM_BOXES 20
+	#define         SPEC_NUM  576
 	long            chNum;
 	double          m_boxMax[NUM_BOXES];
 	double          m_boxY[NUM_BOXES];
+
+	SjOscSpectrumChData()
+	{
+		chNum = 0;
+		for( int i = 0; i < NUM_BOXES; i++ )
+		{
+			m_boxMax[i] = 0;
+			m_boxY[i] = 0;
+		}
+	}
 };
 
 
 class SjOscSpectrum
 {
 public:
-	SjOscSpectrum       (long sampleCount);
-	~SjOscSpectrum      ();
+	                SjOscSpectrum       ();
+	                ~SjOscSpectrum      ();
 	void            Calc                (const wxSize& clientSize,
 	                                     const unsigned char* bufferStart);
 	void            Draw                (wxDC& dc, bool volumeBeat, bool showFigures, bool forceAnim)
@@ -922,10 +932,8 @@ public:
 
 private:
 	wxSize          m_clientSize;
-	long            m_sampleCount;
 	kiss_fftr_cfg   m_kiss_fft_setup;
-	SjOscSpectrumChData
-	m_chData[2];
+	SjOscSpectrumChData m_chData[2];
 
 	void            Draw                (wxDC&, SjOscSpectrumChData* chData, bool volumeBeat, bool showFigures, bool forceAnim);
 	void            DrawBand            (wxDC& dc, int x, int y, int w, int h, double val, double crazy);
@@ -947,9 +955,8 @@ private:
 };
 
 
-SjOscSpectrum::SjOscSpectrum(long sampleCount)
+SjOscSpectrum::SjOscSpectrum()
 {
-	m_sampleCount       = sampleCount;
 	m_kiss_fft_setup    = kiss_fftr_alloc(SPEC_NUM*2, 0, NULL, 0);
 	m_chData[0].chNum   = 0;
 	m_chData[1].chNum   = 1;
@@ -1031,6 +1038,12 @@ void SjOscSpectrum::Calc(const wxSize& clientSize, const unsigned char* bufferSt
 
 void SjOscSpectrum::DrawBand(wxDC& dc, int x, int y, int w, int h, double val, double crazy)
 {
+	// make sure, "val" is in range.  normally, there should be no overflows, but if, for any reasons,
+	// silverjuke may get very slow as eg. handH gets way too large.
+	if( val > 1.0 ) val = 1.0;
+	if( val < 0 ) val = 0;
+
+	// draw the band to the given box
 	long bandH = (long)((double)h*val);
 	int  yy;
 
@@ -1353,15 +1366,21 @@ void SjOscTitle::CalcCurrTitleSize(wxDC& dc)
 class SjOscWindow : public wxWindow
 {
 public:
-	SjOscWindow         (SjOscModule*, wxWindow* parent);
-	~SjOscWindow		();
+	                    SjOscWindow         (SjOscModule*, wxWindow* parent);
+	                    ~SjOscWindow        ();
 
 private:
 	SjOscModule*        m_oscModule;
     wxBitmap            m_offscreenBitmap;
     wxMemoryDC          m_offscreenDc;
-    long                m_sampleCount;
     unsigned char*      m_bufferStart;
+    unsigned char*      m_bufferTemp;
+    #define             BUFFER_MIN_BYTES (576*2*sizeof(float))
+    long                m_bufferTotalBytes;
+    long                m_bufferValidBytes;
+    bool                m_bufferDrawn;
+    wxCriticalSection   m_bufferCritical;
+    long                m_sampleCount_;
 	wxColour            m_textColour;
 	wxColour            m_fgColour;
 	wxPen               m_fgPen;
@@ -1380,23 +1399,23 @@ private:
 	bool                ImplOk              () const            { return (m_oscModule&&m_oscModule->m_impl); }
 	void                OnKeyDown           (wxKeyEvent& e)     { if(ImplOk()) m_oscModule->m_impl->OnKeyDown(e); }
 	void                OnKeyUp             (wxKeyEvent& e)     { if(ImplOk()) m_oscModule->m_impl->OnKeyUp(e); }
-	void                OnMouseLeftDown     (wxMouseEvent& e)   { if(ImplOk()) m_oscModule->m_impl->OnMouseLeftDown(this, e); }
-	void                OnMouseLeftUp       (wxMouseEvent& e)   { if(ImplOk()) m_oscModule->m_impl->OnMouseLeftUp(this, e); }
-	void                OnMouseRightUp      (wxMouseEvent& e)   { if(ImplOk()) m_oscModule->m_impl->OnMouseRightUp(this, e); }
-	void                OnMouseLeftDClick   (wxMouseEvent& e)   { if(ImplOk()) m_oscModule->m_impl->OnMouseLeftDClick(this, e); }
-	void                OnMouseEnter        (wxMouseEvent& e)   { if(ImplOk()) m_oscModule->m_impl->OnMouseEnter(this, e); }
-	void                OnShowFigures       (wxCommandEvent&) { ShowFigures(-1); }
+	void                OnMouseLeftDown     (wxMouseEvent& e)   { if(ImplOk()) m_oscModule->m_impl->OnMouseLeftDown(e); }
+	void                OnMouseLeftUp       (wxMouseEvent& e)   { if(ImplOk()) m_oscModule->m_impl->OnMouseLeftUp(e); }
+	void                OnMouseRightUp      (wxContextMenuEvent& e)   { if(ImplOk()) m_oscModule->m_impl->OnMouseRightUp(e); }
+	void                OnMouseLeftDClick   (wxMouseEvent& e)   { if(ImplOk()) m_oscModule->m_impl->OnMouseLeftDClick(e); }
+	void                OnMouseEnter        (wxMouseEvent& e)   { if(ImplOk()) m_oscModule->m_impl->OnMouseEnter(e); }
+	void                OnShowFigures       (wxCommandEvent&)   { ShowFigures(-1); }
 	void                OnTimer             (wxTimerEvent&);
 	friend class        SjOscModule;
-	DECLARE_EVENT_TABLE ();
+	                    DECLARE_EVENT_TABLE ();
 };
 
 
-#define IDC_SHOWSPECTRUM        (IDM_FIRSTPRIVATE+1)
-#define IDC_SHOWOSCILLOSCOPE    (IDM_FIRSTPRIVATE+2)
-#define IDC_SHOWSTARFIELD       (IDM_FIRSTPRIVATE+3)
-#define IDC_SHOWFIGURES         (IDM_FIRSTPRIVATE+4)
-#define IDC_TIMER               (IDM_FIRSTPRIVATE+7)
+#define IDC_SHOWSPECTRUM        (IDO_VIS_OPTIONFIRST+1)
+#define IDC_SHOWOSCILLOSCOPE    (IDO_VIS_OPTIONFIRST+2)
+#define IDC_SHOWSTARFIELD       (IDO_VIS_OPTIONFIRST+3)
+#define IDC_SHOWFIGURES         (IDO_VIS_OPTIONFIRST+4)
+#define IDC_TIMER               (IDO_VIS_OPTIONFIRST+7)
 
 
 BEGIN_EVENT_TABLE(SjOscWindow, wxWindow)
@@ -1408,7 +1427,7 @@ BEGIN_EVENT_TABLE(SjOscWindow, wxWindow)
 	EVT_LEFT_DOWN       (                       SjOscWindow::OnMouseLeftDown        )
 	EVT_LEFT_UP         (                       SjOscWindow::OnMouseLeftUp          )
 	EVT_LEFT_DCLICK     (                       SjOscWindow::OnMouseLeftDClick      )
-	EVT_RIGHT_UP        (                       SjOscWindow::OnMouseRightUp         )
+	EVT_CONTEXT_MENU    (                       SjOscWindow::OnMouseRightUp         )
 	EVT_TIMER           (IDC_TIMER,             SjOscWindow::OnTimer                )
 END_EVENT_TABLE()
 
@@ -1422,24 +1441,23 @@ SjOscWindow::SjOscWindow(SjOscModule* oscModule, wxWindow* parent)
 {
 	m_oscModule = oscModule;
 
-	// get the number of samples wanted
-	// (currently we exactly 576 for the spcectrum analyzer)
-	m_sampleCount = SjMs2Bytes(SLEEP_MS) / (SJ_WW_CH*SJ_WW_BYTERES);
-	if( m_sampleCount < 576*2 )
-	{
-		m_sampleCount = 576*2;
+	m_bufferTotalBytes = 0;
+	m_bufferValidBytes = 0;
+	m_bufferDrawn = false;
+	m_bufferStart = (unsigned char*)malloc(BUFFER_MIN_BYTES);
+	m_bufferTemp = (unsigned char*)malloc(BUFFER_MIN_BYTES);
+	if( m_bufferStart && m_bufferTemp ) {
+		m_bufferTotalBytes = BUFFER_MIN_BYTES;
 	}
 
-	m_bufferStart = (unsigned char*)malloc(m_sampleCount*SJ_WW_CH*SJ_WW_BYTERES);
-
 	// set colors
 	m_textColour = wxColour(0x2F, 0x60, 0xA3);
 	m_fgColour = wxColour(0x3D, 0x80, 0xDF);
 	m_fgPen = wxPen(m_fgColour, 1, wxSOLID);
 
 	// create the drawing objects
-	m_spectrum = new SjOscSpectrum(m_sampleCount);
-	m_oscilloscope = new SjOscOscilloscope(m_sampleCount);
+	m_spectrum = new SjOscSpectrum();
+	m_oscilloscope = new SjOscOscilloscope(BUFFER_MIN_BYTES/sizeof(float));
 	m_title = new SjOscTitle();
 	m_rotor = new SjOscRotor();
 	m_hands = new SjOscHands();
@@ -1463,6 +1481,7 @@ SjOscWindow::~SjOscWindow()
 	if( m_firework )     { delete m_firework; }
 	if( m_starfield )    { delete m_starfield; }
 	if( m_bufferStart )  { free(m_bufferStart); }
+	if( m_bufferTemp )   { free(m_bufferTemp); }
 	m_oscModule = NULL;
 }
 
@@ -1473,6 +1492,8 @@ void SjOscWindow::OnTimer(wxTimerEvent&)
 
 	if( m_oscModule )
 	{
+		long                validBytes;
+
 		// volume stuff
 		long                volume, maxVolume = 1;
 		bool                volumeBeat;
@@ -1483,7 +1504,18 @@ void SjOscWindow::OnTimer(wxTimerEvent&)
 		wxString            newTitle;
 
 		// get data
-		g_mainFrame->m_player.GetVisData(m_bufferStart, m_sampleCount*SJ_WW_CH*SJ_WW_BYTERES, 0);
+		if( m_bufferStart==NULL || m_bufferTemp == NULL ) return;
+		m_bufferCritical.Enter();
+			validBytes = m_bufferValidBytes;
+			m_bufferDrawn = true;
+			if( validBytes > 0 ) {
+				memcpy(m_bufferTemp, m_bufferStart, validBytes);
+			}
+			else {
+				validBytes = BUFFER_MIN_BYTES;
+				memset(m_bufferTemp, 0, validBytes);
+			}
+		m_bufferCritical.Leave();
 
 		// get window client size, correct offscreen DC if needed
 		wxSize clientSize = m_oscModule->m_oscWindow->GetClientSize();
@@ -1494,10 +1526,10 @@ void SjOscWindow::OnTimer(wxTimerEvent&)
 		}
 
 		// calculate the points for the lines, collect volume
-		m_oscilloscope->Calc(clientSize, m_bufferStart, volume);
+		m_oscilloscope->Calc(clientSize, m_bufferTemp, volume);
 		if( m_oscModule->m_showFlags&SJ_OSC_SHOW_SPECTRUM )
 		{
-			m_spectrum->Calc(clientSize, m_bufferStart);
+			m_spectrum->Calc(clientSize, m_bufferTemp);
 		}
 
 		// get data that are shared between the threads
@@ -1603,24 +1635,25 @@ SjOscModule::SjOscModule(SjInterfaceBase* interf)
 	m_name          = _("Spectrum Monitor");
 	m_oscWindow     = NULL;
 	m_impl          = NULL;
+	m_sort          = 3001; // very end of list, default is 1000
 }
 
 
-bool SjOscModule::Start(SjVisImpl* impl, bool justContinue)
+bool SjOscModule::Start(SjVisWindow* impl)
 {
 	if( m_oscWindow == NULL )
 	{
 		m_impl = impl;
 
-		m_showFlags             = g_tools->m_config->Read(wxT("player/oscflags"), SJ_OSC_SHOW_DEFAULT);
-		m_oscWindow = new SjOscWindow(this, impl->GetWindow());
+		m_showFlags		= g_tools->m_config->Read(wxT("player/oscflags"), SJ_OSC_SHOW_DEFAULT);
+		m_oscWindow = new SjOscWindow(this, impl);
 
 		if( m_oscWindow  )
 		{
 			ReceiveMsg(IDMODMSG_TRACK_ON_AIR_CHANGED);
 
-			m_forceSpectrAnim= !justContinue;
-			m_forceOscAnim   = !justContinue;
+			m_forceSpectrAnim= true;
+			m_forceOscAnim   = true;
 
 			wxRect visRect = impl->GetRendererClientRect();
 			m_oscWindow->SetSize(visRect);
@@ -1659,16 +1692,10 @@ void SjOscModule::ReceiveMsg(int msg)
 		m_trackName = urlInfo.GetTrackName();
 		m_leadArtistName = urlInfo.GetLeadArtistName();
 	}
-	else if( msg == IDMODMSG_WINDOW_SIZE_MOVE_BEGIN )
-	{
-	}
-	else if( msg == IDMODMSG_WINDOW_SIZE_MOVE_END )
-	{
-	}
 }
 
 
-void SjOscModule::PleaseUpdateSize(SjVisImpl* impl)
+void SjOscModule::PleaseUpdateSize(SjVisWindow* impl)
 {
 	wxRect visRect = impl->GetRendererClientRect();
 	m_oscWindow->SetSize(visRect);
@@ -1716,3 +1743,43 @@ void SjOscModule::OnMenuOption(int i)
 
 	g_tools->m_config->Write(wxT("player/oscflags"), m_showFlags);
 }
+
+
+
+void SjOscModule::AddVisData(const float* src, long bytes)
+{
+	if( m_oscWindow && m_oscWindow->m_bufferStart && bytes )
+	{
+		m_oscWindow->m_bufferCritical.Enter();
+
+			// resize the buffer, if needed
+			if( m_oscWindow->m_bufferDrawn ) {
+				m_oscWindow->m_bufferValidBytes = 0;
+				m_oscWindow->m_bufferDrawn = false;
+			}
+			long bytesWanted = m_oscWindow->m_bufferValidBytes + bytes / 2/*use use short, not float*/;
+			if( bytesWanted > m_oscWindow->m_bufferTotalBytes )
+			{
+                m_oscWindow->m_bufferStart = (unsigned char*)realloc(m_oscWindow->m_bufferStart, bytesWanted);
+                m_oscWindow->m_bufferTemp  = (unsigned char*)realloc(m_oscWindow->m_bufferTemp,  bytesWanted);
+                if( m_oscWindow->m_bufferStart == NULL || m_oscWindow->m_bufferTemp == NULL ) { return; }
+			}
+
+			// copy the buffer, convert float to singed shorts
+			long s, numSamples = bytes/4;
+			signed short* dest =  (signed short*)(&m_oscWindow->m_bufferStart[m_oscWindow->m_bufferValidBytes]);
+			float sample;
+			for( s = 0; s < numSamples; s++ )
+			{
+				sample = src[s] * float_to_short;
+				if( sample < -32768 ) sample = -32768;
+				if( sample >  32767 ) sample =  32767;
+				dest[s] = sample;
+			}
+
+			m_oscWindow->m_bufferValidBytes += bytes / 2;
+
+		m_oscWindow->m_bufferCritical.Leave();
+	}
+}
+
