@@ -88,7 +88,7 @@ private:
 
 
 SjLogListCtrl::SjLogListCtrl(SjLogGui* logGui, wxWindow* parent, wxWindowID id, long aIndex)
-	: wxListCtrl(parent, id, wxDefaultPosition, wxSize(-1, 160), wxLC_REPORT | wxLC_VIRTUAL /*| wxLC_NO_HEADER*/)
+	: wxListCtrl(parent, id, wxDefaultPosition, wxSize(600, 160), wxLC_REPORT | wxLC_VIRTUAL /*| wxLC_NO_HEADER*/)
 {
 	m_logGui = logGui;
 
@@ -221,7 +221,7 @@ public:
 	SjLogGui*           m_logGui;
 
 	#if SJ_USE_SCRIPTS
-	SjSee               m_see;
+	SjSee*              m_see;
 	#endif
 
 	wxStaticBitmap*     m_icon;
@@ -231,8 +231,10 @@ public:
 	wxSizer*            m_sizerDetails;
 	bool                m_sizerDetailsAttached;
 	SjLogListCtrl*      m_listCtrl;
+	#if SJ_USE_SCRIPTS
 	wxTextCtrl*         m_evalInput;
 	wxWindow*           m_evalButton;
+	#endif
 	wxWindow*           m_clearButton;
 	wxWindow*           m_saveButton;
 	wxCheckBox*         m_autoOpenCheckBox;
@@ -245,7 +247,9 @@ public:
 
 	void                OnOk                (wxCommandEvent& e) { DoClose(); }
 	void                OnDetails           (wxCommandEvent& e);
+	#if SJ_USE_SCRIPTS
 	void                OnEval              (wxCommandEvent& e);
+	#endif
 	void                OnClear             (wxCommandEvent& e);
 	void                OnSave              (wxCommandEvent& e);
 	void                OnAutoOpen          (wxCommandEvent& e) { SjLogGui::SetAutoOpen(m_autoOpenCheckBox->GetValue()!=0); }
@@ -258,8 +262,10 @@ public:
 
 #define IDC_DETAILS_BUTTON       IDC_BUTTONBARMENU
 #define IDC_LIST_CTRL           (IDM_FIRSTPRIVATE+3)
+#if SJ_USE_SCRIPTS
 #define IDC_EVAL_INPUT          (IDM_FIRSTPRIVATE+4)
 #define IDC_EVAL_BUTTON         (IDM_FIRSTPRIVATE+5)
+#endif
 #define IDC_CLEAR_BUTTON        (IDM_FIRSTPRIVATE+6)
 #define IDC_SAVE_BUTTON         (IDM_FIRSTPRIVATE+7)
 #define IDC_AUTO_OPEN_CHECKBOX  (IDM_FIRSTPRIVATE+8)
@@ -268,8 +274,10 @@ public:
 BEGIN_EVENT_TABLE(SjLogDialog, SjDialog)
 	EVT_BUTTON      (wxID_OK,               SjLogDialog::OnOk       )
 	EVT_BUTTON      (IDC_DETAILS_BUTTON,    SjLogDialog::OnDetails  )
+	#if SJ_USE_SCRIPTS
 	EVT_TEXT_ENTER  (IDC_EVAL_INPUT,        SjLogDialog::OnEval     )
 	EVT_BUTTON      (IDC_EVAL_BUTTON,       SjLogDialog::OnEval     )
+	#endif
 	EVT_BUTTON      (IDC_CLEAR_BUTTON,      SjLogDialog::OnClear    )
 	EVT_BUTTON      (IDC_SAVE_BUTTON,       SjLogDialog::OnSave     )
 	EVT_CHECKBOX    (IDC_AUTO_OPEN_CHECKBOX,SjLogDialog::OnAutoOpen )
@@ -289,6 +297,7 @@ SjLogDialog::SjLogDialog(SjLogGui* logGui,
 	           parent? SJ_MODELESS : SJ_MODAL,
 	           SJ_RESIZEABLE_IF_POSSIBLE)
 {
+	m_see = NULL;
 	m_logGui = logGui;
 	s_dlg = this;
 
@@ -353,18 +362,18 @@ SjLogDialog::SjLogDialog(SjLogGui* logGui,
 	wxSizer* sizer4 = new wxBoxSizer(wxHORIZONTAL);
 	m_sizerDetails->Add(sizer4, 0, wxGROW|wxTOP, SJ_DLG_SPACE/2);
 
-	m_evalInput = new wxTextCtrl(this, IDC_EVAL_INPUT, wxT(""), wxDefaultPosition, wxSize(300, -1), wxTE_PROCESS_ENTER);
-	sizer4->Add(m_evalInput, 1, wxRIGHT|wxALIGN_CENTER_VERTICAL, SJ_DLG_SPACE/2);
+	#if SJ_USE_SCRIPTS
+		m_evalInput = new wxTextCtrl(this, IDC_EVAL_INPUT, wxT(""), wxDefaultPosition, wxSize(300, -1), wxTE_PROCESS_ENTER);
+		sizer4->Add(m_evalInput, 1, wxRIGHT|wxALIGN_CENTER_VERTICAL, SJ_DLG_SPACE/2);
 
-	#define TOOLBAR_BUTTON(id, name) new wxButton(this, id, name, wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT)
+		m_evalButton = new wxButton(this, IDC_EVAL_BUTTON, _("Evaluate"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT);
+		sizer4->Add(m_evalButton, 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, SJ_DLG_SPACE/2);
+	#endif
 
-	m_evalButton = TOOLBAR_BUTTON(IDC_EVAL_BUTTON, _("Evaluate"));
-	sizer4->Add(m_evalButton, 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, SJ_DLG_SPACE/2);
-
-	m_clearButton = TOOLBAR_BUTTON(IDC_CLEAR_BUTTON, _("Clear"));
+	m_clearButton = new wxButton(this, IDC_CLEAR_BUTTON, _("Clear"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT);
 	sizer4->Add(m_clearButton, 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, SJ_DLG_SPACE/2);
 
-	m_saveButton = TOOLBAR_BUTTON(IDC_SAVE_BUTTON, _("Save"));
+	m_saveButton = new wxButton(this, IDC_SAVE_BUTTON, _("Save"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT);
 	sizer4->Add(m_saveButton, 0, wxALIGN_CENTER_VERTICAL, SJ_DLG_SPACE);
 
 	m_autoOpenCheckBox = new wxCheckBox(this, IDC_AUTO_OPEN_CHECKBOX, _("Open console on errors and warnings"));
@@ -413,6 +422,8 @@ SjLogDialog::~SjLogDialog()
 	if( !m_sizerDetailsAttached ) {
 		delete m_sizerDetails;
 	}
+
+	delete m_see; // may still be NULL
 }
 
 
@@ -420,8 +431,10 @@ void SjLogDialog::ShowDetails(bool show)
 {
 	wxButton* detailsButton = (wxButton*)FindWindow(IDC_DETAILS_BUTTON);
 	m_listCtrl->Show(show);
+	#if SJ_USE_SCRIPTS
 	m_evalInput->Show(show);
 	m_evalButton->Show(show);
+	#endif
 	m_clearButton->Show(show);
 	m_saveButton->Show(show);
 	m_autoOpenCheckBox->Show(show);
@@ -490,8 +503,14 @@ void SjLogDialog::OnDetails(wxCommandEvent& event)
 }
 
 
+#if SJ_USE_SCRIPTS
 void SjLogDialog::OnEval(wxCommandEvent& event)
 {
+	// create scripting object, if not yet done
+	if( m_see == NULL ) {
+		m_see = new SjSee();
+	}
+
 	// execute a simple macro
 	wxString script = m_evalInput->GetValue();
 	script.Trim(true);
@@ -505,39 +524,37 @@ void SjLogDialog::OnEval(wxCommandEvent& event)
 		}
 
 		// prepare execute
-		#if SJ_USE_SCRIPTS
-			m_see.SetExecutionScope(_("Console"));
-			size_t oldCount1 = m_logGui->m_aMessages.GetCount();
-			size_t oldCount2 = m_logGui->m_aPacked.GetCount();
+		m_see->SetExecutionScope(_("Console"));
+		size_t oldCount1 = m_logGui->m_aMessages.GetCount();
+		size_t oldCount2 = m_logGui->m_aPacked.GetCount();
 
-			// execute
-			if( m_see.Execute(script) )
+		// execute
+		if( m_see->Execute(script) )
+		{
+			// print the result (if not empty or if nothng has been logged by Execute())
+			bool     sthLogged = (oldCount1!=m_logGui->m_aMessages.GetCount() || oldCount2!=m_logGui->m_aPacked.GetCount());
+			wxString result = m_see->GetResultString();
+			if( !sthLogged || !result.IsEmpty() )
 			{
-				// print the result (if not empty or if nothng has been logged by Execute())
-				bool     sthLogged = (oldCount1!=m_logGui->m_aMessages.GetCount() || oldCount2!=m_logGui->m_aPacked.GetCount());
-				wxString result = m_see.GetResultString();
-				if( !sthLogged || !result.IsEmpty() )
-				{
-					if( result.IsEmpty() ) {
-						result = wxT("undefined");
-					}
-					else if( result.Len()>110 ) {
-						result = result.Left(100).Trim()+wxT("..");
-					}
-
-					wxLogInfo(wxT("%s=%s [%s]"), scriptShortened.c_str(), result.c_str(), m_see.m_executionScope.c_str());
+				if( result.IsEmpty() ) {
+					result = wxT("undefined");
 				}
+				else if( result.Len()>110 ) {
+					result = result.Left(100).Trim()+wxT("..");
+				}
+
+				wxLogInfo(wxT("%s=%s [%s]"), scriptShortened.c_str(), result.c_str(), m_see->m_executionScope.c_str());
 			}
-		#endif
+		}
 	}
 }
+#endif
 
 
 void SjLogDialog::OnClear(wxCommandEvent& event)
 {
 	if( !m_logGui->m_aPacked.IsEmpty() )
 	{
-		wxWindowDisabler disabler(this);
 		if( SjMessageBox(_("Clear all messages?"), SJ_PROGRAM_NAME, wxICON_QUESTION|wxYES_NO, this) == wxYES )
 		{
 			m_logGui->m_aPacked.Clear();
@@ -553,7 +570,7 @@ void SjLogDialog::OnClear(wxCommandEvent& event)
 // dialog was cancelled
 int SjLogDialog::OpenLogFile(wxFile& file, wxString& retFilename)
 {
-	wxWindowDisabler disabler(this);
+	SJ_WINDOW_DISABLER(this);
 
 	// get the file name
 	// -----------------
@@ -688,7 +705,7 @@ SjLogGui::SjLogGui()
 
 	// set active logging target to this
 	m_oldTarget = wxLog::SetActiveTarget(this);
-	wxASSERT( wxLog::GetLogLevel() >= wxLOG_Info ); // true for wx 2.x and 3.x (we want wxLogInfo to work)
+	wxASSERT( wxLog::GetLogLevel() >= wxLOG_Info ); // true for wx 2.x and 3.x (we want wxLogInfo to work, however, we _pop up_ a message dialog only for warnings and errors)
 	wxLog::SetVerbose(true); // verbose defaults to false on wx 3.x and wxLogInfo won't work therefore
 
 
@@ -774,7 +791,7 @@ wxString SjLogGui::GetAndClearCatchedErrors()
 }
 
 
-void SjLogGui::DoLog(wxLogLevel level, const wxChar* msg, time_t timestamp)
+void SjLogGui::DoLogRecord(wxLogLevel level, const wxString& msg, const wxLogRecordInfo& info)
 {
 	// this function is called by the logging system eg. if
 	// wxLogError() or wxLogWarning() is called.
@@ -796,17 +813,7 @@ void SjLogGui::DoLog(wxLogLevel level, const wxChar* msg, time_t timestamp)
 	}
 
 	// forward to GUI logging
-	if( level == wxLOG_Info )
-	{
-		m_aMessages.Add(msg);
-		m_aSeverity.Add(wxLOG_Info);
-		m_aTimes.Add((long)timestamp);
-		m_bHasMessages = true;
-	}
-	else
-	{
-		wxLogGui::DoLog(level, msg, timestamp);
-	}
+	wxLogGui::DoLogRecord(level, msg, info);
 }
 
 
@@ -951,8 +958,7 @@ void SjLogGui::Flush()
 			// ... open modal
 			if( s_dlg && s_dlg->IsModal() )
 			{
-				wxASSERT( 0 );
-				s_dlg->MessagesChanged(firstNewIndex); // no raise - normally, this should not happen at all ...
+				s_dlg->MessagesChanged(firstNewIndex); // no raise - normally, this should not happen at all ... maybe on shutdown
 			}
 			else
 			{
@@ -974,8 +980,7 @@ void SjLogGui::OpenManually()
 		{
 			if( !s_dlg->m_showingDetails )
 			{
-				wxCommandEvent fwd(wxEVT_COMMAND_BUTTON_CLICKED, IDC_DETAILS_BUTTON);
-				s_dlg->GetEventHandler()->AddPendingEvent(fwd);
+				s_dlg->GetEventHandler()->QueueEvent(new wxCommandEvent(wxEVT_COMMAND_BUTTON_CLICKED, IDC_DETAILS_BUTTON));
 			}
 			s_dlg->Raise();
 		}
