@@ -50,6 +50,8 @@ void* SjImgThread::Entry()
 	bool                        objOk;
 	long                        imagesThisRound;
 
+	wxLog::SetThreadActiveTarget(SjLogGui::s_this);
+
 	/* Start endless loop
 	 *
 	 * NB: the image thread _MUST NOT_ use GUI routines, eg. wxBitmap does not work on GTK.
@@ -119,6 +121,7 @@ void* SjImgThread::Entry()
 			 */
 			{
 				SjLogString logString;
+				bool logError = false;
 
 				objOk = FALSE;
 				if( m_errorousUrls.Index(obj->m_url) == wxNOT_FOUND )
@@ -136,12 +139,19 @@ void* SjImgThread::Entry()
 					if( !objOk )
 					{
 						m_errorousUrls.Add(obj->m_url);
-						wxLogError(_("Cannot open \"%s\"."), obj->m_url.c_str());
+						logError = true;
 					}
 				}
 				else
 				{
-					wxLogError(_("Cannot open \"%s\"."), obj->m_url.c_str());
+					logError = true;
+				}
+
+				if( logError )
+				{
+					wxString filename = obj->m_url;
+					if( filename.StartsWith("file:") ) { filename = wxFileSystem::URLToFileName(filename).GetFullPath(); }
+					wxLogError(_("Cannot open \"%s\"."), filename.c_str());
 				}
 
 				obj->m_errors = logString.GetAndClearErrors();
@@ -175,8 +185,7 @@ void* SjImgThread::Entry()
 				if( obj->m_evtHandler )
 				{
 					obj->m_usage = 1;
-					SjImageThereEvent evt(obj);
-					obj->m_evtHandler->AddPendingEvent(evt);
+					obj->m_evtHandler->QueueEvent(new SjImageThereEvent(obj));
 				}
 			}
 
@@ -253,7 +262,7 @@ void SjImgThread::RequireStart(wxEvtHandler* evtHandler)
 			wxBusyCursor wait;
 
 			if( (m_condition = new wxCondition(m_mutex)) != NULL
-			        &&  m_condition->IsOk() != FALSE )
+			 &&  m_condition->IsOk() != FALSE )
 			{
 				Create();
 				Run();
@@ -298,7 +307,8 @@ void SjImgThread::RequireStart(wxEvtHandler* evtHandler)
 }
 
 
-SjImgThreadObj* SjImgThread::RequireImage(wxEvtHandler*     evtHandler,
+SjImgThreadObj* SjImgThread::RequireImage(
+        wxEvtHandler*     evtHandler,
         const wxString&   url,
         const SjImgOp&    op  )
 {
@@ -363,10 +373,10 @@ SjImgThreadObj* SjImgThread::RequireImage(wxEvtHandler*     evtHandler,
 		/* do we have to signal the thread to create a new image?
 		 */
 		if( nodeInCache == NULL
-		        || objInCache->m_op != op )
+		 || objInCache->m_op != op )
 		{
 			if( (nodeWaiting=SearchImg(m_anchorWaiting, url, timestamp, op, TRUE/*exact operation match*/))
-			        && (nodeWaiting->GetData())->m_evtHandler==evtHandler )
+			 && (nodeWaiting->GetData())->m_evtHandler==evtHandler )
 			{
 				/* there is already an image waiting with the same edit operations,
 				 * and the same event handler. TODO: support multiple event handlers
@@ -384,8 +394,8 @@ SjImgThreadObj* SjImgThread::RequireImage(wxEvtHandler*     evtHandler,
 				newObj = new SjImgThreadObj(evtHandler, url, timestamp, op);
 
 				if( m_useDiskCache
-				        && m_directDiskCache
-				        && newObj->LoadFromDiskCache() )
+				 && m_directDiskCache
+				 && newObj->LoadFromDiskCache() )
 				{
 					/* could load the image from the disk cache -- add to cached objects
 					 */
@@ -395,7 +405,7 @@ SjImgThreadObj* SjImgThread::RequireImage(wxEvtHandler*     evtHandler,
 					objInCache = newObj;
 				}
 				else if( newObj->m_url.StartsWith(wxT("cover:"))
-				         && newObj->LoadFromFile() )
+				      && newObj->LoadFromFile() )
 				{
 					/* the image is a stub-cover and the thread cannot draw -- create the
 					 * image now and add it to the cached objeccts
@@ -522,7 +532,8 @@ void SjImgThread::CleanupRamCache(long cacheLeaveBytes)
 }
 
 
-SjImgThreadObjList::Node* SjImgThread::SearchImg( SjImgThreadObjList&   anchor,
+SjImgThreadObjList::Node* SjImgThread::SearchImg(
+        SjImgThreadObjList&   anchor,
         const wxString&       url,
         unsigned long         timestamp,
         const SjImgOp&        op,
@@ -665,10 +676,11 @@ void SjImgThread::Shutdown()
 
 				if( SjTools::GetMsTicks()-startWaiting > 4000 )
 				{
-					#ifdef __WXDEBUG__
+					if( g_debug )
+					{
 						::wxMessageBox(wxT("I'm waiting since 4 seconds for the image thread to terminate ... what's on? I will exit now."),
 								   SJ_PROGRAM_NAME);
-					#endif
+					}
 					break;
 				}
 
