@@ -149,7 +149,7 @@ wxString SjTempNCache::GetDefaultTempDir()
 	{ wxLogNull null; ::wxRemoveFile(test); }
 
 	wxFileName fn(test);
-	fn.AppendDir(wxT("silverjuke-tmp")); // versions < 15 used "Silverjuke" with incompatible contents
+	fn.AppendDir("silverjuke-tmp-" + SjNormaliseString(wxGetUserId(), 0)); // add the user name as otherwise different users may use /tmp/silverjuke-tmp/
 	return SjLittleDirSel::NormalizeDir(fn.GetPath(wxPATH_GET_VOLUME|wxPATH_GET_SEPARATOR));
 }
 
@@ -524,7 +524,7 @@ wxString SjTempNCache::AddToManagedTemp(const wxString& ext__,
 		ext = wxT("tmp");
 	}
 
-	wxString orgFileName = wxString::Format(wxT("temp:%lu-%lu.%s"), (unsigned long)SjTools::GetMsTicks(), SjTools::Rand(0x10000000L), ext.c_str());
+	wxString orgFileName = wxString::Format(wxT("temp:%lu-%lu.%s"), (unsigned long)SjTools::GetMsTicks(), (unsigned long)SjTools::Rand(0x10000000L), ext.c_str());
 	return Add(orgFileName, protectTilExit, TRUE/*do lock*/);
 }
 
@@ -542,9 +542,9 @@ void SjTempNCache::RemoveFromManagedTemp(const wxString& tempPath)
 	if( idHex.Len()==8 )
 	{
 		long id = 0;
-		idHex.ToLong(&id, 16);
+		if( !idHex.ToLong(&id, 16) ) { id = 0; }
 		if( id
-		        && InitDb() )
+		 && InitDb() )
 		{
 			// remove the db entry
 			m_sqlDbCritical.Enter();
@@ -574,7 +574,7 @@ static wxString GetIDdName(const wxString& orgFileName,
 		ext = wxT("tmp");
 	}
 
-	return wxString::Format(SJ_TEMP_PREFIX wxT("%08x.%s"), (unsigned long)id, ext.c_str());
+	return wxString::Format(SJ_TEMP_PREFIX wxT("%08x.%s"), (int)id, ext.c_str());
 }
 
 
@@ -873,7 +873,7 @@ void SjTempNCache::CleanupOldFiles(bool force)
 			if( currIdHex.Len()==8 )
 			{
 				currId = 0;
-				currIdHex.ToLong(&currId, 16);
+				if( !currIdHex.ToLong(&currId, 16) ) { currId = 0; }
 				if( currId /*sj-00000000.db must not be deleted (note the headroom)*/ )
 				{
 					dirEntries.Add(new SjTempDirEntry(di.m_fullPath, currId, di.m_bytes, di.m_modTime));
@@ -955,3 +955,35 @@ void SjTempNCache::CleanupOldFiles(bool force)
 	}
 }
 
+
+wxString SjTempNCache::GetAsLocalFile(const wxString& url)
+{
+	wxString file = wxFileSystem::URLToFileName(url).GetFullPath(); // convert file:-URLs
+	if( ::wxFileExists(file) )
+	{
+		// Fine: the URL is a local file
+		return file;
+	}
+
+	// Bad: the URL must be copied to a local file
+	wxFileSystem fs;
+	wxFSFile* fsFile = fs.OpenFile(url, wxFS_READ);
+	if( fsFile )
+	{
+		wxInputStream* stream = fsFile->GetStream();
+		if( stream )
+		{
+			wxString tempFileName = g_tools->m_cache.AddToManagedTemp(SjTools::GetExt(url), SJ_TEMP_PROTECT_TIL_EXIT);
+			wxFile tempFile(tempFileName, wxFile::write);
+			if( tempFile.IsOpened()
+			 && SjTools::CopyStreamToFile(*stream, tempFile) )
+			{
+				return tempFileName; // copy success
+			}
+		}
+	}
+
+	// error, cannot retrieve the URL
+	return "";
+}
+
