@@ -433,8 +433,8 @@ enum SjIcon
 class SjTools
 {
 public:
-	SjTools();
-	~SjTools();
+	                SjTools();
+	                ~SjTools();
 
 	/********************************************************************
 	 *  Crash Precaution
@@ -460,8 +460,7 @@ public:
 private:
 	void            InitCrashPrecaution ();
 	wxString        m_crashInfoFileName;
-	wxCriticalSection
-	m_crashPrecautionLocker;
+	wxCriticalSection m_crashPrecautionLocker;
 
 
 	/********************************************************************
@@ -500,17 +499,16 @@ public:
 	 ********************************************************************/
 
 public:
-	static unsigned long	Crc32Init           ();
-	static unsigned long	Crc32Add            (unsigned long crc32, const char* buffer, int bufferBytes);
-	static unsigned long	Crc32AddLong        (unsigned long crc32, long lng)	{ return Crc32Add(crc32, (const char*)&lng, sizeof(long)); }
-	static unsigned long	Crc32AddString      (unsigned long crc32, const wxString& string) { const wxCharBuffer stringBuffer = string.mb_str(wxConvUTF8); const char* stringPtr = stringBuffer.data();	return Crc32Add(crc32, stringPtr, strlen(stringPtr)); }
+	static uint32_t Crc32Init           ();
+	static uint32_t Crc32Add            (uint32_t crc32, const char* buffer, int bufferBytes);
+	static uint32_t Crc32AddLong        (uint32_t crc32, long lng)	{ return Crc32Add(crc32, (const char*)&lng, sizeof(long)); }
+	static uint32_t Crc32AddString      (uint32_t crc32, const wxString& string) { const wxCharBuffer stringBuffer = string.mb_str(wxConvUTF8); const char* stringPtr = stringBuffer.data();	return Crc32Add(crc32, stringPtr, strlen(stringPtr)); }
 	static void     ToggleFlag          (long& bitfield, long flag) { if(bitfield&flag) {bitfield&=~flag;} else {bitfield|=flag;} }
 	static void     SetFlag             (long& bitfield, long flag, bool set) { if(set) {bitfield|=flag;} else {bitfield&=~flag;} }
 	static bool     SetFlagRetChanged   (long& bitfield, long flag, bool set) { long old=bitfield; SetFlag(bitfield, flag, set); return (old!=bitfield)/*return TRUE if changed*/; }
 private:
 	static bool     m_crc32InitDone;
-	static unsigned long
-	m_crc32Table[256];
+	static uint32_t m_crc32Table[256];
 
 public:
 	static long     Rand                (long n); // returns a value between 0 and n-1
@@ -569,7 +567,6 @@ private:
 	 ********************************************************************/
 
 public:
-	wxCursor        m_staticMovehandCursor;
 	wxCursor        m_staticResizeNWSECursor;
 	wxCursor        m_staticResizeWECursor;
 	wxCursor        m_staticNoEntryCursor;
@@ -603,15 +600,13 @@ public:
 public:
 	static unsigned long    GetFileSize         (const wxString& name);
 	static wxString         GetFileContent      (wxInputStream* inputStream, wxMBConv*);
-	static wxString         GetFileNameFromUrl  (const wxString& url, wxString* retPath=NULL, bool stripExtension=FALSE, bool removeSepFromPath=FALSE);
-	static wxString         SetFileNameToUrl    (const wxString& url, const wxString& fileName, bool leaveExtension);
-	static bool             IsAbsUrl            (const wxString& url);
+	static wxString         GetFileNameFromUrl  (/*don't use this for future improvements, see comment in implemetnation*/const wxString& url, wxString* retPath=NULL, bool stripExtension=FALSE, bool removeSepFromPath=FALSE);
 	static bool             AreFilesSame        (const wxString& src, const wxString& dest);
 	static bool             CopyFile            (const wxString& src, const wxString& dest);
 	static bool             CopyStreamToFile    (wxInputStream&, wxFile&);
-	static wxString         EnsureValidFileNameChars
-	(const wxString&);
+	static wxString         EnsureValidFileNameChars (const wxString&);
 	static wxString         EnsureValidPathChars(const wxString&);
+	static wxString         EnsureTrailingSlash (const wxString&);
 
 
 	/********************************************************************
@@ -631,6 +626,8 @@ public:
 	static wxString FormatRect          (const wxRect&);
 	static wxRect   ParseRect           (const wxString&);
 
+	static bool     ParseRectOrDisplayNumber(const wxString&, wxRect& rect, bool& rectFullscreen);
+
 	#define         SJ_FT_ALLOW_ZERO    0x01L
 	#define         SJ_FT_MIN_5_CHARS   0x02L
 	#define         SJ_FT_PREPEND_MINUS 0x04L
@@ -762,6 +759,7 @@ private:
 
 
 extern SjTools* g_tools;
+extern int      g_debug;
 
 
 /*******************************************************************************
@@ -827,10 +825,10 @@ private:
 class SjCoverFinder
 {
 public:
-	                SjCoverFinder(const wxString& keywords=wxEmptyString) { Init(keywords); }
-	void            Init(const wxString& keywords);
-	long            Apply(const wxArrayString& paths, const wxString& albumName); // returns the index in the given array or -1
-	wxString        GetWords() { return m_keywords;} ;
+	                SjCoverFinder       (const wxString& keywords=wxEmptyString) { Init(keywords); }
+	void            Init                (const wxString& keywords);
+	long            Apply               (const wxArrayString& paths, const wxString& albumName); // returns the index in the given array or -1
+	wxString        GetWords            () { return m_keywords;} ;
 
 private:
 	wxString        m_keywords;
@@ -850,9 +848,9 @@ public:
 	// constructor
 	// if you give a char-buffer to the constructor, this buffer is NOT freed,
 	// but MODIFIED (line ends to zeros)
-	SjLineTokenizer     (const wxString&);
+	                SjLineTokenizer     (const wxString&);
 	//SjLineTokenizer   (wxChar* data, long dataBytes);
-	~SjLineTokenizer    ();
+	                ~SjLineTokenizer    ();
 
 	// get next line, line will be null-terminated.
 	// as SjLineTokenizer treats both, "\n" and "\r" as lineends,
@@ -887,7 +885,7 @@ public:
 	void            Clear               () { m_hash.Clear(); m_keys.Clear(); m_values.Clear(); m_i = 0; }
 
 	// lookup a key
-	wxString Lookup              (const wxString& key, const wxString& defVal) const
+	wxString Lookup(const wxString& key, const wxString& defVal) const
 	{
 		wxString* val = m_hash.Lookup(key);
 		if( val && !val->IsEmpty() )
@@ -920,14 +918,14 @@ class SjStringSerializer
 {
 public:
 	// serialize strings
-	SjStringSerializer  () { m_hasErrors=FALSE; }
+					SjStringSerializer  () { m_hasErrors=FALSE; }
 	void            AddString           (const wxString&);
 	void            AddLong             (long);
 	void            AddFloat            (float);
 	wxString        GetResult           () const { return m_str; }
 
 	// unserialize string
-	SjStringSerializer  (const wxString& str);
+	                SjStringSerializer  (const wxString& str);
 	wxString        GetString           ();
 	long            GetLong             ();
 	float           GetFloat            ();
@@ -950,8 +948,8 @@ private:
 class SjStrReplacer
 {
 public:
-	SjStrReplacer       () { m_compiled = FALSE; }
-	SjStrReplacer       (const wxString& pattern, const wxString& replacement, long flags=0) { Compile(pattern, replacement, flags); }
+	                SjStrReplacer       () { m_compiled = FALSE; }
+	                SjStrReplacer       (const wxString& pattern, const wxString& replacement, long flags=0) { Compile(pattern, replacement, flags); }
 
 	#define         wxRE_WHOLEWORDS     0x10000000L
 	#define         wxRE_REGEX          0x20000000L
@@ -976,7 +974,7 @@ private:
 class SjPlaceholdReplacer
 {
 public:
-	SjPlaceholdReplacer () { }
+	                SjPlaceholdReplacer () { }
 	virtual         ~SjPlaceholdReplacer() { }
 	void            ReplaceAll          (wxString& text);
 
@@ -1011,7 +1009,7 @@ WX_DECLARE_OBJARRAY(SjPlaceholdPart, SjArrayPlaceholdPart);
 class SjPlaceholdMatcher
 {
 public:
-	SjPlaceholdMatcher  () {}
+	                SjPlaceholdMatcher  () {}
 	virtual         ~SjPlaceholdMatcher () {}
 	void            Compile             (const wxString& pattern, const wxString& highPriorityDelim);
 	bool            HasPlaceholder      (const wxString& placeholder);
@@ -1026,14 +1024,13 @@ protected:
 	virtual bool    GotMatch            (const wxString& placeholder, const wxString& text) = 0;
 
 private:
-	SjArrayPlaceholdPart
-	m_parts;
+	SjArrayPlaceholdPart m_parts;
 	wxString        m_highPriorityDelim;
 	wxArrayString   m_goBack;
 	int             m_goForward;
-#ifdef __WXDEBUG__
-	wxString       m_pattern;
-#endif
+    #ifdef __WXDEBUG__
+		wxString    m_pattern;
+    #endif
 };
 
 
@@ -1043,7 +1040,7 @@ class SjTrackInfo;
 class SjTrackInfoMatcher : public SjPlaceholdMatcher
 {
 public:
-	SjTrackInfoMatcher  ();
+	                SjTrackInfoMatcher  ();
 	void            Compile             (long tiFieldToSplit, const wxString& pattern);
 	wxString        GetPattern          () const { return m_rawPattern; }
 	static wxString GetDefaultPattern   ();
@@ -1105,7 +1102,25 @@ private:
 
 
 /*******************************************************************************
- *  Hardware Graphic Stuff, Misc.
+ * SjWheelHelper Class
+ ******************************************************************************/
+
+
+class SjWheelHelper
+{
+	public:
+		// the wheel helper class collects mouse wheel events and pop actions based on
+		// delta and the collected rotations.  use a static/persistent object for this to work.
+		            SjWheelHelper           ();
+		void        PushRotationNPopAction  (wxMouseEvent& e, long& actions, long& dir);
+
+	private:
+		long        m_availRotation;
+};
+
+
+/*******************************************************************************
+ * Hardware Graphic Stuff, Misc.
  ******************************************************************************/
 
 
@@ -1113,16 +1128,8 @@ private:
 #define SJ_ONE_GB 0x40000000L
 #define SJ_ONE_MB 0x00100000L
 
-// more mono-channels are not supported; these are 8 stereo channels which should be enough
-// the max. is used eg. by the volume normalizer
-#define SJ_WW_MAX_CH            16
-
-// Do not change the constants if you don't REALLY know what you are doing!
-// Internally, Silverjuke always calculates with these audio settings.
-#define SJ_WW_FREQ              44100
-#define SJ_WW_BYTERES           2
-#define SJ_WW_CH                2
-long    SjMs2Bytes          (long ms);
+// Create OS-specific from generic string. (Eg. "Exit" => "Quit")
+wxString _os(const wxString&);
 
 
 #endif /* __SJ_TOOLS_H__ */
