@@ -51,8 +51,8 @@
 
 enum SjFileType
 {
-    SJ_FT_UNKNOWN = 0
-                    ,   SJ_FT_KNOWN_UNSUPPORTED
+	    SJ_FT_UNKNOWN = 0
+    ,   SJ_FT_KNOWN_UNSUPPORTED
     ,   SJ_FT_MP1_2_3
     ,   SJ_FT_OGG_VORBIS
     ,   SJ_FT_FLAC
@@ -64,8 +64,20 @@ enum SjFileType
 };
 
 
-static Tagger_File* getTaggerFile(const wxString& url, wxFSFile* fsFile, SjFileType& ftOut)
+Tagger_Options* g_taggerOptions = NULL;
+
+
+static Tagger_File* getTaggerFile(const wxString& url, wxInputStream* inputStream/*NULL=open file for writing*/, SjFileType& ftOut)
 {
+	// create globals
+	if( g_taggerOptions == NULL )
+	{
+		g_taggerOptions = new Tagger_Options();
+		g_taggerOptions->m_flags = g_tools->m_config->Read("tageditor/tagflags",  SJTF_DEFAULTS);
+		g_taggerOptions->m_ratingUser = g_tools->m_config->Read("tageditor/ratinguser",  "r@silverjuke.net");
+	}
+
+	// create file
 	Tagger_File* file = NULL;
 
 	// get file type by extension
@@ -74,43 +86,43 @@ static Tagger_File* getTaggerFile(const wxString& url, wxFSFile* fsFile, SjFileT
 	wxString ext = SjTools::GetExt(url);
 	if( ext == wxT("mp1") || ext == wxT("mp2") || ext == wxT("mp3") || ext == wxT("mp3pro") )
 	{
-		file = new MPEG_File(fsFile, NULL, Tagger_ReadTags|Tagger_ReadAudioProperties);
+		file = new MPEG_File(url, inputStream, Tagger_ReadTags|Tagger_ReadAudioProperties);
 		ftOut = SJ_FT_MP1_2_3;
 		mpegTried = TRUE;
 	}
 	else if( ext == wxT("ogg") )
 	{
-		file = new OggVorbis_File(fsFile);
+		file = new OggVorbis_File(url, inputStream);
 		ftOut = SJ_FT_OGG_VORBIS;
 	}
 	else if( ext == wxT("fla") || ext == wxT("flac") )
 	{
-		file = new FLAC_File(fsFile);
+		file = new FLAC_File(url, inputStream);
 		ftOut = SJ_FT_FLAC;
 	}
 	else if( ext == wxT("wma") || ext == wxT("wmv") || ext == wxT("asf") )
 	{
-		file = new WMA_File(fsFile);
+		file = new WMA_File(url, inputStream);
 		ftOut = SJ_FT_WMA;
 	}
 	else if( ext == wxT("mp+") || ext == wxT("mpc") || ext == wxT("mpp") )
 	{
-		file = new MPC_File(fsFile);
+		file = new MPC_File(url, inputStream);
 		ftOut = SJ_FT_MUSEPACK;
 	}
 	else if( ext == wxT("ape") )
 	{
-		file = new Monkeys_File(fsFile);
+		file = new Monkeys_File(url, inputStream);
 		ftOut = SJ_FT_MONKEYS_AUDIO;
 	}
 	else if( ext == wxT("wv") )
 	{
-		file = new WavPack_File(fsFile);
+		file = new WavPack_File(url, inputStream);
 		ftOut = SJ_FT_WAVPACK;
 	}
 	else if( ext == wxT("m4a") )
 	{
-		file = new MP4_File(fsFile);
+		file = new MP4_File(url, inputStream);
 		ftOut = SJ_FT_MP4;
 	}
 
@@ -123,10 +135,10 @@ static Tagger_File* getTaggerFile(const wxString& url, wxFSFile* fsFile, SjFileT
 	// final try with MPEG type
 	if( file == NULL && !mpegTried )
 	{
-		file = new MPEG_File(fsFile, NULL, Tagger_ReadTags|Tagger_ReadAudioProperties);
+		file = new MPEG_File(url, inputStream, Tagger_ReadTags|Tagger_ReadAudioProperties);
 		if( file->IsValid()
-		        && file->audioProperties()
-		        && ((MPEG_Properties*)file->audioProperties())->IsValid() )
+		 && file->audioProperties()
+		 && ((MPEG_Properties*)file->audioProperties())->IsValid() )
 		{
 			ftOut = SJ_FT_MP1_2_3;
 		}
@@ -142,13 +154,11 @@ static Tagger_File* getTaggerFile(const wxString& url, wxFSFile* fsFile, SjFileT
 }
 
 
-
 /*******************************************************************************
- *  SjTaggerFsHandler
+ * SjTaggerFsHandler
  ******************************************************************************/
 
 
-
 class SjTaggerInputStream : public wxMemoryInputStream
 {
 public:
@@ -172,7 +182,6 @@ private:
 };
 
 
-
 class SjTaggerFsHandler : public wxFileSystemHandler
 {
 public:
@@ -181,7 +190,6 @@ public:
 };
 
 
-
 bool SjTaggerFsHandler::CanOpen(const wxString& location)
 {
 	wxString protocol = GetProtocol(location);
@@ -189,7 +197,6 @@ bool SjTaggerFsHandler::CanOpen(const wxString& location)
 }
 
 
-
 wxFSFile* SjTaggerFsHandler::OpenFile(wxFileSystem& fs, const wxString& location)
 {	// location is eg. "c:/files/any.mp3#id3:image2" ...
 	wxString        left  = GetLeftLocation(location);      // ... then left is "c:/files/any.mp3"
@@ -205,7 +212,7 @@ wxFSFile* SjTaggerFsHandler::OpenFile(wxFileSystem& fs, const wxString& location
 
 		wxFSFile* fsFile = fs.OpenFile(left, wxFS_READ|wxFS_SEEKABLE);
 		if( fsFile == NULL ) { return NULL; }
-		MP4_File   mp4File(fsFile, NULL);
+		MP4_File   mp4File(left, fsFile->GetStream());
 		modTime = fsFile->GetModificationTime();
 		delete fsFile;
 
@@ -224,7 +231,7 @@ wxFSFile* SjTaggerFsHandler::OpenFile(wxFileSystem& fs, const wxString& location
 		// to read tags eg. from zipped files.
 		wxFSFile* fsFile = fs.OpenFile(left, wxFS_READ|wxFS_SEEKABLE);
 		if( fsFile == NULL ) { return NULL; }
-		MPEG_File   mpegFile(fsFile, NULL, Tagger_ReadTags);
+		MPEG_File   mpegFile(left, fsFile->GetStream(), Tagger_ReadTags);
 		modTime = fsFile->GetModificationTime();
 		delete fsFile;
 
@@ -235,7 +242,7 @@ wxFSFile* SjTaggerFsHandler::OpenFile(wxFileSystem& fs, const wxString& location
 		// get correct picture frame
 		long index;
 		right.Replace(wxT("image"), wxT(""));
-		right.BeforeFirst('.').ToLong(&index);
+		if( !right.BeforeFirst('.').ToLong(&index) ) { index = 0; }
 		index--; // the filenames start with "1", not with "0"
 
 		const ID3v2_FrameList* frameList = id3v2->frameList(wxT("APIC"));
@@ -270,13 +277,11 @@ wxFSFile* SjTaggerFsHandler::OpenFile(wxFileSystem& fs, const wxString& location
 }
 
 
-
 /*******************************************************************************
- *  globally init the usage of ID3Etc
+ * globally init the usage of ID3Etc
  ******************************************************************************/
 
 
-
 void SjInitID3Etc(bool initFsHandler)
 {
 	if( initFsHandler )
@@ -286,21 +291,17 @@ void SjInitID3Etc(bool initFsHandler)
 }
 
 
-
 void SjExitID3Etc()
 {
 	Tagger_File::exitLibrary();
 }
 
 
-
-
 /*******************************************************************************
- *  get track information to a stream defined by a wxFSFile object
+ * get track information to a stream defined by a wxFSFile object
  ******************************************************************************/
 
 
-
 SjResult SjGetTrackInfoFromID3Etc(wxFSFile* fsFile, SjTrackInfo& ti, long flags)
 {
 	wxASSERT(fsFile);
@@ -320,7 +321,7 @@ SjResult SjGetTrackInfoFromID3Etc(wxFSFile* fsFile, SjTrackInfo& ti, long flags)
 
 	// get tag...
 	SjFileType fileTypeOut;
-	Tagger_File* file = getTaggerFile(url, fsFile, fileTypeOut);
+	Tagger_File* file = getTaggerFile(url, fsFile->GetStream(), fileTypeOut);
 	if( file )
 	{
 		Tagger_Tag* tag = file->tag();
@@ -394,6 +395,14 @@ SjResult SjGetTrackInfoFromID3Etc(wxFSFile* fsFile, SjTrackInfo& ti, long flags)
 			// get the beats per minute
 			ti.m_beatsPerMinute = tag->beatsPerMinute();
 			if( ti.m_beatsPerMinute > 0 ) ti.m_validFields |= SJ_TI_BEATSPERMINUTE;
+
+			// get the rating
+			if( g_taggerOptions->m_flags&SJTF_READ_RATINGS )
+			{
+				ti.m_rating = tag->rating();
+				wxASSERT( ti.m_rating >= 0 && ti.m_rating <= 5 );
+				if( ti.m_rating > 0 ) ti.m_validFields |= SJ_TI_RATING;
+			}
 		}
 
 		// check for special tags (ID3v2, MP4)
@@ -432,7 +441,7 @@ SjResult SjGetTrackInfoFromID3Etc(wxFSFile* fsFile, SjTrackInfo& ti, long flags)
 						if( ext.IsEmpty() || ext == wxT("jpeg") ) ext = wxT("jpg");
 
 						// add to list of arts
-						ti.AddArt(wxString::Format(wxT("%s#id3:image%i.%s"), url.c_str(), index+1/*let the name start with "1"*/, ext.c_str()));
+						ti.AddArt(wxString::Format(wxT("%s#id3:image%i.%s"), url.c_str(), (int)(index+1)/*let the name start with "1"*/, ext.c_str()));
 					}
 
 					index++;
@@ -456,8 +465,6 @@ SjResult SjGetTrackInfoFromID3Etc(wxFSFile* fsFile, SjTrackInfo& ti, long flags)
 }
 
 
-
-
 void SjGetMoreInfoFromID3Etc(wxFSFile* fsFile, SjProp& prop)
 {
 	wxString url = fsFile->GetLocation(), temp;
@@ -471,7 +478,7 @@ void SjGetMoreInfoFromID3Etc(wxFSFile* fsFile, SjProp& prop)
 
 	// get tag...
 	SjFileType fileTypeOut;
-	Tagger_File* file = getTaggerFile(url, fsFile, fileTypeOut);
+	Tagger_File* file = getTaggerFile(url, fsFile->GetStream(), fileTypeOut);
 	if( file )
 	{
 		// set up the different tags and properties
@@ -613,7 +620,7 @@ void SjGetMoreInfoFromID3Etc(wxFSFile* fsFile, SjProp& prop)
 		if( mpcProp )
 		{
 			// write version
-			prop.Add(wxT("MPC Version"), wxString::Format(wxT("SV%i"), mpcProp->mpcVersion()));
+			prop.Add(wxT("MPC Version"), wxString::Format(wxT("SV%i"), (int)mpcProp->mpcVersion()));
 		}
 
 		// write tag types
@@ -730,7 +737,7 @@ void SjGetMoreInfoFromID3Etc(wxFSFile* fsFile, SjProp& prop)
 		// Write out all fields of the ID3v1 tag
 		if( id3v1 )
 		{
-			prop.Add(wxString::Format(wxT("ID3v1.%i Fields"), id3v1->majorVersion()), wxT(""), SJ_PROP_HEADLINE);
+			prop.Add(wxString::Format(wxT("ID3v1.%i Fields"), (int)id3v1->majorVersion()), wxT(""), SJ_PROP_HEADLINE);
 
 			prop.Add(wxT("Title"),  id3v1->title(),         SJ_PROP_EMPTYIFEMPTY);
 			prop.Add(wxT("Artist"), id3v1->leadArtist(),    SJ_PROP_EMPTYIFEMPTY);
@@ -800,8 +807,7 @@ void SjGetMoreInfoFromID3Etc(wxFSFile* fsFile, SjProp& prop)
 		}
 
 		// Write out generic tag - debug mode only as this does not generate any additional information
-#ifdef __WXDEBUG__
-		if( mp4tag )
+		if( g_debug && mp4tag )
 		{
 			Tagger_Tag* anytag = mp4tag;
 
@@ -816,6 +822,7 @@ void SjGetMoreInfoFromID3Etc(wxFSFile* fsFile, SjProp& prop)
 			prop.Add(wxT("Group"),          anytag->group(),            SJ_PROP_EMPTYIFEMPTY);
 			prop.Add(wxT("Year"),           anytag->year(),             SJ_PROP_EMPTYIFEMPTY);
 			prop.Add(wxT("BPM"),            anytag->beatsPerMinute(),   SJ_PROP_EMPTYIFEMPTY);
+			prop.Add(wxT("Rating"),         anytag->rating(),           SJ_PROP_EMPTYIFEMPTY);
 			long l1, l2;
 			anytag->track(l1, l2);
 			prop.Add(wxT("Track"),          wxString::Format(wxT("%i/%i"), (int)l1, (int)l2));
@@ -826,7 +833,6 @@ void SjGetMoreInfoFromID3Etc(wxFSFile* fsFile, SjProp& prop)
 			prop.Add(wxT("Samplerate"),     audioProp->sampleRate(),    SJ_PROP_EMPTYIFEMPTY);
 			prop.Add(wxT("Channels"),       audioProp->channels(),      SJ_PROP_EMPTYIFEMPTY);
 		}
-#endif
 
 		// done so far, deleting the file delete all related tags & Co.
 		delete file;
@@ -834,13 +840,11 @@ void SjGetMoreInfoFromID3Etc(wxFSFile* fsFile, SjProp& prop)
 }
 
 
-
 /*******************************************************************************
- *  set track information to a stream defined by a wxFSFile object
+ * set track information to a stream defined by a wxFSFile object
  ******************************************************************************/
 
 
-
 bool SjSetTrackInfoToID3Etc(const wxString& url, const SjTrackInfo& ti)
 {
 	// crash handling
@@ -851,14 +855,12 @@ bool SjSetTrackInfoToID3Etc(const wxString& url, const SjTrackInfo& ti)
 
 	// open file
 	bool            success = FALSE;
-	wxFileSystem    fs;
-	wxFSFile*       fsFile = fs.OpenFile(url, wxFS_READ|wxFS_SEEKABLE);
-	if( fsFile )
 	{
 		SjFileType fileTypeOut;
-		Tagger_File* file = getTaggerFile(url, fsFile, fileTypeOut);
+		Tagger_File* file = getTaggerFile(url, NULL /*force write access*/, fileTypeOut);
 		if( file )
 		{
+			wxASSERT( !file->ReadOnly() );
 			Tagger_Tag* tag = file->tag();
 			if( tag )
 			{
@@ -952,6 +954,16 @@ bool SjSetTrackInfoToID3Etc(const wxString& url, const SjTrackInfo& ti)
 					tag->setBeatsPerMinute(ti.m_beatsPerMinute);
 				}
 
+				// set RATING
+				if( ti.m_validFields & SJ_TI_RATING )
+				{
+					wxASSERT( ti.m_rating >= 0 && ti.m_rating <= 5 );
+					if( g_taggerOptions->m_flags&SJTF_WRITE_RATINGS )
+					{
+						tag->setRating(ti.m_rating);
+					}
+				}
+
 				// save the file
 				if( file->save() )
 				{
@@ -961,19 +973,18 @@ bool SjSetTrackInfoToID3Etc(const wxString& url, const SjTrackInfo& ti)
 
 			delete file;
 		}
-
-		delete fsFile;
 	}
 
 	// some so far
 	if( !success )
 	{
-		wxLogError(_("Cannot write \"%s\".")/*n/t*/, url.c_str());
+		wxString filename(url);
+		if( filename.StartsWith("file:") ) {
+			filename = wxFileSystem::URLToFileName(filename).GetFullPath();
+		}
+		wxLogError(_("Cannot write \"%s\".")/*n/t*/, filename.c_str());
 	}
 
 	return success;
 }
 
-
-
-
