@@ -286,7 +286,7 @@ wxString ID3v2_Tag::genre() const
 					{
 						//int number = (*itStr).toInt();
 						long number;
-						itStr.ToLong(&number);
+						if( !itStr.ToLong(&number) ) { number = 0; }
 						if(number >= 0 && number <= 255)
 						{
 							hasNumber = true;
@@ -320,7 +320,7 @@ wxString ID3v2_Tag::genre() const
 			{
 				long lng;
 				wxString temp = s.substr(1, s.size() - 2);
-				temp.ToLong(&lng);
+				if( !temp.ToLong(&lng) ) { lng = 0; }
 				return ID3v1_Tag::lookupGenreName(lng);
 			}
 			else
@@ -355,7 +355,7 @@ long ID3v2_Tag::year() const
 	if( !ret.IsEmpty() ) {
 		if(ret.Len()>4) ret = ret.Left(4);
 		long l = 0;
-		ret.ToLong(&l);
+		if( !ret.ToLong(&l) ) { l = 0; }
 		return l;
 	}
 	return 0;
@@ -368,13 +368,59 @@ long ID3v2_Tag::beatsPerMinute() const
 	wxString ret = simpleFrame(wxT("TBPM"));
 	if( !ret.IsEmpty() ) {
 		long l = 0;
-		ret.ToLong(&l);
+		if( !ret.ToLong(&l) ) { l = 0; }
 		return l;
 	}
 	return 0;
 }
 
 
+long ID3v2_Tag::rating() const
+{
+	ID3v2_PopularimeterFrame* frame = NULL;
+	bool                      exactMatch = false;
+	ID3v2_FrameList*          list = frameList("POPM");
+	if( list )
+	{
+		for ( ID3v2_FrameList::Node* node = list->GetLast(); node; node = node->GetPrevious() )
+		{
+			frame = (ID3v2_PopularimeterFrame*)node->GetData();
+			if( frame->GetEmail() == g_taggerOptions->m_ratingUser ) {
+				exactMatch = true;
+				break;
+			}
+		}
+	}
+
+	if( frame && (exactMatch || g_taggerOptions->m_flags&SJTF_READ_OTHERS_RATINGS) )
+	{
+		int rating255 = frame->GetRating255();
+		if( rating255 >= 224 )      // accept 224-255 for "5 Stars", write 255
+		{
+			return 5;
+		}
+		else if( rating255 >= 160 ) // accept 160-223 for "4 Stars", write 196
+		{
+			return 4;
+		}
+		else if( rating255 >= 96 )  // accept 96-159 for "3 Stars", write 128
+		{
+			return 3;
+		}
+		else if( rating255 >= 32 )  // accept 32-95 for "2 Stars", write 64
+		{
+			return 2;
+		}
+		else if( rating255 >= 1 )   // accept 1-31 for "1 Star", write 1
+		{
+			return 1;
+		}
+	}
+
+	return 0; // unset
+}
+
+
 
 void ID3v2_Tag::track(long& nr, long& count) const
 {
@@ -433,6 +479,8 @@ void ID3v2_Tag::setGenre(const wxString &s)
 		return;
 	}
 
+	// we write the Genre following the ID3v2.4 standard - a numberic value string as "11" or a string as "Oldie".
+	// (for ID3v2.4 this would be "(11)" or "Oldie" or "(11)Oldie" - maybe we should write only the name, however, we should check all major players before doing so, see also https://github.com/r10s/silverjuke/issues/53 )
 	int index = ID3v1_Tag::lookupGenreIndex(s);
 	if(index != 255)
 	{
@@ -479,6 +527,57 @@ void ID3v2_Tag::setBeatsPerMinute(long i)
 
 
 
+void ID3v2_Tag::setRating(long rating5)
+{
+	ID3v2_PopularimeterFrame* frame = NULL;
+	bool                      exactMatch = false;
+
+	if( g_taggerOptions->m_flags&SJTF_REMOVE_OTHERS_RATINGS )
+	{
+		removeFrames("POPM");
+	}
+	else
+	{
+		ID3v2_FrameList* list = frameList("POPM");
+		if( list )
+		{
+			for ( ID3v2_FrameList::Node* node = list->GetLast(); node; node = node->GetPrevious() )
+			{
+				frame = (ID3v2_PopularimeterFrame*)node->GetData();
+				if( frame->GetEmail() == g_taggerOptions->m_ratingUser ) {
+					exactMatch = true;
+					break;
+				}
+			}
+		}
+	}
+
+	if( frame == NULL || (!exactMatch && !(g_taggerOptions->m_flags&SJTF_CHANGE_OTHERS_RATINGS)) )
+	{
+		if( rating5 == 0 ) {
+			return; // done - no rating defined, no rating frame existant, fine
+		}
+
+		frame = new ID3v2_PopularimeterFrame();
+		frame->SetEmail(g_taggerOptions->m_ratingUser);
+		addFrame(frame);
+	}
+
+	int rating255;
+	switch( rating5 )
+	{
+		case 1:  rating255 =   1; break;
+		case 2:  rating255 =  64; break;
+		case 3:  rating255 = 128; break;
+		case 4:  rating255 = 196; break;
+		case 5:  rating255 = 255; break;
+		default: rating255 =   0; break; // unset
+	}
+
+	frame->SetRating255(rating255);
+}
+
+
 void ID3v2_Tag::setTrack(long nr, long count)
 {
 	if(nr <= 0)
